@@ -23,8 +23,8 @@
 #endif
 
 #ifdef CONF_PLATFORM_LINUX
-#include <sys/socket.h>
 #include <netinet/in.h>
+#include <sys/socket.h>
 #endif
 
 #ifdef __cplusplus
@@ -47,17 +47,16 @@ extern "C" {
 		<dbg_break>
 */
 #ifdef CONF_DEBUG
-#define dbg_assert(test,msg) dbg_assert_imp(__FILE__, __LINE__, test, msg)
+#define dbg_assert(test, msg) dbg_assert_imp(__FILE__, __LINE__, test, msg)
 #else
-#define dbg_assert(test,msg)
+#define dbg_assert(test, msg)
 #endif
 void dbg_assert_imp(const char *filename, int line, int test, const char *msg);
 
-
 #ifdef __clang_analyzer__
 #include <assert.h>
 #undef dbg_assert
-#define dbg_assert(test,msg) assert(test)
+#define dbg_assert(test, msg) assert(test)
 #endif
 
 #ifdef __GNUC__
@@ -99,7 +98,7 @@ void dbg_break_imp(void);
 		<dbg_assert>
 */
 void dbg_msg(const char *sys, const char *fmt, ...)
-GNUC_ATTRIBUTE((format(printf, 2, 3)));
+	GNUC_ATTRIBUTE((format(printf, 2, 3)));
 
 /* Group: Memory */
 
@@ -166,7 +165,8 @@ void mem_zero(void *block, unsigned size);
 int mem_comp(const void *a, const void *b, int size);
 
 /* Group: File IO */
-enum {
+enum
+{
 	IOFLAG_READ = 1,
 	IOFLAG_WRITE = 2,
 	IOFLAG_RANDOM = 4,
@@ -321,7 +321,6 @@ int io_flush(IOHANDLE io);
 */
 int io_error(IOHANDLE io);
 
-
 /*
 	Function: io_stdin
 		Returns an <IOHANDLE> to the standard input.
@@ -532,7 +531,7 @@ void thread_detach(void *thread);
 void *thread_init_and_detach(void (*threadfunc)(void *), void *user, const char *name);
 
 /* Group: Locks */
-typedef void* LOCK;
+typedef void *LOCK;
 
 LOCK lock_create(void);
 void lock_destroy(LOCK lock);
@@ -541,18 +540,17 @@ int lock_trylock(LOCK lock);
 void lock_wait(LOCK lock);
 void lock_unlock(LOCK lock);
 
-
 /* Group: Semaphores */
 #if defined(CONF_FAMILY_WINDOWS)
-	typedef void* SEMAPHORE;
+typedef void *SEMAPHORE;
 #elif defined(CONF_PLATFORM_MACOSX)
-	#include <semaphore.h>
-	typedef sem_t* SEMAPHORE;
+#include <semaphore.h>
+typedef sem_t *SEMAPHORE;
 #elif defined(CONF_FAMILY_UNIX)
-	#include <semaphore.h>
-	typedef sem_t SEMAPHORE;
+#include <semaphore.h>
+typedef sem_t SEMAPHORE;
 #else
-	#error not implemented on this platform
+#error not implemented on this platform
 #endif
 
 void sphore_init(SEMAPHORE *sem);
@@ -617,6 +615,32 @@ int64 time_freq(void);
 */
 int time_timestamp(void);
 
+/*
+	Function: time_houroftheday
+		Retrieves the hours since midnight (0..23)
+
+	Returns:
+		The current hour of the day
+*/
+int time_houroftheday(void);
+
+enum
+{
+	SEASON_SPRING = 0,
+	SEASON_SUMMER,
+	SEASON_AUTUMN,
+	SEASON_WINTER
+};
+
+/*
+	Function: time_season
+		Retrieves the current season of the year.
+
+	Returns:
+		one of the SEASON_* enum literals
+*/
+int time_season(void);
+
 /*
 Function: time_get_microseconds
 Fetches a sample from a high resolution timer and converts it in microseconds.
@@ -637,14 +661,14 @@ typedef struct
 
 enum
 {
-	NETADDR_MAXSTRSIZE = 1+(8*4+7)+1+1+5+1, // [XXXX:XXXX:XXXX:XXXX:XXXX:XXXX:XXXX:XXXX]:XXXXX
+	NETADDR_MAXSTRSIZE = 1 + (8 * 4 + 7) + 1 + 1 + 5 + 1, // [XXXX:XXXX:XXXX:XXXX:XXXX:XXXX:XXXX:XXXX]:XXXXX
 
 	NETTYPE_INVALID = 0,
 	NETTYPE_IPV4 = 1,
 	NETTYPE_IPV6 = 2,
 	NETTYPE_LINK_BROADCAST = 4,
 	NETTYPE_WEBSOCKET_IPV4 = 8,
-	NETTYPE_ALL = NETTYPE_IPV4|NETTYPE_IPV6|NETTYPE_WEBSOCKET_IPV4
+	NETTYPE_ALL = NETTYPE_IPV4 | NETTYPE_IPV6 | NETTYPE_WEBSOCKET_IPV4
 };
 
 typedef struct
@@ -787,7 +811,7 @@ typedef struct
 #endif
 } MMSGS;
 
-void net_init_mmsgs(MMSGS* m);
+void net_init_mmsgs(MMSGS *m);
 
 /*
 	Function: net_udp_recv
@@ -804,7 +828,7 @@ void net_init_mmsgs(MMSGS* m);
 		On success it returns the number of bytes received. Returns -1
 		on error.
 */
-int net_udp_recv(NETSOCKET sock, NETADDR *addr, void *buffer, int maxsize, MMSGS* m, unsigned char **data);
+int net_udp_recv(NETSOCKET sock, NETADDR *addr, void *buffer, int maxsize, MMSGS *m, unsigned char **data);
 
 /*
 	Function: net_udp_close
@@ -818,7 +842,6 @@ int net_udp_recv(NETSOCKET sock, NETADDR *addr, void *buffer, int maxsize, MMSGS
 */
 int net_udp_close(NETSOCKET sock);
 
-
 /* Group: Network TCP */
 
 /*
@@ -996,6 +1019,22 @@ void str_append(char *dst, const char *src, int dst_size);
 */
 void str_copy(char *dst, const char *src, int dst_size);
 
+/*
+	Function: str_utf8_truncate
+		Truncates a utf8 encoded string to a given length.
+
+	Parameters:
+		dst - Pointer to a buffer that shall receive the string.
+		dst_size - Size of the buffer dst.
+		str - String to be truncated.
+		truncation_len - Maximum codepoints in the returned string.
+
+	Remarks:
+		- The strings are treated as utf8-encoded zero-terminated strings.
+		- Guarantees that dst string will contain zero-termination.
+*/
+void str_utf8_truncate(char *dst, int dst_size, const char *src, int truncation_len);
+
 /*
 	Function: str_truncate
 		Truncates a string to a given length.
@@ -1003,13 +1042,13 @@ void str_copy(char *dst, const char *src, int dst_size);
 	Parameters:
 		dst - Pointer to a buffer that shall receive the string.
 		dst_size - Size of the buffer dst.
-		str - String to be truncated.
+		src - String to be truncated.
 		truncation_len - Maximum length of the returned string (not
 		counting the zero termination).
 
 	Remarks:
 		- The strings are treated as zero-terminated strings.
-		- Guarantees that dst string will contain zero-termination.
+		- Garantees that dst string will contain zero-termination.
 */
 void str_truncate(char *dst, int dst_size, const char *src, int truncation_len);
 
@@ -1044,7 +1083,7 @@ int str_length(const char *str);
 		- Guarantees that dst string will contain zero-termination.
 */
 int str_format(char *buffer, int buffer_size, const char *format, ...)
-GNUC_ATTRIBUTE((format(printf, 3, 4)));
+	GNUC_ATTRIBUTE((format(printf, 3, 4)));
 
 /*
 	Function: str_trim_words
@@ -1453,9 +1492,9 @@ int str_hex_decode(void *dst, int dst_size, const char *src);
 */
 void str_timestamp(char *buffer, int buffer_size);
 void str_timestamp_format(char *buffer, int buffer_size, const char *format)
-GNUC_ATTRIBUTE((format(strftime, 3, 0)));
+	GNUC_ATTRIBUTE((format(strftime, 3, 0)));
 void str_timestamp_ex(time_t time, char *buffer, int buffer_size, const char *format)
-GNUC_ATTRIBUTE((format(strftime, 4, 0)));
+	GNUC_ATTRIBUTE((format(strftime, 4, 0)));
 
 #define FORMAT_TIME "%H:%M:%S"
 #define FORMAT_SPACE "%Y-%m-%d %H:%M:%S"
@@ -1618,7 +1657,6 @@ int fs_rename(const char *oldname, const char *newname);
 	Group: Undocumented
 */
 
-
 /*
 	Function: net_tcp_connect_non_blocking
 
@@ -1673,7 +1711,6 @@ int open_link(const char *link);
 
 void swap_endian(void *data, unsigned elem_size, unsigned num);
 
-
 typedef void (*DBG_LOGGER)(const char *line, void *user);
 typedef void (*DBG_LOGGER_FINISH)(void *user);
 void dbg_logger(DBG_LOGGER logger, DBG_LOGGER_FINISH finish, void *user);
@@ -1690,7 +1727,6 @@ typedef struct
 	int recv_bytes;
 } NETSTATS;
 
-
 void net_stats(NETSTATS *stats);
 
 int str_toint(const char *str);
@@ -1919,6 +1955,22 @@ int str_utf16le_encode(char *ptr, int chr);
 */
 int str_utf8_check(const char *str);
 
+/*
+	Function: str_utf8_copy
+		Copies a utf8 string to a buffer.
+
+	Parameters:
+		dst - Pointer to a buffer that shall receive the string.
+		src - utf8 string to be copied.
+		dst_size - Size of the buffer dst.
+
+	Remarks:
+		- The strings are treated as zero-terminated strings.
+		- Guarantees that dst string will contain zero-termination.
+		- Guarantees that dst always contains a valid utf8 string.
+*/
+void str_utf8_copy(char *dst, const char *src, int dst_size);
+
 /*
 	Function: str_next_token
 		Writes the next token after str into buf, returns the rest of the string.
@@ -1949,13 +2001,42 @@ const char *str_next_token(const char *str, const char *delim, char *buffer, int
 */
 int str_in_list(const char *list, const char *delim, const char *needle);
 
+/*
+	Function: pid
+		Returns the pid of the current process.
+	
+	Returns:
+		pid of the current process
+*/
 int pid(void);
 
+#if defined(CONF_FAMILY_WINDOWS)
+typedef void *PROCESS;
+#else
+typedef pid_t PROCESS;
+#endif
+
 /*
 	Function: shell_execute
 		Executes a given file.
+
+	Returns:
+		handle/pid of the new process
 */
-void shell_execute(const char *file);
+PROCESS shell_execute(const char *file);
+
+/*
+	Function: kill_process
+		Sends kill signal to a process.
+
+	Parameters:
+		process - handle/pid of the process
+
+	Returns:
+		0 - Error
+		1 - Success
+*/
+int kill_process(PROCESS process);
 
 /*
 	Function: os_is_winxp_or_lower
@@ -1972,7 +2053,6 @@ int os_is_winxp_or_lower(void);
 		Generates a null-terminated password of length `2 *
 		random_length`.
 
-
 	Parameters:
 		buffer - Pointer to the start of the output buffer.
 		length - Length of the buffer.
