@@ -6,7 +6,6 @@
 #include "base/tl/range.h"
 #include <functional>
 
-
 /*
 	insert 4
 		v
@@ -14,7 +13,6 @@
 
 */
 
-
 template<class R, class T>
 R partition_linear(R range, T value)
 {
@@ -30,7 +28,6 @@ R partition_linear(R range, T value)
 	return range;
 }
 
-
 template<class R, class T>
 R partition_binary(R range, T value)
 {
@@ -47,11 +44,11 @@ R partition_binary(R range, T value)
 
 	while(range.size() > 1)
 	{
-		unsigned pivot = (range.size()-1)/2;
+		unsigned pivot = (range.size() - 1) / 2;
 		if(range.index(pivot) < value)
-			range = range.slice(pivot+1, range.size()-1);
+			range = range.slice(pivot + 1, range.size() - 1);
 		else
-			range = range.slice(0, pivot+1);
+			range = range.slice(0, pivot + 1);
 	}
 	return range;
 }
@@ -71,12 +68,13 @@ template<class R, class T>
 R find_binary(R range, T value)
 {
 	range = partition_linear(range, value);
-	if(range.empty()) return range;
-	if(range.front() == value) return range;
+	if(range.empty())
+		return range;
+	if(range.front() == value)
+		return range;
 	return R();
 }
 
-
 template<class R>
 void sort_bubble(R range)
 {
@@ -107,14 +105,12 @@ void sort_quick(R range)
 	concept_index::check(range);
 }*/
 
-
 template<class R>
 void sort(R range)
 {
 	sort_bubble(range);
 }
 
-
 template<class R>
 bool sort_verify(R range)
 {
