@@ -4,17 +4,19 @@
 #define ENGINE_CLIENT_H
 #include "kernel.h"
 
-#include "message.h"
 #include "graphics.h"
+#include "message.h"
 #include <engine/friends.h>
 
+struct SWarning;
+
 enum
 {
-	RECORDER_MANUAL=0,
-	RECORDER_AUTO=1,
-	RECORDER_RACE=2,
-	RECORDER_REPLAYS=3,
-	RECORDER_MAX=4,
+	RECORDER_MANUAL = 0,
+	RECORDER_AUTO = 1,
+	RECORDER_RACE = 2,
+	RECORDER_REPLAYS = 3,
+	RECORDER_MAX = 4,
 };
 
 typedef bool (*CLIENTFUNC_FILTER)(const void *pData, int DataSize, void *pUser);
@@ -41,6 +43,7 @@ protected:
 	int m_GameTickSpeed;
 
 	float m_FrameTimeAvg;
+
 public:
 	char m_aNews[3000];
 	int64 m_ReconnectTime;
@@ -59,17 +62,17 @@ public:
 		STATE_LOADING - The client has connected to a server and is loading resources.
 		STATE_ONLINE - The client is connected to a server and running the game.
 		STATE_DEMOPLAYBACK - The client is playing a demo
-		STATE_QUITING - The client is quitting.
+		STATE_QUITTING - The client is quitting.
 	*/
 
 	enum
 	{
-		STATE_OFFLINE=0,
+		STATE_OFFLINE = 0,
 		STATE_CONNECTING,
 		STATE_LOADING,
 		STATE_ONLINE,
 		STATE_DEMOPLAYBACK,
-		STATE_QUITING,
+		STATE_QUITTING,
 		STATE_RESTARTING,
 	};
 
@@ -103,9 +106,9 @@ public:
 	virtual void Restart() = 0;
 	virtual void Quit() = 0;
 	virtual const char *DemoPlayer_Play(const char *pFilename, int StorageType) = 0;
-	#if defined(CONF_VIDEORECORDER)
+#if defined(CONF_VIDEORECORDER)
 	virtual const char *DemoPlayer_Render(const char *pFilename, int StorageType, const char *pVideoName, int SpeedIndex) = 0;
-	#endif
+#endif
 	virtual void DemoRecorder_Start(const char *pFilename, bool WithTimestamp, int Recorder) = 0;
 	virtual void DemoRecorder_HandleAutoStart() = 0;
 	virtual void DemoRecorder_Stop(int Recorder, bool RemoveFile = false) = 0;
@@ -150,8 +153,8 @@ public:
 
 	enum
 	{
-		SNAP_CURRENT=0,
-		SNAP_PREV=1
+		SNAP_CURRENT = 0,
+		SNAP_PREV = 1
 	};
 
 	// TODO: Refactor: should redo this a bit i think, too many virtual calls
@@ -164,7 +167,7 @@ public:
 	virtual void SnapSetStaticsize(int ItemType, int Size) = 0;
 
 	virtual int SendMsg(CMsgPacker *pMsg, int Flags) = 0;
-	virtual int SendMsgY(CMsgPacker *pMsg, int Flags, int NetClient=1) = 0;
+	virtual int SendMsgY(CMsgPacker *pMsg, int Flags, int NetClient = 1) = 0;
 
 	template<class T>
 	int SendPackMsg(T *pMsg, int Flags)
@@ -176,6 +179,8 @@ public:
 	}
 
 	//
+	virtual const char *PlayerName() = 0;
+	virtual const char *DummyName() = 0;
 	virtual const char *ErrorString() = 0;
 	virtual const char *LatestVersion() = 0;
 	virtual bool ConnectionProblems() = 0;
@@ -205,10 +210,11 @@ public:
 
 	virtual void GenerateTimeoutSeed() = 0;
 
-	virtual IFriends* Foes() = 0;
+	virtual IFriends *Foes() = 0;
 
 	virtual void GetSmoothTick(int *pSmoothTick, float *pSmoothIntraTick, float MixAmount) = 0;
 
+	virtual SWarning *GetCurWarning() = 0;
 };
 
 class IGameClient : public IInterface
@@ -221,6 +227,7 @@ public:
 	virtual void OnRconType(bool UsernameReq) = 0;
 	virtual void OnRconLine(const char *pLine) = 0;
 	virtual void OnInit() = 0;
+	virtual void InvalidateSnapshot() = 0;
 	virtual void OnNewSnapshot() = 0;
 	virtual void OnEnterGame() = 0;
 	virtual void OnShutdown() = 0;
@@ -245,6 +252,8 @@ public:
 
 	virtual void OnDummyDisconnect() = 0;
 	virtual void Echo(const char *pString) = 0;
+	virtual bool CanDisplayWarning() = 0;
+	virtual bool IsDisplayingWarning() = 0;
 };
 
 extern IGameClient *CreateGameClient();
