@@ -3,10 +3,30 @@
 #ifndef ENGINE_CLIENT_CLIENT_H
 #define ENGINE_CLIENT_CLIENT_H
 
+#include <list>
 #include <memory>
 
 #include <base/hash.h>
+#include <engine/client.h>
+#include <engine/client/demoedit.h>
+#include <engine/client/friends.h>
 #include <engine/client/http.h>
+#include <engine/client/serverbrowser.h>
+#include <engine/client/updater.h>
+#include <engine/editor.h>
+#include <engine/engine.h>
+#include <engine/graphics.h>
+#include <engine/input.h>
+#include <engine/map.h>
+#include <engine/masterserver.h>
+#include <engine/shared/config.h>
+#include <engine/shared/demo.h>
+#include <engine/shared/fifo.h>
+#include <engine/shared/ghost.h>
+#include <engine/shared/network.h>
+#include <engine/sound.h>
+#include <engine/steam.h>
+#include <engine/warning.h>
 
 #define CONNECTLINK "ddnet:"
 
@@ -16,7 +36,7 @@ public:
 	enum
 	{
 		// restrictions: Must be power of two
-		MAX_VALUES=128,
+		MAX_VALUES = 128,
 	};
 
 	float m_Min, m_Max;
@@ -33,7 +53,6 @@ public:
 	void Render(IGraphics *pGraphics, IGraphics::CTextureHandle FontTexture, float x, float y, float w, float h, const char *pDescription);
 };
 
-
 class CSmoothTime
 {
 	int64 m_Snap;
@@ -74,12 +93,13 @@ class CClient : public IClient, public CDemoPlayer::IListener
 	IConsole *m_pConsole;
 	IStorage *m_pStorage;
 	IUpdater *m_pUpdater;
+	ISteam *m_pSteam;
 	IEngineMasterServer *m_pMasterServer;
 
 	enum
 	{
-		NUM_SNAPSHOT_TYPES=2,
-		PREDICTION_MARGIN=1000/50/2, // magic network prediction value
+		NUM_SNAPSHOT_TYPES = 2,
+		PREDICTION_MARGIN = 1000 / 50 / 2, // magic network prediction value
 	};
 
 	enum
@@ -132,7 +152,7 @@ class CClient : public IClient, public CDemoPlayer::IListener
 	int m_UseTempRconCommands;
 	char m_Password[32];
 	bool m_SendPassword;
-	bool m_ButtonRender=false;
+	bool m_ButtonRender = false;
 
 	// version-checking
 	char m_aVersionStr[10];
@@ -150,6 +170,7 @@ class CClient : public IClient, public CDemoPlayer::IListener
 	//
 	char m_aCmdConnect[256];
 	char m_aCmdPlayDemo[MAX_PATH_LENGTH];
+	char m_aCmdEditMap[MAX_PATH_LENGTH];
 
 	// map download
 	std::shared_ptr<CGetFile> m_pMapdownloadTask;
@@ -171,6 +192,8 @@ class CClient : public IClient, public CDemoPlayer::IListener
 	char m_aDDNetInfoTmp[64];
 	std::shared_ptr<CGetFile> m_pDDNetInfoTask;
 
+	char m_aDummyNameBuf[16];
+
 	// time
 	CSmoothTime m_GameTime[2];
 	CSmoothTime m_PredictedTime;
@@ -186,7 +209,6 @@ class CClient : public IClient, public CDemoPlayer::IListener
 
 	int m_CurrentInput[2];
 	bool m_LastDummy;
-	bool m_LastDummy2;
 	bool m_DummySendConnInfo;
 
 	// graphs
@@ -223,7 +245,7 @@ class CClient : public IClient, public CDemoPlayer::IListener
 	{
 		enum
 		{
-			STATE_INIT=0,
+			STATE_INIT = 0,
 			STATE_START,
 			STATE_READY,
 		};
@@ -233,9 +255,11 @@ class CClient : public IClient, public CDemoPlayer::IListener
 	} m_VersionInfo;
 
 	volatile int m_GfxState;
-	static void GraphicsThreadProxy(void *pThis) { ((CClient*)pThis)->GraphicsThread(); }
+	static void GraphicsThreadProxy(void *pThis) { ((CClient *)pThis)->GraphicsThread(); }
 	void GraphicsThread();
 
+	std::vector<SWarning> m_Warnings;
+
 #if defined(CONF_FAMILY_UNIX)
 	CFifo m_Fifo;
 #endif
@@ -249,12 +273,13 @@ public:
 	IEngineMasterServer *MasterServer() { return m_pMasterServer; }
 	IStorage *Storage() { return m_pStorage; }
 	IUpdater *Updater() { return m_pUpdater; }
+	ISteam *Steam() { return m_pSteam; }
 
 	CClient();
 
 	// ----- send functions -----
 	virtual int SendMsg(CMsgPacker *pMsg, int Flags);
-	virtual int SendMsgY(CMsgPacker *pMsg, int Flags, int NetClient=1);
+	virtual int SendMsgY(CMsgPacker *pMsg, int Flags, int NetClient = 1);
 
 	void SendInfo();
 	void SendEnterGame();
@@ -320,6 +345,8 @@ public:
 	virtual void Restart();
 	virtual void Quit();
 
+	virtual const char *PlayerName();
+	virtual const char *DummyName();
 	virtual const char *ErrorString();
 
 	const char *LoadMap(const char *pName, const char *pFilename, SHA256_DIGEST *pWantedSha256, unsigned WantedCrc);
@@ -337,6 +364,7 @@ public:
 
 	void RequestDDNetInfo();
 	void ResetDDNetInfo();
+	bool IsDDNetInfoChanged();
 	void FinishDDNetInfo();
 	void LoadDDNetInfo();
 
@@ -421,8 +449,10 @@ public:
 
 	void ServerBrowserUpdate();
 
+	void HandleConnectAddress(const NETADDR *pAddr);
 	void HandleConnectLink(const char *pLink);
 	void HandleDemoPath(const char *pPath);
+	void HandleMapPath(const char *pPath);
 
 	// gfx
 	void SwitchWindowScreen(int Index);
@@ -434,29 +464,31 @@ public:
 
 	// DDRace
 
-	void GenerateTimeoutSeed();
+	virtual void GenerateTimeoutSeed();
 	void GenerateTimeoutCodes();
 
 	virtual int GetCurrentRaceTime();
 
-	const char *GetCurrentMap();
-	const char *GetCurrentMapPath();
-	unsigned GetMapCrc();
+	virtual const char *GetCurrentMap();
+	virtual const char *GetCurrentMapPath();
+	virtual unsigned GetMapCrc();
 
-	void RaceRecord_Start(const char *pFilename);
-	void RaceRecord_Stop();
-	bool RaceRecord_IsRecording();
+	virtual void RaceRecord_Start(const char *pFilename);
+	virtual void RaceRecord_Stop();
+	virtual bool RaceRecord_IsRecording();
 
 	virtual void DemoSliceBegin();
 	virtual void DemoSliceEnd();
 	virtual void DemoSlice(const char *pDstPath, CLIENTFUNC_FILTER pfnFilter, void *pUser);
 	virtual void SaveReplay(const int Length);
 
-	bool EditorHasUnsavedData() { return m_pEditor->HasUnsavedData(); }
+	virtual bool EditorHasUnsavedData() { return m_pEditor->HasUnsavedData(); }
 
-	virtual IFriends* Foes() { return &m_Foes; }
+	virtual IFriends *Foes() { return &m_Foes; }
 
-	void GetSmoothTick(int *pSmoothTick, float *pSmoothIntraTick, float MixAmount);
+	virtual void GetSmoothTick(int *pSmoothTick, float *pSmoothIntraTick, float MixAmount);
+
+	virtual SWarning *GetCurWarning();
 };
 
 #endif
