@@ -11,10 +11,9 @@
 #include "curl/curl.h"
 #include "curl/easy.h"
 
-static char CA_FILE_PATH[512];
 // TODO: Non-global pls?
 static CURLSH *gs_Share;
-static LOCK gs_aLocks[CURL_LOCK_DATA_LAST+1];
+static LOCK gs_aLocks[CURL_LOCK_DATA_LAST + 1];
 
 static int GetLockIndex(int Data)
 {
@@ -42,13 +41,6 @@ static void CurlUnlock(CURL *pHandle, curl_lock_data Data, void *pUser)
 
 bool HttpInit(IStorage *pStorage)
 {
-	// print curl version
-	{
-		curl_version_info_data *pVersion = curl_version_info(CURLVERSION_NOW);
-		dbg_msg("http", "libcurl version %s (compiled = " LIBCURL_VERSION ")", pVersion->version);
-	}
-
-	pStorage->GetBinaryPath("data/ca-ddnet.pem", CA_FILE_PATH, sizeof(CA_FILE_PATH));
 	if(curl_global_init(CURL_GLOBAL_DEFAULT))
 	{
 		return true;
@@ -58,6 +50,12 @@ bool HttpInit(IStorage *pStorage)
 	{
 		return true;
 	}
+	// print curl version
+	{
+		curl_version_info_data *pVersion = curl_version_info(CURLVERSION_NOW);
+		dbg_msg("http", "libcurl version %s (compiled = " LIBCURL_VERSION ")", pVersion->version);
+	}
+
 	for(unsigned int i = 0; i < sizeof(gs_aLocks) / sizeof(gs_aLocks[0]); i++)
 	{
 		gs_aLocks[i] = lock_create();
@@ -77,10 +75,11 @@ void EscapeUrl(char *pBuf, int Size, const char *pStr)
 	curl_free(pEsc);
 }
 
-CRequest::CRequest(const char *pUrl, bool CanTimeout) :
-	m_CanTimeout(CanTimeout),
+CRequest::CRequest(const char *pUrl, CTimeout Timeout, bool LogProgress) :
+	m_Timeout(Timeout),
 	m_Size(0),
 	m_Progress(0),
+	m_LogProgress(LogProgress),
 	m_State(HTTP_QUEUED),
 	m_Abort(false)
 {
@@ -89,18 +88,19 @@ CRequest::CRequest(const char *pUrl, bool CanTimeout) :
 
 void CRequest::Run()
 {
+	int FinalState;
 	if(!BeforeInit())
 	{
-		m_State = HTTP_ERROR;
-		OnCompletion();
-		return;
+		FinalState = HTTP_ERROR;
+	}
+	else
+	{
+		CURL *pHandle = curl_easy_init();
+		FinalState = RunImpl(pHandle);
+		curl_easy_cleanup(pHandle);
 	}
 
-	CURL *pHandle = curl_easy_init();
-	m_State = RunImpl(pHandle);
-	curl_easy_cleanup(pHandle);
-
-	OnCompletion();
+	m_State = OnCompletion(FinalState);
 }
 
 int CRequest::RunImpl(CURL *pHandle)
@@ -117,18 +117,10 @@ int CRequest::RunImpl(CURL *pHandle)
 	char aErr[CURL_ERROR_SIZE];
 	curl_easy_setopt(pHandle, CURLOPT_ERRORBUFFER, aErr);
 
-	if(m_CanTimeout)
-	{
-		curl_easy_setopt(pHandle, CURLOPT_CONNECTTIMEOUT_MS, (long)g_Config.m_ClHTTPConnectTimeoutMs);
-		curl_easy_setopt(pHandle, CURLOPT_LOW_SPEED_LIMIT, (long)g_Config.m_ClHTTPLowSpeedLimit);
-		curl_easy_setopt(pHandle, CURLOPT_LOW_SPEED_TIME, (long)g_Config.m_ClHTTPLowSpeedTime);
-	}
-	else
-	{
-		curl_easy_setopt(pHandle, CURLOPT_CONNECTTIMEOUT_MS, 0L);
-		curl_easy_setopt(pHandle, CURLOPT_LOW_SPEED_LIMIT, 0L);
-		curl_easy_setopt(pHandle, CURLOPT_LOW_SPEED_TIME, 0L);
-	}
+	curl_easy_setopt(pHandle, CURLOPT_CONNECTTIMEOUT_MS, m_Timeout.ConnectTimeoutMs);
+	curl_easy_setopt(pHandle, CURLOPT_LOW_SPEED_LIMIT, m_Timeout.LowSpeedLimit);
+	curl_easy_setopt(pHandle, CURLOPT_LOW_SPEED_TIME, m_Timeout.LowSpeedTime);
+
 	curl_easy_setopt(pHandle, CURLOPT_SHARE, gs_Share);
 	curl_easy_setopt(pHandle, CURLOPT_PROTOCOLS, CURLPROTO_HTTP | CURLPROTO_HTTPS);
 	curl_easy_setopt(pHandle, CURLOPT_FOLLOWLOCATION, 1L);
@@ -136,20 +128,8 @@ int CRequest::RunImpl(CURL *pHandle)
 	curl_easy_setopt(pHandle, CURLOPT_FAILONERROR, 1L);
 	curl_easy_setopt(pHandle, CURLOPT_URL, m_aUrl);
 	curl_easy_setopt(pHandle, CURLOPT_NOSIGNAL, 1L);
-	curl_easy_setopt(pHandle, CURLOPT_USERAGENT, "DDNet " GAME_RELEASE_VERSION " (" CONF_PLATFORM_STRING "; " CONF_ARCH_STRING ")");
+	curl_easy_setopt(pHandle, CURLOPT_USERAGENT, GAME_NAME " " GAME_RELEASE_VERSION " (" CONF_PLATFORM_STRING "; " CONF_ARCH_STRING ")");
 
-	// We only trust our own custom-selected CAs for our own servers.
-	// Other servers can use any CA trusted by the system.
-	if(false
-		|| str_comp_nocase_num("maps.ddnet.tw/", m_aUrl, 14) == 0
-		|| str_comp_nocase_num("http://maps.ddnet.tw/", m_aUrl, 21) == 0
-		|| str_comp_nocase_num("https://maps.ddnet.tw/", m_aUrl, 22) == 0
-		|| str_comp_nocase_num("http://info.ddnet.tw/", m_aUrl, 21) == 0
-		|| str_comp_nocase_num("https://info.ddnet.tw/", m_aUrl, 22) == 0
-		|| str_comp_nocase_num("https://update5.ddnet.tw/", m_aUrl, 25) == 0)
-	{
-		curl_easy_setopt(pHandle, CURLOPT_CAINFO, CA_FILE_PATH);
-	}
 	curl_easy_setopt(pHandle, CURLOPT_WRITEDATA, this);
 	curl_easy_setopt(pHandle, CURLOPT_WRITEFUNCTION, WriteCallback);
 	curl_easy_setopt(pHandle, CURLOPT_NOPROGRESS, 0L);
@@ -161,21 +141,20 @@ int CRequest::RunImpl(CURL *pHandle)
 		return HTTP_ERROR;
 	}
 
-	dbg_msg("http", "http %s", m_aUrl);
+	if(g_Config.m_DbgCurl || m_LogProgress)
+		dbg_msg("http", "http %s", m_aUrl);
 	m_State = HTTP_RUNNING;
 	int Ret = curl_easy_perform(pHandle);
-	if(!BeforeCompletion())
-	{
-		return HTTP_ERROR;
-	}
 	if(Ret != CURLE_OK)
 	{
-		dbg_msg("http", "task failed. libcurl error: %s", aErr);
+		if(g_Config.m_DbgCurl || m_LogProgress)
+			dbg_msg("http", "task failed. libcurl error: %s", aErr);
 		return (Ret == CURLE_ABORTED_BY_CALLBACK) ? HTTP_ABORTED : HTTP_ERROR;
 	}
 	else
 	{
-		dbg_msg("http", "task done %s", m_aUrl);
+		if(g_Config.m_DbgCurl || m_LogProgress)
+			dbg_msg("http", "task done %s", m_aUrl);
 		return HTTP_DONE;
 	}
 }
@@ -195,8 +174,8 @@ int CRequest::ProgressCallback(void *pUser, double DlTotal, double DlCurr, doubl
 	return pTask->m_Abort ? -1 : 0;
 }
 
-CGet::CGet(const char *pUrl, bool CanTimeout) :
-	CRequest(pUrl, CanTimeout),
+CGet::CGet(const char *pUrl, CTimeout Timeout) :
+	CRequest(pUrl, Timeout),
 	m_BufferSize(0),
 	m_BufferLength(0),
 	m_pBuffer(NULL)
@@ -268,29 +247,29 @@ size_t CGet::OnData(char *pData, size_t DataSize)
 	return DataSize;
 }
 
-CGetFile::CGetFile(IStorage *pStorage, const char *pUrl, const char *pDest, int StorageType, bool CanTimeout) :
-	CRequest(pUrl, CanTimeout),
+CGetFile::CGetFile(IStorage *pStorage, const char *pUrl, const char *pDest, int StorageType, CTimeout Timeout, bool LogProgress) :
+	CRequest(pUrl, Timeout, LogProgress),
 	m_pStorage(pStorage),
-	m_StorageType(StorageType)
+	m_StorageType(StorageType),
+	m_File(0)
 {
 	str_copy(m_aDest, pDest, sizeof(m_aDest));
+
+	if(m_StorageType == -2)
+		m_pStorage->GetBinaryPath(m_aDest, m_aDestFull, sizeof(m_aDestFull));
+	else
+		m_pStorage->GetCompletePath(m_StorageType, m_aDest, m_aDestFull, sizeof(m_aDestFull));
 }
 
 bool CGetFile::BeforeInit()
 {
-	char aPath[512];
-	if(m_StorageType == -2)
-		m_pStorage->GetBinaryPath(m_aDest, aPath, sizeof(aPath));
-	else
-		m_pStorage->GetCompletePath(m_StorageType, m_aDest, aPath, sizeof(aPath));
-
-	if(fs_makedir_rec_for(aPath) < 0)
+	if(fs_makedir_rec_for(m_aDestFull) < 0)
 	{
-		dbg_msg("http", "i/o error, cannot create folder for: %s", aPath);
+		dbg_msg("http", "i/o error, cannot create folder for: %s", m_aDestFull);
 		return false;
 	}
 
-	m_File = io_open(aPath, IOFLAG_WRITE);
+	m_File = io_open(m_aDestFull, IOFLAG_WRITE);
 	if(!m_File)
 	{
 		dbg_msg("http", "i/o error, cannot open file: %s", m_aDest);
@@ -304,13 +283,23 @@ size_t CGetFile::OnData(char *pData, size_t DataSize)
 	return io_write(m_File, pData, DataSize);
 }
 
-bool CGetFile::BeforeCompletion()
+int CGetFile::OnCompletion(int State)
 {
-	return io_close(m_File) == 0;
+	if(m_File && io_close(m_File) != 0)
+	{
+		State = HTTP_ERROR;
+	}
+
+	if(State == HTTP_ERROR || State == HTTP_ABORTED)
+	{
+		m_pStorage->RemoveFile(m_aDestFull, IStorage::TYPE_ABSOLUTE);
+	}
+
+	return State;
 }
 
-CPostJson::CPostJson(const char *pUrl, bool CanTimeout, const char *pJson)
-	: CRequest(pUrl, CanTimeout)
+CPostJson::CPostJson(const char *pUrl, CTimeout Timeout, const char *pJson) :
+	CRequest(pUrl, Timeout)
 {
 	str_copy(m_aJson, pJson, sizeof(m_aJson));
 }
