@@ -1,9 +1,9 @@
 #ifndef ENGINE_CLIENT_HTTP_H
 #define ENGINE_CLIENT_HTTP_H
 
+#include <engine/kernel.h>
 #include <engine/shared/jobs.h>
 #include <engine/storage.h>
-#include <engine/kernel.h>
 
 typedef struct _json_value json_value;
 typedef void CURL;
@@ -17,6 +17,13 @@ enum
 	HTTP_ABORTED,
 };
 
+struct CTimeout
+{
+	long ConnectTimeoutMs;
+	long LowSpeedLimit;
+	long LowSpeedTime;
+};
+
 class CRequest : public IJob
 {
 	// Abort the request with an error if `BeforeInit()` or `AfterInit()`
@@ -26,16 +33,16 @@ class CRequest : public IJob
 	virtual bool AfterInit(void *pCurl) { return true; }
 	virtual size_t OnData(char *pData, size_t DataSize) = 0;
 
-	virtual void OnProgress() { }
-	virtual bool BeforeCompletion() { return true; }
-	virtual void OnCompletion() { }
+	virtual void OnProgress() {}
 
 	char m_aUrl[256];
-	bool m_CanTimeout;
+
+	CTimeout m_Timeout;
 
 	double m_Size;
 	double m_Current;
 	int m_Progress;
+	bool m_LogProgress;
 
 	std::atomic<int> m_State;
 	std::atomic<bool> m_Abort;
@@ -46,8 +53,11 @@ class CRequest : public IJob
 	void Run();
 	int RunImpl(CURL *pHandle);
 
+protected:
+	virtual int OnCompletion(int State) { return State; }
+
 public:
-	CRequest(const char *pUrl, bool CanTimeout);
+	CRequest(const char *pUrl, CTimeout Timeout, bool LogProgress = true);
 
 	double Current() const { return m_Current; }
 	double Size() const { return m_Size; }
@@ -65,10 +75,20 @@ class CGet : public CRequest
 	unsigned char *m_pBuffer;
 
 public:
-	CGet(const char *pUrl, bool CanTimeout);
+	CGet(const char *pUrl, CTimeout Timeout);
 	~CGet();
 
-	size_t ResultSize() const { if(!Result()) { return 0; } else { return m_BufferSize; } }
+	size_t ResultSize() const
+	{
+		if(!Result())
+		{
+			return 0;
+		}
+		else
+		{
+			return m_BufferSize;
+		}
+	}
 	unsigned char *Result() const;
 	unsigned char *TakeResult();
 	json_value *ResultJson() const;
@@ -78,21 +98,23 @@ class CGetFile : public CRequest
 {
 	virtual size_t OnData(char *pData, size_t DataSize);
 	virtual bool BeforeInit();
-	virtual bool BeforeCompletion();
 
 	IStorage *m_pStorage;
 
-	char m_aDest[256];
+	char m_aDest[MAX_PATH_LENGTH];
+	char m_aDestFull[MAX_PATH_LENGTH];
 	int m_StorageType;
 	IOHANDLE m_File;
 
+protected:
+	virtual int OnCompletion(int State);
+
 public:
-	CGetFile(IStorage *pStorage, const char *pUrl, const char *pDest, int StorageType = -2, bool CanTimeout = true);
+	CGetFile(IStorage *pStorage, const char *pUrl, const char *pDest, int StorageType = -2, CTimeout Timeout = CTimeout{4000, 500, 5}, bool LogProgress = true);
 
 	const char *Dest() const { return m_aDest; }
 };
 
-
 class CPostJson : public CRequest
 {
 	virtual size_t OnData(char *pData, size_t DataSize) { return DataSize; }
@@ -101,7 +123,7 @@ class CPostJson : public CRequest
 	char m_aJson[1024];
 
 public:
-	CPostJson(const char *pUrl, bool CanTimeout, const char *pJson);
+	CPostJson(const char *pUrl, CTimeout Timeout, const char *pJson);
 };
 
 bool HttpInit(IStorage *pStorage);
