@@ -4,8 +4,11 @@
 #define ENGINE_GRAPHICS_H
 
 #include "kernel.h"
+#include "warning.h"
 
 #include <base/color.h>
+#include <stddef.h>
+#include <stdint.h>
 
 #include <vector>
 #define GRAPHICS_TYPE_UNSIGNED_BYTE 0x1401
@@ -40,15 +43,31 @@ struct SQuadRenderInfo
 	float m_Rotation;
 };
 
+struct SGraphicTile
+{
+	vec2 m_TopLeft;
+	vec2 m_TopRight;
+	vec2 m_BottomRight;
+	vec2 m_BottomLeft;
+};
+
+struct SGraphicTileTexureCoords
+{
+	vec3 m_TexCoordTopLeft;
+	vec3 m_TexCoordTopRight;
+	vec3 m_TexCoordBottomRight;
+	vec3 m_TexCoordBottomLeft;
+};
+
 class CImageInfo
 {
 public:
 	enum
 	{
-		FORMAT_AUTO=-1,
-		FORMAT_RGB=0,
-		FORMAT_RGBA=1,
-		FORMAT_ALPHA=2,
+		FORMAT_AUTO = -1,
+		FORMAT_RGB = 0,
+		FORMAT_RGBA = 1,
+		FORMAT_ALPHA = 2,
 	};
 
 	/* Variable: width
@@ -78,12 +97,34 @@ public:
 	int m_Red, m_Green, m_Blue;
 };
 
-struct GL_SPoint { float x, y; };
-struct GL_STexCoord { float u, v; };
-struct GL_SColorf { float r, g, b, a; };
+struct GL_SPoint
+{
+	float x, y;
+};
+struct GL_STexCoord
+{
+	float u, v;
+};
+struct GL_STexCoord3D
+{
+	GL_STexCoord3D &operator=(const GL_STexCoord &TexCoord)
+	{
+		u = TexCoord.u;
+		v = TexCoord.v;
+		return *this;
+	}
+	float u, v, w;
+};
+struct GL_SColorf
+{
+	float r, g, b, a;
+};
 
 //use normalized color values
-struct GL_SColor { unsigned char r, g, b, a; };
+struct GL_SColor
+{
+	unsigned char r, g, b, a;
+};
 
 struct GL_SVertex
 {
@@ -92,7 +133,21 @@ struct GL_SVertex
 	GL_SColor m_Color;
 };
 
-typedef void(*WINDOW_RESIZE_FUNC)(void *pUser);
+struct GL_SVertexTex3D
+{
+	GL_SPoint m_Pos;
+	GL_SColorf m_Color;
+	GL_STexCoord3D m_Tex;
+};
+
+struct GL_SVertexTex3DStream
+{
+	GL_SPoint m_Pos;
+	GL_SColor m_Color;
+	GL_STexCoord3D m_Tex;
+};
+
+typedef void (*WINDOW_RESIZE_FUNC)(void *pUser);
 
 class IGraphics : public IInterface
 {
@@ -102,33 +157,40 @@ protected:
 	int m_ScreenHeight;
 	int m_DesktopScreenWidth;
 	int m_DesktopScreenHeight;
+
 public:
 	/* Constants: Texture Loading Flags
 		TEXLOAD_NORESAMPLE - Prevents the texture from any resampling
 	*/
 	enum
 	{
-		TEXLOAD_NORESAMPLE = 1<<0,
-		TEXLOAD_NOMIPMAPS = 1<<1,
-		TEXLOAD_NO_COMPRESSION = 1<<2,
+		TEXLOAD_NORESAMPLE = 1 << 0,
+		TEXLOAD_NOMIPMAPS = 1 << 1,
+		TEXLOAD_NO_COMPRESSION = 1 << 2,
+		TEXLOAD_TO_3D_TEXTURE = (1 << 3),
+		TEXLOAD_TO_2D_ARRAY_TEXTURE = (1 << 4),
+		TEXLOAD_TO_3D_TEXTURE_SINGLE_LAYER = (1 << 5),
+		TEXLOAD_TO_2D_ARRAY_TEXTURE_SINGLE_LAYER = (1 << 6),
+		TEXLOAD_NO_2D_TEXTURE = (1 << 7),
 	};
 
-
 	class CTextureHandle
 	{
 		friend class IGraphics;
 		int m_Id;
+
 	public:
-		CTextureHandle()
-		: m_Id(-1)
-		{}
+		CTextureHandle() :
+			m_Id(-1)
+		{
+		}
 
 		operator int() const { return m_Id; }
 	};
 
 	int ScreenWidth() const { return m_ScreenWidth; }
 	int ScreenHeight() const { return m_ScreenHeight; }
-	float ScreenAspect() const { return (float)ScreenWidth()/(float)ScreenHeight(); }
+	float ScreenAspect() const { return (float)ScreenWidth() / (float)ScreenHeight(); }
 
 	virtual bool Fullscreen(bool State) = 0;
 	virtual void SetWindowBordered(bool State) = 0;
@@ -156,8 +218,11 @@ public:
 
 	virtual int LoadPNG(CImageInfo *pImg, const char *pFilename, int StorageType) = 0;
 
+	// destination and source buffer require to have the same width and height
+	virtual void CopyTextureBufferSub(uint8_t *pDestBuffer, uint8_t *pSourceBuffer, int FullWidth, int FullHeight, int ColorChannelCount, int SubOffsetX, int SubOffsetY, int SubCopyWidth, int SubCopyHeight) = 0;
+
 	virtual int UnloadTexture(CTextureHandle Index) = 0;
-	virtual CTextureHandle LoadTextureRaw(int Width, int Height, int Format, const void *pData, int StoreFormat, int Flags) = 0;
+	virtual CTextureHandle LoadTextureRaw(int Width, int Height, int Format, const void *pData, int StoreFormat, int Flags, const char *pTexName = NULL) = 0;
 	virtual int LoadTextureRawSub(CTextureHandle TextureID, int x, int y, int Width, int Height, int Format, const void *pData) = 0;
 	virtual CTextureHandle LoadTexture(const char *pFilename, int StorageType, int StoreFormat, int Flags) = 0;
 	virtual void TextureSet(CTextureHandle Texture) = 0;
@@ -165,6 +230,7 @@ public:
 
 	virtual void FlushVertices(bool KeepVertices = false) = 0;
 	virtual void FlushTextVertices(int TextureSize, int TextTextureIndex, int TextOutlineTextureIndex, float *pOutlineTextColor) = 0;
+	virtual void FlushVerticesTex3D() = 0;
 
 	// specific render functions
 	virtual void RenderTileLayer(int BufferContainerIndex, float *pColor, char **pOffsets, unsigned int *IndicedVertexDrawNum, size_t NumIndicesOffet) = 0;
@@ -186,13 +252,18 @@ public:
 	virtual void UpdateBufferContainer(int ContainerIndex, struct SBufferContainerInfo *pContainerInfo) = 0;
 	virtual void IndicesNumRequiredNotify(unsigned int RequiredIndicesCount) = 0;
 
-	virtual bool IsBufferingEnabled() = 0;
+	virtual bool IsTileBufferingEnabled() = 0;
+	virtual bool IsQuadBufferingEnabled() = 0;
+	virtual bool IsTextBufferingEnabled() = 0;
+	virtual bool IsQuadContainerBufferingEnabled() = 0;
+	virtual bool HasTextureArrays() = 0;
 
 	struct CLineItem
 	{
 		float m_X0, m_Y0, m_X1, m_Y1;
 		CLineItem() {}
-		CLineItem(float x0, float y0, float x1, float y1) : m_X0(x0), m_Y0(y0), m_X1(x1), m_Y1(y1) {}
+		CLineItem(float x0, float y0, float x1, float y1) :
+			m_X0(x0), m_Y0(y0), m_X1(x1), m_Y1(y1) {}
 	};
 	virtual void LinesBegin() = 0;
 	virtual void LinesEnd() = 0;
@@ -202,28 +273,39 @@ public:
 	virtual void QuadsEnd() = 0;
 	virtual void TextQuadsBegin() = 0;
 	virtual void TextQuadsEnd(int TextureSize, int TextTextureIndex, int TextOutlineTextureIndex, float *pOutlineTextColor) = 0;
+	virtual void QuadsTex3DBegin() = 0;
+	virtual void QuadsTex3DEnd() = 0;
 	virtual void QuadsEndKeepVertices() = 0;
 	virtual void QuadsDrawCurrentVertices(bool KeepVertices = true) = 0;
 	virtual void QuadsSetRotation(float Angle) = 0;
 	virtual void QuadsSetSubset(float TopLeftU, float TopLeftV, float BottomRightU, float BottomRightV) = 0;
-	virtual void QuadsSetSubsetFree(float x0, float y0, float x1, float y1, float x2, float y2, float x3, float y3) = 0;
+	virtual void QuadsSetSubsetFree(float x0, float y0, float x1, float y1, float x2, float y2, float x3, float y3, int Index = -1) = 0;
 
 	struct CQuadItem
 	{
 		float m_X, m_Y, m_Width, m_Height;
 		CQuadItem() {}
-		CQuadItem(float x, float y, float w, float h) : m_X(x), m_Y(y), m_Width(w), m_Height(h) {}
-		void Set(float x, float y, float w, float h) { m_X = x; m_Y = y; m_Width = w; m_Height = h; }
+		CQuadItem(float x, float y, float w, float h) :
+			m_X(x), m_Y(y), m_Width(w), m_Height(h) {}
+		void Set(float x, float y, float w, float h)
+		{
+			m_X = x;
+			m_Y = y;
+			m_Width = w;
+			m_Height = h;
+		}
 	};
 	virtual void QuadsDraw(CQuadItem *pArray, int Num) = 0;
 	virtual void QuadsDrawTL(const CQuadItem *pArray, int Num) = 0;
 
+	virtual void QuadsTex3DDrawTL(const CQuadItem *pArray, int Num) = 0;
+
 	struct CFreeformItem
 	{
 		float m_X0, m_Y0, m_X1, m_Y1, m_X2, m_Y2, m_X3, m_Y3;
 		CFreeformItem() {}
-		CFreeformItem(float x0, float y0, float x1, float y1, float x2, float y2, float x3, float y3)
-			: m_X0(x0), m_Y0(y0), m_X1(x1), m_Y1(y1), m_X2(x2), m_Y2(y2), m_X3(x3), m_Y3(y3) {}
+		CFreeformItem(float x0, float y0, float x1, float y1, float x2, float y2, float x3, float y3) :
+			m_X0(x0), m_Y0(y0), m_X1(x1), m_Y1(y1), m_X2(x2), m_Y2(y2), m_X3(x3), m_Y3(y3) {}
 	};
 
 	virtual int CreateQuadContainer() = 0;
@@ -253,11 +335,13 @@ public:
 		int m_Index;
 		float m_R, m_G, m_B, m_A;
 		CColorVertex() {}
-		CColorVertex(int i, float r, float g, float b, float a) : m_Index(i), m_R(r), m_G(g), m_B(b), m_A(a) {}
+		CColorVertex(int i, float r, float g, float b, float a) :
+			m_Index(i), m_R(r), m_G(g), m_B(b), m_A(a) {}
 	};
 	virtual void SetColorVertex(const CColorVertex *pArray, int Num) = 0;
 	virtual void SetColor(float r, float g, float b, float a) = 0;
 	virtual void SetColor(ColorRGBA rgb) = 0;
+	virtual void SetColor4(vec4 TopLeft, vec4 TopRight, vec4 BottomLeft, vec4 BottomRight) = 0;
 	virtual void ChangeColorOfCurrentQuadVertices(float r, float g, float b, float a) = 0;
 	virtual void ChangeColorOfQuadVertices(int QuadOffset, unsigned char r, unsigned char g, unsigned char b, unsigned char a) = 0;
 
@@ -276,6 +360,8 @@ public:
 	virtual void SetWindowGrab(bool Grab) = 0;
 	virtual void NotifyWindow() = 0;
 
+	virtual SWarning *GetCurWarning() = 0;
+
 protected:
 	inline CTextureHandle CreateTextureHandle(int Index)
 	{
