@@ -10,10 +10,10 @@
 
 #include "kernel.h"
 #include "message.h"
+#include <engine/shared/protocol.h>
 #include <game/generated/protocol.h>
 #include <game/generated/protocol7.h>
 #include <game/generated/protocolglue.h>
-#include <engine/shared/protocol.h>
 
 struct CAntibotRoundData;
 
@@ -41,6 +41,7 @@ public:
 	int Tick() const { return m_CurrentGameTick; }
 	int TickSpeed() const { return m_TickSpeed; }
 
+	virtual int Port() const = 0;
 	virtual int MaxClients() const = 0;
 	virtual int ClientCount() = 0;
 	virtual int DistinctClientCount() = 0;
@@ -61,7 +62,7 @@ public:
 	{
 		int Result = 0;
 		T tmp;
-		if (ClientID == -1)
+		if(ClientID == -1)
 		{
 			for(int i = 0; i < MAX_CLIENTS; i++)
 				if(ClientIngame(i))
@@ -69,7 +70,9 @@ public:
 					mem_copy(&tmp, pMsg, sizeof(T));
 					Result = SendPackMsgTranslate(&tmp, Flags, i);
 				}
-		} else {
+		}
+		else
+		{
 			mem_copy(&tmp, pMsg, sizeof(T));
 			Result = SendPackMsgTranslate(&tmp, Flags, ClientID);
 		}
@@ -129,8 +132,10 @@ public:
 
 	int SendPackMsgTranslate(CNetMsg_Sv_KillMsg *pMsg, int Flags, int ClientID)
 	{
-		if (!Translate(pMsg->m_Victim, ClientID)) return 0;
-		if (!Translate(pMsg->m_Killer, ClientID)) pMsg->m_Killer = pMsg->m_Victim;
+		if(!Translate(pMsg->m_Victim, ClientID))
+			return 0;
+		if(!Translate(pMsg->m_Killer, ClientID))
+			pMsg->m_Killer = pMsg->m_Victim;
 		return SendPackMsgOne(pMsg, Flags, ClientID);
 	}
 
@@ -145,19 +150,19 @@ public:
 		return SendMsg(&Packer, Flags, ClientID);
 	}
 
-	bool Translate(int& Target, int Client)
+	bool Translate(int &Target, int Client)
 	{
 		if(IsSixup(Client))
 			return true;
 		CClientInfo Info;
 		GetClientInfo(Client, &Info);
-		if (Info.m_DDNetVersion >= VERSION_DDNET_OLD)
+		if(Info.m_DDNetVersion >= VERSION_DDNET_OLD)
 			return true;
 		int *pMap = GetIdMap(Client);
 		bool Found = false;
-		for (int i = 0; i < VANILLA_MAX_CLIENTS; i++)
+		for(int i = 0; i < VANILLA_MAX_CLIENTS; i++)
 		{
-			if (Target == pMap[i])
+			if(Target == pMap[i])
 			{
 				Target = i;
 				Found = true;
@@ -167,17 +172,17 @@ public:
 		return Found;
 	}
 
-	bool ReverseTranslate(int& Target, int Client)
+	bool ReverseTranslate(int &Target, int Client)
 	{
 		if(IsSixup(Client))
 			return true;
 		CClientInfo Info;
 		GetClientInfo(Client, &Info);
-		if (Info.m_DDNetVersion >= VERSION_DDNET_OLD)
+		if(Info.m_DDNetVersion >= VERSION_DDNET_OLD)
 			return true;
-		Target = clamp(Target, 0, VANILLA_MAX_CLIENTS-1);
+		Target = clamp(Target, 0, VANILLA_MAX_CLIENTS - 1);
 		int *pMap = GetIdMap(Client);
-		if (pMap[Target] == -1)
+		if(pMap[Target] == -1)
 			return false;
 		Target = pMap[Target];
 		return true;
@@ -197,9 +202,10 @@ public:
 
 	virtual void SnapSetStaticsize(int ItemType, int Size) = 0;
 
-	enum {
-		RCON_CID_SERV=-1,
-		RCON_CID_VOTE=-2,
+	enum
+	{
+		RCON_CID_SERV = -1,
+		RCON_CID_VOTE = -2,
 	};
 	virtual void SetRconCID(int ClientID) = 0;
 	virtual int GetAuthedState(int ClientID) = 0;
@@ -207,7 +213,6 @@ public:
 	virtual void Kick(int ClientID, const char *pReason) = 0;
 	virtual void Ban(int ClientID, int Seconds, const char *pReason) = 0;
 
-
 	virtual void DemoRecorder_HandleAutoStart() = 0;
 	virtual bool DemoRecorder_IsRecording() = 0;
 
@@ -220,9 +225,11 @@ public:
 
 	virtual void GetClientAddr(int ClientID, NETADDR *pAddr) = 0;
 
-	virtual int* GetIdMap(int ClientID) = 0;
+	virtual int *GetIdMap(int ClientID) = 0;
 
 	virtual bool DnsblWhite(int ClientID) = 0;
+	virtual bool DnsblPending(int ClientID) = 0;
+	virtual bool DnsblBlack(int ClientID) = 0;
 	virtual const char *GetAnnouncementLine(char const *FileName) = 0;
 	virtual bool ClientPrevIngame(int ClientID) = 0;
 	virtual const char *GetNetErrorString(int ClientID) = 0;
@@ -250,7 +257,7 @@ public:
 	virtual void OnMapChange(char *pNewMapName, int MapNameSize) = 0;
 
 	// FullShutdown is true if the program is about to exit (not if the map is changed)
-	virtual void OnShutdown(bool FullShutdown = false) = 0;
+	virtual void OnShutdown() = 0;
 
 	virtual void OnTick() = 0;
 	virtual void OnPreSnap() = 0;
