@@ -1,10 +1,10 @@
 /* (c) Magnus Auvinen. See licence.txt in the root of the distribution for more information. */
 /* If you are missing that file, acquire a complete release at teeworlds.com.                */
 #include <base/system.h>
-#include <engine/shared/network.h>
-#include <engine/shared/config.h>
 #include <engine/console.h>
 #include <engine/masterserver.h>
+#include <engine/shared/config.h>
+#include <engine/shared/network.h>
 
 #include <mastersrv/mastersrv.h>
 
@@ -67,7 +67,7 @@ void CRegister::RegisterSendFwcheckresponse(NETADDR *pAddr, SECURITY_TOKEN Respo
 void CRegister::RegisterSendHeartbeat(NETADDR Addr, SECURITY_TOKEN ResponseToken)
 {
 	static unsigned char aData[sizeof(SERVERBROWSE_HEARTBEAT) + 2];
-	unsigned short Port = g_Config.m_SvPort;
+	unsigned short Port = m_pNetServer->Address().port;
 	CNetChunk Packet;
 
 	mem_copy(aData, SERVERBROWSE_HEARTBEAT, sizeof(SERVERBROWSE_HEARTBEAT));
@@ -82,7 +82,7 @@ void CRegister::RegisterSendHeartbeat(NETADDR Addr, SECURITY_TOKEN ResponseToken
 	if(g_Config.m_SvExternalPort)
 		Port = g_Config.m_SvExternalPort;
 	aData[sizeof(SERVERBROWSE_HEARTBEAT)] = Port >> 8;
-	aData[sizeof(SERVERBROWSE_HEARTBEAT)+1] = Port&0xff;
+	aData[sizeof(SERVERBROWSE_HEARTBEAT) + 1] = Port & 0xff;
 	if(m_Sixup)
 		m_pNetServer->SendConnlessSixup(&Packet, ResponseToken);
 	else
@@ -106,7 +106,7 @@ void CRegister::RegisterSendCountRequest(NETADDR Addr, SECURITY_TOKEN ResponseTo
 void CRegister::RegisterGotCount(CNetChunk *pChunk)
 {
 	unsigned char *pData = (unsigned char *)pChunk->m_pData;
-	int Count = (pData[sizeof(SERVERBROWSE_COUNT)]<<8) | pData[sizeof(SERVERBROWSE_COUNT)+1];
+	int Count = (pData[sizeof(SERVERBROWSE_COUNT)] << 8) | pData[sizeof(SERVERBROWSE_COUNT) + 1];
 
 	for(int i = 0; i < IMasterServer::MAX_MASTERSERVERS; i++)
 	{
@@ -135,7 +135,7 @@ void CRegister::RegisterUpdate(int Nettype)
 
 	m_pMasterServer->Update();
 
-	if(m_Sixup && (m_RegisterState == REGISTERSTATE_HEARTBEAT || m_RegisterState == REGISTERSTATE_REGISTERED) && Now > m_LastTokenRequest+Freq*5)
+	if(m_Sixup && (m_RegisterState == REGISTERSTATE_HEARTBEAT || m_RegisterState == REGISTERSTATE_REGISTERED) && Now > m_LastTokenRequest + Freq * 5)
 	{
 		m_pNetServer->SendTokenSixup(m_aMasterserverInfo[m_RegisterRegisteredServer].m_Addr, NET_SECURITY_TOKEN_UNKNOWN);
 		m_LastTokenRequest = Now;
@@ -191,7 +191,7 @@ void CRegister::RegisterUpdate(int Nettype)
 			if(m_aMasterserverInfo[i].m_Count == -1)
 			{
 				Left++;
-				if(m_aMasterserverInfo[i].m_LastSend+Freq < Now)
+				if(m_aMasterserverInfo[i].m_LastSend + Freq < Now)
 				{
 					m_aMasterserverInfo[i].m_LastSend = Now;
 					if(m_Sixup && m_aMasterserverInfo[i].m_Token == NET_SECURITY_TOKEN_UNKNOWN)
@@ -203,7 +203,7 @@ void CRegister::RegisterUpdate(int Nettype)
 		}
 
 		// check if we are done or timed out
-		if(Left == 0 || Now > m_RegisterStateStart+Freq*5)
+		if(Left == 0 || Now > m_RegisterStateStart + Freq * 5)
 		{
 			// choose server
 			int Best = -1;
@@ -237,13 +237,13 @@ void CRegister::RegisterUpdate(int Nettype)
 	else if(m_RegisterState == REGISTERSTATE_HEARTBEAT)
 	{
 		// check if we should send heartbeat
-		if(Now > m_aMasterserverInfo[m_RegisterRegisteredServer].m_LastSend+Freq*15)
+		if(Now > m_aMasterserverInfo[m_RegisterRegisteredServer].m_LastSend + Freq * 15)
 		{
 			m_aMasterserverInfo[m_RegisterRegisteredServer].m_LastSend = Now;
 			RegisterSendHeartbeat(m_aMasterserverInfo[m_RegisterRegisteredServer].m_Addr, m_aMasterserverInfo[m_RegisterRegisteredServer].m_Token);
 		}
 
-		if(Now > m_RegisterStateStart+Freq*60)
+		if(Now > m_RegisterStateStart + Freq * 60)
 		{
 			m_pConsole->Print(IConsole::OUTPUT_LEVEL_STANDARD, m_pName, "WARNING: Master server is not responding, switching master");
 			RegisterNewState(REGISTERSTATE_START);
@@ -257,7 +257,7 @@ void CRegister::RegisterUpdate(int Nettype)
 		m_RegisterFirst = 0;
 
 		// check if we should send new heartbeat again
-		if(Now > m_RegisterStateStart+Freq)
+		if(Now > m_RegisterStateStart + Freq)
 		{
 			if(m_RegisterCount == 120) // redo the whole process after 60 minutes to balance out the master servers
 				RegisterNewState(REGISTERSTATE_START);
@@ -271,7 +271,7 @@ void CRegister::RegisterUpdate(int Nettype)
 	else if(m_RegisterState == REGISTERSTATE_ERROR)
 	{
 		// check for restart
-		if(Now > m_RegisterStateStart+Freq*60)
+		if(Now > m_RegisterStateStart + Freq * 60)
 			RegisterNewState(REGISTERSTATE_START);
 	}
 }
@@ -312,12 +312,12 @@ int CRegister::RegisterProcessPacket(CNetChunk *pPacket, SECURITY_TOKEN Response
 	{
 		m_pConsole->Print(IConsole::OUTPUT_LEVEL_STANDARD, m_pName, "ERROR: the master server reports that clients can not connect to this server.");
 		char aBuf[256];
-		str_format(aBuf, sizeof(aBuf), "ERROR: configure your firewall/nat to let through udp on port %d.", g_Config.m_SvPort);
+		str_format(aBuf, sizeof(aBuf), "ERROR: configure your firewall/nat to let through udp on port %d.", m_pNetServer->Address().port);
 		m_pConsole->Print(IConsole::OUTPUT_LEVEL_STANDARD, m_pName, aBuf);
 		//RegisterNewState(REGISTERSTATE_ERROR);
 		return 1;
 	}
-	else if(pPacket->m_DataSize == sizeof(SERVERBROWSE_COUNT)+2 &&
+	else if(pPacket->m_DataSize == sizeof(SERVERBROWSE_COUNT) + 2 &&
 		mem_comp(pPacket->m_pData, SERVERBROWSE_COUNT, sizeof(SERVERBROWSE_COUNT)) == 0)
 	{
 		RegisterGotCount(pPacket);
