@@ -10,15 +10,15 @@
 #include <engine/server.h>
 
 #include <engine/map.h>
-#include <engine/shared/demo.h>
-#include <engine/shared/protocol.h>
-#include <engine/shared/snapshot.h>
-#include <engine/shared/network.h>
 #include <engine/server/register.h>
 #include <engine/shared/console.h>
+#include <engine/shared/demo.h>
 #include <engine/shared/econ.h>
 #include <engine/shared/fifo.h>
 #include <engine/shared/netban.h>
+#include <engine/shared/network.h>
+#include <engine/shared/protocol.h>
+#include <engine/shared/snapshot.h>
 #include <engine/shared/uuid_manager.h>
 
 #include <base/tl/array.h>
@@ -29,20 +29,15 @@
 #include "authmanager.h"
 #include "name_ban.h"
 
-#if defined (CONF_UPNP)
-	#include "upnp.h"
-#endif
-
-#if defined (CONF_SQL)
-	#include "sql_connector.h"
-	#include "sql_server.h"
+#if defined(CONF_UPNP)
+#include "upnp.h"
 #endif
 
 class CSnapIDPool
 {
 	enum
 	{
-		MAX_IDS = 16*1024,
+		MAX_IDS = 16 * 1024,
 	};
 
 	class CID
@@ -62,7 +57,6 @@ class CSnapIDPool
 	int m_InUsage;
 
 public:
-
 	CSnapIDPool();
 
 	void Reset();
@@ -72,12 +66,12 @@ public:
 	void FreeID(int ID);
 };
 
-
 class CServerBan : public CNetBan
 {
 	class CServer *m_pServer;
 
-	template<class T> int BanExt(T *pBanPool, const typename T::CDataType *pData, int Seconds, const char *pReason);
+	template<class T>
+	int BanExt(T *pBanPool, const typename T::CDataType *pData, int Seconds, const char *pReason);
 
 public:
 	class CServer *Server() const { return m_pServer; }
@@ -88,9 +82,10 @@ public:
 	virtual int BanRange(const CNetRange *pRange, int Seconds, const char *pReason);
 
 	static void ConBanExt(class IConsole::IResult *pResult, void *pUser);
+	static void ConBanRegion(class IConsole::IResult *pResult, void *pUser);
+	static void ConBanRegionRange(class IConsole::IResult *pResult, void *pUser);
 };
 
-
 class CServer : public IServer
 {
 	class IGameServer *m_pGameServer;
@@ -102,34 +97,29 @@ class CServer : public IServer
 	CUPnP m_UPnP;
 #endif
 
-#if defined(CONF_SQL)
-	lock m_GlobalSqlLock;
-
-	CSqlServer *m_apSqlReadServers[MAX_SQLSERVERS];
-	CSqlServer *m_apSqlWriteServers[MAX_SQLSERVERS];
-#endif
-
 #if defined(CONF_FAMILY_UNIX)
 	UNIXSOCKETADDR m_ConnLoggingDestAddr;
 	bool m_ConnLoggingSocketCreated;
 	UNIXSOCKET m_ConnLoggingSocket;
 #endif
 
+	class CDbConnectionPool *m_pConnectionPool;
+
 public:
 	class IGameServer *GameServer() { return m_pGameServer; }
 	class IConsole *Console() { return m_pConsole; }
 	class IStorage *Storage() { return m_pStorage; }
 	class IEngineAntibot *Antibot() { return m_pAntibot; }
+	class CDbConnectionPool *DbPool() { return m_pConnectionPool; }
 
 	enum
 	{
-		MAX_RCONCMD_SEND=16,
+		MAX_RCONCMD_SEND = 16,
 	};
 
 	class CClient
 	{
 	public:
-
 		enum
 		{
 			STATE_EMPTY = 0,
@@ -139,11 +129,11 @@ public:
 			STATE_READY,
 			STATE_INGAME,
 
-			SNAPRATE_INIT=0,
+			SNAPRATE_INIT = 0,
 			SNAPRATE_FULL,
 			SNAPRATE_RECOVER,
 
-			DNSBL_STATE_NONE=0,
+			DNSBL_STATE_NONE = 0,
 			DNSBL_STATE_PENDING,
 			DNSBL_STATE_BLACKLISTED,
 			DNSBL_STATE_WHITELISTED,
@@ -221,7 +211,16 @@ public:
 
 	int64 m_GameStartTime;
 	//int m_CurrentGameTick;
+
+	enum
+	{
+		UNINITIALIZED = 0,
+		RUNNING = 1,
+		STOPPING = 2
+	};
+
 	int m_RunServer;
+
 	int m_MapReload;
 	bool m_ReloadedWhenEmpty;
 	int m_RconClientID;
@@ -233,7 +232,7 @@ public:
 
 	enum
 	{
-		SIX=0,
+		SIX = 0,
 		SIXUP,
 	};
 
@@ -243,7 +242,7 @@ public:
 	unsigned char *m_apCurrentMapData[2];
 	unsigned int m_aCurrentMapSize[2];
 
-	CDemoRecorder m_aDemoRecorder[MAX_CLIENTS+1];
+	CDemoRecorder m_aDemoRecorder[MAX_CLIENTS + 1];
 	CRegister m_Register;
 	CRegister m_RegSixup;
 	CAuthManager m_AuthManager;
@@ -291,6 +290,7 @@ public:
 	int ClientCountry(int ClientID);
 	bool ClientIngame(int ClientID);
 	bool ClientAuthed(int ClientID);
+	int Port() const;
 	int MaxClients() const;
 	int ClientCount();
 	int DistinctClientCount();
@@ -319,9 +319,11 @@ public:
 
 	void ProcessClientPacket(CNetChunk *pPacket);
 
-	class CCache {
+	class CCache
+	{
 	public:
-		class CCacheChunk {
+		class CCacheChunk
+		{
 		public:
 			CCacheChunk(const void *pData, int Size);
 			CCacheChunk(const CCacheChunk &) = delete;
@@ -351,7 +353,7 @@ public:
 	void SendServerInfoConnless(const NETADDR *pAddr, int Token, int Type);
 	void UpdateServerInfo(bool Resend = false);
 
-	void PumpNetwork();
+	void PumpNetwork(bool PacketWaiting);
 
 	char *GetMapName();
 	int LoadMap(const char *pMapName);
@@ -386,11 +388,9 @@ public:
 	static void ConNameUnban(IConsole::IResult *pResult, void *pUser);
 	static void ConNameBans(IConsole::IResult *pResult, void *pUser);
 
-#if defined (CONF_SQL)
 	// console commands for sqlmasters
 	static void ConAddSqlServer(IConsole::IResult *pResult, void *pUserData);
 	static void ConDumpSqlServers(IConsole::IResult *pResult, void *pUserData);
-#endif
 
 	static void ConchainSpecialInfoupdate(IConsole::IResult *pResult, void *pUserData, IConsole::FCommandCallback pfnCallback, void *pCallbackUserData);
 	static void ConchainMaxclientsperipUpdate(IConsole::IResult *pResult, void *pUserData, IConsole::FCommandCallback pfnCallback, void *pCallbackUserData);
@@ -411,7 +411,6 @@ public:
 
 	void RegisterCommands();
 
-
 	virtual int SnapNewID();
 	virtual void SnapFreeID(int ID);
 	virtual void *SnapNewItem(int Type, int ID, int Size);
@@ -425,13 +424,21 @@ public:
 	unsigned m_AnnouncementLastLine;
 	void RestrictRconOutput(int ClientID) { m_RconRestrict = ClientID; }
 
-	virtual int* GetIdMap(int ClientID);
+	virtual int *GetIdMap(int ClientID);
 
 	void InitDnsbl(int ClientID);
 	bool DnsblWhite(int ClientID)
 	{
 		return m_aClients[ClientID].m_DnsblState == CClient::DNSBL_STATE_NONE ||
-		m_aClients[ClientID].m_DnsblState == CClient::DNSBL_STATE_WHITELISTED;
+		       m_aClients[ClientID].m_DnsblState == CClient::DNSBL_STATE_WHITELISTED;
+	}
+	bool DnsblPending(int ClientID)
+	{
+		return m_aClients[ClientID].m_DnsblState == CClient::DNSBL_STATE_PENDING;
+	}
+	bool DnsblBlack(int ClientID)
+	{
+		return m_aClients[ClientID].m_DnsblState == CClient::DNSBL_STATE_BLACKLISTED;
 	}
 
 	void AuthRemoveKey(int KeySlot);
@@ -451,13 +458,12 @@ public:
 #ifdef CONF_FAMILY_UNIX
 	enum CONN_LOGGING_CMD
 	{
-		OPEN_SESSION=1,
-		CLOSE_SESSION=2,
+		OPEN_SESSION = 1,
+		CLOSE_SESSION = 2,
 	};
 
 	void SendConnLoggingCommand(CONN_LOGGING_CMD cmd, const NETADDR *pAddr);
 #endif
-
 };
 
 #endif
