@@ -3,8 +3,8 @@
 
 #include "datafile.h"
 
-#include <base/math.h>
 #include <base/hash_ctxt.h>
+#include <base/math.h>
 #include <base/system.h>
 #include <engine/storage.h>
 
@@ -12,12 +12,12 @@
 
 #include <zlib.h>
 
-static const int DEBUG=0;
+static const int DEBUG = 0;
 
 enum
 {
-	OFFSET_UUID_TYPE=0x8000,
-	ITEMTYPE_EX=0xffff,
+	OFFSET_UUID_TYPE = 0x8000,
+	ITEMTYPE_EX = 0xffff,
 };
 
 struct CItemEx
@@ -57,13 +57,12 @@ static int GetTypeFromIndex(int Index)
 	return ITEMTYPE_EX - Index - 1;
 }
 
-
 struct CDatafileItemType
 {
 	int m_Type;
 	int m_Start;
 	int m_Num;
-} ;
+};
 
 struct CDatafileItem
 {
@@ -128,14 +127,13 @@ bool CDataFileReader::Open(class IStorage *pStorage, const char *pFilename, int
 		return false;
 	}
 
-
 	// take the CRC of the file and store it
 	unsigned Crc = 0;
 	SHA256_DIGEST Sha256;
 	{
 		enum
 		{
-			BUFFER_SIZE = 64*1024
+			BUFFER_SIZE = 64 * 1024
 		};
 
 		SHA256_CTX Sha256Ctxt;
@@ -155,10 +153,9 @@ bool CDataFileReader::Open(class IStorage *pStorage, const char *pFilename, int
 		io_seek(File, 0, IOSEEK_START);
 	}
 
-
 	// TODO: change this header
 	CDatafileHeader Header;
-	if (sizeof(Header) != io_read(File, &Header, sizeof(Header)))
+	if(sizeof(Header) != io_read(File, &Header, sizeof(Header)))
 	{
 		dbg_msg("datafile", "couldn't load header");
 		return 0;
@@ -173,7 +170,7 @@ bool CDataFileReader::Open(class IStorage *pStorage, const char *pFilename, int
 	}
 
 #if defined(CONF_ARCH_ENDIAN_BIG)
-	swap_endian(&Header, sizeof(int), sizeof(Header)/sizeof(int));
+	swap_endian(&Header, sizeof(int), sizeof(Header) / sizeof(int));
 #endif
 	if(Header.m_Version != 3 && Header.m_Version != 4)
 	{
@@ -183,27 +180,27 @@ bool CDataFileReader::Open(class IStorage *pStorage, const char *pFilename, int
 
 	// read in the rest except the data
 	unsigned Size = 0;
-	Size += Header.m_NumItemTypes*sizeof(CDatafileItemType);
-	Size += (Header.m_NumItems+Header.m_NumRawData)*sizeof(int);
+	Size += Header.m_NumItemTypes * sizeof(CDatafileItemType);
+	Size += (Header.m_NumItems + Header.m_NumRawData) * sizeof(int);
 	if(Header.m_Version == 4)
-		Size += Header.m_NumRawData*sizeof(int); // v4 has uncompressed data sizes as well
+		Size += Header.m_NumRawData * sizeof(int); // v4 has uncompressed data sizes as well
 	Size += Header.m_ItemSize;
 
 	unsigned AllocSize = Size;
 	AllocSize += sizeof(CDatafile); // add space for info structure
-	AllocSize += Header.m_NumRawData*sizeof(void*); // add space for data pointers
+	AllocSize += Header.m_NumRawData * sizeof(void *); // add space for data pointers
 
 	CDatafile *pTmpDataFile = (CDatafile *)malloc(AllocSize);
 	pTmpDataFile->m_Header = Header;
 	pTmpDataFile->m_DataStartOffset = sizeof(CDatafileHeader) + Size;
-	pTmpDataFile->m_ppDataPtrs = (char **)(pTmpDataFile+1);
-	pTmpDataFile->m_pData = (char *)(pTmpDataFile+1)+Header.m_NumRawData*sizeof(char *);
+	pTmpDataFile->m_ppDataPtrs = (char **)(pTmpDataFile + 1);
+	pTmpDataFile->m_pData = (char *)(pTmpDataFile + 1) + Header.m_NumRawData * sizeof(char *);
 	pTmpDataFile->m_File = File;
 	pTmpDataFile->m_Sha256 = Sha256;
 	pTmpDataFile->m_Crc = Crc;
 
 	// clear the data pointers
-	mem_zero(pTmpDataFile->m_ppDataPtrs, Header.m_NumRawData*sizeof(void*));
+	mem_zero(pTmpDataFile->m_ppDataPtrs, Header.m_NumRawData * sizeof(void *));
 
 	// read types, offsets, sizes and item data
 	unsigned ReadSize = io_read(File, pTmpDataFile->m_pData, Size);
@@ -285,24 +282,33 @@ bool CDataFileReader::Open(class IStorage *pStorage, const char *pFilename, int
 
 int CDataFileReader::NumData()
 {
-	if(!m_pDataFile) { return 0; }
+	if(!m_pDataFile)
+	{
+		return 0;
+	}
 	return m_pDataFile->m_Header.m_NumRawData;
 }
 
 // returns the size in the file
 int CDataFileReader::GetFileDataSize(int Index)
 {
-	if(!m_pDataFile) { return 0; }
+	if(!m_pDataFile)
+	{
+		return 0;
+	}
 
-	if(Index == m_pDataFile->m_Header.m_NumRawData-1)
-		return m_pDataFile->m_Header.m_DataSize-m_pDataFile->m_Info.m_pDataOffsets[Index];
-	return m_pDataFile->m_Info.m_pDataOffsets[Index+1]-m_pDataFile->m_Info.m_pDataOffsets[Index];
+	if(Index == m_pDataFile->m_Header.m_NumRawData - 1)
+		return m_pDataFile->m_Header.m_DataSize - m_pDataFile->m_Info.m_pDataOffsets[Index];
+	return m_pDataFile->m_Info.m_pDataOffsets[Index + 1] - m_pDataFile->m_Info.m_pDataOffsets[Index];
 }
 
 // returns the size of the resulting data
 int CDataFileReader::GetDataSize(int Index)
 {
-	if(!m_pDataFile) { return 0; }
+	if(!m_pDataFile)
+	{
+		return 0;
+	}
 
 	if(m_pDataFile->m_Header.m_Version == 4)
 		return m_pDataFile->m_Info.m_pDataSizes[Index];
@@ -312,7 +318,10 @@ int CDataFileReader::GetDataSize(int Index)
 
 void *CDataFileReader::GetDataImpl(int Index, int Swap)
 {
-	if(!m_pDataFile) { return 0; }
+	if(!m_pDataFile)
+	{
+		return 0;
+	}
 
 	if(Index < 0 || Index >= m_pDataFile->m_Header.m_NumRawData)
 		return 0;
@@ -337,12 +346,12 @@ void *CDataFileReader::GetDataImpl(int Index, int Swap)
 			m_pDataFile->m_ppDataPtrs[Index] = (char *)malloc(UncompressedSize);
 
 			// read the compressed data
-			io_seek(m_pDataFile->m_File, m_pDataFile->m_DataStartOffset+m_pDataFile->m_Info.m_pDataOffsets[Index], IOSEEK_START);
+			io_seek(m_pDataFile->m_File, m_pDataFile->m_DataStartOffset + m_pDataFile->m_Info.m_pDataOffsets[Index], IOSEEK_START);
 			io_read(m_pDataFile->m_File, pTemp, DataSize);
 
 			// decompress the data, TODO: check for errors
 			s = UncompressedSize;
-			uncompress((Bytef*)m_pDataFile->m_ppDataPtrs[Index], &s, (Bytef*)pTemp, DataSize); // ignore_convention
+			uncompress((Bytef *)m_pDataFile->m_ppDataPtrs[Index], &s, (Bytef *)pTemp, DataSize); // ignore_convention
 #if defined(CONF_ARCH_ENDIAN_BIG)
 			SwapSize = s;
 #endif
@@ -355,13 +364,13 @@ void *CDataFileReader::GetDataImpl(int Index, int Swap)
 			// load the data
 			dbg_msg("datafile", "loading data index=%d size=%d", Index, DataSize);
 			m_pDataFile->m_ppDataPtrs[Index] = (char *)malloc(DataSize);
-			io_seek(m_pDataFile->m_File, m_pDataFile->m_DataStartOffset+m_pDataFile->m_Info.m_pDataOffsets[Index], IOSEEK_START);
+			io_seek(m_pDataFile->m_File, m_pDataFile->m_DataStartOffset + m_pDataFile->m_Info.m_pDataOffsets[Index], IOSEEK_START);
 			io_read(m_pDataFile->m_File, m_pDataFile->m_ppDataPtrs[Index], DataSize);
 		}
 
 #if defined(CONF_ARCH_ENDIAN_BIG)
 		if(Swap && SwapSize)
-			swap_endian(m_pDataFile->m_ppDataPtrs[Index], sizeof(int), SwapSize/sizeof(int));
+			swap_endian(m_pDataFile->m_ppDataPtrs[Index], sizeof(int), SwapSize / sizeof(int));
 #endif
 	}
 
@@ -392,9 +401,9 @@ int CDataFileReader::GetItemSize(int Index)
 {
 	if(!m_pDataFile)
 		return 0;
-	if(Index == m_pDataFile->m_Header.m_NumItems-1)
-		return m_pDataFile->m_Header.m_ItemSize-m_pDataFile->m_Info.m_pItemOffsets[Index] - sizeof(CDatafileItem);
-	return m_pDataFile->m_Info.m_pItemOffsets[Index+1]-m_pDataFile->m_Info.m_pItemOffsets[Index] - sizeof(CDatafileItem);
+	if(Index == m_pDataFile->m_Header.m_NumItems - 1)
+		return m_pDataFile->m_Header.m_ItemSize - m_pDataFile->m_Info.m_pItemOffsets[Index] - sizeof(CDatafileItem);
+	return m_pDataFile->m_Info.m_pItemOffsets[Index + 1] - m_pDataFile->m_Info.m_pItemOffsets[Index] - sizeof(CDatafileItem);
 }
 
 int CDataFileReader::GetExternalItemType(int InternalType)
@@ -439,19 +448,26 @@ int CDataFileReader::GetInternalItemType(int ExternalType)
 
 void *CDataFileReader::GetItem(int Index, int *pType, int *pID)
 {
-	if(!m_pDataFile) { if(pType) *pType = 0; if(pID) *pID = 0; return 0; }
+	if(!m_pDataFile)
+	{
+		if(pType)
+			*pType = 0;
+		if(pID)
+			*pID = 0;
+		return 0;
+	}
 
-	CDatafileItem *i = (CDatafileItem *)(m_pDataFile->m_Info.m_pItemStart+m_pDataFile->m_Info.m_pItemOffsets[Index]);
+	CDatafileItem *i = (CDatafileItem *)(m_pDataFile->m_Info.m_pItemStart + m_pDataFile->m_Info.m_pItemOffsets[Index]);
 	if(pType)
 	{
 		// remove sign extension
-		*pType = GetExternalItemType((i->m_TypeAndID>>16)&0xffff);
+		*pType = GetExternalItemType((i->m_TypeAndID >> 16) & 0xffff);
 	}
 	if(pID)
 	{
-		*pID = i->m_TypeAndID&0xffff;
+		*pID = i->m_TypeAndID & 0xffff;
 	}
-	return (void *)(i+1);
+	return (void *)(i + 1);
 }
 
 void CDataFileReader::GetType(int Type, int *pStart, int *pNum)
@@ -507,7 +523,8 @@ void *CDataFileReader::FindItem(int Type, int ID)
 
 int CDataFileReader::NumItems()
 {
-	if(!m_pDataFile) return 0;
+	if(!m_pDataFile)
+		return 0;
 	return m_pDataFile->m_Header.m_NumItems;
 }
 
@@ -543,23 +560,25 @@ SHA256_DIGEST CDataFileReader::Sha256()
 
 unsigned CDataFileReader::Crc()
 {
-	if(!m_pDataFile) return 0xFFFFFFFF;
+	if(!m_pDataFile)
+		return 0xFFFFFFFF;
 	return m_pDataFile->m_Crc;
 }
 
 int CDataFileReader::MapSize()
 {
-	if(!m_pDataFile) return 0;
+	if(!m_pDataFile)
+		return 0;
 	return m_pDataFile->m_Header.m_Size + 16;
 }
 
 IOHANDLE CDataFileReader::File()
 {
-	if(!m_pDataFile) return 0;
+	if(!m_pDataFile)
+		return 0;
 	return m_pDataFile->m_File;
 }
 
-
 CDataFileWriter::CDataFileWriter()
 {
 	m_File = 0;
@@ -632,7 +651,7 @@ int CDataFileWriter::AddItem(int Type, int ID, int Size, void *pData)
 {
 	dbg_assert((Type >= 0 && Type < MAX_ITEM_TYPES) || Type >= OFFSET_UUID, "incorrect type");
 	dbg_assert(m_NumItems < 1024, "too many items");
-	dbg_assert(Size%sizeof(int) == 0, "incorrect boundary");
+	dbg_assert(Size % sizeof(int) == 0, "incorrect boundary");
 
 	if(Type >= OFFSET_UUID)
 	{
@@ -664,7 +683,7 @@ int CDataFileWriter::AddItem(int Type, int ID, int Size, void *pData)
 	m_pItemTypes[Type].m_Num++;
 
 	m_NumItems++;
-	return m_NumItems-1;
+	return m_NumItems - 1;
 }
 
 int CDataFileWriter::AddData(int Size, void *pData)
@@ -675,7 +694,7 @@ int CDataFileWriter::AddData(int Size, void *pData)
 	unsigned long s = compressBound(Size);
 	void *pCompData = malloc(s); // temporary buffer that we use during compression
 
-	int Result = compress((Bytef*)pCompData, &s, (Bytef*)pData, Size); // ignore_convention
+	int Result = compress((Bytef *)pCompData, &s, (Bytef *)pData, Size); // ignore_convention
 	if(Result != Z_OK)
 	{
 		dbg_msg("datafile", "compression error %d", Result);
@@ -689,17 +708,17 @@ int CDataFileWriter::AddData(int Size, void *pData)
 	free(pCompData);
 
 	m_NumDatas++;
-	return m_NumDatas-1;
+	return m_NumDatas - 1;
 }
 
 int CDataFileWriter::AddDataSwapped(int Size, void *pData)
 {
-	dbg_assert(Size%sizeof(int) == 0, "incorrect boundary");
+	dbg_assert(Size % sizeof(int) == 0, "incorrect boundary");
 
 #if defined(CONF_ARCH_ENDIAN_BIG)
 	void *pSwapped = malloc(Size); // temporary buffer that we use during compression
 	mem_copy(pSwapped, pData, Size);
-	swap_endian(pSwapped, sizeof(int), Size/sizeof(int));
+	swap_endian(pSwapped, sizeof(int), Size / sizeof(int));
 	int Index = AddData(Size, pSwapped);
 	free(pSwapped);
 	return Index;
@@ -708,10 +727,10 @@ int CDataFileWriter::AddDataSwapped(int Size, void *pData)
 #endif
 }
 
-
 int CDataFileWriter::Finish()
 {
-	if(!m_File) return 1;
+	if(!m_File)
+		return 1;
 
 	int ItemSize = 0;
 	int TypesSize, HeaderSize, OffsetSize, FileSize, SwapSize;
@@ -730,12 +749,11 @@ int CDataFileWriter::Finish()
 		ItemSize += m_pItems[i].m_Size + sizeof(CDatafileItem);
 	}
 
-
 	for(int i = 0; i < m_NumDatas; i++)
 		DataSize += m_pDatas[i].m_CompressedSize;
 
 	// calculate the complete size
-	TypesSize = m_NumItemTypes*sizeof(CDatafileItemType);
+	TypesSize = m_NumItemTypes * sizeof(CDatafileItemType);
 	HeaderSize = sizeof(CDatafileHeader);
 	OffsetSize = (m_NumItems + m_NumDatas + m_NumDatas) * sizeof(int); // ItemOffsets, DataOffsets, DataUncompressedSizes
 	FileSize = HeaderSize + TypesSize + OffsetSize + ItemSize + DataSize;
@@ -765,7 +783,7 @@ int CDataFileWriter::Finish()
 		if(DEBUG)
 			dbg_msg("datafile", "HeaderSize=%d", (int)sizeof(Header));
 #if defined(CONF_ARCH_ENDIAN_BIG)
-		swap_endian(&Header, sizeof(int), sizeof(Header)/sizeof(int));
+		swap_endian(&Header, sizeof(int), sizeof(Header) / sizeof(int));
 #endif
 		io_write(m_File, &Header, sizeof(Header));
 	}
@@ -783,7 +801,7 @@ int CDataFileWriter::Finish()
 			if(DEBUG)
 				dbg_msg("datafile", "writing type=%x start=%d num=%d", Info.m_Type, Info.m_Start, Info.m_Num);
 #if defined(CONF_ARCH_ENDIAN_BIG)
-			swap_endian(&Info, sizeof(int), sizeof(CDatafileItemType)/sizeof(int));
+			swap_endian(&Info, sizeof(int), sizeof(CDatafileItemType) / sizeof(int));
 #endif
 			io_write(m_File, &Info, sizeof(Info));
 			Count += m_pItemTypes[i].m_Num;
@@ -803,7 +821,7 @@ int CDataFileWriter::Finish()
 					dbg_msg("datafile", "writing item offset num=%d offset=%d", k, Offset);
 				int Temp = Offset;
 #if defined(CONF_ARCH_ENDIAN_BIG)
-				swap_endian(&Temp, sizeof(int), sizeof(Temp)/sizeof(int));
+				swap_endian(&Temp, sizeof(int), sizeof(Temp) / sizeof(int));
 #endif
 				io_write(m_File, &Temp, sizeof(Temp));
 				Offset += m_pItems[k].m_Size + sizeof(CDatafileItem);
@@ -821,7 +839,7 @@ int CDataFileWriter::Finish()
 			dbg_msg("datafile", "writing data offset num=%d offset=%d", i, Offset);
 		int Temp = Offset;
 #if defined(CONF_ARCH_ENDIAN_BIG)
-		swap_endian(&Temp, sizeof(int), sizeof(Temp)/sizeof(int));
+		swap_endian(&Temp, sizeof(int), sizeof(Temp) / sizeof(int));
 #endif
 		io_write(m_File, &Temp, sizeof(Temp));
 		Offset += m_pDatas[i].m_CompressedSize;
@@ -834,7 +852,7 @@ int CDataFileWriter::Finish()
 			dbg_msg("datafile", "writing data uncompressed size num=%d size=%d", i, m_pDatas[i].m_UncompressedSize);
 		int UncompressedSize = m_pDatas[i].m_UncompressedSize;
 #if defined(CONF_ARCH_ENDIAN_BIG)
-		swap_endian(&UncompressedSize, sizeof(int), sizeof(UncompressedSize)/sizeof(int));
+		swap_endian(&UncompressedSize, sizeof(int), sizeof(UncompressedSize) / sizeof(int));
 #endif
 		io_write(m_File, &UncompressedSize, sizeof(UncompressedSize));
 	}
@@ -849,14 +867,14 @@ int CDataFileWriter::Finish()
 			while(k != -1)
 			{
 				CDatafileItem Item;
-				Item.m_TypeAndID = (i<<16)|m_pItems[k].m_ID;
+				Item.m_TypeAndID = (i << 16) | m_pItems[k].m_ID;
 				Item.m_Size = m_pItems[k].m_Size;
 				if(DEBUG)
 					dbg_msg("datafile", "writing item type=%x idx=%d id=%d size=%d", i, k, m_pItems[k].m_ID, m_pItems[k].m_Size);
 
 #if defined(CONF_ARCH_ENDIAN_BIG)
-				swap_endian(&Item, sizeof(int), sizeof(Item)/sizeof(int));
-				swap_endian(m_pItems[k].m_pData, sizeof(int), m_pItems[k].m_Size/sizeof(int));
+				swap_endian(&Item, sizeof(int), sizeof(Item) / sizeof(int));
+				swap_endian(m_pItems[k].m_pData, sizeof(int), m_pItems[k].m_Size / sizeof(int));
 #endif
 				io_write(m_File, &Item, sizeof(Item));
 				io_write(m_File, m_pItems[k].m_pData, m_pItems[k].m_Size);
