@@ -6,24 +6,25 @@
 
 #include <base/color.h>
 #include <engine/graphics.h>
+#include <stdint.h>
 
 enum
 {
-	TEXTFLAG_RENDER=1,
-	TEXTFLAG_ALLOW_NEWLINE=2,
-	TEXTFLAG_STOP_AT_END=4
+	TEXTFLAG_RENDER = 1,
+	TEXTFLAG_ALLOW_NEWLINE = 2,
+	TEXTFLAG_STOP_AT_END = 4
 };
 
 enum ETextRenderFlags
 {
-	TEXT_RENDER_FLAG_NO_X_BEARING = 1<<0,
-	TEXT_RENDER_FLAG_NO_Y_BEARING = 1<<1,
-	TEXT_RENDER_FLAG_ONLY_ADVANCE_WIDTH = 1<<2,
-	TEXT_RENDER_FLAG_NO_PIXEL_ALIGMENT = 1<<3,
-	TEXT_RENDER_FLAG_KERNING = 1<<4,
-	TEXT_RENDER_FLAG_NO_OVERSIZE = 1<<5,
-	TEXT_RENDER_FLAG_NO_FIRST_CHARACTER_X_BEARING = 1<<6,
-	TEXT_RENDER_FLAG_NO_LAST_CHARACTER_ADVANCE = 1<<7,
+	TEXT_RENDER_FLAG_NO_X_BEARING = 1 << 0,
+	TEXT_RENDER_FLAG_NO_Y_BEARING = 1 << 1,
+	TEXT_RENDER_FLAG_ONLY_ADVANCE_WIDTH = 1 << 2,
+	TEXT_RENDER_FLAG_NO_PIXEL_ALIGMENT = 1 << 3,
+	TEXT_RENDER_FLAG_KERNING = 1 << 4,
+	TEXT_RENDER_FLAG_NO_OVERSIZE = 1 << 5,
+	TEXT_RENDER_FLAG_NO_FIRST_CHARACTER_X_BEARING = 1 << 6,
+	TEXT_RENDER_FLAG_NO_LAST_CHARACTER_ADVANCE = 1 << 7,
 };
 
 enum
@@ -38,6 +39,7 @@ class CTextCursor
 public:
 	int m_Flags;
 	int m_LineCount;
+	int m_GlyphCount;
 	int m_CharCount;
 	int m_MaxLines;
 
@@ -76,10 +78,10 @@ class ITextRender : public IInterface
 public:
 	virtual void SetCursor(CTextCursor *pCursor, float x, float y, float FontSize, int Flags) = 0;
 
-	virtual CFont *LoadFont(const char *pFilename) = 0;
+	virtual CFont *LoadFont(const char *pFilename, const unsigned char *pBuf, size_t Size) = 0;
+	virtual bool LoadFallbackFont(CFont *pFont, const char *pFilename, const unsigned char *pBuf, size_t Size) = 0;
 	virtual CFont *GetFont(int FontIndex) = 0;
 	virtual CFont *GetFont(const char *pFilename) = 0;
-	virtual void DestroyFont(CFont *pFont) = 0;
 
 	virtual void SetDefaultFont(CFont *pFont) = 0;
 	virtual void SetCurFont(CFont *pFont) = 0;
@@ -99,16 +101,16 @@ public:
 	virtual void RenderTextContainer(int TextContainerIndex, STextRenderColor *pTextColor, STextRenderColor *pTextOutlineColor) = 0;
 	virtual void RenderTextContainer(int TextContainerIndex, STextRenderColor *pTextColor, STextRenderColor *pTextOutlineColor, float X, float Y) = 0;
 
-	virtual void UploadEntityLayerText(IGraphics::CTextureHandle Texture, const char *pText, int Length, float x, float y, int FontHeight) = 0;
-	virtual int AdjustFontSize(const char *pText, int TextLength, int MaxSize = -1) = 0;
+	virtual void UploadEntityLayerText(void *pTexBuff, int ImageColorChannelCount, int TexWidth, int TexHeight, int TexSubWidth, int TexSubHeight, const char *pText, int Length, float x, float y, int FontHeight) = 0;
+	virtual int AdjustFontSize(const char *pText, int TextLength, int MaxSize, int MaxWidth) = 0;
 	virtual int CalculateTextWidth(const char *pText, int TextLength, int FontWidth, int FontHeight) = 0;
 
 	// old foolish interface
 	virtual void TextColor(float r, float g, float b, float a) = 0;
 	virtual void TextColor(ColorRGBA rgb) = 0;
 	virtual void TextOutlineColor(float r, float g, float b, float a) = 0;
-	virtual void Text(void *pFontSetV, float x, float y, float Size, const char *pText, int MaxWidth) = 0;
-	virtual float TextWidth(void *pFontSetV, float Size, const char *pText, int Length, float *pAlignedHeight = NULL) = 0;
+	virtual void Text(void *pFontSetV, float x, float y, float Size, const char *pText, float LineWidth) = 0;
+	virtual float TextWidth(void *pFontSetV, float Size, const char *pText, int StrLength, float LineWidth, float *pAlignedHeight = NULL) = 0;
 	virtual int TextLineCount(void *pFontSetV, float Size, const char *pText, float LineWidth) = 0;
 
 	virtual void OnWindowResize() = 0;
