@@ -1,8 +1,8 @@
 /* (c) Magnus Auvinen. See licence.txt in the root of the distribution for more information. */
 /* If you are missing that file, acquire a complete release at teeworlds.com.                */
+#include "binds.h"
 #include <engine/config.h>
 #include <engine/shared/config.h>
-#include "binds.h"
 
 bool CBinds::CBindsSpecial::OnInput(IInput::CEvent Event)
 {
@@ -12,10 +12,10 @@ bool CBinds::CBindsSpecial::OnInput(IInput::CEvent Event)
 		int Mask = m_pBinds->GetModifierMask(Input());
 
 		bool ret = false;
-		for(int Mod = 0; Mod < MODIFIER_COUNT; Mod++)
+		for(int Mod = 0; Mod < MODIFIER_COMBINATION_COUNT; Mod++)
 		{
-			if(Mask&(1 << Mod) && m_pBinds->m_aapKeyBindings[Mod][Event.m_Key])
-				m_pBinds->GetConsole()->ExecuteLineStroked(Event.m_Flags&IInput::FLAG_PRESS, m_pBinds->m_aapKeyBindings[Mod][Event.m_Key]);
+			if(Mask & (1 << Mod) && m_pBinds->m_aapKeyBindings[Mod][Event.m_Key])
+				m_pBinds->GetConsole()->ExecuteLineStroked(Event.m_Flags & IInput::FLAG_PRESS, m_pBinds->m_aapKeyBindings[Mod][Event.m_Key]);
 			ret = true;
 		}
 		return ret;
@@ -33,7 +33,7 @@ CBinds::CBinds()
 CBinds::~CBinds()
 {
 	for(int i = 0; i < KEY_LAST; i++)
-		for(int j = 0; j < MODIFIER_COUNT; j++)
+		for(int j = 0; j < MODIFIER_COMBINATION_COUNT; j++)
 			if(m_aapKeyBindings[j][i])
 				free(m_aapKeyBindings[j][i]);
 }
@@ -59,17 +59,14 @@ void CBinds::Bind(int KeyID, const char *pStr, bool FreeOnly, int Modifier)
 	char aBuf[256];
 	if(!pStr[0])
 	{
-		str_format(aBuf, sizeof(aBuf), "unbound %s (%d)", Input()->KeyName(KeyID), KeyID);
+		str_format(aBuf, sizeof(aBuf), "unbound %s%s (%d)", GetKeyBindModifiersName(Modifier), Input()->KeyName(KeyID), KeyID);
 	}
 	else
 	{
 		int Size = str_length(pStr) + 1;
 		m_aapKeyBindings[Modifier][KeyID] = (char *)malloc(Size);
 		str_copy(m_aapKeyBindings[Modifier][KeyID], pStr, Size);
-		if(Modifier)
-			str_format(aBuf, sizeof(aBuf), "bound %s+%s (%d) = %s", GetModifierName(Modifier), Input()->KeyName(KeyID), KeyID, m_aapKeyBindings[Modifier][KeyID]);
-		else
-			str_format(aBuf, sizeof(aBuf), "bound %s (%d) = %s", Input()->KeyName(KeyID), KeyID, m_aapKeyBindings[Modifier][KeyID]);
+		str_format(aBuf, sizeof(aBuf), "bound %s%s (%d) = %s", GetKeyBindModifiersName(Modifier), Input()->KeyName(KeyID), KeyID, m_aapKeyBindings[Modifier][KeyID]);
 	}
 	Console()->Print(IConsole::OUTPUT_LEVEL_STANDARD, "binds", aBuf);
 }
@@ -133,31 +130,26 @@ bool CBinds::OnInput(IInput::CEvent e)
 	if(!Mask)
 		Mask = 1 << MODIFIER_NONE;
 
-	if(Mask == ((1 << MODIFIER_CTRL) | (1 << MODIFIER_SHIFT)))
-	{
-		if(m_aapKeyBindings[0][e.m_Key] && e.m_Flags&IInput::FLAG_RELEASE)
-			Console()->ExecuteLineStroked(0, m_aapKeyBindings[0][e.m_Key]);
-		return true;
-	}
-
 	bool ret = false;
-	for(int Mod = 1; Mod < MODIFIER_COUNT; Mod++)
+	for(int Mod = 1; Mod < MODIFIER_COMBINATION_COUNT; Mod++)
 	{
-		if(m_aapKeyBindings[Mod][e.m_Key] && Mask & (1 << Mod))	// always trigger +xxx binds despite any modifier
+		if(m_aapKeyBindings[Mod][e.m_Key] && (Mask == Mod))
 		{
-			if(e.m_Flags&IInput::FLAG_PRESS)
+			if(e.m_Flags & IInput::FLAG_PRESS)
 				Console()->ExecuteLineStroked(1, m_aapKeyBindings[Mod][e.m_Key]);
-			if(e.m_Flags&IInput::FLAG_RELEASE)
+			if(e.m_Flags & IInput::FLAG_RELEASE)
 				Console()->ExecuteLineStroked(0, m_aapKeyBindings[Mod][e.m_Key]);
 			ret = true;
 		}
 	}
 
+	// Shift for emoticons works while moving through map
 	if(m_aapKeyBindings[0][e.m_Key] && (!ret || m_aapKeyBindings[0][e.m_Key][0] == '+'))
 	{
-		if(e.m_Flags&IInput::FLAG_PRESS)
+		// When ctrl+shift are pressed (ctrl+shift binds and also the hard-coded ctrl+shift+d, ctrl+shift+g, ctrl+shift+e), ignore other +xxx binds
+		if(e.m_Flags & IInput::FLAG_PRESS && Mask != ((1 << MODIFIER_CTRL) | (1 << MODIFIER_SHIFT)))
 			Console()->ExecuteLineStroked(1, m_aapKeyBindings[0][e.m_Key]);
-		if(e.m_Flags&IInput::FLAG_RELEASE)
+		if(e.m_Flags & IInput::FLAG_RELEASE)
 			Console()->ExecuteLineStroked(0, m_aapKeyBindings[0][e.m_Key]);
 		ret = true;
 	}
@@ -167,7 +159,7 @@ bool CBinds::OnInput(IInput::CEvent e)
 
 void CBinds::UnbindAll()
 {
-	for(int i = 0; i < MODIFIER_COUNT; i++)
+	for(int i = 0; i < MODIFIER_COMBINATION_COUNT; i++)
 	{
 		for(int j = 0; j < KEY_LAST; j++)
 		{
@@ -188,7 +180,7 @@ const char *CBinds::Get(int KeyID, int Modifier)
 void CBinds::GetKey(const char *pBindStr, char *aBuf, unsigned BufSize)
 {
 	aBuf[0] = 0;
-	for(int Mod = 0; Mod < MODIFIER_COUNT; Mod++)
+	for(int Mod = 0; Mod < MODIFIER_COMBINATION_COUNT; Mod++)
 	{
 		for(int KeyId = 0; KeyId < KEY_LAST; KeyId++)
 		{
@@ -196,7 +188,8 @@ void CBinds::GetKey(const char *pBindStr, char *aBuf, unsigned BufSize)
 			if(!pBind[0])
 				continue;
 
-			if(str_comp(pBind, pBindStr) == 0){
+			if(str_comp(pBind, pBindStr) == 0)
+			{
 				if(Mod)
 					str_format(aBuf, BufSize, "%s+%s", GetModifierName(Mod), Input()->KeyName(KeyId));
 				else
@@ -251,9 +244,8 @@ void CBinds::SetDefaults()
 	Bind(KEY_P, "say /pause");
 
 	// DDRace
-
-	if(g_Config.m_ClDDRaceBinds)
-		SetDDRaceBinds(false);
+	g_Config.m_ClDDRaceBindsSet = 0;
+	SetDDRaceBinds(false);
 }
 
 void CBinds::OnConsoleInit()
@@ -300,14 +292,14 @@ void CBinds::ConDumpBinds(IConsole::IResult *pResult, void *pUserData)
 
 		int Modifier;
 		int id = pBinds->GetBindSlot(pKeyName, &Modifier);
-		if (!id)
+		if(!id)
 		{
 			str_format(aBuf, sizeof(aBuf), "key '%s' not found", pKeyName);
 			pBinds->Console()->Print(IConsole::OUTPUT_LEVEL_STANDARD, "binds", aBuf);
 		}
 		else
 		{
-			if (!pBinds->m_aapKeyBindings[Modifier][id])
+			if(!pBinds->m_aapKeyBindings[Modifier][id])
 				str_format(aBuf, sizeof(aBuf), "%s (%d) is not bound", pKeyName, id);
 			else
 				str_format(aBuf, sizeof(aBuf), "%s (%d) = %s", pKeyName, id, pBinds->m_aapKeyBindings[Modifier][id]);
@@ -318,16 +310,14 @@ void CBinds::ConDumpBinds(IConsole::IResult *pResult, void *pUserData)
 	else if(pResult->NumArguments() == 0)
 	{
 		char aBuf[1024];
-		for(int i = 0; i < MODIFIER_COUNT; i++)
+		for(int i = 0; i < MODIFIER_COMBINATION_COUNT; i++)
 		{
 			for(int j = 0; j < KEY_LAST; j++)
 			{
 				if(!pBinds->m_aapKeyBindings[i][j])
 					continue;
-				if(i)
-					str_format(aBuf, sizeof(aBuf), "%s+%s (%d) = %s", pBinds->GetModifierName(i), pBinds->Input()->KeyName(j), j, pBinds->m_aapKeyBindings[i][j]);
-				else
-					str_format(aBuf, sizeof(aBuf), "%s (%d) = %s", pBinds->Input()->KeyName(j), j, pBinds->m_aapKeyBindings[i][j]);
+
+				str_format(aBuf, sizeof(aBuf), "%s%s (%d) = %s", GetKeyBindModifiersName(i), pBinds->Input()->KeyName(j), j, pBinds->m_aapKeyBindings[i][j]);
 				pBinds->Console()->Print(IConsole::OUTPUT_LEVEL_STANDARD, "binds", aBuf);
 			}
 		}
@@ -363,7 +353,7 @@ int CBinds::GetKeyID(const char *pKeyName)
 	// check for numeric
 	if(pKeyName[0] == '&')
 	{
-		int i = str_toint(pKeyName+1);
+		int i = str_toint(pKeyName + 1);
 		if(i > 0 && i < KEY_LAST)
 			return i; // numeric
 	}
@@ -381,20 +371,25 @@ int CBinds::GetKeyID(const char *pKeyName)
 int CBinds::GetBindSlot(const char *pBindString, int *Mod)
 {
 	*Mod = MODIFIER_NONE;
-	char aMod[32] = { 0 };
+	char aMod[32];
+	aMod[0] = '\0';
 	const char *pKey = str_next_token(pBindString, "+", aMod, sizeof(aMod));
-	if(aMod[0] && *(pKey))
+	while(aMod[0] && *(pKey))
 	{
 		if(!str_comp(aMod, "shift"))
-			*Mod = MODIFIER_SHIFT;
+			*Mod |= (1 << MODIFIER_SHIFT);
 		else if(!str_comp(aMod, "ctrl"))
-			*Mod = MODIFIER_CTRL;
+			*Mod |= (1 << MODIFIER_CTRL);
 		else if(!str_comp(aMod, "alt"))
-			*Mod = MODIFIER_ALT;
+			*Mod |= (1 << MODIFIER_ALT);
 		else
 			return 0;
-	}
 
+		if(str_find(pKey + 1, "+"))
+			pKey = str_next_token(pKey + 1, "+", aMod, sizeof(aMod));
+		else
+			break;
+	}
 	return GetKeyID(*Mod == MODIFIER_NONE ? aMod : pKey + 1);
 }
 
@@ -414,24 +409,36 @@ const char *CBinds::GetModifierName(int Modifier)
 	}
 }
 
+const char *CBinds::GetKeyBindModifiersName(int Modifier)
+{
+	static char aModifier[256];
+	aModifier[0] = '\0';
+	for(int k = 1; k < MODIFIER_COUNT; k++)
+	{
+		if(Modifier & (1 << k))
+		{
+			str_append(aModifier, GetModifierName(k), sizeof(aModifier));
+			str_append(aModifier, "+", sizeof(aModifier));
+		}
+	}
+	return aModifier;
+}
+
 void CBinds::ConfigSaveCallback(IConfig *pConfig, void *pUserData)
 {
 	CBinds *pSelf = (CBinds *)pUserData;
 
 	char aBuffer[256];
-	char *pEnd = aBuffer+sizeof(aBuffer);
+	char *pEnd = aBuffer + sizeof(aBuffer);
 	pConfig->WriteLine("unbindall");
-	for(int i = 0; i < MODIFIER_COUNT; i++)
+	for(int i = 0; i < MODIFIER_COMBINATION_COUNT; i++)
 	{
 		for(int j = 0; j < KEY_LAST; j++)
 		{
 			if(!pSelf->m_aapKeyBindings[i][j])
 				continue;
-			if(i)
-				str_format(aBuffer, sizeof(aBuffer), "bind %s+%s \"", pSelf->GetModifierName(i), pSelf->Input()->KeyName(j));
-			else
-				str_format(aBuffer, sizeof(aBuffer), "bind %s \"", pSelf->Input()->KeyName(j));
 
+			str_format(aBuffer, sizeof(aBuffer), "bind %s%s \"", GetKeyBindModifiersName(i), pSelf->Input()->KeyName(j));
 			// process the string. we need to escape some characters
 			char *pDst = aBuffer + str_length(aBuffer);
 			str_escape(&pDst, pSelf->m_aapKeyBindings[i][j], pEnd);
@@ -446,34 +453,37 @@ void CBinds::ConfigSaveCallback(IConfig *pConfig, void *pUserData)
 
 void CBinds::SetDDRaceBinds(bool FreeOnly)
 {
-	Bind(KEY_KP_PLUS, "zoom+", FreeOnly);
-	Bind(KEY_KP_MINUS, "zoom-", FreeOnly);
-	Bind(KEY_KP_MULTIPLY, "zoom", FreeOnly);
-	Bind(KEY_PAUSE, "say /pause", FreeOnly);
-	Bind(KEY_UP, "+jump", FreeOnly);
-	Bind(KEY_LEFT, "+left", FreeOnly);
-	Bind(KEY_RIGHT, "+right", FreeOnly);
-	Bind(KEY_LEFTBRACKET, "+prevweapon", FreeOnly);
-	Bind(KEY_RIGHTBRACKET, "+nextweapon", FreeOnly);
-	Bind(KEY_C, "say /rank", FreeOnly);
-	Bind(KEY_V, "say /info", FreeOnly);
-	Bind(KEY_B, "say /top5", FreeOnly);
-	Bind(KEY_X, "emote 14", FreeOnly);
-	Bind(KEY_H, "emote 2", FreeOnly);
-	Bind(KEY_M, "emote 5", FreeOnly);
-	Bind(KEY_S, "+showhookcoll", FreeOnly);
-	Bind(KEY_X, "toggle cl_dummy 0 1", FreeOnly);
-	Bind(KEY_PAGEDOWN, "toggle cl_show_quads 0 1", FreeOnly);
-	Bind(KEY_PAGEUP, "toggle cl_overlay_entities 0 100", FreeOnly);
-	Bind(KEY_KP_0, "say /emote normal 999999", FreeOnly);
-	Bind(KEY_KP_1, "say /emote happy 999999", FreeOnly);
-	Bind(KEY_KP_2, "say /emote angry 999999", FreeOnly);
-	Bind(KEY_KP_3, "say /emote pain 999999", FreeOnly);
-	Bind(KEY_KP_4, "say /emote surprise 999999", FreeOnly);
-	Bind(KEY_KP_5, "say /emote blink 999999", FreeOnly);
-	Bind(KEY_MOUSE_3, "+spectate", FreeOnly);
-	Bind(KEY_MINUS, "spectate_previous", FreeOnly);
-	Bind(KEY_EQUALS, "spectate_next", FreeOnly);
+	if(g_Config.m_ClDDRaceBindsSet < 1)
+	{
+		Bind(KEY_KP_PLUS, "zoom+", FreeOnly);
+		Bind(KEY_KP_MINUS, "zoom-", FreeOnly);
+		Bind(KEY_KP_MULTIPLY, "zoom", FreeOnly);
+		Bind(KEY_PAUSE, "say /pause", FreeOnly);
+		Bind(KEY_UP, "+jump", FreeOnly);
+		Bind(KEY_LEFT, "+left", FreeOnly);
+		Bind(KEY_RIGHT, "+right", FreeOnly);
+		Bind(KEY_LEFTBRACKET, "+prevweapon", FreeOnly);
+		Bind(KEY_RIGHTBRACKET, "+nextweapon", FreeOnly);
+		Bind(KEY_C, "say /rank", FreeOnly);
+		Bind(KEY_V, "say /info", FreeOnly);
+		Bind(KEY_B, "say /top5", FreeOnly);
+		Bind(KEY_X, "emote 14", FreeOnly);
+		Bind(KEY_H, "emote 2", FreeOnly);
+		Bind(KEY_M, "emote 5", FreeOnly);
+		Bind(KEY_S, "+showhookcoll", FreeOnly);
+		Bind(KEY_X, "toggle cl_dummy 0 1", FreeOnly);
+		Bind(KEY_PAGEDOWN, "toggle cl_show_quads 0 1", FreeOnly);
+		Bind(KEY_PAGEUP, "toggle cl_overlay_entities 0 100", FreeOnly);
+		Bind(KEY_KP_0, "say /emote normal 999999", FreeOnly);
+		Bind(KEY_KP_1, "say /emote happy 999999", FreeOnly);
+		Bind(KEY_KP_2, "say /emote angry 999999", FreeOnly);
+		Bind(KEY_KP_3, "say /emote pain 999999", FreeOnly);
+		Bind(KEY_KP_4, "say /emote surprise 999999", FreeOnly);
+		Bind(KEY_KP_5, "say /emote blink 999999", FreeOnly);
+		Bind(KEY_MOUSE_3, "+spectate", FreeOnly);
+		Bind(KEY_MINUS, "spectate_previous", FreeOnly);
+		Bind(KEY_EQUALS, "spectate_next", FreeOnly);
+	}
 
 	g_Config.m_ClDDRaceBindsSet = 1;
 }
