@@ -6,28 +6,93 @@
 #include <engine/shared/config.h>
 
 #include <base/math.h>
-#include <game/collision.h>
-#include <game/client/gameclient.h>
 #include <game/client/component.h>
+#include <game/client/gameclient.h>
+#include <game/collision.h>
 
 #include "camera.h"
 #include "controls.h"
 
 #include <engine/serverbrowser.h>
 
+const float ZoomStep = 0.866025f;
+
 CCamera::CCamera()
 {
 	m_CamType = CAMTYPE_UNDEFINED;
 	m_ZoomSet = false;
 	m_Zoom = 1.0f;
+	m_Zooming = false;
+}
+
+float CCamera::ZoomProgress(float CurrentTime) const
+{
+	return (CurrentTime - m_ZoomSmoothingStart) / (m_ZoomSmoothingEnd - m_ZoomSmoothingStart);
+}
+
+void CCamera::ScaleZoom(float Factor)
+{
+	float CurrentTarget = m_Zooming ? m_ZoomSmoothingTarget : m_Zoom;
+	ChangeZoom(CurrentTarget * Factor);
+}
+
+float CCamera::MaxZoomLevel()
+{
+	return (Graphics()->IsTileBufferingEnabled() ? 60 : 30);
+}
+
+float CCamera::MinZoomLevel()
+{
+	return 0.01f;
+}
+
+void CCamera::ChangeZoom(float Target)
+{
+	if(Target > MaxZoomLevel() || Target < MinZoomLevel())
+	{
+		return;
+	}
+
+	float Now = Client()->LocalTime();
+	float Current = m_Zoom;
+	float Derivative = 0.0f;
+	if(m_Zooming)
+	{
+		float Progress = ZoomProgress(Now);
+		Current = m_ZoomSmoothing.Evaluate(Progress);
+		Derivative = m_ZoomSmoothing.Derivative(Progress);
+	}
+
+	m_ZoomSmoothingTarget = Target;
+	m_ZoomSmoothing = CCubicBezier::With(Current, Derivative, 0, m_ZoomSmoothingTarget);
+	m_ZoomSmoothingStart = Now;
+	m_ZoomSmoothingEnd = Now + (float)g_Config.m_ClSmoothZoomTime / 1000;
+
+	m_Zooming = true;
 }
 
 void CCamera::OnRender()
 {
+	if(m_Zooming)
+	{
+		float Time = Client()->LocalTime();
+		if(Time >= m_ZoomSmoothingEnd)
+		{
+			m_Zoom = m_ZoomSmoothingTarget;
+			m_Zooming = false;
+		}
+		else
+		{
+			m_Zoom = m_ZoomSmoothing.Evaluate(ZoomProgress(Time));
+		}
+		m_Zoom = clamp(m_Zoom, MinZoomLevel(), MaxZoomLevel());
+	}
+
 	if(!(m_pClient->m_Snap.m_SpecInfo.m_Active || GameClient()->m_GameInfo.m_AllowZoom || Client()->State() == IClient::STATE_DEMOPLAYBACK))
 	{
 		m_ZoomSet = false;
 		m_Zoom = 1.0f;
+		m_Zooming = false;
 	}
 	else if(!m_ZoomSet && g_Config.m_ClDefaultZoom != 10)
 	{
@@ -66,9 +131,9 @@ void CCamera::OnRender()
 		{
 			float DeadZone = g_Config.m_ClDyncam ? g_Config.m_ClDyncamDeadzone : g_Config.m_ClMouseDeadzone;
 			float FollowFactor = (g_Config.m_ClDyncam ? g_Config.m_ClDyncamFollowFactor : g_Config.m_ClMouseFollowfactor) / 100.0f;
-			float OffsetAmount = maximum(l-DeadZone, 0.0f) * FollowFactor;
+			float OffsetAmount = maximum(l - DeadZone, 0.0f) * FollowFactor;
 
-			CameraOffset = normalize(m_pClient->m_pControls->m_MousePos[g_Config.m_ClDummy])*OffsetAmount;
+			CameraOffset = normalize(m_pClient->m_pControls->m_MousePos[g_Config.m_ClDummy]) * OffsetAmount;
 		}
 
 		if(m_pClient->m_Snap.m_SpecInfo.m_Active)
@@ -87,41 +152,29 @@ void CCamera::OnConsoleInit()
 	Console()->Register("zoom", "", CFGFLAG_CLIENT, ConZoomReset, this, "Zoom reset");
 }
 
-const float ZoomStep = 0.866025f;
-
 void CCamera::OnReset()
 {
-	m_Zoom = 1.0f;
-
-	if(g_Config.m_ClDefaultZoom < 10)
-	{
-		m_Zoom = pow(1/ZoomStep, 10 - g_Config.m_ClDefaultZoom);
-	}
-	else if(g_Config.m_ClDefaultZoom > 10)
-	{
-		m_Zoom = pow(ZoomStep, g_Config.m_ClDefaultZoom - 10);
-	}
-
+	m_Zoom = pow(ZoomStep, g_Config.m_ClDefaultZoom - 10);
+	m_Zooming = false;
 }
 
 void CCamera::ConZoomPlus(IConsole::IResult *pResult, void *pUserData)
 {
 	CCamera *pSelf = (CCamera *)pUserData;
 	if(pSelf->m_pClient->m_Snap.m_SpecInfo.m_Active || pSelf->GameClient()->m_GameInfo.m_AllowZoom || pSelf->Client()->State() == IClient::STATE_DEMOPLAYBACK)
-		((CCamera *)pUserData)->m_Zoom *= ZoomStep;
+	{
+		pSelf->ScaleZoom(ZoomStep);
+	}
 }
 void CCamera::ConZoomMinus(IConsole::IResult *pResult, void *pUserData)
 {
 	CCamera *pSelf = (CCamera *)pUserData;
 	if(pSelf->m_pClient->m_Snap.m_SpecInfo.m_Active || pSelf->GameClient()->m_GameInfo.m_AllowZoom || pSelf->Client()->State() == IClient::STATE_DEMOPLAYBACK)
 	{
-		if(((CCamera *)pUserData)->m_Zoom < 500.0f/ZoomStep)
-		{
-			((CCamera *)pUserData)->m_Zoom *= 1/ZoomStep;
-		}
+		pSelf->ScaleZoom(1 / ZoomStep);
 	}
 }
 void CCamera::ConZoomReset(IConsole::IResult *pResult, void *pUserData)
 {
-	((CCamera *)pUserData)->OnReset();
+	((CCamera *)pUserData)->ChangeZoom(pow(ZoomStep, g_Config.m_ClDefaultZoom - 10));
 }
