@@ -3,15 +3,15 @@
 #include <engine/graphics.h>
 #include <engine/serverbrowser.h>
 #include <engine/shared/config.h>
-#include <game/generated/protocol.h>
 #include <game/generated/client_data.h>
+#include <game/generated/protocol.h>
 
-#include <game/gamecore.h> // get_angle
-#include <game/client/animstate.h>
-#include <game/client/ui.h>
-#include <game/client/render.h>
 #include "chat.h"
 #include "emoticon.h"
+#include <game/client/animstate.h>
+#include <game/client/render.h>
+#include <game/client/ui.h>
+#include <game/gamecore.h> // get_angle
 
 CEmoticon::CEmoticon()
 {
@@ -55,7 +55,7 @@ bool CEmoticon::OnMouseMove(float x, float y)
 		return false;
 
 	UI()->ConvertMouseMove(&x, &y);
-	m_SelectorMouse += vec2(x,y);
+	m_SelectorMouse += vec2(x, y);
 	return true;
 }
 
@@ -64,7 +64,6 @@ void CEmoticon::DrawCircle(float x, float y, float r, int Segments)
 	RenderTools()->DrawCircle(x, y, r, Segments);
 }
 
-
 void CEmoticon::OnRender()
 {
 	if(!m_Active)
@@ -86,20 +85,19 @@ void CEmoticon::OnRender()
 
 	m_WasActive = true;
 
-	if (length(m_SelectorMouse) > 170.0f)
+	if(length(m_SelectorMouse) > 170.0f)
 		m_SelectorMouse = normalize(m_SelectorMouse) * 170.0f;
 
-	float SelectedAngle = GetAngle(m_SelectorMouse) + 2*pi/24;
-	if (SelectedAngle < 0)
-		SelectedAngle += 2*pi;
+	float SelectedAngle = GetAngle(m_SelectorMouse) + 2 * pi / 24;
+	if(SelectedAngle < 0)
+		SelectedAngle += 2 * pi;
 
 	m_SelectedEmote = -1;
 	m_SelectedEyeEmote = -1;
-	if (length(m_SelectorMouse) > 110.0f)
-		m_SelectedEmote = (int)(SelectedAngle / (2*pi) * NUM_EMOTICONS);
+	if(length(m_SelectorMouse) > 110.0f)
+		m_SelectedEmote = (int)(SelectedAngle / (2 * pi) * NUM_EMOTICONS);
 	else if(length(m_SelectorMouse) > 40.0f)
-		m_SelectedEyeEmote = (int)(SelectedAngle / (2*pi) * NUM_EMOTES);
-
+		m_SelectedEyeEmote = (int)(SelectedAngle / (2 * pi) * NUM_EMOTES);
 
 	CUIRect Screen = *UI()->Screen();
 
@@ -109,18 +107,18 @@ void CEmoticon::OnRender()
 
 	Graphics()->TextureClear();
 	Graphics()->QuadsBegin();
-	Graphics()->SetColor(0,0,0,0.3f);
-	DrawCircle(Screen.w/2, Screen.h/2, 190.0f, 64);
+	Graphics()->SetColor(0, 0, 0, 0.3f);
+	DrawCircle(Screen.w / 2, Screen.h / 2, 190.0f, 64);
 	Graphics()->QuadsEnd();
 
 	Graphics()->TextureSet(g_pData->m_aImages[IMAGE_EMOTICONS].m_Id);
 	Graphics()->QuadsBegin();
 
-	for (int i = 0; i < NUM_EMOTICONS; i++)
+	for(int i = 0; i < NUM_EMOTICONS; i++)
 	{
-		float Angle = 2*pi*i/NUM_EMOTICONS;
-		if (Angle > pi)
-			Angle -= 2*pi;
+		float Angle = 2 * pi * i / NUM_EMOTICONS;
+		if(Angle > pi)
+			Angle -= 2 * pi;
 
 		bool Selected = m_SelectedEmote == i;
 
@@ -129,7 +127,7 @@ void CEmoticon::OnRender()
 		float NudgeX = 150.0f * cosf(Angle);
 		float NudgeY = 150.0f * sinf(Angle);
 		RenderTools()->SelectSprite(SPRITE_OOP + i);
-		IGraphics::CQuadItem QuadItem(Screen.w/2 + NudgeX, Screen.h/2 + NudgeY, Size, Size);
+		IGraphics::CQuadItem QuadItem(Screen.w / 2 + NudgeX, Screen.h / 2 + NudgeY, Size, Size);
 		Graphics()->QuadsDraw(&QuadItem, 1);
 	}
 
@@ -139,19 +137,19 @@ void CEmoticon::OnRender()
 	{
 		Graphics()->TextureClear();
 		Graphics()->QuadsBegin();
-		Graphics()->SetColor(1.0,1.0,1.0,0.3f);
-		DrawCircle(Screen.w/2, Screen.h/2, 100.0f, 64);
+		Graphics()->SetColor(1.0, 1.0, 1.0, 0.3f);
+		DrawCircle(Screen.w / 2, Screen.h / 2, 100.0f, 64);
 		Graphics()->QuadsEnd();
 
 		CTeeRenderInfo *pTeeInfo = &m_pClient->m_aClients[m_pClient->m_LocalIDs[g_Config.m_ClDummy]].m_RenderInfo;
 
 		Graphics()->TextureSet(pTeeInfo->m_Texture);
 
-		for (int i = 0; i < NUM_EMOTES; i++)
+		for(int i = 0; i < NUM_EMOTES; i++)
 		{
-			float Angle = 2*pi*i/NUM_EMOTES;
-			if (Angle > pi)
-				Angle -= 2*pi;
+			float Angle = 2 * pi * i / NUM_EMOTES;
+			if(Angle > pi)
+				Angle -= 2 * pi;
 
 			bool Selected = m_SelectedEyeEmote == i;
 
@@ -159,25 +157,27 @@ void CEmoticon::OnRender()
 			float NudgeY = 70.0f * sinf(Angle);
 
 			pTeeInfo->m_Size = Selected ? 64.0f : 48.0f;
-			RenderTools()->RenderTee(CAnimState::GetIdle(), pTeeInfo, i, vec2(-1,0), vec2(Screen.w/2 + NudgeX, Screen.h/2 + NudgeY));
+			RenderTools()->RenderTee(CAnimState::GetIdle(), pTeeInfo, i, vec2(-1, 0), vec2(Screen.w / 2 + NudgeX, Screen.h / 2 + NudgeY));
 			pTeeInfo->m_Size = 64.0f;
 		}
 
 		Graphics()->TextureClear();
 		Graphics()->QuadsBegin();
-		Graphics()->SetColor(0,0,0,0.3f);
-		DrawCircle(Screen.w/2, Screen.h/2, 30.0f, 64);
+		Graphics()->SetColor(0, 0, 0, 0.3f);
+		DrawCircle(Screen.w / 2, Screen.h / 2, 30.0f, 64);
 		Graphics()->QuadsEnd();
 	}
 	else
 		m_SelectedEyeEmote = -1;
 
+	Graphics()->WrapClamp();
 	Graphics()->TextureSet(g_pData->m_aImages[IMAGE_CURSOR].m_Id);
 	Graphics()->QuadsBegin();
-	Graphics()->SetColor(1,1,1,1);
-	IGraphics::CQuadItem QuadItem(m_SelectorMouse.x+Screen.w/2,m_SelectorMouse.y+Screen.h/2,24,24);
+	Graphics()->SetColor(1, 1, 1, 1);
+	IGraphics::CQuadItem QuadItem(m_SelectorMouse.x + Screen.w / 2, m_SelectorMouse.y + Screen.h / 2, 24, 24);
 	Graphics()->QuadsDrawTL(&QuadItem, 1);
 	Graphics()->QuadsEnd();
+	Graphics()->WrapNormal();
 }
 
 void CEmoticon::Emote(int Emoticon)
