@@ -1,14 +1,14 @@
 /* (c) Magnus Auvinen. See licence.txt in the root of the distribution for more information. */
 /* If you are missing that file, acquire a complete release at teeworlds.com.                */
 #include <engine/graphics.h>
-#include <engine/textrender.h>
-#include <game/generated/protocol.h>
-#include <game/generated/client_data.h>
 #include <engine/shared/config.h>
+#include <engine/textrender.h>
+#include <game/generated/client_data.h>
+#include <game/generated/protocol.h>
 
-#include <game/client/gameclient.h>
-#include <game/client/animstate.h>
 #include "killmessages.h"
+#include <game/client/animstate.h>
+#include <game/client/gameclient.h>
 
 void CKillMessages::OnWindowResize()
 {
@@ -25,7 +25,7 @@ void CKillMessages::OnWindowResize()
 void CKillMessages::OnReset()
 {
 	m_KillmsgCurrent = 0;
-	for (int i = 0; i < MAX_KILLMSGS; i++)
+	for(int i = 0; i < MAX_KILLMSGS; i++)
 	{
 		m_aKillmsgs[i].m_Tick = -100000;
 
@@ -35,7 +35,6 @@ void CKillMessages::OnReset()
 		if(m_aKillmsgs[i].m_KillerTextContainerIndex != -1)
 			TextRender()->DeleteTextContainer(m_aKillmsgs[i].m_KillerTextContainerIndex);
 
-
 		m_aKillmsgs[i].m_VictimTextContainerIndex = m_aKillmsgs[i].m_KillerTextContainerIndex = -1;
 	}
 }
@@ -89,15 +88,15 @@ void CKillMessages::OnMessage(int MsgType, void *pRawMsg)
 
 		Kill.m_VitctimTextWidth = Kill.m_KillerTextWidth = 0.f;
 
-		float Width = 400 * 3.0f*Graphics()->ScreenAspect();
+		float Width = 400 * 3.0f * Graphics()->ScreenAspect();
 		float Height = 400 * 3.0f;
 
-		Graphics()->MapScreen(0, 0, Width*1.5f, Height*1.5f);
+		Graphics()->MapScreen(0, 0, Width * 1.5f, Height * 1.5f);
 
 		float FontSize = 36.0f;
 		if(Kill.m_aVictimName[0] != 0)
 		{
-			Kill.m_VitctimTextWidth = TextRender()->TextWidth(0, FontSize, Kill.m_aVictimName, -1);
+			Kill.m_VitctimTextWidth = TextRender()->TextWidth(0, FontSize, Kill.m_aVictimName, -1, -1.0f);
 
 			CTextCursor Cursor;
 			TextRender()->SetCursor(&Cursor, 0, 0, FontSize, TEXTFLAG_RENDER);
@@ -108,7 +107,7 @@ void CKillMessages::OnMessage(int MsgType, void *pRawMsg)
 
 		if(Kill.m_aKillerName[0] != 0)
 		{
-			Kill.m_KillerTextWidth = TextRender()->TextWidth(0, FontSize, Kill.m_aKillerName, -1);
+			Kill.m_KillerTextWidth = TextRender()->TextWidth(0, FontSize, Kill.m_aKillerName, -1, -1.0f);
 
 			CTextCursor Cursor;
 			TextRender()->SetCursor(&Cursor, 0, 0, FontSize, TEXTFLAG_RENDER);
@@ -118,7 +117,7 @@ void CKillMessages::OnMessage(int MsgType, void *pRawMsg)
 		}
 
 		// add the message
-		m_KillmsgCurrent = (m_KillmsgCurrent+1)%MAX_KILLMSGS;
+		m_KillmsgCurrent = (m_KillmsgCurrent + 1) % MAX_KILLMSGS;
 
 		if(m_aKillmsgs[m_KillmsgCurrent].m_VictimTextContainerIndex != -1)
 		{
@@ -141,19 +140,19 @@ void CKillMessages::OnRender()
 	if(!g_Config.m_ClShowKillMessages)
 		return;
 
-	float Width = 400*3.0f*Graphics()->ScreenAspect();
-	float Height = 400*3.0f;
+	float Width = 400 * 3.0f * Graphics()->ScreenAspect();
+	float Height = 400 * 3.0f;
 
-	Graphics()->MapScreen(0, 0, Width*1.5f, Height*1.5f);
+	Graphics()->MapScreen(0, 0, Width * 1.5f, Height * 1.5f);
 	Graphics()->SetColor(1.f, 1.f, 1.f, 1.f);
 
-	float StartX = Width*1.5f-10.0f;
+	float StartX = Width * 1.5f - 10.0f;
 	float y = 30.0f + 100.0f * ((g_Config.m_ClShowfps ? 1 : 0) + g_Config.m_ClShowpred);
 
 	for(int i = 1; i <= MAX_KILLMSGS; i++)
 	{
-		int r = (m_KillmsgCurrent+i)%MAX_KILLMSGS;
-		if(Client()->GameTick(g_Config.m_ClDummy) > m_aKillmsgs[r].m_Tick+50*10)
+		int r = (m_KillmsgCurrent + i) % MAX_KILLMSGS;
+		if(Client()->GameTick(g_Config.m_ClDummy) > m_aKillmsgs[r].m_Tick + 50 * 10)
 			continue;
 
 		float x = StartX;
@@ -175,20 +174,20 @@ void CKillMessages::OnRender()
 		// render victim tee
 		x -= 24.0f;
 
-		if(m_pClient->m_Snap.m_pGameInfoObj && m_pClient->m_Snap.m_pGameInfoObj->m_GameFlags&GAMEFLAG_FLAGS)
+		if(m_pClient->m_Snap.m_pGameInfoObj && m_pClient->m_Snap.m_pGameInfoObj->m_GameFlags & GAMEFLAG_FLAGS)
 		{
-			if(m_aKillmsgs[r].m_ModeSpecial&1)
+			if(m_aKillmsgs[r].m_ModeSpecial & 1)
 			{
 				Graphics()->TextureSet(g_pData->m_aImages[IMAGE_GAME].m_Id);
 				int QuadOffset = 0;
 				if(m_aKillmsgs[r].m_VictimID == m_aKillmsgs[r].m_FlagCarrierBlue)
 					++QuadOffset;
 
-				Graphics()->RenderQuadContainerAsSprite(m_SpriteQuadContainerIndex, QuadOffset, x, y-16);
+				Graphics()->RenderQuadContainerAsSprite(m_SpriteQuadContainerIndex, QuadOffset, x, y - 16);
 			}
 		}
 
-		RenderTools()->RenderTee(CAnimState::GetIdle(), &m_aKillmsgs[r].m_VictimRenderInfo, EMOTE_PAIN, vec2(-1,0), vec2(x, y+28));
+		RenderTools()->RenderTee(CAnimState::GetIdle(), &m_aKillmsgs[r].m_VictimRenderInfo, EMOTE_PAIN, vec2(-1, 0), vec2(x, y + 28));
 		x -= 32.0f;
 
 		// render weapon
@@ -202,9 +201,9 @@ void CKillMessages::OnRender()
 
 		if(m_aKillmsgs[r].m_VictimID != m_aKillmsgs[r].m_KillerID)
 		{
-			if(m_pClient->m_Snap.m_pGameInfoObj && m_pClient->m_Snap.m_pGameInfoObj->m_GameFlags&GAMEFLAG_FLAGS)
+			if(m_pClient->m_Snap.m_pGameInfoObj && m_pClient->m_Snap.m_pGameInfoObj->m_GameFlags & GAMEFLAG_FLAGS)
 			{
-				if(m_aKillmsgs[r].m_ModeSpecial&2)
+				if(m_aKillmsgs[r].m_ModeSpecial & 2)
 				{
 					Graphics()->TextureSet(g_pData->m_aImages[IMAGE_GAME].m_Id);
 
@@ -218,7 +217,7 @@ void CKillMessages::OnRender()
 
 			// render killer tee
 			x -= 24.0f;
-			RenderTools()->RenderTee(CAnimState::GetIdle(), &m_aKillmsgs[r].m_KillerRenderInfo, EMOTE_ANGRY, vec2(1,0), vec2(x, y+28));
+			RenderTools()->RenderTee(CAnimState::GetIdle(), &m_aKillmsgs[r].m_KillerRenderInfo, EMOTE_ANGRY, vec2(1, 0), vec2(x, y + 28));
 			x -= 32.0f;
 
 			// render killer name
