@@ -28,7 +28,7 @@ void CMapSounds::OnMapLoad()
 	{
 		m_aSounds[i] = 0;
 
-		CMapItemSound *pSound = (CMapItemSound *)pMap->GetItem(Start+i, 0, 0);
+		CMapItemSound *pSound = (CMapItemSound *)pMap->GetItem(Start + i, 0, 0);
 		if(pSound->m_External)
 		{
 			char Buf[256];
@@ -55,7 +55,7 @@ void CMapSounds::OnMapLoad()
 
 		for(int l = 0; l < pGroup->m_NumLayers; l++)
 		{
-			CMapItemLayer *pLayer = Layers()->GetLayer(pGroup->m_StartLayer+l);
+			CMapItemLayer *pLayer = Layers()->GetLayer(pGroup->m_StartLayer + l);
 
 			if(!pLayer)
 				continue;
@@ -75,11 +75,12 @@ void CMapSounds::OnMapLoad()
 				if(!pSources)
 					continue;
 
-				for(int i = 0; i < pSoundLayer->m_NumSources; i++) {
+				for(int i = 0; i < pSoundLayer->m_NumSources; i++)
+				{
 					CSourceQueueEntry source;
 					source.m_Sound = pSoundLayer->m_Sound;
 					source.m_pSource = &pSources[i];
-					source.m_HighDetail = pLayer->m_Flags&LAYERFLAG_DETAIL;
+					source.m_HighDetail = pLayer->m_Flags & LAYERFLAG_DETAIL;
 
 					if(!source.m_pSource || source.m_Sound == -1)
 						continue;
@@ -106,11 +107,11 @@ void CMapSounds::OnRender()
 		static float s_Time = 0.0f;
 		if(m_pClient->m_Snap.m_pGameInfoObj) // && !(m_pClient->m_Snap.m_pGameInfoObj->m_GameStateFlags&GAMESTATEFLAG_PAUSED))
 		{
-			s_Time = mix((Client()->PrevGameTick(g_Config.m_ClDummy)-m_pClient->m_Snap.m_pGameInfoObj->m_RoundStartTick) / (float)Client()->GameTickSpeed(),
-								(Client()->GameTick(g_Config.m_ClDummy)-m_pClient->m_Snap.m_pGameInfoObj->m_RoundStartTick) / (float)Client()->GameTickSpeed(),
-								Client()->IntraGameTick(g_Config.m_ClDummy));
+			s_Time = mix((Client()->PrevGameTick(g_Config.m_ClDummy) - m_pClient->m_Snap.m_pGameInfoObj->m_RoundStartTick) / (float)Client()->GameTickSpeed(),
+				(Client()->GameTick(g_Config.m_ClDummy) - m_pClient->m_Snap.m_pGameInfoObj->m_RoundStartTick) / (float)Client()->GameTickSpeed(),
+				Client()->IntraGameTick(g_Config.m_ClDummy));
 		}
-		float Offset = s_Time-pSource->m_pSource->m_TimeDelay;
+		float Offset = s_Time - pSource->m_pSource->m_TimeDelay;
 		if(!DemoPlayerPaused && Offset >= 0.0f && g_Config.m_SndEnable && (g_Config.m_GfxHighDetail || !pSource->m_HighDetail))
 		{
 			if(pSource->m_Voice.IsValid())
@@ -122,25 +123,27 @@ void CMapSounds::OnRender()
 			{
 				// need to enqueue
 				int Flags = 0;
-				if(pSource->m_pSource->m_Loop) Flags |= ISound::FLAG_LOOP;
-				if(!pSource->m_pSource->m_Pan) Flags |= ISound::FLAG_NO_PANNING;
+				if(pSource->m_pSource->m_Loop)
+					Flags |= ISound::FLAG_LOOP;
+				if(!pSource->m_pSource->m_Pan)
+					Flags |= ISound::FLAG_NO_PANNING;
 
 				pSource->m_Voice = m_pClient->m_pSounds->PlaySampleAt(CSounds::CHN_MAPSOUND, m_aSounds[pSource->m_Sound], 1.0f, vec2(fx2f(pSource->m_pSource->m_Position.x), fx2f(pSource->m_pSource->m_Position.y)), Flags);
 				Sound()->SetVoiceTimeOffset(pSource->m_Voice, Offset);
-				Sound()->SetVoiceFalloff(pSource->m_Voice, pSource->m_pSource->m_Falloff/255.0f);
+				Sound()->SetVoiceFalloff(pSource->m_Voice, pSource->m_pSource->m_Falloff / 255.0f);
 				switch(pSource->m_pSource->m_Shape.m_Type)
 				{
 				case CSoundShape::SHAPE_CIRCLE:
-					{
-						Sound()->SetVoiceCircle(pSource->m_Voice, pSource->m_pSource->m_Shape.m_Circle.m_Radius);
-						break;
-					}
+				{
+					Sound()->SetVoiceCircle(pSource->m_Voice, pSource->m_pSource->m_Shape.m_Circle.m_Radius);
+					break;
+				}
 
 				case CSoundShape::SHAPE_RECTANGLE:
-					{
-						Sound()->SetVoiceRectangle(pSource->m_Voice, fx2f(pSource->m_pSource->m_Shape.m_Rectangle.m_Width), fx2f(pSource->m_pSource->m_Shape.m_Rectangle.m_Height));
-						break;
-					}
+				{
+					Sound()->SetVoiceRectangle(pSource->m_Voice, fx2f(pSource->m_pSource->m_Shape.m_Rectangle.m_Width), fx2f(pSource->m_pSource->m_Shape.m_Rectangle.m_Height));
+					break;
+				}
 				};
 			}
 		}
@@ -162,7 +165,7 @@ void CMapSounds::OnRender()
 
 		for(int l = 0; l < pGroup->m_NumLayers; l++)
 		{
-			CMapItemLayer *pLayer = Layers()->GetLayer(pGroup->m_StartLayer+l);
+			CMapItemLayer *pLayer = Layers()->GetLayer(pGroup->m_StartLayer + l);
 
 			if(!pLayer)
 				continue;
@@ -179,7 +182,8 @@ void CMapSounds::OnRender()
 				if(!pSources)
 					continue;
 
-				for(int s = 0; s < pSoundLayer->m_NumSources; s++) {
+				for(int s = 0; s < pSoundLayer->m_NumSources; s++)
+				{
 					for(int i = 0; i < m_lSourceQueue.size(); i++)
 					{
 						CSourceQueueEntry *pVoice = &m_lSourceQueue[i];
@@ -195,25 +199,26 @@ void CMapSounds::OnRender()
 						if(pVoice->m_pSource->m_PosEnv >= 0)
 						{
 							float aChannels[4];
-							CMapLayers::EnvelopeEval(pVoice->m_pSource->m_PosEnvOffset/1000.0f, pVoice->m_pSource->m_PosEnv, aChannels, m_pClient->m_pMapLayersBackGround);
+							CMapLayers::EnvelopeEval(pVoice->m_pSource->m_PosEnvOffset / 1000.0f, pVoice->m_pSource->m_PosEnv, aChannels, m_pClient->m_pMapLayersBackGround);
 							OffsetX = aChannels[0];
 							OffsetY = aChannels[1];
 						}
 
-						float x = fx2f(pVoice->m_pSource->m_Position.x)+OffsetX;
-						float y = fx2f(pVoice->m_pSource->m_Position.y)+OffsetY;
+						float x = fx2f(pVoice->m_pSource->m_Position.x) + OffsetX;
+						float y = fx2f(pVoice->m_pSource->m_Position.y) + OffsetY;
 
-						x += Center.x*(1.0f-pGroup->m_ParallaxX/100.0f);
-						y += Center.y*(1.0f-pGroup->m_ParallaxY/100.0f);
+						x += Center.x * (1.0f - pGroup->m_ParallaxX / 100.0f);
+						y += Center.y * (1.0f - pGroup->m_ParallaxY / 100.0f);
 
-						x -= pGroup->m_OffsetX; y -= pGroup->m_OffsetY;
+						x -= pGroup->m_OffsetX;
+						y -= pGroup->m_OffsetY;
 
 						Sound()->SetVoiceLocation(pVoice->m_Voice, x, y);
 
 						if(pVoice->m_pSource->m_SoundEnv >= 0)
 						{
 							float aChannels[4];
-							CMapLayers::EnvelopeEval(pVoice->m_pSource->m_SoundEnvOffset/1000.0f, pVoice->m_pSource->m_SoundEnv, aChannels, m_pClient->m_pMapLayersBackGround);
+							CMapLayers::EnvelopeEval(pVoice->m_pSource->m_SoundEnvOffset / 1000.0f, pVoice->m_pSource->m_SoundEnv, aChannels, m_pClient->m_pMapLayersBackGround);
 							float Volume = clamp(aChannels[0], 0.0f, 1.0f);
 
 							Sound()->SetVoiceVolume(pVoice->m_Voice, Volume);
