@@ -3,17 +3,25 @@
 #ifndef GAME_CLIENT_COMPONENTS_MENUS_H
 #define GAME_CLIENT_COMPONENTS_MENUS_H
 
-#include <base/vmath.h>
 #include <base/tl/sorted_array.h>
+#include <base/vmath.h>
 
 #include <engine/demo.h>
 #include <engine/friends.h>
 #include <engine/shared/config.h>
+#include <engine/shared/linereader.h>
+#include <game/client/components/mapimages.h>
 
-#include <game/voting.h>
 #include <game/client/component.h>
 #include <game/client/ui.h>
+#include <game/voting.h>
 
+struct CServerProcess
+{
+	PROCESS Process;
+	bool Initialized;
+	CLineReader LineReader;
+};
 
 // compnent to fetch keypresses, override all other input
 class CMenusKeyBinder : public CComponent
@@ -32,19 +40,21 @@ class CMenus : public CComponent
 	static ColorRGBA ms_GuiColor;
 	static ColorRGBA ms_ColorTabbarInactiveOutgame;
 	static ColorRGBA ms_ColorTabbarActiveOutgame;
+	static ColorRGBA ms_ColorTabbarHoverOutgame;
 	static ColorRGBA ms_ColorTabbarInactiveIngame;
 	static ColorRGBA ms_ColorTabbarActiveIngame;
+	static ColorRGBA ms_ColorTabbarHoverIngame;
 	static ColorRGBA ms_ColorTabbarInactive;
 	static ColorRGBA ms_ColorTabbarActive;
+	static ColorRGBA ms_ColorTabbarHover;
 
 	float ButtonColorMul(const void *pID);
 
-
 	int DoButton_DemoPlayer(const void *pID, const char *pText, int Checked, const CUIRect *pRect);
 	int DoButton_Sprite(const void *pID, int ImageID, int SpriteID, int Checked, const CUIRect *pRect, int Corners);
 	int DoButton_Toggle(const void *pID, int Checked, const CUIRect *pRect, bool Active);
-	int DoButton_Menu(const void *pID, const char *pText, int Checked, const CUIRect *pRect);
-	int DoButton_MenuTab(const void *pID, const char *pText, int Checked, const CUIRect *pRect, int Corners);
+	int DoButton_Menu(const void *pID, const char *pText, int Checked, const CUIRect *pRect, const char *pImageName = 0, int Corners = CUI::CORNER_ALL, float r = 5.0f, float FontFactor = 0.0f, vec4 ColorHot = vec4(1.0f, 1.0f, 1.0f, 0.75f), vec4 Color = vec4(1, 1, 1, 0.5f));
+	int DoButton_MenuTab(const void *pID, const char *pText, int Checked, const CUIRect *pRect, int Corners, const ColorRGBA *pDefaultColor = NULL, const ColorRGBA *pActiveColor = NULL, const ColorRGBA *pHoverColor = NULL, float EdgeRounding = 10);
 
 	int DoButton_CheckBox_Common(const void *pID, const char *pText, const char *pBoxText, const CUIRect *pRect);
 	int DoButton_CheckBox(const void *pID, const char *pText, int Checked, const CUIRect *pRect);
@@ -66,8 +76,8 @@ class CMenus : public CComponent
 	static void ui_draw_checkbox(const void *id, const char *text, int checked, const CUIRect *r, const void *extra);
 	static void ui_draw_checkbox_number(const void *id, const char *text, int checked, const CUIRect *r, const void *extra);
 	*/
-	int DoEditBox(void *pID, const CUIRect *pRect, char *pStr, unsigned StrSize, float FontSize, float *Offset, bool Hidden=false, int Corners=CUI::CORNER_ALL, const char *pEmptyText = "");
-	int DoClearableEditBox(void *pID, void *pClearID, const CUIRect *pRect, char *pStr, unsigned StrSize, float FontSize, float *Offset, bool Hidden=false, int Corners=CUI::CORNER_ALL, const char *pEmptyText = "");
+	int DoEditBox(void *pID, const CUIRect *pRect, char *pStr, unsigned StrSize, float FontSize, float *Offset, bool Hidden = false, int Corners = CUI::CORNER_ALL, const char *pEmptyText = "");
+	int DoClearableEditBox(void *pID, void *pClearID, const CUIRect *pRect, char *pStr, unsigned StrSize, float FontSize, float *Offset, bool Hidden = false, int Corners = CUI::CORNER_ALL, const char *pEmptyText = "");
 	//static int ui_do_edit_box(void *id, const CUIRect *rect, char *str, unsigned str_size, float font_size, bool hidden=false);
 
 	float DoScrollbarV(const void *pID, const CUIRect *pRect, float Current);
@@ -87,17 +97,66 @@ class CMenus : public CComponent
 	};
 
 	void UiDoListboxStart(const void *pID, const CUIRect *pRect, float RowHeight, const char *pTitle, const char *pBottomText, int NumItems,
-						int ItemsPerRow, int SelectedIndex, float ScrollValue);
-	CListboxItem UiDoListboxNextItem(const void *pID, bool Selected = false, bool KeyEvents = true);
+		int ItemsPerRow, int SelectedIndex, float ScrollValue, bool LogicOnly = false);
+	CListboxItem UiDoListboxNextItem(const void *pID, bool Selected = false, bool KeyEvents = true, bool NoHoverEffects = false);
 	CListboxItem UiDoListboxNextRow();
 	int UiDoListboxEnd(float *pScrollValue, bool *pItemActivated, bool *pListBoxActive = 0);
 
 	//static void demolist_listdir_callback(const char *name, int is_dir, void *user);
 	//static void demolist_list_callback(const CUIRect *rect, int index, void *user);
 
+	// menus_settings_assets.cpp
+public:
+	struct SCustomItem
+	{
+		IGraphics::CTextureHandle m_RenderTexture;
+
+		char m_aName[50];
+
+		bool operator<(const SCustomItem &Other) const { return str_comp(m_aName, Other.m_aName) < 0; }
+	};
+
+	struct SCustomEntities : public SCustomItem
+	{
+		struct SEntitiesImage
+		{
+			IGraphics::CTextureHandle m_Texture;
+		};
+		SEntitiesImage m_aImages[MAP_IMAGE_MOD_TYPE_COUNT];
+	};
+
+	struct SCustomGame : public SCustomItem
+	{
+	};
+
+	struct SCustomEmoticon : public SCustomItem
+	{
+	};
+
+	struct SCustomParticle : public SCustomItem
+	{
+	};
+
+protected:
+	sorted_array<SCustomEntities> m_EntitiesList;
+	sorted_array<SCustomGame> m_GameList;
+	sorted_array<SCustomEmoticon> m_EmoticonList;
+	sorted_array<SCustomParticle> m_ParticlesList;
+
+	static void LoadEntities(struct SCustomEntities *pEntitiesItem, void *pUser);
+	static int EntitiesScan(const char *pName, int IsDir, int DirType, void *pUser);
+
+	static int GameScan(const char *pName, int IsDir, int DirType, void *pUser);
+	static int EmoticonsScan(const char *pName, int IsDir, int DirType, void *pUser);
+	static int ParticlesScan(const char *pName, int IsDir, int DirType, void *pUser);
+
+	void ClearCustomItems(int CurTab);
+
+	int m_MenuPage;
 	int m_GamePage;
 	int m_Popup;
 	int m_ActivePage;
+	bool m_ShowStart;
 	bool m_MenuActive;
 	bool m_UseMouseButtons;
 	vec2 m_MousePos;
@@ -105,6 +164,19 @@ class CMenus : public CComponent
 
 	int64 m_LastInput;
 
+	// images
+	struct CMenuImage
+	{
+		char m_aName[64];
+		IGraphics::CTextureHandle m_OrgTexture;
+		IGraphics::CTextureHandle m_GreyTexture;
+	};
+	array<CMenuImage> m_lMenuImages;
+
+	static int MenuImageScan(const char *pName, int IsDir, int DirType, void *pUser);
+
+	const CMenuImage *FindMenuImage(const char *pName);
+
 	// loading
 	int m_LoadCurrent;
 	int m_LoadTotal;
@@ -117,7 +189,10 @@ class CMenus : public CComponent
 	void PopupMessage(const char *pTopic, const char *pBody, const char *pButton);
 
 	// TODO: this is a bit ugly but.. well.. yeah
-	enum { MAX_INPUTEVENTS = 32 };
+	enum
+	{
+		MAX_INPUTEVENTS = 32
+	};
 	static IInput::CEvent m_aInputEvents[MAX_INPUTEVENTS];
 	static int m_NumInputEvents;
 
@@ -157,7 +232,7 @@ class CMenus : public CComponent
 	// demo
 	enum
 	{
-		SORT_DEMONAME=0,
+		SORT_DEMONAME = 0,
 		SORT_MARKERS,
 		SORT_LENGTH,
 		SORT_DATE,
@@ -179,14 +254,14 @@ class CMenus : public CComponent
 
 		int NumMarkers() const
 		{
-			return ((m_TimelineMarkers.m_aNumTimelineMarkers[0]<<24)&0xFF000000) | ((m_TimelineMarkers.m_aNumTimelineMarkers[1]<<16)&0xFF0000) |
-				((m_TimelineMarkers.m_aNumTimelineMarkers[2]<<8)&0xFF00) | (m_TimelineMarkers.m_aNumTimelineMarkers[3]&0xFF);
+			return ((m_TimelineMarkers.m_aNumTimelineMarkers[0] << 24) & 0xFF000000) | ((m_TimelineMarkers.m_aNumTimelineMarkers[1] << 16) & 0xFF0000) |
+			       ((m_TimelineMarkers.m_aNumTimelineMarkers[2] << 8) & 0xFF00) | (m_TimelineMarkers.m_aNumTimelineMarkers[3] & 0xFF);
 		}
 
 		int Length() const
 		{
-			return ((m_Info.m_aLength[0]<<24)&0xFF000000) | ((m_Info.m_aLength[1]<<16)&0xFF0000) |
-				((m_Info.m_aLength[2]<<8)&0xFF00) | (m_Info.m_aLength[3]&0xFF);
+			return ((m_Info.m_aLength[0] << 24) & 0xFF000000) | ((m_Info.m_aLength[1] << 16) & 0xFF0000) |
+			       ((m_Info.m_aLength[2] << 8) & 0xFF00) | (m_Info.m_aLength[3] & 0xFF);
 		}
 
 		bool operator<(const CDemoItem &Other) const
@@ -277,6 +352,9 @@ class CMenus : public CComponent
 	void RenderDemoPlayer(CUIRect MainView);
 	void RenderDemoList(CUIRect MainView);
 
+	// found in menus_start.cpp
+	void RenderStartMenu(CUIRect MainView);
+
 	// found in menus_ingame.cpp
 	void RenderGame(CUIRect MainView);
 	void RenderPlayers(CUIRect MainView);
@@ -299,6 +377,7 @@ class CMenus : public CComponent
 
 	// found in menus_settings.cpp
 	void RenderLanguageSelection(CUIRect MainView);
+	void RenderThemeSelection(CUIRect MainView, bool Header = true);
 	void RenderSettingsGeneral(CUIRect MainView);
 	void RenderSettingsPlayer(CUIRect MainView);
 	void RenderSettingsDummyPlayer(CUIRect MainView);
@@ -307,13 +386,22 @@ class CMenus : public CComponent
 	void RenderSettingsGraphics(CUIRect MainView);
 	void RenderSettingsSound(CUIRect MainView);
 	void RenderSettings(CUIRect MainView);
+	void RenderSettingsCustom(CUIRect MainView);
 
+	void SetNeedSendInfo();
 	void SetActive(bool Active);
 
 	IGraphics::CTextureHandle m_TextureBlob;
+
+	bool CheckHotKey(int Key) const;
+
+	class CMenuBackground *m_pBackground;
+
 public:
 	void RenderBackground();
 
+	void SetMenuBackground(class CMenuBackground *pBackground) { m_pBackground = pBackground; }
+
 	void UseMouseButtons(bool Use) { m_UseMouseButtons = Use; }
 
 	static CMenusKeyBinder m_Binder;
@@ -321,9 +409,10 @@ public:
 	CMenus();
 
 	void RenderLoading();
-	void RenderUpdating(const char *pCaption, int current=0, int total=0);
+	void RenderUpdating(const char *pCaption, int current = 0, int total = 0);
 
 	bool IsActive() const { return m_MenuActive; }
+	void KillServer();
 
 	virtual void OnInit();
 
@@ -335,7 +424,7 @@ public:
 
 	enum
 	{
-		PAGE_NEWS=1,
+		PAGE_NEWS = 1,
 		PAGE_GAME,
 		PAGE_PLAYERS,
 		PAGE_SERVER_INFO,
@@ -351,7 +440,7 @@ public:
 		PAGE_NETWORK,
 		PAGE_GHOST,
 
-		SETTINGS_LANGUAGE=0,
+		SETTINGS_LANGUAGE = 0,
 		SETTINGS_GENERAL,
 		SETTINGS_PLAYER,
 		SETTINGS_TEE,
@@ -360,6 +449,7 @@ public:
 		SETTINGS_GRAPHICS,
 		SETTINGS_SOUND,
 		SETTINGS_DDNET,
+		SETTINGS_ASSETS,
 	};
 
 	// DDRace
@@ -380,7 +470,8 @@ public:
 		int m_Slot;
 		bool m_Own;
 
-		CGhostItem() : m_Slot(-1), m_Own(false) { m_aFilename[0] = 0; }
+		CGhostItem() :
+			m_Slot(-1), m_Own(false) { m_aFilename[0] = 0; }
 
 		bool operator<(const CGhostItem &Other) { return m_Time < Other.m_Time; }
 
@@ -396,13 +487,20 @@ public:
 	void DeleteGhostItem(int Index);
 
 	void setPopup(int Popup) { m_Popup = Popup; }
+	int GetCurPopup() { return m_Popup; }
+	bool CanDisplayWarning();
+
+	void PopupWarning(const char *pTopic, const char *pBody, const char *pButton, int64 Duration);
+
+	int64 m_PopupWarningLastTime;
+	int64 m_PopupWarningDuration;
 
 	int m_DemoPlayerState;
 	char m_aDemoPlayerPopupHint[256];
 
 	enum
 	{
-		POPUP_NONE=0,
+		POPUP_NONE = 0,
 		POPUP_FIRST_LAUNCH,
 		POPUP_CONNECTING,
 		POPUP_MESSAGE,
@@ -420,15 +518,16 @@ public:
 		POPUP_QUIT,
 		POPUP_DISCONNECT,
 		POPUP_DISCONNECT_DUMMY,
+		POPUP_WARNING,
 
 		// demo player states
-		DEMOPLAYER_NONE=0,
+		DEMOPLAYER_NONE = 0,
 		DEMOPLAYER_SLICE_SAVE,
 	};
 
 private:
-
 	static int GhostlistFetchCallback(const char *pName, int IsDir, int StorageType, void *pUser);
+	void SetMenuPage(int NewPage);
 
 	// found in menus_ingame.cpp
 	void RenderInGameNetwork(CUIRect MainView);
@@ -438,5 +537,7 @@ private:
 	void RenderSettingsDDNet(CUIRect MainView);
 	void RenderSettingsHUD(CUIRect MainView);
 	ColorHSLA RenderHSLScrollbars(CUIRect *pRect, unsigned int *pColor, bool Alpha = false);
+
+	CServerProcess m_ServerProcess;
 };
 #endif
