@@ -1,16 +1,16 @@
 /* (c) Magnus Auvinen. See licence.txt in the root of the distribution for more information. */
 /* If you are missing that file, acquire a complete release at teeworlds.com.                */
-#include <engine/textrender.h>
 #include <engine/graphics.h>
 #include <engine/shared/config.h>
-#include <game/generated/protocol.h>
+#include <engine/textrender.h>
 #include <game/generated/client_data.h>
+#include <game/generated/protocol.h>
 
-#include <game/client/gameclient.h>
-#include <game/client/animstate.h>
-#include "nameplates.h"
-#include "controls.h"
 #include "camera.h"
+#include "controls.h"
+#include "nameplates.h"
+#include <game/client/animstate.h>
+#include <game/client/gameclient.h>
 
 #include "players.h"
 
@@ -24,8 +24,7 @@ void CNamePlates::MapscreenToGroup(float CenterX, float CenterY, CMapItemGroup *
 void CNamePlates::RenderNameplate(
 	const CNetObj_Character *pPrevChar,
 	const CNetObj_Character *pPlayerChar,
-	const CNetObj_PlayerInfo *pPlayerInfo
-	)
+	const CNetObj_PlayerInfo *pPlayerInfo)
 {
 	int ClientID = pPlayerInfo->m_ClientID;
 
@@ -53,7 +52,7 @@ void CNamePlates::RenderNameplatePos(vec2 Position, const CNetObj_PlayerInfo *pP
 		TextRender()->SetRenderFlags(ETextRenderFlags::TEXT_RENDER_FLAG_NO_FIRST_CHARACTER_X_BEARING | ETextRenderFlags::TEXT_RENDER_FLAG_NO_LAST_CHARACTER_ADVANCE);
 		float a = 1;
 		if(g_Config.m_ClNameplatesAlways == 0)
-			a = clamp(1-powf(distance(m_pClient->m_pControls->m_TargetPos[g_Config.m_ClDummy], Position)/200.0f,16.0f), 0.0f, 1.0f);
+			a = clamp(1 - powf(distance(m_pClient->m_pControls->m_TargetPos[g_Config.m_ClDummy], Position) / 200.0f, 16.0f), 0.0f, 1.0f);
 
 		const char *pName = m_pClient->m_aClients[pPlayerInfo->m_ClientID].m_aName;
 		if(str_comp(pName, m_aNamePlates[ClientID].m_aName) != 0 || FontSize != m_aNamePlates[ClientID].m_NameTextFontSize)
@@ -73,7 +72,7 @@ void CNamePlates::RenderNameplatePos(vec2 Position, const CNetObj_PlayerInfo *pP
 			Graphics()->GetScreen(&ScreenX0, &ScreenY0, &ScreenX1, &ScreenY1);
 			MapscreenToGroup(m_pClient->m_pCamera->m_Center.x, m_pClient->m_pCamera->m_Center.y, Layers()->GameGroup());
 
-			m_aNamePlates[ClientID].m_NameTextWidth = TextRender()->TextWidth(0, FontSize, pName, -1);
+			m_aNamePlates[ClientID].m_NameTextWidth = TextRender()->TextWidth(0, FontSize, pName, -1, -1.0f);
 
 			m_aNamePlates[ClientID].m_NameTextContainerIndex = TextRender()->CreateTextContainer(&Cursor, pName);
 			Graphics()->MapScreen(ScreenX0, ScreenY0, ScreenX1, ScreenY1);
@@ -99,7 +98,7 @@ void CNamePlates::RenderNameplatePos(vec2 Position, const CNetObj_PlayerInfo *pP
 				Graphics()->GetScreen(&ScreenX0, &ScreenY0, &ScreenX1, &ScreenY1);
 				MapscreenToGroup(m_pClient->m_pCamera->m_Center.x, m_pClient->m_pCamera->m_Center.y, Layers()->GameGroup());
 
-				m_aNamePlates[ClientID].m_ClanNameTextWidth = TextRender()->TextWidth(0, FontSizeClan, pClan, -1);
+				m_aNamePlates[ClientID].m_ClanNameTextWidth = TextRender()->TextWidth(0, FontSizeClan, pClan, -1, -1.0f);
 
 				m_aNamePlates[ClientID].m_ClanNameTextContainerIndex = TextRender()->CreateTextContainer(&Cursor, pClan);
 				Graphics()->MapScreen(ScreenX0, ScreenY0, ScreenX1, ScreenY1);
@@ -121,10 +120,10 @@ void CNamePlates::RenderNameplatePos(vec2 Position, const CNetObj_PlayerInfo *pP
 		}
 		else
 		{
-			TOutlineColor.Set(0.0f, 0.0f, 0.0f, 0.5f*a);
+			TOutlineColor.Set(0.0f, 0.0f, 0.0f, 0.5f * a);
 			TColor.Set(rgb.r, rgb.g, rgb.b, a);
 		}
-		if(g_Config.m_ClNameplatesTeamcolors && m_pClient->m_Snap.m_pGameInfoObj && m_pClient->m_Snap.m_pGameInfoObj->m_GameFlags&GAMEFLAG_TEAMS)
+		if(g_Config.m_ClNameplatesTeamcolors && m_pClient->m_Snap.m_pGameInfoObj && m_pClient->m_Snap.m_pGameInfoObj->m_GameFlags & GAMEFLAG_TEAMS)
 		{
 			if(m_pClient->m_aClients[ClientID].m_Team == TEAM_RED)
 				TColor.Set(1.0f, 0.5f, 0.5f, a);
@@ -135,26 +134,75 @@ void CNamePlates::RenderNameplatePos(vec2 Position, const CNetObj_PlayerInfo *pP
 		TOutlineColor.m_A *= Alpha;
 		TColor.m_A *= Alpha;
 
+		float YOffset = Position.y - 38;
+
 		if(m_aNamePlates[ClientID].m_NameTextContainerIndex != -1)
-			TextRender()->RenderTextContainer(m_aNamePlates[ClientID].m_NameTextContainerIndex, &TColor, &TOutlineColor, Position.x - tw / 2.0f, Position.y - FontSize - 38.0f);
+		{
+			YOffset -= FontSize;
+			TextRender()->RenderTextContainer(m_aNamePlates[ClientID].m_NameTextContainerIndex, &TColor, &TOutlineColor, Position.x - tw / 2.0f, YOffset);
+		}
 
 		if(g_Config.m_ClNameplatesClan)
 		{
+			YOffset -= FontSizeClan;
 			if(m_aNamePlates[ClientID].m_ClanNameTextContainerIndex != -1)
-				TextRender()->RenderTextContainer(m_aNamePlates[ClientID].m_ClanNameTextContainerIndex, &TColor, &TOutlineColor, Position.x - m_aNamePlates[ClientID].m_ClanNameTextWidth / 2.0f, Position.y - FontSize - FontSizeClan - 38.0f);
+				TextRender()->RenderTextContainer(m_aNamePlates[ClientID].m_ClanNameTextContainerIndex, &TColor, &TOutlineColor, Position.x - m_aNamePlates[ClientID].m_ClanNameTextWidth / 2.0f, YOffset);
+		}
+
+		if(g_Config.m_ClNameplatesFriendMark && m_pClient->m_aClients[ClientID].m_Friend)
+		{
+			YOffset -= FontSize;
+			char aFriendMark[] = "♥";
+			TextRender()->TextColor(ColorRGBA(1.0f, 0.0f, 0.0f));
+			float XOffSet = TextRender()->TextWidth(0, FontSize, aFriendMark, -1, -1.0f) / 2.0f;
+			TextRender()->Text(0, Position.x - XOffSet, YOffset, FontSize, aFriendMark, -1.0f);
 		}
 
 		if(g_Config.m_Debug || g_Config.m_ClNameplatesIDs) // render client id when in debug as well
 		{
+			YOffset -= FontSize;
 			char aBuf[128];
-			str_format(aBuf, sizeof(aBuf),"%d", pPlayerInfo->m_ClientID);
-			float Offset = g_Config.m_ClNameplatesClan ? (FontSize * 2 + FontSizeClan) : (FontSize * 2);
-			float tw_id = TextRender()->TextWidth(0, FontSize, aBuf, -1);
+			str_format(aBuf, sizeof(aBuf), "%d", pPlayerInfo->m_ClientID);
+			float XOffset = TextRender()->TextWidth(0, FontSize, aBuf, -1, -1.0f) / 2.0f;
 			TextRender()->TextColor(rgb);
-			TextRender()->Text(0, Position.x-tw_id/2.0f, Position.y-Offset-38.0f, 28.0f, aBuf, -1);
+			TextRender()->Text(0, Position.x - XOffset, YOffset, FontSize, aBuf, -1.0f);
 		}
 
-		TextRender()->TextColor(1,1,1,1);
+		if(g_Config.m_ClNameplatesHA) // render health and armor in nameplate
+		{
+			int Health = m_pClient->m_Snap.m_aCharacters[ClientID].m_Cur.m_Health;
+			int Armor = m_pClient->m_Snap.m_aCharacters[ClientID].m_Cur.m_Armor;
+
+			if(Health > 0 || Armor > 0)
+			{
+				float HFontSize = 5.0f + 20.0f * g_Config.m_ClNameplatesHASize / 100.0f;
+				float AFontSize = 6.0f + 24.0f * g_Config.m_ClNameplatesHASize / 100.0f;
+				char aHealth[40] = "\0";
+				char aArmor[40] = "\0";
+				for(int i = 0; i < Health; i++)
+					str_append(aHealth, "♥", sizeof(aHealth));
+				for(int i = Health; i < 10; i++)
+					str_append(aHealth, "♡", sizeof(aHealth));
+				str_append(aHealth, "\0", sizeof(aHealth));
+				for(int i = 0; i < Armor; i++)
+					str_append(aArmor, "⚫", sizeof(aArmor));
+				for(int i = Armor; i < 10; i++)
+					str_append(aArmor, "⚪", sizeof(aArmor));
+				str_append(aArmor, "\0", sizeof(aArmor));
+
+				YOffset -= HFontSize + AFontSize;
+				float PosHealth = TextRender()->TextWidth(0, HFontSize, aHealth, -1, -1.0f);
+				TextRender()->TextColor(ColorRGBA(1.0f, 0.0f, 0.0f));
+				TextRender()->Text(0, Position.x - PosHealth / 2.0f, YOffset, HFontSize, aHealth, -1);
+
+				YOffset -= -AFontSize + 3.0f;
+				float PosArmor = TextRender()->TextWidth(0, AFontSize, aArmor, -1, -1.0f);
+				TextRender()->TextColor(ColorRGBA(1.0f, 1.0f, 0.0f));
+				TextRender()->Text(0, Position.x - PosArmor / 2.0f, YOffset, AFontSize, aArmor, -1);
+			}
+		}
+
+		TextRender()->TextColor(1, 1, 1, 1);
 		TextRender()->TextOutlineColor(0.0f, 0.0f, 0.0f, 0.3f);
 
 		TextRender()->SetRenderFlags(0);
@@ -193,7 +241,7 @@ void CNamePlates::OnRender()
 	}
 }
 
-void CNamePlates::SetPlayers(CPlayers* pPlayers)
+void CNamePlates::SetPlayers(CPlayers *pPlayers)
 {
 	m_pPlayers = pPlayers;
 }
@@ -209,7 +257,6 @@ void CNamePlates::ResetNamePlates()
 
 		m_aNamePlates[i].Reset();
 	}
-
 }
 
 void CNamePlates::OnWindowResize()
