@@ -1,13 +1,13 @@
 /* (c) Magnus Auvinen. See licence.txt in the root of the distribution for more information. */
 /* If you are missing that file, acquire a complete release at teeworlds.com.                */
 #include <base/math.h>
-#include <engine/graphics.h>
 #include <engine/demo.h>
+#include <engine/graphics.h>
 
-#include <game/generated/client_data.h>
+#include "particles.h"
 #include <game/client/render.h>
 #include <game/gamecore.h>
-#include "particles.h"
+#include <game/generated/client_data.h>
 
 CParticles::CParticles()
 {
@@ -17,18 +17,17 @@ CParticles::CParticles()
 	m_RenderGeneral.m_pParts = this;
 }
 
-
 void CParticles::OnReset()
 {
 	// reset particles
 	for(int i = 0; i < MAX_PARTICLES; i++)
 	{
-		m_aParticles[i].m_PrevPart = i-1;
-		m_aParticles[i].m_NextPart = i+1;
+		m_aParticles[i].m_PrevPart = i - 1;
+		m_aParticles[i].m_NextPart = i + 1;
 	}
 
 	m_aParticles[0].m_PrevPart = 0;
-	m_aParticles[MAX_PARTICLES-1].m_NextPart = -1;
+	m_aParticles[MAX_PARTICLES - 1].m_NextPart = -1;
 	m_FirstFree = 0;
 
 	for(int i = 0; i < NUM_GROUPS; i++)
@@ -45,7 +44,7 @@ void CParticles::Add(int Group, CParticle *pPart, float TimePassed)
 	}
 	else
 	{
-		if(m_pClient->m_Snap.m_pGameInfoObj && m_pClient->m_Snap.m_pGameInfoObj->m_GameStateFlags&GAMESTATEFLAG_PAUSED)
+		if(m_pClient->m_Snap.m_pGameInfoObj && m_pClient->m_Snap.m_pGameInfoObj->m_GameStateFlags & GAMESTATEFLAG_PAUSED)
 			return;
 	}
 
@@ -97,15 +96,15 @@ void CParticles::Update(float TimePassed)
 		{
 			int Next = m_aParticles[i].m_NextPart;
 			//m_aParticles[i].vel += flow_get(m_aParticles[i].pos)*time_passed * m_aParticles[i].flow_affected;
-			m_aParticles[i].m_Vel.y += m_aParticles[i].m_Gravity*TimePassed;
+			m_aParticles[i].m_Vel.y += m_aParticles[i].m_Gravity * TimePassed;
 
 			for(int f = 0; f < FrictionCount; f++) // apply friction
 				m_aParticles[i].m_Vel *= m_aParticles[i].m_Friction;
 
 			// move the point
-			vec2 Vel = m_aParticles[i].m_Vel*TimePassed;
-			Collision()->MovePoint(&m_aParticles[i].m_Pos, &Vel, 0.1f+0.9f*frandom(), NULL);
-			m_aParticles[i].m_Vel = Vel* (1.0f/TimePassed);
+			vec2 Vel = m_aParticles[i].m_Vel * TimePassed;
+			Collision()->MovePoint(&m_aParticles[i].m_Pos, &Vel, 0.1f + 0.9f * frandom(), NULL);
+			m_aParticles[i].m_Vel = Vel * (1.0f / TimePassed);
 
 			m_aParticles[i].m_Life += TimePassed;
 			m_aParticles[i].m_Rot += TimePassed * m_aParticles[i].m_Rotspeed;
@@ -148,12 +147,12 @@ void CParticles::OnRender()
 	{
 		const IDemoPlayer::CInfo *pInfo = DemoPlayer()->BaseInfo();
 		if(!pInfo->m_Paused)
-			Update((float)((t-LastTime)/(double)time_freq())*pInfo->m_Speed);
+			Update((float)((t - LastTime) / (double)time_freq()) * pInfo->m_Speed);
 	}
 	else
 	{
-		if(m_pClient->m_Snap.m_pGameInfoObj && !(m_pClient->m_Snap.m_pGameInfoObj->m_GameStateFlags&GAMESTATEFLAG_PAUSED))
-			Update((float)((t-LastTime)/(double)time_freq()));
+		if(m_pClient->m_Snap.m_pGameInfoObj && !(m_pClient->m_Snap.m_pGameInfoObj->m_GameStateFlags & GAMESTATEFLAG_PAUSED))
+			Update((float)((t - LastTime) / (double)time_freq()));
 	}
 
 	LastTime = t;
@@ -176,9 +175,9 @@ void CParticles::OnInit()
 void CParticles::RenderGroup(int Group)
 {
 	Graphics()->TextureSet(g_pData->m_aImages[IMAGE_PARTICLES].m_Id);
-	
+
 	// don't use the buffer methods here, else the old renderer gets many draw calls
-	if(Graphics()->IsBufferingEnabled())
+	if(Graphics()->IsQuadContainerBufferingEnabled())
 	{
 		int i = m_aFirstPart[Group];
 
@@ -205,14 +204,14 @@ void CParticles::RenderGroup(int Group)
 
 			LastQuadOffset = m_aParticles[i].m_Spr;
 		}
-		
+
 		while(i != -1)
 		{
 			int QuadOffset = m_aParticles[i].m_Spr;
 			float a = m_aParticles[i].m_Life / m_aParticles[i].m_LifeSpan;
 			vec2 p = m_aParticles[i].m_Pos;
 			float Size = mix(m_aParticles[i].m_StartSize, m_aParticles[i].m_EndSize, a);
-			
+
 			if(LastColor[0] != m_aParticles[i].m_Color.r || LastColor[1] != m_aParticles[i].m_Color.g || LastColor[2] != m_aParticles[i].m_Color.b || LastColor[3] != m_aParticles[i].m_Color.a || LastQuadOffset != QuadOffset)
 			{
 				Graphics()->RenderQuadContainerAsSpriteMultiple(m_ParticleQuadContainerIndex, LastQuadOffset, CurParticleRenderCount, s_aParticleRenderInfo);
@@ -236,14 +235,13 @@ void CParticles::RenderGroup(int Group)
 
 			s_aParticleRenderInfo[CurParticleRenderCount].m_Scale = Size;
 			s_aParticleRenderInfo[CurParticleRenderCount].m_Rotation = m_aParticles[i].m_Rot;
-			
-			++CurParticleRenderCount;			
+
+			++CurParticleRenderCount;
 
 			i = m_aParticles[i].m_NextPart;
 		}
 
 		Graphics()->RenderQuadContainerAsSpriteMultiple(m_ParticleQuadContainerIndex, LastQuadOffset, CurParticleRenderCount, s_aParticleRenderInfo);
-
 	}
 	else
 	{
