@@ -3,8 +3,8 @@
 #include <ctype.h>
 
 #include <base/system.h>
-#include <engine/shared/config.h>
 #include <engine/serverbrowser.h>
+#include <engine/shared/config.h>
 #include <engine/storage.h>
 
 #include <game/client/race.h>
@@ -21,18 +21,20 @@ struct CDemoItem
 
 struct CDemoListParam
 {
+	const CRaceDemo *m_pThis;
 	std::vector<CDemoItem> *m_plDemos;
 	const char *pMap;
 };
 
-CRaceDemo::CRaceDemo() : m_RaceState(RACE_NONE), m_RaceStartTick(-1), m_RecordStopTick(-1), m_Time(0) {}
+CRaceDemo::CRaceDemo() :
+	m_RaceState(RACE_NONE), m_RaceStartTick(-1), m_RecordStopTick(-1), m_Time(0) {}
 
 void CRaceDemo::GetPath(char *pBuf, int Size, int Time) const
 {
 	const char *pMap = Client()->GetCurrentMap();
 
 	char aPlayerName[MAX_NAME_LENGTH];
-	str_copy(aPlayerName, g_Config.m_PlayerName, sizeof(aPlayerName));
+	str_copy(aPlayerName, Client()->PlayerName(), sizeof(aPlayerName));
 	str_sanitize_filename(aPlayerName);
 
 	if(Time < 0)
@@ -59,7 +61,7 @@ void CRaceDemo::OnNewSnapshot()
 
 	static int s_LastRaceTick = -1;
 
-	bool RaceFlag = m_pClient->m_Snap.m_pGameInfoObj->m_GameStateFlags&GAMESTATEFLAG_RACETIME;
+	bool RaceFlag = m_pClient->m_Snap.m_pGameInfoObj->m_GameStateFlags & GAMESTATEFLAG_RACETIME;
 	bool ServerControl = RaceFlag && g_Config.m_ClRaceRecordServerControl;
 	int RaceTick = -m_pClient->m_Snap.m_pGameInfoObj->m_WarmupTimer;
 
@@ -173,7 +175,7 @@ void CRaceDemo::StopRecord(int Time)
 
 int CRaceDemo::RaceDemolistFetchCallback(const char *pName, time_t Date, int IsDir, int StorageType, void *pUser)
 {
-	CDemoListParam *pParam = (CDemoListParam*) pUser;
+	CDemoListParam *pParam = (CDemoListParam *)pUser;
 	int Length = str_length(pName);
 	int MapLen = str_length(pParam->pMap);
 	if(IsDir || !str_endswith(pName, ".demo") || !str_startswith(pName, pParam->pMap) || pName[MapLen] != '_')
@@ -190,7 +192,7 @@ int CRaceDemo::RaceDemolistFetchCallback(const char *pName, time_t Date, int IsD
 	if(g_Config.m_ClDemoName)
 	{
 		char aPlayerName[MAX_NAME_LENGTH];
-		str_copy(aPlayerName, g_Config.m_PlayerName, sizeof(aPlayerName));
+		str_copy(aPlayerName, pParam->m_pThis->Client()->PlayerName(), sizeof(aPlayerName));
 		str_sanitize_filename(aPlayerName);
 
 		if(pTEnd[0] != '_' || str_comp(pTEnd + 1, aPlayerName) != 0)
@@ -209,7 +211,7 @@ int CRaceDemo::RaceDemolistFetchCallback(const char *pName, time_t Date, int IsD
 bool CRaceDemo::CheckDemo(int Time) const
 {
 	std::vector<CDemoItem> lDemos;
-	CDemoListParam Param = { &lDemos, Client()->GetCurrentMap() };
+	CDemoListParam Param = {this, &lDemos, Client()->GetCurrentMap()};
 	Storage()->ListDirectoryInfo(IStorage::TYPE_SAVE, ms_pRaceDemoDir, RaceDemolistFetchCallback, &Param);
 
 	// loop through demo files
