@@ -2,20 +2,20 @@
 /* If you are missing that file, acquire a complete release at teeworlds.com.                */
 #include <engine/demo.h>
 #include <engine/graphics.h>
-#include <engine/textrender.h>
 #include <engine/shared/config.h>
+#include <engine/textrender.h>
 
 #include <game/generated/client_data.h>
 #include <game/generated/protocol.h>
 
-#include <game/localization.h>
 #include <game/client/animstate.h>
-#include <game/client/gameclient.h>
-#include <game/client/render.h>
 #include <game/client/components/countryflags.h>
 #include <game/client/components/motd.h>
-#include <game/client/components/statboard.h>
 #include <game/client/components/skins.h>
+#include <game/client/components/statboard.h>
+#include <game/client/gameclient.h>
+#include <game/client/render.h>
+#include <game/localization.h>
 
 #include "scoreboard.h"
 
@@ -49,7 +49,7 @@ void CScoreboard::OnMessage(int MsgType, void *pRawMsg)
 	if(MsgType == NETMSGTYPE_SV_RECORD)
 	{
 		CNetMsg_Sv_Record *pMsg = (CNetMsg_Sv_Record *)pRawMsg;
-		m_ServerRecord = (float)pMsg->m_ServerTimeBest/100;
+		m_ServerRecord = (float)pMsg->m_ServerTimeBest / 100;
 		//m_PlayerRecord = (float)pMsg->m_PlayerTimeBest/100;
 	}
 }
@@ -66,7 +66,7 @@ void CScoreboard::RenderGoals(float x, float y, float w)
 	Graphics()->BlendNormal();
 	Graphics()->TextureClear();
 	Graphics()->QuadsBegin();
-	Graphics()->SetColor(0,0,0,0.5f);
+	Graphics()->SetColor(0, 0, 0, 0.5f);
 	RenderTools()->DrawRoundRect(x, y, w, h, 10.0f);
 	Graphics()->QuadsEnd();
 
@@ -77,20 +77,20 @@ void CScoreboard::RenderGoals(float x, float y, float w)
 		{
 			char aBuf[64];
 			str_format(aBuf, sizeof(aBuf), "%s: %d", Localize("Score limit"), m_pClient->m_Snap.m_pGameInfoObj->m_ScoreLimit);
-			TextRender()->Text(0, x+10.0f, y + (h - 20.f) / 2.f, 20.0f, aBuf, -1);
+			TextRender()->Text(0, x + 10.0f, y + (h - 20.f) / 2.f, 20.0f, aBuf, -1.0f);
 		}
 		if(m_pClient->m_Snap.m_pGameInfoObj->m_TimeLimit)
 		{
 			char aBuf[64];
 			str_format(aBuf, sizeof(aBuf), Localize("Time limit: %d min"), m_pClient->m_Snap.m_pGameInfoObj->m_TimeLimit);
-			TextRender()->Text(0, x+230.0f, y + (h - 20.f) / 2.f, 20.0f, aBuf, -1);
+			TextRender()->Text(0, x + 230.0f, y + (h - 20.f) / 2.f, 20.0f, aBuf, -1.0f);
 		}
 		if(m_pClient->m_Snap.m_pGameInfoObj->m_RoundNum && m_pClient->m_Snap.m_pGameInfoObj->m_RoundCurrent)
 		{
 			char aBuf[64];
 			str_format(aBuf, sizeof(aBuf), "%s %d/%d", Localize("Round"), m_pClient->m_Snap.m_pGameInfoObj->m_RoundCurrent, m_pClient->m_Snap.m_pGameInfoObj->m_RoundNum);
-			float tw = TextRender()->TextWidth(0, 20.0f, aBuf, -1);
-			TextRender()->Text(0, x+w-tw-10.0f, y + (h - 20.f) / 2.f, 20.0f, aBuf, -1);
+			float tw = TextRender()->TextWidth(0, 20.0f, aBuf, -1, -1.0f);
+			TextRender()->Text(0, x + w - tw - 10.0f, y + (h - 20.f) / 2.f, 20.0f, aBuf, -1.0f);
 		}
 	}
 }
@@ -103,21 +103,21 @@ void CScoreboard::RenderSpectators(float x, float y, float w)
 	Graphics()->BlendNormal();
 	Graphics()->TextureClear();
 	Graphics()->QuadsBegin();
-	Graphics()->SetColor(0,0,0,0.5f);
+	Graphics()->SetColor(0, 0, 0, 0.5f);
 	RenderTools()->DrawRoundRect(x, y, w, h, 10.0f);
 	Graphics()->QuadsEnd();
 
 	// Headline
 	y += 10.0f;
-	TextRender()->Text(0, x+10.0f, y + (30.f - 28.f) / 2.f, 28.0f, Localize("Spectators"), w-20.0f);
+	TextRender()->Text(0, x + 10.0f, y + (30.f - 28.f) / 2.f, 28.0f, Localize("Spectators"), w - 20.0f);
 
 	// spectator names
 	y += 30.0f;
 	bool Multiple = false;
 
 	CTextCursor Cursor;
-	TextRender()->SetCursor(&Cursor, x+10.0f, y, 22.0f, TEXTFLAG_RENDER);
-	Cursor.m_LineWidth = w-20.0f;
+	TextRender()->SetCursor(&Cursor, x + 10.0f, y, 22.0f, TEXTFLAG_RENDER);
+	Cursor.m_LineWidth = w - 20.0f;
 	Cursor.m_MaxLines = 4;
 
 	for(int i = 0; i < MAX_CLIENTS; ++i)
@@ -197,25 +197,19 @@ void CScoreboard::RenderScoreboard(float x, float y, float w, int Team, const ch
 	float TitleFontsize = 40.0f;
 	if(!pTitle)
 	{
-		if(m_pClient->m_Snap.m_pGameInfoObj->m_GameStateFlags&GAMESTATEFLAG_GAMEOVER)
+		if(m_pClient->m_Snap.m_pGameInfoObj->m_GameStateFlags & GAMESTATEFLAG_GAMEOVER)
 			pTitle = Localize("Game over");
 		else
 		{
-			if(str_length(Client()->GetCurrentMap()) > 16)
-			{
-				str_truncate(aBuf, sizeof(aBuf), Client()->GetCurrentMap(), 16);
-				str_append(aBuf, "...", sizeof(aBuf));
-				pTitle = aBuf;
-			}
-			else
-			{
-				pTitle = Client()->GetCurrentMap();
-			}
+			str_utf8_truncate(aBuf, sizeof(aBuf), Client()->GetCurrentMap(), 16);
+			if(str_comp(aBuf, Client()->GetCurrentMap()))
+				str_append(aBuf, "…", sizeof(aBuf));
+			pTitle = aBuf;
 		}
 	}
-	TextRender()->Text(0, x + 20.0f, y + (50.f - TitleFontsize) / 2.f, TitleFontsize, pTitle, -1);
+	TextRender()->Text(0, x + 20.0f, y + (50.f - TitleFontsize) / 2.f, TitleFontsize, pTitle, -1.0f);
 
-	if(m_pClient->m_Snap.m_pGameInfoObj->m_GameFlags&GAMEFLAG_TEAMS)
+	if(m_pClient->m_Snap.m_pGameInfoObj->m_GameFlags & GAMEFLAG_TEAMS)
 	{
 		if(m_pClient->m_Snap.m_pGameDataObj)
 		{
@@ -240,9 +234,9 @@ void CScoreboard::RenderScoreboard(float x, float y, float w, int Team, const ch
 
 	if(m_pClient->m_GameInfo.m_TimeScore && g_Config.m_ClDDRaceScoreBoard)
 	{
-		if (m_ServerRecord > 0)
+		if(m_ServerRecord > 0)
 		{
-			str_format(aBuf, sizeof(aBuf), "%02d:%02d", ((int)m_ServerRecord)/60, ((int)m_ServerRecord)%60);
+			str_format(aBuf, sizeof(aBuf), "%02d:%02d", ((int)m_ServerRecord) / 60, ((int)m_ServerRecord) % 60);
 		}
 		else
 			aBuf[0] = 0;
@@ -250,10 +244,10 @@ void CScoreboard::RenderScoreboard(float x, float y, float w, int Team, const ch
 
 	float tw;
 
-	if (!lower16 && !lower32 && !lower24)
+	if(!lower16 && !lower32 && !lower24)
 	{
-		tw = TextRender()->TextWidth(0, TitleFontsize, aBuf, -1);
-		TextRender()->Text(0, x+w-tw-20.0f, y + (50.f - TitleFontsize) / 2.f, TitleFontsize, aBuf, -1);
+		tw = TextRender()->TextWidth(0, TitleFontsize, aBuf, -1, -1.0f);
+		TextRender()->Text(0, x + w - tw - 20.0f, y + (50.f - TitleFontsize) / 2.f, TitleFontsize, aBuf, -1.0f);
 	}
 
 	// calculate measurements
@@ -291,44 +285,44 @@ void CScoreboard::RenderScoreboard(float x, float y, float w, int Team, const ch
 		RoundRadius = 15.0f;
 	}
 
-	float ScoreOffset = x+10.0f, ScoreLength = TextRender()->TextWidth(0, 22.0f/*HeadlineFontsize*/, "00:00:0", -1);
-	float TeeOffset = ScoreOffset+ScoreLength, TeeLength = 60*TeeSizeMod;
-	float NameOffset = TeeOffset+TeeLength, NameLength = 300.0f-TeeLength;
-	float PingOffset = x+610.0f, PingLength = 65.0f;
-	float CountryOffset = PingOffset-(LineHeight-Spacing-TeeSizeMod*5.0f)*2.0f, CountryLength = (LineHeight-Spacing-TeeSizeMod*5.0f)*2.0f;
-	float ClanOffset = x+360.0f, ClanLength = 240.0f-CountryLength;
-
-	// render headlines
-	y += 50.0f;
-	float HeadlineFontsize = 22.0f;
-	const char *pScore = (m_pClient->m_GameInfo.m_TimeScore && g_Config.m_ClDDRaceScoreBoard) ? Localize("Time") : Localize("Score");
-	float ScoreWidth = TextRender()->TextWidth(0, HeadlineFontsize, pScore, -1);
-	tw = ScoreLength > ScoreWidth ? ScoreLength : ScoreWidth;
-	TextRender()->Text(0, ScoreOffset+ScoreLength-tw, y + (HeadlineFontsize * 2.f - HeadlineFontsize) / 2.f, HeadlineFontsize, pScore, -1);
-
-	TextRender()->Text(0, NameOffset, y + (HeadlineFontsize * 2.f - HeadlineFontsize) / 2.f, HeadlineFontsize, Localize("Name"), -1);
-
-	tw = TextRender()->TextWidth(0, HeadlineFontsize, Localize("Clan"), -1);
-	TextRender()->Text(0, ClanOffset+ClanLength/2-tw/2, y + (HeadlineFontsize * 2.f - HeadlineFontsize) / 2.f, HeadlineFontsize, Localize("Clan"), -1);
-
-	tw = TextRender()->TextWidth(0, HeadlineFontsize, Localize("Ping"), -1);
-	TextRender()->Text(0, PingOffset+PingLength-tw, y + (HeadlineFontsize * 2.f - HeadlineFontsize) / 2.f, HeadlineFontsize, Localize("Ping"), -1);
-
-	// render player entries
-	y += HeadlineFontsize*2.0f;
 	float FontSize = 24.0f;
 	if(m_pClient->m_Snap.m_aTeamSize[Team] > 48)
 		FontSize = 16.0f;
 	else if(m_pClient->m_Snap.m_aTeamSize[Team] > 32)
 		FontSize = 20.0f;
+
+	float ScoreOffset = x + 10.0f, ScoreLength = TextRender()->TextWidth(0, FontSize, "00:00:00", -1, -1.0f);
+	float TeeOffset = ScoreOffset + ScoreLength + 15.0f, TeeLength = 60 * TeeSizeMod;
+	float NameOffset = TeeOffset + TeeLength, NameLength = 300.0f - TeeLength;
+	float PingOffset = x + 610.0f, PingLength = 65.0f;
+	float CountryOffset = PingOffset - (LineHeight - Spacing - TeeSizeMod * 5.0f) * 2.0f, CountryLength = (LineHeight - Spacing - TeeSizeMod * 5.0f) * 2.0f;
+	float ClanOffset = x + 360.0f, ClanLength = 240.0f - CountryLength;
+
+	// render headlines
+	y += 50.0f;
+	float HeadlineFontsize = 22.0f;
+	const char *pScore = (m_pClient->m_GameInfo.m_TimeScore && g_Config.m_ClDDRaceScoreBoard) ? Localize("Time") : Localize("Score");
+	tw = TextRender()->TextWidth(0, HeadlineFontsize, pScore, -1, -1.0f);
+	TextRender()->Text(0, ScoreOffset + ScoreLength - tw, y + (HeadlineFontsize * 2.f - HeadlineFontsize) / 2.f, HeadlineFontsize, pScore, -1.0f);
+
+	TextRender()->Text(0, NameOffset, y + (HeadlineFontsize * 2.f - HeadlineFontsize) / 2.f, HeadlineFontsize, Localize("Name"), -1.0f);
+
+	tw = TextRender()->TextWidth(0, HeadlineFontsize, Localize("Clan"), -1, -1.0f);
+	TextRender()->Text(0, ClanOffset + ClanLength / 2 - tw / 2, y + (HeadlineFontsize * 2.f - HeadlineFontsize) / 2.f, HeadlineFontsize, Localize("Clan"), -1.0f);
+
+	tw = TextRender()->TextWidth(0, HeadlineFontsize, Localize("Ping"), -1, -1.0f);
+	TextRender()->Text(0, PingOffset + PingLength - tw, y + (HeadlineFontsize * 2.f - HeadlineFontsize) / 2.f, HeadlineFontsize, Localize("Ping"), -1.0f);
+
+	// render player entries
+	y += HeadlineFontsize * 2.0f;
 	CTextCursor Cursor;
 
 	int rendered = 0;
-	if (upper16)
+	if(upper16)
 		rendered = -16;
-	if (upper32)
+	if(upper32)
 		rendered = -32;
-	if (upper24)
+	if(upper24)
 		rendered = -24;
 
 	int OldDDTeam = -1;
@@ -336,18 +330,19 @@ void CScoreboard::RenderScoreboard(float x, float y, float w, int Team, const ch
 	for(int i = 0; i < MAX_CLIENTS; i++)
 	{
 		// make sure that we render the correct team
-		const CNetObj_PlayerInfo *pInfo = m_pClient->m_Snap.m_paInfoByDDTeam[i];
+		const CNetObj_PlayerInfo *pInfo = m_pClient->m_Snap.m_paInfoByDDTeamScore[i];
 		if(!pInfo || pInfo->m_Team != Team)
 			continue;
 
-		if (rendered++ < 0) continue;
+		if(rendered++ < 0)
+			continue;
 
 		int DDTeam = m_pClient->m_Teams.Team(pInfo->m_ClientID);
 		int NextDDTeam = 0;
 
 		for(int j = i + 1; j < MAX_CLIENTS; j++)
 		{
-			const CNetObj_PlayerInfo *pInfo2 = m_pClient->m_Snap.m_paInfoByDDTeam[j];
+			const CNetObj_PlayerInfo *pInfo2 = m_pClient->m_Snap.m_paInfoByDDTeamScore[j];
 
 			if(!pInfo2 || pInfo2->m_Team != Team)
 				continue;
@@ -356,11 +351,11 @@ void CScoreboard::RenderScoreboard(float x, float y, float w, int Team, const ch
 			break;
 		}
 
-		if (OldDDTeam == -1)
+		if(OldDDTeam == -1)
 		{
-			for (int j = i - 1; j >= 0; j--)
+			for(int j = i - 1; j >= 0; j--)
 			{
-				const CNetObj_PlayerInfo *pInfo2 = m_pClient->m_Snap.m_paInfoByDDTeam[j];
+				const CNetObj_PlayerInfo *pInfo2 = m_pClient->m_Snap.m_paInfoByDDTeamScore[j];
 
 				if(!pInfo2 || pInfo2->m_Team != Team)
 					continue;
@@ -370,7 +365,7 @@ void CScoreboard::RenderScoreboard(float x, float y, float w, int Team, const ch
 			}
 		}
 
-		if (DDTeam != TEAM_FLOCK)
+		if(DDTeam != TEAM_FLOCK)
 		{
 			Graphics()->TextureClear();
 			Graphics()->QuadsBegin();
@@ -379,30 +374,30 @@ void CScoreboard::RenderScoreboard(float x, float y, float w, int Team, const ch
 
 			int Corners = 0;
 
-			if (OldDDTeam != DDTeam)
+			if(OldDDTeam != DDTeam)
 				Corners |= CUI::CORNER_TL | CUI::CORNER_TR;
-			if (NextDDTeam != DDTeam)
+			if(NextDDTeam != DDTeam)
 				Corners |= CUI::CORNER_BL | CUI::CORNER_BR;
 
 			RenderTools()->DrawRoundRectExt(x - 10.0f, y, w, LineHeight + Spacing, RoundRadius, Corners);
 
 			Graphics()->QuadsEnd();
 
-			if (NextDDTeam != DDTeam)
+			if(NextDDTeam != DDTeam)
 			{
 				char aBuf[64];
 				if(m_pClient->m_Snap.m_aTeamSize[0] > 8)
 				{
-					str_format(aBuf, sizeof(aBuf),"%d", DDTeam);
-					TextRender()->SetCursor(&Cursor, x - 10.0f, y + Spacing + FontSize - (FontSize/1.5f), FontSize/1.5f, TEXTFLAG_RENDER|TEXTFLAG_STOP_AT_END);
-					Cursor.m_LineWidth = NameLength+3;
+					str_format(aBuf, sizeof(aBuf), "%d", DDTeam);
+					TextRender()->SetCursor(&Cursor, x - 10.0f, y + Spacing + FontSize - (FontSize / 1.5f), FontSize / 1.5f, TEXTFLAG_RENDER | TEXTFLAG_STOP_AT_END);
+					Cursor.m_LineWidth = NameLength + 3;
 				}
 				else
 				{
-					str_format(aBuf, sizeof(aBuf),"Team %d", DDTeam);
-					tw = TextRender()->TextWidth(0, FontSize, aBuf, -1);
-					TextRender()->SetCursor(&Cursor, ScoreOffset+w/2.0f-tw/2.0f, y + LineHeight, FontSize/1.5f, TEXTFLAG_RENDER|TEXTFLAG_STOP_AT_END);
-					Cursor.m_LineWidth = NameLength+3;
+					str_format(aBuf, sizeof(aBuf), "Team %d", DDTeam);
+					tw = TextRender()->TextWidth(0, FontSize, aBuf, -1, -1.0f);
+					TextRender()->SetCursor(&Cursor, ScoreOffset + w / 2.0f - tw / 2.0f, y + LineHeight, FontSize / 1.5f, TEXTFLAG_RENDER | TEXTFLAG_STOP_AT_END);
+					Cursor.m_LineWidth = NameLength + 3;
 				}
 				TextRender()->TextEx(&Cursor, aBuf, -1);
 			}
@@ -416,31 +411,33 @@ void CScoreboard::RenderScoreboard(float x, float y, float w, int Team, const ch
 			Graphics()->TextureClear();
 			Graphics()->QuadsBegin();
 			Graphics()->SetColor(1.0f, 1.0f, 1.0f, 0.25f);
-			RenderTools()->DrawRoundRect(x, y, w-20.0f, LineHeight, RoundRadius);
+			RenderTools()->DrawRoundRect(x, y, w - 20.0f, LineHeight, RoundRadius);
 			Graphics()->QuadsEnd();
 		}
 
 		// score
 		if(m_pClient->m_GameInfo.m_TimeScore && g_Config.m_ClDDRaceScoreBoard)
 		{
-			if (pInfo->m_Score == -9999)
+			if(pInfo->m_Score == -9999)
 				aBuf[0] = 0;
 			else
 			{
 				int Time = abs(pInfo->m_Score);
-				str_format(aBuf, sizeof(aBuf), "%02d:%02d", Time/60, Time%60);
+				if(Time / 3600)
+					str_format(aBuf, sizeof(aBuf), "%02d:%02d:%02d", Time / 3600, (Time / 60) % 60, Time % 60);
+				else
+					str_format(aBuf, sizeof(aBuf), "%02d:%02d", Time / 60, Time % 60);
 			}
 		}
 		else
 			str_format(aBuf, sizeof(aBuf), "%d", clamp(pInfo->m_Score, -999, 99999));
-		tw = TextRender()->TextWidth(0, FontSize, aBuf, -1);
-		TextRender()->SetCursor(&Cursor, ScoreOffset+ScoreLength-tw, y + (LineHeight - FontSize) / 2.f, FontSize, TEXTFLAG_RENDER);
+		tw = TextRender()->TextWidth(0, FontSize, aBuf, -1, -1.0f);
+		TextRender()->SetCursor(&Cursor, ScoreOffset + ScoreLength - tw, y + (LineHeight - FontSize) / 2.f, FontSize, TEXTFLAG_RENDER);
 		TextRender()->TextEx(&Cursor, aBuf, -1);
 
 		// flag
-		if(m_pClient->m_Snap.m_pGameInfoObj->m_GameFlags&GAMEFLAG_FLAGS &&
-			m_pClient->m_Snap.m_pGameDataObj && (m_pClient->m_Snap.m_pGameDataObj->m_FlagCarrierRed == pInfo->m_ClientID ||
-			m_pClient->m_Snap.m_pGameDataObj->m_FlagCarrierBlue == pInfo->m_ClientID))
+		if(m_pClient->m_Snap.m_pGameInfoObj->m_GameFlags & GAMEFLAG_FLAGS &&
+			m_pClient->m_Snap.m_pGameDataObj && (m_pClient->m_Snap.m_pGameDataObj->m_FlagCarrierRed == pInfo->m_ClientID || m_pClient->m_Snap.m_pGameDataObj->m_FlagCarrierBlue == pInfo->m_ClientID))
 		{
 			Graphics()->BlendNormal();
 			Graphics()->TextureSet(g_pData->m_aImages[IMAGE_GAME].m_Id);
@@ -449,7 +446,7 @@ void CScoreboard::RenderScoreboard(float x, float y, float w, int Team, const ch
 			RenderTools()->SelectSprite(m_pClient->m_Snap.m_pGameDataObj->m_FlagCarrierBlue == pInfo->m_ClientID ? SPRITE_FLAG_BLUE : SPRITE_FLAG_RED, SPRITE_FLAG_FLIP_X);
 
 			float Size = LineHeight;
-			IGraphics::CQuadItem QuadItem(TeeOffset+0.0f, y-5.0f-Spacing/2.0f, Size/2.0f, Size);
+			IGraphics::CQuadItem QuadItem(TeeOffset + 0.0f, y - 5.0f - Spacing / 2.0f, Size / 2.0f, Size);
 			Graphics()->QuadsDrawTL(&QuadItem, 1);
 			Graphics()->QuadsEnd();
 		}
@@ -457,10 +454,10 @@ void CScoreboard::RenderScoreboard(float x, float y, float w, int Team, const ch
 		// avatar
 		CTeeRenderInfo TeeInfo = m_pClient->m_aClients[pInfo->m_ClientID].m_RenderInfo;
 		TeeInfo.m_Size *= TeeSizeMod;
-		RenderTools()->RenderTee(CAnimState::GetIdle(), &TeeInfo, EMOTE_NORMAL, vec2(1.0f, 0.0f), vec2(TeeOffset+TeeLength/2, y+LineHeight/2));
+		RenderTools()->RenderTee(CAnimState::GetIdle(), &TeeInfo, EMOTE_NORMAL, vec2(1.0f, 0.0f), vec2(TeeOffset + TeeLength / 2, y + LineHeight / 2));
 
 		// name
-		TextRender()->SetCursor(&Cursor, NameOffset, y + (LineHeight - FontSize) / 2.f, FontSize, TEXTFLAG_RENDER|TEXTFLAG_STOP_AT_END);
+		TextRender()->SetCursor(&Cursor, NameOffset, y + (LineHeight - FontSize) / 2.f, FontSize, TEXTFLAG_RENDER | TEXTFLAG_STOP_AT_END);
 		if(m_pClient->m_aClients[pInfo->m_ClientID].m_AuthLevel)
 		{
 			ColorRGBA Color = color_cast<ColorRGBA>(ColorHSLA(g_Config.m_ClAuthedPlayerColor));
@@ -470,9 +467,8 @@ void CScoreboard::RenderScoreboard(float x, float y, float w, int Team, const ch
 		if(g_Config.m_ClShowIDs)
 		{
 			char aId[64] = "";
-			str_format(aId, sizeof(aId)," %2d: ", pInfo->m_ClientID);
-			str_append(aId, m_pClient->m_aClients[pInfo->m_ClientID].m_aName,sizeof(aId));
-			Cursor.m_LineWidth = NameLength+8;
+			str_format(aId, sizeof(aId), "%2d: %s", pInfo->m_ClientID, m_pClient->m_aClients[pInfo->m_ClientID].m_aName);
+			Cursor.m_LineWidth = NameLength;
 			TextRender()->TextEx(&Cursor, aId, -1);
 		}
 		else
@@ -483,7 +479,7 @@ void CScoreboard::RenderScoreboard(float x, float y, float w, int Team, const ch
 
 		// clan
 		if(str_comp(m_pClient->m_aClients[pInfo->m_ClientID].m_aClan,
-				m_pClient->m_aClients[GameClient()->m_LocalIDs[g_Config.m_ClDummy]].m_aClan) == 0)
+			   m_pClient->m_aClients[GameClient()->m_LocalIDs[g_Config.m_ClDummy]].m_aClan) == 0)
 		{
 			ColorRGBA Color = color_cast<ColorRGBA>(ColorHSLA(g_Config.m_ClSameClanColor));
 			TextRender()->TextColor(Color);
@@ -491,8 +487,8 @@ void CScoreboard::RenderScoreboard(float x, float y, float w, int Team, const ch
 		else
 			TextRender()->TextColor(1.0f, 1.0f, 1.0f, 1.0f);
 
-		tw = TextRender()->TextWidth(nullptr, FontSize, m_pClient->m_aClients[pInfo->m_ClientID].m_aClan, -1);
-		TextRender()->SetCursor(&Cursor, ClanOffset + ClanLength / 2 - tw / 2, y + (LineHeight - FontSize) / 2.f, FontSize, TEXTFLAG_RENDER|TEXTFLAG_STOP_AT_END);
+		tw = TextRender()->TextWidth(nullptr, FontSize, m_pClient->m_aClients[pInfo->m_ClientID].m_aClan, -1, -1.0f);
+		TextRender()->SetCursor(&Cursor, ClanOffset + ClanLength / 2 - tw / 2, y + (LineHeight - FontSize) / 2.f, FontSize, TEXTFLAG_RENDER | TEXTFLAG_STOP_AT_END);
 		Cursor.m_LineWidth = ClanLength;
 		TextRender()->TextEx(&Cursor, m_pClient->m_aClients[pInfo->m_ClientID].m_aClan, -1);
 
@@ -501,7 +497,7 @@ void CScoreboard::RenderScoreboard(float x, float y, float w, int Team, const ch
 		// country flag
 		ColorRGBA Color(1.0f, 1.0f, 1.0f, 0.5f);
 		m_pClient->m_pCountryFlags->Render(m_pClient->m_aClients[pInfo->m_ClientID].m_Country, &Color,
-											CountryOffset, y+(Spacing+TeeSizeMod*5.0f)/2.0f, CountryLength, LineHeight-Spacing-TeeSizeMod*5.0f);
+			CountryOffset, y + (Spacing + TeeSizeMod * 5.0f) / 2.0f, CountryLength, LineHeight - Spacing - TeeSizeMod * 5.0f);
 
 		// ping
 		if(g_Config.m_ClEnablePingColor)
@@ -510,20 +506,28 @@ void CScoreboard::RenderScoreboard(float x, float y, float w, int Team, const ch
 			TextRender()->TextColor(rgb);
 		}
 		str_format(aBuf, sizeof(aBuf), "%d", clamp(pInfo->m_Latency, 0, 999));
-		tw = TextRender()->TextWidth(nullptr, FontSize, aBuf, -1);
-		TextRender()->SetCursor(&Cursor, PingOffset+PingLength-tw, y + (LineHeight - FontSize) / 2.f, FontSize, TEXTFLAG_RENDER|TEXTFLAG_STOP_AT_END);
+		tw = TextRender()->TextWidth(nullptr, FontSize, aBuf, -1, -1.0f);
+		TextRender()->SetCursor(&Cursor, PingOffset + PingLength - tw, y + (LineHeight - FontSize) / 2.f, FontSize, TEXTFLAG_RENDER | TEXTFLAG_STOP_AT_END);
 		Cursor.m_LineWidth = PingLength;
 		TextRender()->TextEx(&Cursor, aBuf, -1);
 
 		TextRender()->TextColor(1.0f, 1.0f, 1.0f, 1.0f);
 
-		y += LineHeight+Spacing;
-		if (lower32 || upper32) {
-			if (rendered == 32) break;
-		} else if (lower24 || upper24) {
-			if (rendered == 24) break;
-		} else {
-			if (rendered == 16) break;
+		y += LineHeight + Spacing;
+		if(lower32 || upper32)
+		{
+			if(rendered == 32)
+				break;
+		}
+		else if(lower24 || upper24)
+		{
+			if(rendered == 24)
+				break;
+		}
+		else
+		{
+			if(rendered == 16)
+				break;
 		}
 	}
 }
@@ -531,9 +535,9 @@ void CScoreboard::RenderScoreboard(float x, float y, float w, int Team, const ch
 void CScoreboard::RenderRecordingNotification(float x)
 {
 	if(!m_pClient->DemoRecorder(RECORDER_MANUAL)->IsRecording() &&
-	   !m_pClient->DemoRecorder(RECORDER_AUTO)->IsRecording() &&
-	   !m_pClient->DemoRecorder(RECORDER_RACE)->IsRecording() &&
-	   !m_pClient->DemoRecorder(RECORDER_REPLAYS)->IsRecording())
+		!m_pClient->DemoRecorder(RECORDER_AUTO)->IsRecording() &&
+		!m_pClient->DemoRecorder(RECORDER_RACE)->IsRecording() &&
+		!m_pClient->DemoRecorder(RECORDER_REPLAYS)->IsRecording())
 	{
 		return;
 	}
@@ -546,19 +550,19 @@ void CScoreboard::RenderRecordingNotification(float x)
 	if(m_pClient->DemoRecorder(RECORDER_MANUAL)->IsRecording())
 	{
 		Seconds = m_pClient->DemoRecorder(RECORDER_MANUAL)->Length();
-		str_format(aBuf2, sizeof(aBuf2), Localize("Manual %3d:%02d  "), Seconds/60, Seconds%60);
+		str_format(aBuf2, sizeof(aBuf2), Localize("Manual %3d:%02d  "), Seconds / 60, Seconds % 60);
 		str_append(aBuf, aBuf2, sizeof(aBuf));
 	}
 	if(m_pClient->DemoRecorder(RECORDER_RACE)->IsRecording())
 	{
 		Seconds = m_pClient->DemoRecorder(RECORDER_RACE)->Length();
-		str_format(aBuf2, sizeof(aBuf2), Localize("Race %3d:%02d  "), Seconds/60, Seconds%60);
+		str_format(aBuf2, sizeof(aBuf2), Localize("Race %3d:%02d  "), Seconds / 60, Seconds % 60);
 		str_append(aBuf, aBuf2, sizeof(aBuf));
 	}
 	if(m_pClient->DemoRecorder(RECORDER_AUTO)->IsRecording())
 	{
 		Seconds = m_pClient->DemoRecorder(RECORDER_AUTO)->Length();
-		str_format(aBuf2, sizeof(aBuf2), Localize("Auto %3d:%02d  "), Seconds/60, Seconds%60);
+		str_format(aBuf2, sizeof(aBuf2), Localize("Auto %3d:%02d  "), Seconds / 60, Seconds % 60);
 		str_append(aBuf, aBuf2, sizeof(aBuf));
 	}
 	if(m_pClient->DemoRecorder(RECORDER_REPLAYS)->IsRecording())
@@ -568,26 +572,25 @@ void CScoreboard::RenderRecordingNotification(float x)
 		str_append(aBuf, aBuf2, sizeof(aBuf));
 	}
 
-	float w = TextRender()->TextWidth(0, 20.0f, aBuf, -1);
+	float w = TextRender()->TextWidth(0, 20.0f, aBuf, -1, -1.0f);
 
 	//draw the box
 	Graphics()->BlendNormal();
 	Graphics()->TextureClear();
 	Graphics()->QuadsBegin();
 	Graphics()->SetColor(0.0f, 0.0f, 0.0f, 0.4f);
-	RenderTools()->DrawRoundRectExt(x, 0.0f, w+60.0f, 50.0f, 15.0f, CUI::CORNER_B);
+	RenderTools()->DrawRoundRectExt(x, 0.0f, w + 60.0f, 50.0f, 15.0f, CUI::CORNER_B);
 	Graphics()->QuadsEnd();
 
 	//draw the red dot
 	Graphics()->QuadsBegin();
 	Graphics()->SetColor(1.0f, 0.0f, 0.0f, 1.0f);
-	RenderTools()->DrawRoundRect(x+20, 15.0f, 20.0f, 20.0f, 10.0f);
+	RenderTools()->DrawRoundRect(x + 20, 15.0f, 20.0f, 20.0f, 10.0f);
 	Graphics()->QuadsEnd();
 
-	TextRender()->Text(0, x+50.0f, (50.f - 20.f) / 2.f, 20.0f, aBuf, -1);
+	TextRender()->Text(0, x + 50.0f, (50.f - 20.f) / 2.f, 20.0f, aBuf, -1.0f);
 }
 
-
 void CScoreboard::OnRender()
 {
 	if(!Active())
@@ -597,9 +600,8 @@ void CScoreboard::OnRender()
 	if(m_pClient->m_pMotd->IsActive())
 		m_pClient->m_pMotd->Clear();
 
-
-	float Width = 400*3.0f*Graphics()->ScreenAspect();
-	float Height = 400*3.0f;
+	float Width = 400 * 3.0f * Graphics()->ScreenAspect();
+	float Height = 400 * 3.0f;
 
 	Graphics()->MapScreen(0, 0, Width, Height);
 
@@ -607,23 +609,26 @@ void CScoreboard::OnRender()
 
 	if(m_pClient->m_Snap.m_pGameInfoObj)
 	{
-		if(!(m_pClient->m_Snap.m_pGameInfoObj->m_GameFlags&GAMEFLAG_TEAMS))
+		if(!(m_pClient->m_Snap.m_pGameInfoObj->m_GameFlags & GAMEFLAG_TEAMS))
 		{
 			if(m_pClient->m_Snap.m_aTeamSize[0] > 48)
 			{
-				RenderScoreboard(Width/2-w, 150.0f, w, -4, 0);
-				RenderScoreboard(Width/2, 150.0f, w, -5, "");
-			} else if(m_pClient->m_Snap.m_aTeamSize[0] > 32)
+				RenderScoreboard(Width / 2 - w, 150.0f, w, -4, 0);
+				RenderScoreboard(Width / 2, 150.0f, w, -5, "");
+			}
+			else if(m_pClient->m_Snap.m_aTeamSize[0] > 32)
 			{
-				RenderScoreboard(Width/2-w, 150.0f, w, -7, 0);
-				RenderScoreboard(Width/2, 150.0f, w, -8, "");
-			} else if(m_pClient->m_Snap.m_aTeamSize[0] > 16)
+				RenderScoreboard(Width / 2 - w, 150.0f, w, -7, 0);
+				RenderScoreboard(Width / 2, 150.0f, w, -8, "");
+			}
+			else if(m_pClient->m_Snap.m_aTeamSize[0] > 16)
 			{
-				RenderScoreboard(Width/2-w, 150.0f, w, -6, 0);
-				RenderScoreboard(Width/2, 150.0f, w, -3, "");
-			} else
+				RenderScoreboard(Width / 2 - w, 150.0f, w, -6, 0);
+				RenderScoreboard(Width / 2, 150.0f, w, -3, "");
+			}
+			else
 			{
-				RenderScoreboard(Width/2-w/2, 150.0f, w, 0, 0);
+				RenderScoreboard(Width / 2 - w / 2, 150.0f, w, 0, 0);
 			}
 		}
 		else
@@ -631,7 +636,7 @@ void CScoreboard::OnRender()
 			const char *pRedClanName = GetClanName(TEAM_RED);
 			const char *pBlueClanName = GetClanName(TEAM_BLUE);
 
-			if(m_pClient->m_Snap.m_pGameInfoObj->m_GameStateFlags&GAMESTATEFLAG_GAMEOVER && m_pClient->m_Snap.m_pGameDataObj)
+			if(m_pClient->m_Snap.m_pGameInfoObj->m_GameStateFlags & GAMESTATEFLAG_GAMEOVER && m_pClient->m_Snap.m_pGameDataObj)
 			{
 				char aText[256];
 				str_copy(aText, Localize("Draw!"), sizeof(aText));
@@ -651,18 +656,18 @@ void CScoreboard::OnRender()
 						str_copy(aText, Localize("Blue team wins!"), sizeof(aText));
 				}
 
-				float w = TextRender()->TextWidth(0, 86.0f, aText, -1);
-				TextRender()->Text(0, Width/2-w/2, 39, 86.0f, aText, -1);
+				float w = TextRender()->TextWidth(0, 86.0f, aText, -1, -1.0f);
+				TextRender()->Text(0, Width / 2 - w / 2, 39, 86.0f, aText, -1.0f);
 			}
 
-			RenderScoreboard(Width/2-w-5.0f, 150.0f, w, TEAM_RED, pRedClanName ? pRedClanName : Localize("Red team"));
-			RenderScoreboard(Width/2+5.0f, 150.0f, w, TEAM_BLUE, pBlueClanName ? pBlueClanName : Localize("Blue team"));
+			RenderScoreboard(Width / 2 - w - 5.0f, 150.0f, w, TEAM_RED, pRedClanName ? pRedClanName : Localize("Red team"));
+			RenderScoreboard(Width / 2 + 5.0f, 150.0f, w, TEAM_BLUE, pBlueClanName ? pBlueClanName : Localize("Blue team"));
 		}
 	}
 
-	RenderGoals(Width/2-w/2, 150+760+10, w);
-	RenderSpectators(Width/2-w/2, 150+760+10+50+10, w);
-	RenderRecordingNotification((Width/7)*4);
+	RenderGoals(Width / 2 - w / 2, 150 + 760 + 10, w);
+	RenderSpectators(Width / 2 - w / 2, 150 + 760 + 10 + 50 + 10, w);
+	RenderRecordingNotification((Width / 7) * 4);
 }
 
 bool CScoreboard::Active()
@@ -682,7 +687,7 @@ bool CScoreboard::Active()
 	}
 
 	// if the game is over
-	if(m_pClient->m_Snap.m_pGameInfoObj && m_pClient->m_Snap.m_pGameInfoObj->m_GameStateFlags&GAMESTATEFLAG_GAMEOVER)
+	if(m_pClient->m_Snap.m_pGameInfoObj && m_pClient->m_Snap.m_pGameInfoObj->m_GameStateFlags & GAMESTATEFLAG_GAMEOVER)
 		return true;
 
 	return false;
