@@ -2,13 +2,14 @@
 /* If you are missing that file, acquire a complete release at teeworlds.com.                */
 #include <math.h>
 
-#include <base/system.h>
 #include <base/math.h>
+#include <base/system.h>
 #include <ctime>
 
+#include <engine/engine.h>
 #include <engine/graphics.h>
-#include <engine/storage.h>
 #include <engine/shared/config.h>
+#include <engine/storage.h>
 
 #include "skins.h"
 
@@ -49,25 +50,31 @@ int CSkins::SkinScan(const char *pName, int IsDir, int DirType, void *pUser)
 			return 0;
 	}
 
-	char aBuf[512];
+	char aBuf[MAX_PATH_LENGTH];
 	str_format(aBuf, sizeof(aBuf), "skins/%s", pName);
+	return pSelf->LoadSkin(aNameWithoutPng, aBuf, DirType);
+}
+
+int CSkins::LoadSkin(const char *pName, const char *pPath, int DirType)
+{
+	char aBuf[512];
 	CImageInfo Info;
-	if(!pSelf->Graphics()->LoadPNG(&Info, aBuf, DirType))
+	if(!Graphics()->LoadPNG(&Info, pPath, DirType))
 	{
 		str_format(aBuf, sizeof(aBuf), "failed to load skin from %s", pName);
-		pSelf->Console()->Print(IConsole::OUTPUT_LEVEL_ADDINFO, "game", aBuf);
+		Console()->Print(IConsole::OUTPUT_LEVEL_ADDINFO, "game", aBuf);
 		return 0;
 	}
 
 	CSkin Skin;
-	Skin.m_IsVanilla = IsVanillaSkin(aNameWithoutPng);
-	Skin.m_OrgTexture = pSelf->Graphics()->LoadTextureRaw(Info.m_Width, Info.m_Height, Info.m_Format, Info.m_pData, Info.m_Format, 0);
+	Skin.m_IsVanilla = IsVanillaSkin(pName);
+	Skin.m_OrgTexture = Graphics()->LoadTextureRaw(Info.m_Width, Info.m_Height, Info.m_Format, Info.m_pData, Info.m_Format, 0);
 
 	int BodySize = 96; // body size
-	if (BodySize > Info.m_Height)
+	if(BodySize > Info.m_Height)
 		return 0;
 	unsigned char *d = (unsigned char *)Info.m_pData;
-	int Pitch = Info.m_Width*4;
+	int Pitch = Info.m_Width * 4;
 
 	// dig out blood color
 	{
@@ -75,11 +82,11 @@ int CSkins::SkinScan(const char *pName, int IsDir, int DirType, void *pUser)
 		for(int y = 0; y < BodySize; y++)
 			for(int x = 0; x < BodySize; x++)
 			{
-				if(d[y*Pitch+x*4+3] > 128)
+				if(d[y * Pitch + x * 4 + 3] > 128)
 				{
-					aColors[0] += d[y*Pitch+x*4+0];
-					aColors[1] += d[y*Pitch+x*4+1];
-					aColors[2] += d[y*Pitch+x*4+2];
+					aColors[0] += d[y * Pitch + x * 4 + 0];
+					aColors[1] += d[y * Pitch + x * 4 + 1];
+					aColors[2] += d[y * Pitch + x * 4 + 2];
 				}
 			}
 
@@ -90,15 +97,14 @@ int CSkins::SkinScan(const char *pName, int IsDir, int DirType, void *pUser)
 	int Step = Info.m_Format == CImageInfo::FORMAT_RGBA ? 4 : 3;
 
 	// make the texture gray scale
-	for(int i = 0; i < Info.m_Width*Info.m_Height; i++)
+	for(int i = 0; i < Info.m_Width * Info.m_Height; i++)
 	{
-		int v = (d[i*Step]+d[i*Step+1]+d[i*Step+2])/3;
-		d[i*Step] = v;
-		d[i*Step+1] = v;
-		d[i*Step+2] = v;
+		int v = (d[i * Step] + d[i * Step + 1] + d[i * Step + 2]) / 3;
+		d[i * Step] = v;
+		d[i * Step + 1] = v;
+		d[i * Step + 2] = v;
 	}
 
-
 	int Freq[256] = {0};
 	int OrgWeight = 0;
 	int NewWeight = 192;
@@ -107,8 +113,8 @@ int CSkins::SkinScan(const char *pName, int IsDir, int DirType, void *pUser)
 	for(int y = 0; y < BodySize; y++)
 		for(int x = 0; x < BodySize; x++)
 		{
-			if(d[y*Pitch+x*4+3] > 128)
-				Freq[d[y*Pitch+x*4]]++;
+			if(d[y * Pitch + x * 4 + 3] > 128)
+				Freq[d[y * Pitch + x * 4]]++;
 		}
 
 	for(int i = 1; i < 256; i++)
@@ -118,37 +124,36 @@ int CSkins::SkinScan(const char *pName, int IsDir, int DirType, void *pUser)
 	}
 
 	// reorder
-	int InvOrgWeight = 255-OrgWeight;
-	int InvNewWeight = 255-NewWeight;
+	int InvOrgWeight = 255 - OrgWeight;
+	int InvNewWeight = 255 - NewWeight;
 	for(int y = 0; y < BodySize; y++)
 		for(int x = 0; x < BodySize; x++)
 		{
-			int v = d[y*Pitch+x*4];
+			int v = d[y * Pitch + x * 4];
 			if(v <= OrgWeight)
-				v = (int)(((v/(float)OrgWeight) * NewWeight));
+				v = (int)(((v / (float)OrgWeight) * NewWeight));
 			else
-				v = (int)(((v-OrgWeight)/(float)InvOrgWeight)*InvNewWeight + NewWeight);
-			d[y*Pitch+x*4] = v;
-			d[y*Pitch+x*4+1] = v;
-			d[y*Pitch+x*4+2] = v;
+				v = (int)(((v - OrgWeight) / (float)InvOrgWeight) * InvNewWeight + NewWeight);
+			d[y * Pitch + x * 4] = v;
+			d[y * Pitch + x * 4 + 1] = v;
+			d[y * Pitch + x * 4 + 2] = v;
 		}
 
-	Skin.m_ColorTexture = pSelf->Graphics()->LoadTextureRaw(Info.m_Width, Info.m_Height, Info.m_Format, Info.m_pData, Info.m_Format, 0);
+	Skin.m_ColorTexture = Graphics()->LoadTextureRaw(Info.m_Width, Info.m_Height, Info.m_Format, Info.m_pData, Info.m_Format, 0);
 	free(Info.m_pData);
 
 	// set skin data
-	str_copy(Skin.m_aName, aNameWithoutPng, sizeof(Skin.m_aName));
+	str_copy(Skin.m_aName, pName, sizeof(Skin.m_aName));
 	if(g_Config.m_Debug)
 	{
 		str_format(aBuf, sizeof(aBuf), "load skin %s", Skin.m_aName);
-		pSelf->Console()->Print(IConsole::OUTPUT_LEVEL_ADDINFO, "game", aBuf);
+		Console()->Print(IConsole::OUTPUT_LEVEL_ADDINFO, "game", aBuf);
 	}
-	pSelf->m_aSkins.add(Skin);
+	m_aSkins.add(Skin);
 
 	return 0;
 }
 
-
 void CSkins::OnInit()
 {
 	m_EventSkinPrefix[0] = '\0';
@@ -156,7 +161,7 @@ void CSkins::OnInit()
 	if(g_Config.m_Events)
 	{
 		time_t rawtime;
-		struct tm* timeinfo;
+		struct tm *timeinfo;
 		std::time(&rawtime);
 		timeinfo = localtime(&rawtime);
 		if(timeinfo->tm_mon == 11 && timeinfo->tm_mday >= 24 && timeinfo->tm_mday <= 26)
@@ -190,22 +195,22 @@ const CSkins::CSkin *CSkins::Get(int Index)
 	{
 		Index = Find("default");
 
-		if (Index < 0)
+		if(Index < 0)
 			Index = 0;
 	}
 	return &m_aSkins[Index % m_aSkins.size()];
 }
 
-int CSkins::Find(const char *pName) const
+int CSkins::Find(const char *pName)
 {
 	const char *pSkinPrefix = m_EventSkinPrefix[0] ? m_EventSkinPrefix : g_Config.m_ClSkinPrefix;
 	if(g_Config.m_ClVanillaSkinsOnly && !IsVanillaSkin(pName))
 	{
 		return -1;
 	}
-	else if(pSkinPrefix)
+	else if(pSkinPrefix && pSkinPrefix[0])
 	{
-		char aBuf[64];
+		char aBuf[24];
 		str_format(aBuf, sizeof(aBuf), "%s_%s", pSkinPrefix, pName);
 		// If we find something, use it, otherwise fall back to normal skins.
 		int Result = FindImpl(aBuf);
@@ -217,14 +222,47 @@ int CSkins::Find(const char *pName) const
 	return FindImpl(pName);
 }
 
-int CSkins::FindImpl(const char *pName) const
+int CSkins::FindImpl(const char *pName)
 {
-	for(int i = 0; i < m_aSkins.size(); i++)
+	auto r = ::find_binary(m_aSkins.all(), pName);
+	if(!r.empty())
+		return &r.front() - m_aSkins.base_ptr();
+
+	if(str_comp(pName, "default") == 0)
+		return -1;
+
+	if(!g_Config.m_ClDownloadSkins)
+		return -1;
+
+	if(str_find(pName, "/") != 0)
+		return -1;
+
+	auto d = ::find_binary(m_aDownloadSkins.all(), pName);
+	if(!d.empty())
 	{
-		if(str_comp(m_aSkins[i].m_aName, pName) == 0)
+		if(d.front().m_pTask && d.front().m_pTask->State() == HTTP_DONE)
 		{
-			return i;
+			char aPath[MAX_PATH_LENGTH];
+			str_format(aPath, sizeof(aPath), "downloadedskins/%s.png", d.front().m_aName);
+			Storage()->RenameFile(d.front().m_aPath, aPath, IStorage::TYPE_SAVE);
+			LoadSkin(d.front().m_aName, aPath, IStorage::TYPE_SAVE);
+			d.front().m_pTask = nullptr;
 		}
+		if(d.front().m_pTask && (d.front().m_pTask->State() == HTTP_ERROR || d.front().m_pTask->State() == HTTP_ABORTED))
+		{
+			d.front().m_pTask = nullptr;
+		}
+		return -1;
 	}
+
+	CDownloadSkin Skin;
+	str_copy(Skin.m_aName, pName, sizeof(Skin.m_aName));
+
+	char aUrl[256];
+	str_format(aUrl, sizeof(aUrl), "%s%s.png", g_Config.m_ClSkinDownloadUrl, pName);
+	str_format(Skin.m_aPath, sizeof(Skin.m_aPath), "downloadedskins/%s.%d.tmp", pName, pid());
+	Skin.m_pTask = std::make_shared<CGetFile>(Storage(), aUrl, Skin.m_aPath, IStorage::TYPE_SAVE, CTimeout{0, 0, 0}, false);
+	m_pClient->Engine()->AddJob(Skin.m_pTask);
+	m_aDownloadSkins.add(Skin);
 	return -1;
 }
