@@ -3,8 +3,8 @@
 #ifndef GAME_CLIENT_PREDICTION_ENTITIES_CHARACTER_H
 #define GAME_CLIENT_PREDICTION_ENTITIES_CHARACTER_H
 
-#include <game/client/prediction/entity.h>
 #include "projectile.h"
+#include <game/client/prediction/entity.h>
 
 #include <game/gamecore.h>
 #include <game/generated/client_data.h>
@@ -31,6 +31,7 @@ enum
 class CCharacter : public CEntity
 {
 	friend class CGameWorld;
+
 public:
 	//character's size
 	static const int ms_PhysSize = 28;
@@ -51,6 +52,7 @@ public:
 
 	void OnPredictedInput(CNetObj_PlayerInput *pNewInput);
 	void OnDirectInput(CNetObj_PlayerInput *pNewInput);
+	void ResetInput();
 	void FireWeapon();
 
 	bool TakeDamage(vec2 Force, int Dmg, int From, int Weapon);
@@ -63,7 +65,7 @@ public:
 
 	bool m_Alive;
 
-	CTeamsCore* TeamsCore();
+	CTeamsCore *TeamsCore();
 	bool Freeze(int Time);
 	bool Freeze();
 	bool UnFreeze();
@@ -82,11 +84,11 @@ public:
 	bool m_EndlessHook;
 	enum
 	{
-		HIT_ALL=0,
-		DISABLE_HIT_HAMMER=1,
-		DISABLE_HIT_SHOTGUN=2,
-		DISABLE_HIT_GRENADE=4,
-		DISABLE_HIT_LASER=8
+		HIT_ALL = 0,
+		DISABLE_HIT_HAMMER = 1,
+		DISABLE_HIT_SHOTGUN = 2,
+		DISABLE_HIT_GRENADE = 4,
+		DISABLE_HIT_LASER = 8
 	};
 	int m_Hit;
 	int m_TuneZone;
@@ -104,10 +106,10 @@ public:
 	int GetLastWeapon() { return m_LastWeapon; };
 	void SetLastWeapon(int LastWeap) { m_LastWeapon = LastWeap; };
 	int GetActiveWeapon() { return m_Core.m_ActiveWeapon; };
-	void SetActiveWeapon(int ActiveWeap) { m_Core.m_ActiveWeapon = ActiveWeap; };
+	void SetActiveWeapon(int ActiveWeap);
 	CCharacterCore GetCore() { return m_Core; };
 	void SetCore(CCharacterCore Core) { m_Core = Core; };
-	CCharacterCore* Core() { return &m_Core; };
+	CCharacterCore *Core() { return &m_Core; };
 	bool GetWeaponGot(int Type) { return m_aWeapons[Type].m_Got; };
 	void SetWeaponGot(int Type, bool Value) { m_aWeapons[Type].m_Got = Value; };
 	int GetWeaponAmmo(int Type) { return m_aWeapons[Type].m_Ammo; };
@@ -134,6 +136,7 @@ public:
 	bool Match(CCharacter *pChar);
 	void ResetPrediction();
 	CCharacter() { m_Alive = false; }
+	void SetTuneZone(int Zone);
 
 private:
 	// weapon info
@@ -187,6 +190,9 @@ private:
 	void HandleTuneLayer();
 
 	int m_StrongWeakID;
+
+	int m_LastWeaponSwitchTick;
+	int m_LastTuneZoneTick;
 };
 
 enum
