@@ -3,17 +3,17 @@
 #ifndef GAME_CLIENT_PREDICTION_ENTITIES_PROJECTILE_H
 #define GAME_CLIENT_PREDICTION_ENTITIES_PROJECTILE_H
 
-#include <game/client/prediction/entity.h>
 #include "character.h"
+#include <game/client/prediction/entity.h>
 #include <game/extrainfo.h>
 
 class CProjectile : public CEntity
 {
 	friend class CGameWorld;
 	friend class CItems;
+
 public:
-	CProjectile
-	(
+	CProjectile(
 		CGameWorld *pGameWorld,
 		int Type,
 		int Owner,
@@ -25,8 +25,7 @@ public:
 		float Force,
 		int SoundImpact,
 		int Layer = 0,
-		int Number = 0
-	);
+		int Number = 0);
 
 	vec2 GetPos(float Time);
 	void FillInfo(CNetObj_Projectile *pProj);
