@@ -2,14 +2,14 @@
 /* If you are missing that file, acquire a complete release at teeworlds.com.                */
 
 #include "gameworld.h"
-#include "entity.h"
 #include "entities/character.h"
-#include "entities/projectile.h"
 #include "entities/laser.h"
 #include "entities/pickup.h"
+#include "entities/projectile.h"
+#include "entity.h"
 #include <algorithm>
-#include <utility>
 #include <engine/shared/config.h>
+#include <utility>
 
 //////////////////////////////////////////////////
 // game world
@@ -63,7 +63,7 @@ int CGameWorld::FindEntities(vec2 Pos, float Radius, CEntity **ppEnts, int Max,
 	int Num = 0;
 	for(CEntity *pEnt = m_apFirstEntityTypes[Type]; pEnt; pEnt = pEnt->m_pNextTypeEntity)
 	{
-		if(distance(pEnt->m_Pos, Pos) < Radius+pEnt->m_ProximityRadius)
+		if(distance(pEnt->m_Pos, Pos) < Radius + pEnt->m_ProximityRadius)
 		{
 			if(ppEnts)
 				ppEnts[Num] = pEnt;
@@ -109,7 +109,7 @@ void CGameWorld::InsertEntity(CEntity *pEnt, bool Last)
 
 	if(pEnt->m_ObjType == ENTTYPE_CHARACTER)
 	{
-		auto *pChar = (CCharacter*) pEnt;
+		auto *pChar = (CCharacter *)pEnt;
 		int ID = pChar->GetCID();
 		if(ID >= 0 && ID < MAX_CLIENTS)
 		{
@@ -148,7 +148,7 @@ void CGameWorld::RemoveEntity(CEntity *pEnt)
 
 	if(pEnt->m_ObjType == ENTTYPE_CHARACTER)
 	{
-		CCharacter *pChar = (CCharacter*) pEnt;
+		CCharacter *pChar = (CCharacter *)pEnt;
 		int ID = pChar->GetCID();
 		if(ID >= 0 && ID < MAX_CLIENTS)
 		{
@@ -166,7 +166,7 @@ void CGameWorld::RemoveEntities()
 {
 	// destroy objects marked for destruction
 	for(int i = 0; i < NUM_ENTTYPES; i++)
-		for(CEntity *pEnt = m_apFirstEntityTypes[i]; pEnt; )
+		for(CEntity *pEnt = m_apFirstEntityTypes[i]; pEnt;)
 		{
 			m_pNextTraverseEntity = pEnt->m_pNextTypeEntity;
 			if(pEnt->m_MarkedForDestroy)
@@ -178,7 +178,7 @@ void CGameWorld::RemoveEntities()
 		}
 }
 
-bool distCompare(std::pair<float,int> a, std::pair<float,int> b)
+bool distCompare(std::pair<float, int> a, std::pair<float, int> b)
 {
 	return (a.first < b.first);
 }
@@ -187,7 +187,7 @@ void CGameWorld::Tick()
 {
 	// update all objects
 	for(int i = 0; i < NUM_ENTTYPES; i++)
-		for(CEntity *pEnt = m_apFirstEntityTypes[i]; pEnt; )
+		for(CEntity *pEnt = m_apFirstEntityTypes[i]; pEnt;)
 		{
 			m_pNextTraverseEntity = pEnt->m_pNextTypeEntity;
 			pEnt->Tick();
@@ -195,7 +195,7 @@ void CGameWorld::Tick()
 		}
 
 	for(int i = 0; i < NUM_ENTTYPES; i++)
-		for(CEntity *pEnt = m_apFirstEntityTypes[i]; pEnt; )
+		for(CEntity *pEnt = m_apFirstEntityTypes[i]; pEnt;)
 		{
 			m_pNextTraverseEntity = pEnt->m_pNextTypeEntity;
 			pEnt->TickDefered();
@@ -208,9 +208,8 @@ void CGameWorld::Tick()
 	OnModified();
 }
 
-
 // TODO: should be more general
-CCharacter *CGameWorld::IntersectCharacter(vec2 Pos0, vec2 Pos1, float Radius, vec2& NewPos, CCharacter *pNotThis, int CollideWith, class CCharacter *pThisOnly)
+CCharacter *CGameWorld::IntersectCharacter(vec2 Pos0, vec2 Pos1, float Radius, vec2 &NewPos, CCharacter *pNotThis, int CollideWith, class CCharacter *pThisOnly)
 {
 	// Find other players
 	float ClosestLen = distance(Pos0, Pos1) * 100.0f;
@@ -230,7 +229,7 @@ CCharacter *CGameWorld::IntersectCharacter(vec2 Pos0, vec2 Pos1, float Radius, v
 
 		vec2 IntersectPos = closest_point_on_line(Pos0, Pos1, p->m_Pos);
 		float Len = distance(p->m_Pos, IntersectPos);
-		if(Len < p->m_ProximityRadius+Radius)
+		if(Len < p->m_ProximityRadius + Radius)
 		{
 			Len = distance(Pos0, IntersectPos);
 			if(Len < ClosestLen)
@@ -247,7 +246,7 @@ CCharacter *CGameWorld::IntersectCharacter(vec2 Pos0, vec2 Pos1, float Radius, v
 
 std::list<class CCharacter *> CGameWorld::IntersectedCharacters(vec2 Pos0, vec2 Pos1, float Radius, class CEntity *pNotThis)
 {
-	std::list< CCharacter * > listOfChars;
+	std::list<CCharacter *> listOfChars;
 
 	CCharacter *pChr = (CCharacter *)FindFirst(CGameWorld::ENTTYPE_CHARACTER);
 	for(; pChr; pChr = (CCharacter *)pChr->TypeNext())
@@ -257,7 +256,7 @@ std::list<class CCharacter *> CGameWorld::IntersectedCharacters(vec2 Pos0, vec2
 
 		vec2 IntersectPos = closest_point_on_line(Pos0, Pos1, pChr->m_Pos);
 		float Len = distance(pChr->m_Pos, IntersectPos);
-		if(Len < pChr->m_ProximityRadius+Radius)
+		if(Len < pChr->m_ProximityRadius + Radius)
 		{
 			listOfChars.push_back(pChr);
 		}
@@ -270,7 +269,7 @@ void CGameWorld::ReleaseHooked(int ClientID)
 	CCharacter *pChr = (CCharacter *)CGameWorld::FindFirst(CGameWorld::ENTTYPE_CHARACTER);
 	for(; pChr; pChr = (CCharacter *)pChr->TypeNext())
 	{
-		CCharacterCore* Core = pChr->Core();
+		CCharacterCore *Core = pChr->Core();
 		if(Core->m_HookedPlayer == ClientID)
 		{
 			Core->m_HookedPlayer = -1;
@@ -294,7 +293,7 @@ CEntity *CGameWorld::GetEntity(int ID, int EntType)
 	return 0;
 }
 
-void CGameWorld::CreateExplosion(vec2 Pos, int Owner, int Weapon, bool NoDamage, int ActivatedTeam, int64_t Mask)
+void CGameWorld::CreateExplosion(vec2 Pos, int Owner, int Weapon, bool NoDamage, int ActivatedTeam, int64 Mask)
 {
 	if(Owner < 0 && m_WorldConfig.m_IsSolo && !(Weapon == WEAPON_SHOTGUN && m_WorldConfig.m_IsDDRace))
 		return;
@@ -303,16 +302,16 @@ void CGameWorld::CreateExplosion(vec2 Pos, int Owner, int Weapon, bool NoDamage,
 	CEntity *apEnts[MAX_CLIENTS];
 	float Radius = 135.0f;
 	float InnerRadius = 48.0f;
-	int Num = FindEntities(Pos, Radius, (CEntity**)apEnts, MAX_CLIENTS, CGameWorld::ENTTYPE_CHARACTER);
+	int Num = FindEntities(Pos, Radius, (CEntity **)apEnts, MAX_CLIENTS, CGameWorld::ENTTYPE_CHARACTER);
 	for(int i = 0; i < Num; i++)
 	{
-		CCharacter *pChar = (CCharacter*) apEnts[i];
+		CCharacter *pChar = (CCharacter *)apEnts[i];
 		vec2 Diff = pChar->m_Pos - Pos;
-		vec2 ForceDir(0,1);
+		vec2 ForceDir(0, 1);
 		float l = length(Diff);
 		if(l)
 			ForceDir = normalize(Diff);
-		l = 1-clamp((l-InnerRadius)/(Radius-InnerRadius), 0.0f, 1.0f);
+		l = 1 - clamp((l - InnerRadius) / (Radius - InnerRadius), 0.0f, 1.0f);
 		float Strength;
 		if(Owner == -1 || !GetCharacterByID(Owner))
 			Strength = Tuning()->m_ExplosionStrength;
@@ -321,14 +320,14 @@ void CGameWorld::CreateExplosion(vec2 Pos, int Owner, int Weapon, bool NoDamage,
 
 		float Dmg = Strength * l;
 		if((int)Dmg)
-			if((GetCharacterByID(Owner) ? !(GetCharacterByID(Owner)->m_Hit&CCharacter::DISABLE_HIT_GRENADE) : g_Config.m_SvHit || NoDamage) || Owner == pChar->GetCID())
+			if((GetCharacterByID(Owner) ? !(GetCharacterByID(Owner)->m_Hit & CCharacter::DISABLE_HIT_GRENADE) : g_Config.m_SvHit || NoDamage) || Owner == pChar->GetCID())
 			{
 				if(Owner != -1 && pChar->IsAlive() && !pChar->CanCollide(Owner))
 					continue;
 				if(Owner == -1 && ActivatedTeam != -1 && pChar->IsAlive() && pChar->Team() != ActivatedTeam)
 					continue;
-				pChar->TakeDamage(ForceDir*Dmg*2, (int)Dmg, Owner, Weapon);
-				if(GetCharacterByID(Owner) ? GetCharacterByID(Owner)->m_Hit&CCharacter::DISABLE_HIT_GRENADE : !g_Config.m_SvHit || NoDamage)
+				pChar->TakeDamage(ForceDir * Dmg * 2, (int)Dmg, Owner, Weapon);
+				if(GetCharacterByID(Owner) ? GetCharacterByID(Owner)->m_Hit & CCharacter::DISABLE_HIT_GRENADE : !g_Config.m_SvHit || NoDamage)
 					break;
 			}
 	}
@@ -341,7 +340,7 @@ void CGameWorld::NetObjBegin()
 		{
 			pEnt->m_MarkedForDestroy = true;
 			if(i == ENTTYPE_CHARACTER)
-				((CCharacter*)pEnt)->m_KeepHooked = false;
+				((CCharacter *)pEnt)->m_KeepHooked = false;
 		}
 	OnModified();
 }
@@ -349,7 +348,7 @@ void CGameWorld::NetObjBegin()
 void CGameWorld::NetCharAdd(int ObjID, CNetObj_Character *pCharObj, CNetObj_DDNetCharacter *pExtended, int GameTeam, bool IsLocal)
 {
 	CCharacter *pChar;
-	if((pChar = (CCharacter*) GetEntity(ObjID, ENTTYPE_CHARACTER)))
+	if((pChar = (CCharacter *)GetEntity(ObjID, ENTTYPE_CHARACTER)))
 	{
 		pChar->Read(pCharObj, pExtended, IsLocal);
 		pChar->Keep();
@@ -365,12 +364,12 @@ void CGameWorld::NetObjAdd(int ObjID, int ObjType, const void *pObjData)
 {
 	if(ObjType == NETOBJTYPE_PROJECTILE && m_WorldConfig.m_PredictWeapons)
 	{
-		CProjectile NetProj = CProjectile(this, ObjID, (CNetObj_Projectile*) pObjData);
+		CProjectile NetProj = CProjectile(this, ObjID, (CNetObj_Projectile *)pObjData);
 
 		if(NetProj.m_Type != WEAPON_SHOTGUN && fabs(length(NetProj.m_Direction) - 1.f) > 0.02f) // workaround to skip grenades on ball mod
 			return;
 
-		if(CProjectile *pProj = (CProjectile*) GetEntity(ObjID, ENTTYPE_PROJECTILE))
+		if(CProjectile *pProj = (CProjectile *)GetEntity(ObjID, ENTTYPE_PROJECTILE))
 		{
 			if(NetProj.Match(pProj))
 			{
@@ -380,10 +379,10 @@ void CGameWorld::NetObjAdd(int ObjID, int ObjType, const void *pObjData)
 				return;
 			}
 		}
-		if(!UseExtraInfo((CNetObj_Projectile*)pObjData))
+		if(!UseExtraInfo((CNetObj_Projectile *)pObjData))
 		{
 			// try to match the newly received (unrecognized) projectile with a locally fired one
-			for(CProjectile *pProj = (CProjectile*) FindFirst(CGameWorld::ENTTYPE_PROJECTILE); pProj; pProj = (CProjectile*) pProj->TypeNext())
+			for(CProjectile *pProj = (CProjectile *)FindFirst(CGameWorld::ENTTYPE_PROJECTILE); pProj; pProj = (CProjectile *)pProj->TypeNext())
 			{
 				if(pProj->m_ID == -1 && NetProj.Match(pProj))
 				{
@@ -393,13 +392,13 @@ void CGameWorld::NetObjAdd(int ObjID, int ObjType, const void *pObjData)
 				}
 			}
 			// otherwise try to determine its owner by checking if there is only one player nearby
-			if(NetProj.m_StartTick >= GameTick()-4)
+			if(NetProj.m_StartTick >= GameTick() - 4)
 			{
-				const vec2 NetPos = NetProj.m_Pos - normalize(NetProj.m_Direction)*28.0*0.75;
-				const bool Prev = (GameTick()-NetProj.m_StartTick) > 1;
+				const vec2 NetPos = NetProj.m_Pos - normalize(NetProj.m_Direction) * 28.0 * 0.75;
+				const bool Prev = (GameTick() - NetProj.m_StartTick) > 1;
 				float First = 200.0f, Second = 200.0f;
 				CCharacter *pClosest = 0;
-				for(CCharacter *pChar = (CCharacter*) FindFirst(ENTTYPE_CHARACTER); pChar; pChar = (CCharacter *) pChar->TypeNext())
+				for(CCharacter *pChar = (CCharacter *)FindFirst(ENTTYPE_CHARACTER); pChar; pChar = (CCharacter *)pChar->TypeNext())
 				{
 					float Dist = distance(Prev ? pChar->m_PrevPrevPos : pChar->m_PrevPos, NetPos);
 					if(Dist < First)
@@ -410,17 +409,17 @@ void CGameWorld::NetObjAdd(int ObjID, int ObjType, const void *pObjData)
 					else if(Dist < Second)
 						Second = Dist;
 				}
-				if(pClosest && maximum(First, 2.f)*1.2f < Second)
+				if(pClosest && maximum(First, 2.f) * 1.2f < Second)
 					NetProj.m_Owner = pClosest->m_ID;
 			}
 		}
 		CProjectile *pProj = new CProjectile(NetProj);
-		InsertEntity((CEntity*)pProj);
+		InsertEntity((CEntity *)pProj);
 	}
 	else if(ObjType == NETOBJTYPE_PICKUP && m_WorldConfig.m_PredictWeapons)
 	{
-		CPickup NetPickup = CPickup(this, ObjID, (CNetObj_Pickup*) pObjData);
-		if(CPickup *pPickup = (CPickup*) GetEntity(ObjID, ENTTYPE_PICKUP))
+		CPickup NetPickup = CPickup(this, ObjID, (CNetObj_Pickup *)pObjData);
+		if(CPickup *pPickup = (CPickup *)GetEntity(ObjID, ENTTYPE_PICKUP))
 		{
 			if(NetPickup.Match(pPickup))
 			{
@@ -434,14 +433,14 @@ void CGameWorld::NetObjAdd(int ObjID, int ObjType, const void *pObjData)
 	}
 	else if(ObjType == NETOBJTYPE_LASER && m_WorldConfig.m_PredictWeapons)
 	{
-		CLaser NetLaser = CLaser(this, ObjID, (CNetObj_Laser*) pObjData);
+		CLaser NetLaser = CLaser(this, ObjID, (CNetObj_Laser *)pObjData);
 		CLaser *pMatching = 0;
-		if(CLaser *pLaser = (CLaser*) GetEntity(ObjID, ENTTYPE_LASER))
+		if(CLaser *pLaser = (CLaser *)GetEntity(ObjID, ENTTYPE_LASER))
 			if(NetLaser.Match(pLaser))
 				pMatching = pLaser;
 		if(!pMatching)
 		{
-			for(CLaser *pLaser = (CLaser*) FindFirst(CGameWorld::ENTTYPE_LASER); pLaser; pLaser = (CLaser*) pLaser->TypeNext())
+			for(CLaser *pLaser = (CLaser *)FindFirst(CGameWorld::ENTTYPE_LASER); pLaser; pLaser = (CLaser *)pLaser->TypeNext())
 			{
 				if(pLaser->m_ID == -1 && NetLaser.Match(pLaser))
 				{
@@ -474,7 +473,7 @@ void CGameWorld::NetObjEnd(int LocalID)
 					if(pHookedChar->m_MarkedForDestroy)
 					{
 						pHookedChar->m_Pos = pHookedChar->m_Core.m_Pos = pChar->m_Core.m_HookPos;
-						pHookedChar->m_Core.m_Vel = vec2(0,0);
+						pHookedChar->m_Core.m_Vel = vec2(0, 0);
 						mem_zero(&pHookedChar->m_SavedInput, sizeof(pHookedChar->m_SavedInput));
 						pHookedChar->m_KeepHooked = true;
 						pHookedChar->m_MarkedForDestroy = false;
@@ -482,7 +481,7 @@ void CGameWorld::NetObjEnd(int LocalID)
 	// keep entities that are out of view for a short while, for some entity types
 	if(CCharacter *pLocal = GetCharacterByID(LocalID))
 		for(int i : {ENTTYPE_CHARACTER, ENTTYPE_PROJECTILE, ENTTYPE_LASER})
-			for(CEntity *pEnt = FindFirst(i); pEnt; pEnt=pEnt->TypeNext())
+			for(CEntity *pEnt = FindFirst(i); pEnt; pEnt = pEnt->TypeNext())
 				if(pEnt->m_MarkedForDestroy)
 					if(pEnt->m_SnapTicks < 2 * SERVER_TICK_SPEED || (i != ENTTYPE_CHARACTER && pEnt->m_SnapTicks < 5 * SERVER_TICK_SPEED))
 						if(pEnt->NetworkClipped(pLocal->m_Core.m_Pos))
@@ -495,7 +494,7 @@ void CGameWorld::NetObjEnd(int LocalID)
 		m_apCharacters[i] = 0;
 		m_Core.m_apCharacters[i] = 0;
 	}
-	for(CCharacter *pChar = (CCharacter*) FindFirst(ENTTYPE_CHARACTER); pChar; pChar = (CCharacter*) pChar->TypeNext())
+	for(CCharacter *pChar = (CCharacter *)FindFirst(ENTTYPE_CHARACTER); pChar; pChar = (CCharacter *)pChar->TypeNext())
 	{
 		int ID = pChar->GetCID();
 		if(ID >= 0 && ID < MAX_CLIENTS)
@@ -543,13 +542,13 @@ void CGameWorld::CopyWorld(CGameWorld *pFrom)
 		{
 			CEntity *pCopy = 0;
 			if(Type == ENTTYPE_PROJECTILE)
-				pCopy = new CProjectile(*((CProjectile*)pEnt));
+				pCopy = new CProjectile(*((CProjectile *)pEnt));
 			else if(Type == ENTTYPE_LASER)
-				pCopy = new CLaser(*((CLaser*)pEnt));
+				pCopy = new CLaser(*((CLaser *)pEnt));
 			else if(Type == ENTTYPE_CHARACTER)
-				pCopy = new CCharacter(*((CCharacter*)pEnt));
+				pCopy = new CCharacter(*((CCharacter *)pEnt));
 			else if(Type == ENTTYPE_PICKUP)
-				pCopy = new CPickup(*((CPickup*)pEnt));
+				pCopy = new CPickup(*((CPickup *)pEnt));
 			if(pCopy)
 			{
 				pCopy->m_pParent = pEnt;
@@ -565,16 +564,16 @@ CEntity *CGameWorld::FindMatch(int ObjID, int ObjType, const void *pObjData)
 #define FindType(EntType, EntClass, ObjClass) \
 	{ \
 		CEntity *pEnt = GetEntity(ObjID, EntType); \
-		if(pEnt && EntClass(this, ObjID, (ObjClass*) pObjData).Match((EntClass*)pEnt)) \
+		if(pEnt && EntClass(this, ObjID, (ObjClass *)pObjData).Match((EntClass *)pEnt)) \
 			return pEnt; \
 		return 0; \
 	}
 	switch(ObjType)
 	{
-		case NETOBJTYPE_CHARACTER: FindType(ENTTYPE_CHARACTER, CCharacter, CNetObj_Character);
-		case NETOBJTYPE_PROJECTILE: FindType(ENTTYPE_PROJECTILE, CProjectile, CNetObj_Projectile);
-		case NETOBJTYPE_LASER: FindType(ENTTYPE_LASER, CLaser, CNetObj_Laser);
-		case NETOBJTYPE_PICKUP: FindType(ENTTYPE_PICKUP, CPickup, CNetObj_Pickup);
+	case NETOBJTYPE_CHARACTER: FindType(ENTTYPE_CHARACTER, CCharacter, CNetObj_Character);
+	case NETOBJTYPE_PROJECTILE: FindType(ENTTYPE_PROJECTILE, CProjectile, CNetObj_Projectile);
+	case NETOBJTYPE_LASER: FindType(ENTTYPE_LASER, CLaser, CNetObj_Laser);
+	case NETOBJTYPE_PICKUP: FindType(ENTTYPE_PICKUP, CPickup, CNetObj_Pickup);
 	}
 	return 0;
 }
