@@ -1,36 +1,36 @@
 /* (c) Magnus Auvinen. See licence.txt in the root of the distribution for more information. */
 /* If you are missing that file, acquire a complete release at teeworlds.com.                */
-#include <base/system.h>
 #include <base/math.h>
+#include <base/system.h>
 #include <base/vmath.h>
 
 #include <antibot/antibot_data.h>
 
-#include <math.h>
-#include <engine/map.h>
 #include <engine/kernel.h>
+#include <engine/map.h>
+#include <math.h>
 
-#include <game/mapitems.h>
-#include <game/layers.h>
 #include <game/collision.h>
+#include <game/layers.h>
+#include <game/mapitems.h>
 
 #include <engine/shared/config.h>
 
 vec2 ClampVel(int MoveRestriction, vec2 Vel)
 {
-	if(Vel.x > 0 && (MoveRestriction&CANTMOVE_RIGHT))
+	if(Vel.x > 0 && (MoveRestriction & CANTMOVE_RIGHT))
 	{
 		Vel.x = 0;
 	}
-	if(Vel.x < 0 && (MoveRestriction&CANTMOVE_LEFT))
+	if(Vel.x < 0 && (MoveRestriction & CANTMOVE_LEFT))
 	{
 		Vel.x = 0;
 	}
-	if(Vel.y > 0 && (MoveRestriction&CANTMOVE_DOWN))
+	if(Vel.y > 0 && (MoveRestriction & CANTMOVE_DOWN))
 	{
 		Vel.y = 0;
 	}
-	if(Vel.y < 0 && (MoveRestriction&CANTMOVE_UP))
+	if(Vel.y < 0 && (MoveRestriction & CANTMOVE_UP))
 	{
 		Vel.y = 0;
 	}
@@ -70,24 +70,24 @@ void CCollision::Init(class CLayers *pLayers)
 	if(m_pLayers->TeleLayer())
 	{
 		unsigned int Size = m_pLayers->Map()->GetDataSize(m_pLayers->TeleLayer()->m_Tele);
-		if (Size >= m_Width*m_Height*sizeof(CTeleTile))
+		if(Size >= m_Width * m_Height * sizeof(CTeleTile))
 			m_pTele = static_cast<CTeleTile *>(m_pLayers->Map()->GetData(m_pLayers->TeleLayer()->m_Tele));
 	}
 
 	if(m_pLayers->SpeedupLayer())
 	{
 		unsigned int Size = m_pLayers->Map()->GetDataSize(m_pLayers->SpeedupLayer()->m_Speedup);
-		if (Size >= m_Width*m_Height*sizeof(CSpeedupTile))
+		if(Size >= m_Width * m_Height * sizeof(CSpeedupTile))
 			m_pSpeedup = static_cast<CSpeedupTile *>(m_pLayers->Map()->GetData(m_pLayers->SpeedupLayer()->m_Speedup));
 	}
 
 	if(m_pLayers->SwitchLayer())
 	{
 		unsigned int Size = m_pLayers->Map()->GetDataSize(m_pLayers->SwitchLayer()->m_Switch);
-		if (Size >= m_Width*m_Height*sizeof(CSwitchTile))
+		if(Size >= m_Width * m_Height * sizeof(CSwitchTile))
 			m_pSwitch = static_cast<CSwitchTile *>(m_pLayers->Map()->GetData(m_pLayers->SwitchLayer()->m_Switch));
 
-		m_pDoor = new CDoorTile[m_Width*m_Height];
+		m_pDoor = new CDoorTile[m_Width * m_Height];
 		mem_zero(m_pDoor, m_Width * m_Height * sizeof(CDoorTile));
 	}
 	else
@@ -99,18 +99,18 @@ void CCollision::Init(class CLayers *pLayers)
 	if(m_pLayers->TuneLayer())
 	{
 		unsigned int Size = m_pLayers->Map()->GetDataSize(m_pLayers->TuneLayer()->m_Tune);
-		if (Size >= m_Width*m_Height*sizeof(CTuneTile))
+		if(Size >= m_Width * m_Height * sizeof(CTuneTile))
 			m_pTune = static_cast<CTuneTile *>(m_pLayers->Map()->GetData(m_pLayers->TuneLayer()->m_Tune));
 	}
 
 	if(m_pLayers->FrontLayer())
 	{
 		unsigned int Size = m_pLayers->Map()->GetDataSize(m_pLayers->FrontLayer()->m_Front);
-		if (Size >= m_Width*m_Height*sizeof(CTile))
+		if(Size >= m_Width * m_Height * sizeof(CTile))
 			m_pFront = static_cast<CTile *>(m_pLayers->Map()->GetData(m_pLayers->FrontLayer()->m_Front));
 	}
 
-	for(int i = 0; i < m_Width*m_Height; i++)
+	for(int i = 0; i < m_Width * m_Height; i++)
 	{
 		int Index;
 		if(m_pSwitch)
@@ -125,11 +125,9 @@ void CCollision::Init(class CLayers *pLayers)
 
 			Index = m_pSwitch[i].m_Type;
 
-			if(Index <= TILE_NPH_START)
+			if(Index <= TILE_NPH_ENABLE)
 			{
-				if((Index >= TILE_JUMP && Index <= TILE_BONUS)
-						|| Index == TILE_ALLOW_TELE_GUN
-						|| Index == TILE_ALLOW_BLUE_TELE_GUN)
+				if((Index >= TILE_JUMP && Index <= TILE_SUBSTRACT_TIME) || Index == TILE_ALLOW_TELE_GUN || Index == TILE_ALLOW_BLUE_TELE_GUN)
 					m_pSwitch[i].m_Type = Index;
 				else
 					m_pSwitch[i].m_Type = 0;
@@ -139,12 +137,12 @@ void CCollision::Init(class CLayers *pLayers)
 
 	if(m_NumSwitchers)
 	{
-		m_pSwitchers = new SSwitchers[m_NumSwitchers+1];
+		m_pSwitchers = new SSwitchers[m_NumSwitchers + 1];
 
-		for (int i = 0; i < m_NumSwitchers+1; ++i)
+		for(int i = 0; i < m_NumSwitchers + 1; ++i)
 		{
 			m_pSwitchers[i].m_Initial = true;
-			for (int j = 0; j < MAX_CLIENTS; ++j)
+			for(int j = 0; j < MAX_CLIENTS; ++j)
 			{
 				m_pSwitchers[i].m_Status[j] = true;
 				m_pSwitchers[i].m_EndTick[j] = 0;
@@ -171,7 +169,7 @@ void CCollision::FillAntibot(CAntibotMapData *pMapData)
 
 enum
 {
-	MR_DIR_HERE=0,
+	MR_DIR_HERE = 0,
 	MR_DIR_RIGHT,
 	MR_DIR_DOWN,
 	MR_DIR_LEFT,
@@ -181,7 +179,7 @@ enum
 
 static int GetMoveRestrictionsRaw(int Direction, int Tile, int Flags)
 {
-	Flags = Flags&(TILEFLAG_VFLIP|TILEFLAG_HFLIP|TILEFLAG_ROTATE);
+	Flags = Flags & (TILEFLAG_VFLIP | TILEFLAG_HFLIP | TILEFLAG_ROTATE);
 	switch(Tile)
 	{
 	case TILE_STOP:
@@ -192,10 +190,10 @@ static int GetMoveRestrictionsRaw(int Direction, int Tile, int Flags)
 		case ROTATION_180: return CANTMOVE_UP;
 		case ROTATION_270: return CANTMOVE_RIGHT;
 
-		case TILEFLAG_HFLIP^ROTATION_0: return CANTMOVE_UP;
-		case TILEFLAG_HFLIP^ROTATION_90: return CANTMOVE_RIGHT;
-		case TILEFLAG_HFLIP^ROTATION_180: return CANTMOVE_DOWN;
-		case TILEFLAG_HFLIP^ROTATION_270: return CANTMOVE_LEFT;
+		case TILEFLAG_HFLIP ^ ROTATION_0: return CANTMOVE_UP;
+		case TILEFLAG_HFLIP ^ ROTATION_90: return CANTMOVE_RIGHT;
+		case TILEFLAG_HFLIP ^ ROTATION_180: return CANTMOVE_DOWN;
+		case TILEFLAG_HFLIP ^ ROTATION_270: return CANTMOVE_LEFT;
 		}
 		break;
 	case TILE_STOPS:
@@ -203,18 +201,18 @@ static int GetMoveRestrictionsRaw(int Direction, int Tile, int Flags)
 		{
 		case ROTATION_0:
 		case ROTATION_180:
-		case TILEFLAG_HFLIP^ROTATION_0:
-		case TILEFLAG_HFLIP^ROTATION_180:
-			return CANTMOVE_DOWN|CANTMOVE_UP;
+		case TILEFLAG_HFLIP ^ ROTATION_0:
+		case TILEFLAG_HFLIP ^ ROTATION_180:
+			return CANTMOVE_DOWN | CANTMOVE_UP;
 		case ROTATION_90:
 		case ROTATION_270:
-		case TILEFLAG_HFLIP^ROTATION_90:
-		case TILEFLAG_HFLIP^ROTATION_270:
-			return CANTMOVE_LEFT|CANTMOVE_RIGHT;
+		case TILEFLAG_HFLIP ^ ROTATION_90:
+		case TILEFLAG_HFLIP ^ ROTATION_270:
+			return CANTMOVE_LEFT | CANTMOVE_RIGHT;
 		}
 		break;
 	case TILE_STOPA:
-		return CANTMOVE_LEFT|CANTMOVE_RIGHT|CANTMOVE_UP|CANTMOVE_DOWN;
+		return CANTMOVE_LEFT | CANTMOVE_RIGHT | CANTMOVE_UP | CANTMOVE_DOWN;
 	}
 	return 0;
 }
@@ -243,19 +241,18 @@ static int GetMoveRestrictions(int Direction, int Tile, int Flags)
 	{
 		return Result;
 	}
-	return Result&GetMoveRestrictionsMask(Direction);
+	return Result & GetMoveRestrictionsMask(Direction);
 }
 
 int CCollision::GetMoveRestrictions(CALLBACK_SWITCHACTIVE pfnSwitchActive, void *pUser, vec2 Pos, float Distance, int OverrideCenterTileIndex)
 {
 	static const vec2 DIRECTIONS[NUM_MR_DIRS] =
-	{
-		vec2(0, 0),
-		vec2(1, 0),
-		vec2(0, 1),
-		vec2(-1, 0),
-		vec2(0, -1)
-	};
+		{
+			vec2(0, 0),
+			vec2(1, 0),
+			vec2(0, 1),
+			vec2(-1, 0),
+			vec2(0, -1)};
 	dbg_assert(0.0f <= Distance && Distance <= 32.0f, "invalid distance");
 	int Restrictions = 0;
 	for(int d = 0; d < NUM_MR_DIRS; d++)
@@ -301,8 +298,8 @@ int CCollision::GetTile(int x, int y)
 	if(!m_pTiles)
 		return 0;
 
-	int Nx = clamp(x/32, 0, m_Width-1);
-	int Ny = clamp(y/32, 0, m_Height-1);
+	int Nx = clamp(x / 32, 0, m_Width - 1);
+	int Ny = clamp(y / 32, 0, m_Height - 1);
 	int pos = Ny * m_Width + Nx;
 
 	if(m_pTiles[pos].m_Index >= TILE_SOLID && m_pTiles[pos].m_Index <= TILE_NOLASER)
@@ -314,12 +311,12 @@ int CCollision::GetTile(int x, int y)
 int CCollision::IntersectLine(vec2 Pos0, vec2 Pos1, vec2 *pOutCollision, vec2 *pOutBeforeCollision)
 {
 	float Distance = distance(Pos0, Pos1);
-	int End(Distance+1);
+	int End(Distance + 1);
 	vec2 Last = Pos0;
 	int ix = 0, iy = 0; // Temporary position for checking collision
 	for(int i = 0; i <= End; i++)
 	{
-		float a = i/(float)End;
+		float a = i / (float)End;
 		vec2 Pos = mix(Pos0, Pos1, a);
 		ix = round_to_int(Pos.x);
 		iy = round_to_int(Pos.y);
@@ -345,20 +342,20 @@ int CCollision::IntersectLine(vec2 Pos0, vec2 Pos1, vec2 *pOutCollision, vec2 *p
 int CCollision::IntersectLineTeleHook(vec2 Pos0, vec2 Pos1, vec2 *pOutCollision, vec2 *pOutBeforeCollision, int *pTeleNr)
 {
 	float Distance = distance(Pos0, Pos1);
-	int End(Distance+1);
+	int End(Distance + 1);
 	vec2 Last = Pos0;
 	int ix = 0, iy = 0; // Temporary position for checking collision
 	int dx = 0, dy = 0; // Offset for checking the "through" tile
 	ThroughOffset(Pos0, Pos1, &dx, &dy);
 	for(int i = 0; i <= End; i++)
 	{
-		float a = i/(float)End;
+		float a = i / (float)End;
 		vec2 Pos = mix(Pos0, Pos1, a);
 		ix = round_to_int(Pos.x);
 		iy = round_to_int(Pos.y);
 
 		int Index = GetPureMapIndex(Pos);
-		if (g_Config.m_SvOldTeleportHook)
+		if(g_Config.m_SvOldTeleportHook)
 			*pTeleNr = IsTeleport(Index);
 		else
 			*pTeleNr = IsTeleportHook(Index);
@@ -402,18 +399,18 @@ int CCollision::IntersectLineTeleHook(vec2 Pos0, vec2 Pos1, vec2 *pOutCollision,
 int CCollision::IntersectLineTeleWeapon(vec2 Pos0, vec2 Pos1, vec2 *pOutCollision, vec2 *pOutBeforeCollision, int *pTeleNr)
 {
 	float Distance = distance(Pos0, Pos1);
-	int End(Distance+1);
+	int End(Distance + 1);
 	vec2 Last = Pos0;
 	int ix = 0, iy = 0; // Temporary position for checking collision
 	for(int i = 0; i <= End; i++)
 	{
-		float a = i/(float)End;
+		float a = i / (float)End;
 		vec2 Pos = mix(Pos0, Pos1, a);
 		ix = round_to_int(Pos.x);
 		iy = round_to_int(Pos.y);
 
 		int Index = GetPureMapIndex(Pos);
-		if (g_Config.m_SvOldTeleportWeapons)
+		if(g_Config.m_SvOldTeleportWeapons)
 			*pTeleNr = IsTeleport(Index);
 		else
 			*pTeleNr = IsTeleportWeapon(Index);
@@ -486,13 +483,13 @@ void CCollision::MovePoint(vec2 *pInoutPos, vec2 *pInoutVel, float Elasticity, i
 bool CCollision::TestBox(vec2 Pos, vec2 Size)
 {
 	Size *= 0.5f;
-	if(CheckPoint(Pos.x-Size.x, Pos.y-Size.y))
+	if(CheckPoint(Pos.x - Size.x, Pos.y - Size.y))
 		return true;
-	if(CheckPoint(Pos.x+Size.x, Pos.y-Size.y))
+	if(CheckPoint(Pos.x + Size.x, Pos.y - Size.y))
 		return true;
-	if(CheckPoint(Pos.x-Size.x, Pos.y+Size.y))
+	if(CheckPoint(Pos.x - Size.x, Pos.y + Size.y))
 		return true;
-	if(CheckPoint(Pos.x+Size.x, Pos.y+Size.y))
+	if(CheckPoint(Pos.x + Size.x, Pos.y + Size.y))
 		return true;
 	return false;
 }
@@ -508,7 +505,7 @@ void CCollision::MoveBox(vec2 *pInoutPos, vec2 *pInoutVel, vec2 Size, float Elas
 
 	if(Distance > 0.00001f)
 	{
-		float Fraction = 1.0f/(float)(Max+1);
+		float Fraction = 1.0f / (float)(Max + 1);
 		for(int i = 0; i <= Max; i++)
 		{
 			// Early break as optimization to stop checking for collisions for
@@ -519,7 +516,14 @@ void CCollision::MoveBox(vec2 *pInoutPos, vec2 *pInoutVel, vec2 Size, float Elas
 				break;
 			}
 
-			vec2 NewPos = Pos + Vel*Fraction; // TODO: this row is not nice
+			vec2 NewPos = Pos + Vel * Fraction; // TODO: this row is not nice
+
+			// Fraction can be very small and thus the calculation has no effect, no
+			// reason to continue calculating.
+			if(NewPos == Pos)
+			{
+				break;
+			}
 
 			if(TestBox(vec2(NewPos.x, NewPos.y), Size))
 			{
@@ -581,7 +585,7 @@ void CCollision::Dest()
 
 int CCollision::IsSolid(int x, int y)
 {
-	int index = GetTile(x,y);
+	int index = GetTile(x, y);
 	return index == TILE_SOLID || index == TILE_NOHOOK;
 }
 
@@ -590,13 +594,9 @@ bool CCollision::IsThrough(int x, int y, int xoff, int yoff, vec2 pos0, vec2 pos
 	int pos = GetPureMapIndex(x, y);
 	if(m_pFront && (m_pFront[pos].m_Index == TILE_THROUGH_ALL || m_pFront[pos].m_Index == TILE_THROUGH_CUT))
 		return true;
-	if(m_pFront && m_pFront[pos].m_Index == TILE_THROUGH_DIR && (
-		(m_pFront[pos].m_Flags == ROTATION_0   && pos0.y > pos1.y) ||
-		(m_pFront[pos].m_Flags == ROTATION_90  && pos0.x < pos1.x) ||
-		(m_pFront[pos].m_Flags == ROTATION_180 && pos0.y < pos1.y) ||
-		(m_pFront[pos].m_Flags == ROTATION_270 && pos0.x > pos1.x) ))
+	if(m_pFront && m_pFront[pos].m_Index == TILE_THROUGH_DIR && ((m_pFront[pos].m_Flags == ROTATION_0 && pos0.y > pos1.y) || (m_pFront[pos].m_Flags == ROTATION_90 && pos0.x < pos1.x) || (m_pFront[pos].m_Flags == ROTATION_180 && pos0.y < pos1.y) || (m_pFront[pos].m_Flags == ROTATION_270 && pos0.x > pos1.x)))
 		return true;
-	int offpos = GetPureMapIndex(x+xoff, y+yoff);
+	int offpos = GetPureMapIndex(x + xoff, y + yoff);
 	if(m_pTiles[offpos].m_Index == TILE_THROUGH || (m_pFront && m_pFront[offpos].m_Index == TILE_THROUGH))
 		return true;
 	return false;
@@ -607,17 +607,12 @@ bool CCollision::IsHookBlocker(int x, int y, vec2 pos0, vec2 pos1)
 	int pos = GetPureMapIndex(x, y);
 	if(m_pTiles[pos].m_Index == TILE_THROUGH_ALL || (m_pFront && m_pFront[pos].m_Index == TILE_THROUGH_ALL))
 		return true;
-	if(m_pTiles[pos].m_Index == TILE_THROUGH_DIR && (
-		(m_pTiles[pos].m_Flags == ROTATION_0   && pos0.y < pos1.y) ||
-		(m_pTiles[pos].m_Flags == ROTATION_90  && pos0.x > pos1.x) ||
-		(m_pTiles[pos].m_Flags == ROTATION_180 && pos0.y > pos1.y) ||
-		(m_pTiles[pos].m_Flags == ROTATION_270 && pos0.x < pos1.x) ))
+	if(m_pTiles[pos].m_Index == TILE_THROUGH_DIR && ((m_pTiles[pos].m_Flags == ROTATION_0 && pos0.y < pos1.y) ||
+								(m_pTiles[pos].m_Flags == ROTATION_90 && pos0.x > pos1.x) ||
+								(m_pTiles[pos].m_Flags == ROTATION_180 && pos0.y > pos1.y) ||
+								(m_pTiles[pos].m_Flags == ROTATION_270 && pos0.x < pos1.x)))
 		return true;
-	if(m_pFront && m_pFront[pos].m_Index == TILE_THROUGH_DIR && (
-		(m_pFront[pos].m_Flags == ROTATION_0   && pos0.y < pos1.y) ||
-		(m_pFront[pos].m_Flags == ROTATION_90  && pos0.x > pos1.x) ||
-		(m_pFront[pos].m_Flags == ROTATION_180 && pos0.y > pos1.y) ||
-		(m_pFront[pos].m_Flags == ROTATION_270 && pos0.x < pos1.x) ))
+	if(m_pFront && m_pFront[pos].m_Index == TILE_THROUGH_DIR && ((m_pFront[pos].m_Flags == ROTATION_0 && pos0.y < pos1.y) || (m_pFront[pos].m_Flags == ROTATION_90 && pos0.x > pos1.x) || (m_pFront[pos].m_Flags == ROTATION_180 && pos0.y > pos1.y) || (m_pFront[pos].m_Flags == ROTATION_270 && pos0.x < pos1.x)))
 		return true;
 	return false;
 }
@@ -632,12 +627,12 @@ int CCollision::IsWallJump(int Index)
 
 int CCollision::IsNoLaser(int x, int y)
 {
-	return (CCollision::GetTile(x,y) == TILE_NOLASER);
+	return (CCollision::GetTile(x, y) == TILE_NOLASER);
 }
 
 int CCollision::IsFNoLaser(int x, int y)
 {
-	return (CCollision::GetFTile(x,y) == TILE_NOLASER);
+	return (CCollision::GetFTile(x, y) == TILE_NOLASER);
 }
 
 int CCollision::IsTeleport(int Index)
@@ -726,7 +721,6 @@ int CCollision::IsTeleportHook(int Index)
 	return 0;
 }
 
-
 int CCollision::IsSpeedup(int Index)
 {
 	if(Index < 0 || !m_pSpeedup)
@@ -795,13 +789,13 @@ int CCollision::GetSwitchDelay(int Index)
 
 int CCollision::IsMover(int x, int y, int *pFlags)
 {
-	int Nx = clamp(x/32, 0, m_Width-1);
-	int Ny = clamp(y/32, 0, m_Height-1);
-	int Index = m_pTiles[Ny*m_Width+Nx].m_Index;
-	*pFlags = m_pTiles[Ny*m_Width+Nx].m_Flags;
+	int Nx = clamp(x / 32, 0, m_Width - 1);
+	int Ny = clamp(y / 32, 0, m_Height - 1);
+	int Index = m_pTiles[Ny * m_Width + Nx].m_Index;
+	*pFlags = m_pTiles[Ny * m_Width + Nx].m_Flags;
 	if(Index < 0)
 		return 0;
-	if (Index == TILE_CP || Index == TILE_CP_F)
+	if(Index == TILE_CP || Index == TILE_CP_F)
 		return Index;
 	else
 		return 0;
@@ -810,41 +804,41 @@ int CCollision::IsMover(int x, int y, int *pFlags)
 vec2 CCollision::CpSpeed(int Index, int Flags)
 {
 	if(Index < 0)
-		return vec2(0,0);
+		return vec2(0, 0);
 	vec2 target;
 	if(Index == TILE_CP || Index == TILE_CP_F)
 		switch(Flags)
 		{
 		case ROTATION_0:
-			target.x=0;
-			target.y=-4;
+			target.x = 0;
+			target.y = -4;
 			break;
 		case ROTATION_90:
-			target.x=4;
-			target.y=0;
+			target.x = 4;
+			target.y = 0;
 			break;
 		case ROTATION_180:
-			target.x=0;
-			target.y=4;
+			target.x = 0;
+			target.y = 4;
 			break;
 		case ROTATION_270:
-			target.x=-4;
-			target.y=0;
+			target.x = -4;
+			target.y = 0;
 			break;
 		default:
-			target=vec2(0,0);
+			target = vec2(0, 0);
 			break;
 		}
 	if(Index == TILE_CP_F)
-		target*=4;
+		target *= 4;
 	return target;
 }
 
 int CCollision::GetPureMapIndex(float x, float y)
 {
-	int Nx = clamp(round_to_int(x)/32, 0, m_Width-1);
-	int Ny = clamp(round_to_int(y)/32, 0, m_Height-1);
-	return Ny*m_Width+Nx;
+	int Nx = clamp(round_to_int(x) / 32, 0, m_Width - 1);
+	int Ny = clamp(round_to_int(y) / 32, 0, m_Height - 1);
+	return Ny * m_Width + Nx;
 }
 
 bool CCollision::TileExists(int Index)
@@ -854,9 +848,9 @@ bool CCollision::TileExists(int Index)
 
 	if(m_pTiles[Index].m_Index >= TILE_FREEZE && m_pTiles[Index].m_Index <= TILE_TELE_LASER_DISABLE)
 		return true;
-	if(m_pFront && m_pFront[Index].m_Index >= TILE_FREEZE && m_pFront[Index].m_Index  <= TILE_TELE_LASER_DISABLE)
+	if(m_pFront && m_pFront[Index].m_Index >= TILE_FREEZE && m_pFront[Index].m_Index <= TILE_TELE_LASER_DISABLE)
 		return true;
-	if(m_pTele && (m_pTele[Index].m_Type == TILE_TELEIN || m_pTele[Index].m_Type == TILE_TELEINEVIL || m_pTele[Index].m_Type == TILE_TELECHECKINEVIL ||m_pTele[Index].m_Type == TILE_TELECHECK || m_pTele[Index].m_Type == TILE_TELECHECKIN))
+	if(m_pTele && (m_pTele[Index].m_Type == TILE_TELEIN || m_pTele[Index].m_Type == TILE_TELEINEVIL || m_pTele[Index].m_Type == TILE_TELECHECKINEVIL || m_pTele[Index].m_Type == TILE_TELECHECK || m_pTele[Index].m_Type == TILE_TELECHECKIN))
 		return true;
 	if(m_pSpeedup && m_pSpeedup[Index].m_Force > 0)
 		return true;
@@ -865,7 +859,7 @@ bool CCollision::TileExists(int Index)
 	if(m_pSwitch && m_pSwitch[Index].m_Type)
 		return true;
 	if(m_pTune && m_pTune[Index].m_Type)
-			return true;
+		return true;
 	return TileExistsNext(Index);
 }
 
@@ -882,15 +876,15 @@ bool CCollision::TileExistsNext(int Index)
 		return true;
 	if((m_pTiles[TileBelow].m_Index == TILE_STOP && m_pTiles[TileBelow].m_Flags == ROTATION_0) || (m_pTiles[TileAbove].m_Index == TILE_STOP && m_pTiles[TileAbove].m_Flags == ROTATION_180))
 		return true;
-	if(m_pTiles[TileOnTheRight].m_Index == TILE_STOPA || m_pTiles[TileOnTheLeft].m_Index == TILE_STOPA || ((m_pTiles[TileOnTheRight].m_Index == TILE_STOPS || m_pTiles[TileOnTheLeft].m_Index == TILE_STOPS) && m_pTiles[TileOnTheRight].m_Flags|ROTATION_270|ROTATION_90))
+	if(m_pTiles[TileOnTheRight].m_Index == TILE_STOPA || m_pTiles[TileOnTheLeft].m_Index == TILE_STOPA || ((m_pTiles[TileOnTheRight].m_Index == TILE_STOPS || m_pTiles[TileOnTheLeft].m_Index == TILE_STOPS)))
 		return true;
-	if(m_pTiles[TileBelow].m_Index == TILE_STOPA || m_pTiles[TileAbove].m_Index == TILE_STOPA || ((m_pTiles[TileBelow].m_Index == TILE_STOPS || m_pTiles[TileAbove].m_Index == TILE_STOPS) && m_pTiles[TileBelow].m_Flags|ROTATION_180|ROTATION_0))
+	if(m_pTiles[TileBelow].m_Index == TILE_STOPA || m_pTiles[TileAbove].m_Index == TILE_STOPA || ((m_pTiles[TileBelow].m_Index == TILE_STOPS || m_pTiles[TileAbove].m_Index == TILE_STOPS) && m_pTiles[TileBelow].m_Flags | ROTATION_180 | ROTATION_0))
 		return true;
 	if(m_pFront)
 	{
-		if(m_pFront[TileOnTheRight].m_Index == TILE_STOPA || m_pFront[TileOnTheLeft].m_Index == TILE_STOPA || ((m_pFront[TileOnTheRight].m_Index == TILE_STOPS || m_pFront[TileOnTheLeft].m_Index == TILE_STOPS) && m_pFront[TileOnTheRight].m_Flags|ROTATION_270|ROTATION_90))
+		if(m_pFront[TileOnTheRight].m_Index == TILE_STOPA || m_pFront[TileOnTheLeft].m_Index == TILE_STOPA || ((m_pFront[TileOnTheRight].m_Index == TILE_STOPS || m_pFront[TileOnTheLeft].m_Index == TILE_STOPS)))
 			return true;
-		if(m_pFront[TileBelow].m_Index == TILE_STOPA || m_pFront[TileAbove].m_Index == TILE_STOPA || ((m_pFront[TileBelow].m_Index == TILE_STOPS || m_pFront[TileAbove].m_Index == TILE_STOPS) && m_pFront[TileBelow].m_Flags|ROTATION_180|ROTATION_0))
+		if(m_pFront[TileBelow].m_Index == TILE_STOPA || m_pFront[TileAbove].m_Index == TILE_STOPA || ((m_pFront[TileBelow].m_Index == TILE_STOPS || m_pFront[TileAbove].m_Index == TILE_STOPS) && m_pFront[TileBelow].m_Flags | ROTATION_180 | ROTATION_0))
 			return true;
 		if((m_pFront[TileOnTheRight].m_Index == TILE_STOP && m_pFront[TileOnTheRight].m_Flags == ROTATION_270) || (m_pFront[TileOnTheLeft].m_Index == TILE_STOP && m_pFront[TileOnTheLeft].m_Flags == ROTATION_90))
 			return true;
@@ -899,9 +893,9 @@ bool CCollision::TileExistsNext(int Index)
 	}
 	if(m_pDoor)
 	{
-		if(m_pDoor[TileOnTheRight].m_Index == TILE_STOPA || m_pDoor[TileOnTheLeft].m_Index == TILE_STOPA || ((m_pDoor[TileOnTheRight].m_Index == TILE_STOPS || m_pDoor[TileOnTheLeft].m_Index == TILE_STOPS) && m_pDoor[TileOnTheRight].m_Flags|ROTATION_270|ROTATION_90))
+		if(m_pDoor[TileOnTheRight].m_Index == TILE_STOPA || m_pDoor[TileOnTheLeft].m_Index == TILE_STOPA || ((m_pDoor[TileOnTheRight].m_Index == TILE_STOPS || m_pDoor[TileOnTheLeft].m_Index == TILE_STOPS)))
 			return true;
-		if(m_pDoor[TileBelow].m_Index == TILE_STOPA || m_pDoor[TileAbove].m_Index == TILE_STOPA || ((m_pDoor[TileBelow].m_Index == TILE_STOPS || m_pDoor[TileAbove].m_Index == TILE_STOPS) && m_pDoor[TileBelow].m_Flags|ROTATION_180|ROTATION_0))
+		if(m_pDoor[TileBelow].m_Index == TILE_STOPA || m_pDoor[TileAbove].m_Index == TILE_STOPA || ((m_pDoor[TileBelow].m_Index == TILE_STOPS || m_pDoor[TileAbove].m_Index == TILE_STOPS) && m_pDoor[TileBelow].m_Flags | ROTATION_180 | ROTATION_0))
 			return true;
 		if((m_pDoor[TileOnTheRight].m_Index == TILE_STOP && m_pDoor[TileOnTheRight].m_Flags == ROTATION_270) || (m_pDoor[TileOnTheLeft].m_Index == TILE_STOP && m_pDoor[TileOnTheLeft].m_Flags == ROTATION_90))
 			return true;
@@ -915,7 +909,7 @@ int CCollision::GetMapIndex(vec2 Pos)
 {
 	int Nx = clamp((int)Pos.x / 32, 0, m_Width - 1);
 	int Ny = clamp((int)Pos.y / 32, 0, m_Height - 1);
-	int Index = Ny*m_Width+Nx;
+	int Index = Ny * m_Width + Nx;
 
 	if(TileExists(Index))
 		return Index;
@@ -925,7 +919,7 @@ int CCollision::GetMapIndex(vec2 Pos)
 
 std::list<int> CCollision::GetMapIndices(vec2 PrevPos, vec2 Pos, unsigned MaxIndices)
 {
-	std::list< int > Indices;
+	std::list<int> Indices;
 	float d = distance(PrevPos, Pos);
 	int End(d + 1);
 	if(!d)
@@ -948,10 +942,10 @@ std::list<int> CCollision::GetMapIndices(vec2 PrevPos, vec2 Pos, unsigned MaxInd
 		vec2 Tmp = vec2(0, 0);
 		int Nx = 0;
 		int Ny = 0;
-		int Index,LastIndex = 0;
+		int Index, LastIndex = 0;
 		for(int i = 0; i < End; i++)
 		{
-			a = i/d;
+			a = i / d;
 			Tmp = mix(PrevPos, Pos, a);
 			Nx = clamp((int)Tmp.x / 32, 0, m_Width - 1);
 			Ny = clamp((int)Tmp.y / 32, 0, m_Height - 1);
@@ -972,11 +966,11 @@ std::list<int> CCollision::GetMapIndices(vec2 PrevPos, vec2 Pos, unsigned MaxInd
 vec2 CCollision::GetPos(int Index)
 {
 	if(Index < 0)
-		return vec2(0,0);
+		return vec2(0, 0);
 
-	int x = Index%m_Width;
-	int y = Index/m_Width;
-	return vec2(x*32+16, y*32+16);
+	int x = Index % m_Width;
+	int y = Index / m_Width;
+	return vec2(x * 32 + 16, y * 32 + 16);
 }
 
 int CCollision::GetTileIndex(int Index)
@@ -1009,7 +1003,7 @@ int CCollision::GetFTileFlags(int Index)
 
 int CCollision::GetIndex(int Nx, int Ny)
 {
-	return m_pTiles[Ny*m_Width+Nx].m_Index;
+	return m_pTiles[Ny * m_Width + Nx].m_Index;
 }
 
 int CCollision::GetIndex(vec2 PrevPos, vec2 Pos)
@@ -1018,13 +1012,13 @@ int CCollision::GetIndex(vec2 PrevPos, vec2 Pos)
 
 	if(!Distance)
 	{
-		int Nx = clamp((int)Pos.x/32, 0, m_Width-1);
-		int Ny = clamp((int)Pos.y/32, 0, m_Height-1);
+		int Nx = clamp((int)Pos.x / 32, 0, m_Width - 1);
+		int Ny = clamp((int)Pos.y / 32, 0, m_Height - 1);
 
-		if ((m_pTele) ||
-			(m_pSpeedup && m_pSpeedup[Ny*m_Width+Nx].m_Force > 0))
+		if((m_pTele) ||
+			(m_pSpeedup && m_pSpeedup[Ny * m_Width + Nx].m_Force > 0))
 		{
-			return Ny*m_Width+Nx;
+			return Ny * m_Width + Nx;
 		}
 	}
 
@@ -1035,14 +1029,14 @@ int CCollision::GetIndex(vec2 PrevPos, vec2 Pos)
 
 	for(float f = 0; f < Distance; f++)
 	{
-		a = f/Distance;
+		a = f / Distance;
 		Tmp = mix(PrevPos, Pos, a);
-		Nx = clamp((int)Tmp.x/32, 0, m_Width-1);
-		Ny = clamp((int)Tmp.y/32, 0, m_Height-1);
-		if ((m_pTele) ||
-			(m_pSpeedup && m_pSpeedup[Ny*m_Width+Nx].m_Force > 0))
+		Nx = clamp((int)Tmp.x / 32, 0, m_Width - 1);
+		Ny = clamp((int)Tmp.y / 32, 0, m_Height - 1);
+		if((m_pTele) ||
+			(m_pSpeedup && m_pSpeedup[Ny * m_Width + Nx].m_Force > 0))
 		{
-			return Ny*m_Width+Nx;
+			return Ny * m_Width + Nx;
 		}
 	}
 
@@ -1051,19 +1045,19 @@ int CCollision::GetIndex(vec2 PrevPos, vec2 Pos)
 
 int CCollision::GetFIndex(int Nx, int Ny)
 {
-	if(!m_pFront) return 0;
-	return m_pFront[Ny*m_Width+Nx].m_Index;
+	if(!m_pFront)
+		return 0;
+	return m_pFront[Ny * m_Width + Nx].m_Index;
 }
 
 int CCollision::GetFTile(int x, int y)
 {
 	if(!m_pFront)
-	return 0;
-	int Nx = clamp(x/32, 0, m_Width-1);
-	int Ny = clamp(y/32, 0, m_Height-1);
-	if(m_pFront[Ny*m_Width+Nx].m_Index == TILE_DEATH
-		|| m_pFront[Ny*m_Width+Nx].m_Index == TILE_NOLASER)
-		return m_pFront[Ny*m_Width+Nx].m_Index;
+		return 0;
+	int Nx = clamp(x / 32, 0, m_Width - 1);
+	int Ny = clamp(y / 32, 0, m_Height - 1);
+	if(m_pFront[Ny * m_Width + Nx].m_Index == TILE_DEATH || m_pFront[Ny * m_Width + Nx].m_Index == TILE_NOLASER)
+		return m_pFront[Ny * m_Width + Nx].m_Index;
 	else
 		return 0;
 }
@@ -1073,56 +1067,56 @@ int CCollision::Entity(int x, int y, int Layer)
 	if((0 > x || x >= m_Width) || (0 > y || y >= m_Height))
 	{
 		char aBuf[12];
-		switch (Layer)
+		switch(Layer)
 		{
-			case LAYER_GAME:
-				str_format(aBuf,sizeof(aBuf), "Game");
-				break;
-			case LAYER_FRONT:
-				str_format(aBuf,sizeof(aBuf), "Front");
-				break;
-			case LAYER_SWITCH:
-				str_format(aBuf,sizeof(aBuf), "Switch");
-				break;
-			case LAYER_TELE:
-				str_format(aBuf,sizeof(aBuf), "Tele");
-				break;
-			case LAYER_SPEEDUP:
-				str_format(aBuf,sizeof(aBuf), "Speedup");
-				break;
-			case LAYER_TUNE:
-				str_format(aBuf,sizeof(aBuf), "Tune");
-				break;
-			default:
-				str_format(aBuf,sizeof(aBuf), "Unknown");
+		case LAYER_GAME:
+			str_format(aBuf, sizeof(aBuf), "Game");
+			break;
+		case LAYER_FRONT:
+			str_format(aBuf, sizeof(aBuf), "Front");
+			break;
+		case LAYER_SWITCH:
+			str_format(aBuf, sizeof(aBuf), "Switch");
+			break;
+		case LAYER_TELE:
+			str_format(aBuf, sizeof(aBuf), "Tele");
+			break;
+		case LAYER_SPEEDUP:
+			str_format(aBuf, sizeof(aBuf), "Speedup");
+			break;
+		case LAYER_TUNE:
+			str_format(aBuf, sizeof(aBuf), "Tune");
+			break;
+		default:
+			str_format(aBuf, sizeof(aBuf), "Unknown");
 		}
-		dbg_msg("collision","something is VERY wrong with the %s layer please report this at https://github.com/ddnet/ddnet, you will need to post the map as well and any steps that u think may have led to this", aBuf);
+		dbg_msg("collision", "something is VERY wrong with the %s layer please report this at https://github.com/ddnet/ddnet, you will need to post the map as well and any steps that u think may have led to this", aBuf);
 		return 0;
 	}
-	switch (Layer)
+	switch(Layer)
 	{
-		case LAYER_GAME:
-			return m_pTiles[y*m_Width+x].m_Index - ENTITY_OFFSET;
-		case LAYER_FRONT:
-			return m_pFront[y*m_Width+x].m_Index - ENTITY_OFFSET;
-		case LAYER_SWITCH:
-			return m_pSwitch[y*m_Width+x].m_Type - ENTITY_OFFSET;
-		case LAYER_TELE:
-			return m_pTele[y*m_Width+x].m_Type - ENTITY_OFFSET;
-		case LAYER_SPEEDUP:
-			return m_pSpeedup[y*m_Width+x].m_Type - ENTITY_OFFSET;
-		case LAYER_TUNE:
-			return m_pTune[y*m_Width+x].m_Type - ENTITY_OFFSET;
-		default:
-			return 0;
-			break;
+	case LAYER_GAME:
+		return m_pTiles[y * m_Width + x].m_Index - ENTITY_OFFSET;
+	case LAYER_FRONT:
+		return m_pFront[y * m_Width + x].m_Index - ENTITY_OFFSET;
+	case LAYER_SWITCH:
+		return m_pSwitch[y * m_Width + x].m_Type - ENTITY_OFFSET;
+	case LAYER_TELE:
+		return m_pTele[y * m_Width + x].m_Type - ENTITY_OFFSET;
+	case LAYER_SPEEDUP:
+		return m_pSpeedup[y * m_Width + x].m_Type - ENTITY_OFFSET;
+	case LAYER_TUNE:
+		return m_pTune[y * m_Width + x].m_Type - ENTITY_OFFSET;
+	default:
+		return 0;
+		break;
 	}
 }
 
 void CCollision::SetCollisionAt(float x, float y, int id)
 {
-	int Nx = clamp(round_to_int(x)/32, 0, m_Width-1);
-	int Ny = clamp(round_to_int(y)/32, 0, m_Height-1);
+	int Nx = clamp(round_to_int(x) / 32, 0, m_Width - 1);
+	int Ny = clamp(round_to_int(y) / 32, 0, m_Height - 1);
 
 	m_pTiles[Ny * m_Width + Nx].m_Index = id;
 }
@@ -1131,8 +1125,8 @@ void CCollision::SetDCollisionAt(float x, float y, int Type, int Flags, int Numb
 {
 	if(!m_pDoor)
 		return;
-	int Nx = clamp(round_to_int(x)/32, 0, m_Width-1);
-	int Ny = clamp(round_to_int(y)/32, 0, m_Height-1);
+	int Nx = clamp(round_to_int(x) / 32, 0, m_Width - 1);
+	int Ny = clamp(round_to_int(y) / 32, 0, m_Height - 1);
 
 	m_pDoor[Ny * m_Width + Nx].m_Index = Type;
 	m_pDoor[Ny * m_Width + Nx].m_Flags = Flags;
@@ -1150,7 +1144,8 @@ int CCollision::GetDTileNumber(int Index)
 {
 	if(!m_pDoor || Index < 0 || !m_pDoor[Index].m_Index)
 		return 0;
-	if(m_pDoor[Index].m_Number) return m_pDoor[Index].m_Number;
+	if(m_pDoor[Index].m_Number)
+		return m_pDoor[Index].m_Number;
 	return 0;
 }
 
@@ -1165,9 +1160,9 @@ void ThroughOffset(vec2 Pos0, vec2 Pos1, int *Ox, int *Oy)
 {
 	float x = Pos0.x - Pos1.x;
 	float y = Pos0.y - Pos1.y;
-	if (fabs(x) > fabs(y))
+	if(fabs(x) > fabs(y))
 	{
-		if (x < 0)
+		if(x < 0)
 		{
 			*Ox = -32;
 			*Oy = 0;
@@ -1180,7 +1175,7 @@ void ThroughOffset(vec2 Pos0, vec2 Pos1, int *Ox, int *Oy)
 	}
 	else
 	{
-		if (y < 0)
+		if(y < 0)
 		{
 			*Ox = 0;
 			*Oy = -32;
@@ -1200,22 +1195,20 @@ int CCollision::IntersectNoLaser(vec2 Pos0, vec2 Pos1, vec2 *pOutCollision, vec2
 
 	for(float f = 0; f < d; f++)
 	{
-		float a = f/d;
+		float a = f / d;
 		vec2 Pos = mix(Pos0, Pos1, a);
-		int Nx = clamp(round_to_int(Pos.x)/32, 0, m_Width-1);
-		int Ny = clamp(round_to_int(Pos.y)/32, 0, m_Height-1);
-		if(GetIndex(Nx, Ny) == TILE_SOLID
-			|| GetIndex(Nx, Ny) == TILE_NOHOOK
-			|| GetIndex(Nx, Ny) == TILE_NOLASER
-			|| GetFIndex(Nx, Ny) == TILE_NOLASER)
+		int Nx = clamp(round_to_int(Pos.x) / 32, 0, m_Width - 1);
+		int Ny = clamp(round_to_int(Pos.y) / 32, 0, m_Height - 1);
+		if(GetIndex(Nx, Ny) == TILE_SOLID || GetIndex(Nx, Ny) == TILE_NOHOOK || GetIndex(Nx, Ny) == TILE_NOLASER || GetFIndex(Nx, Ny) == TILE_NOLASER)
 		{
 			if(pOutCollision)
 				*pOutCollision = Pos;
 			if(pOutBeforeCollision)
 				*pOutBeforeCollision = Last;
-			if (GetFIndex(Nx, Ny) == TILE_NOLASER)	return GetFCollisionAt(Pos.x, Pos.y);
-			else return GetCollisionAt(Pos.x, Pos.y);
-
+			if(GetFIndex(Nx, Ny) == TILE_NOLASER)
+				return GetFCollisionAt(Pos.x, Pos.y);
+			else
+				return GetCollisionAt(Pos.x, Pos.y);
 		}
 		Last = Pos;
 	}
@@ -1233,7 +1226,7 @@ int CCollision::IntersectNoLaserNW(vec2 Pos0, vec2 Pos1, vec2 *pOutCollision, ve
 
 	for(float f = 0; f < d; f++)
 	{
-		float a = f/d;
+		float a = f / d;
 		vec2 Pos = mix(Pos0, Pos1, a);
 		if(IsNoLaser(round_to_int(Pos.x), round_to_int(Pos.y)) || IsFNoLaser(round_to_int(Pos.x), round_to_int(Pos.y)))
 		{
@@ -1241,8 +1234,10 @@ int CCollision::IntersectNoLaserNW(vec2 Pos0, vec2 Pos1, vec2 *pOutCollision, ve
 				*pOutCollision = Pos;
 			if(pOutBeforeCollision)
 				*pOutBeforeCollision = Last;
-			if(IsNoLaser(round_to_int(Pos.x), round_to_int(Pos.y))) return GetCollisionAt(Pos.x, Pos.y);
-			else return  GetFCollisionAt(Pos.x, Pos.y);
+			if(IsNoLaser(round_to_int(Pos.x), round_to_int(Pos.y)))
+				return GetCollisionAt(Pos.x, Pos.y);
+			else
+				return GetFCollisionAt(Pos.x, Pos.y);
 		}
 		Last = Pos;
 	}
@@ -1260,7 +1255,7 @@ int CCollision::IntersectAir(vec2 Pos0, vec2 Pos1, vec2 *pOutCollision, vec2 *pO
 
 	for(float f = 0; f < d; f++)
 	{
-		float a = f/d;
+		float a = f / d;
 		vec2 Pos = mix(Pos0, Pos1, a);
 		if(IsSolid(round_to_int(Pos.x), round_to_int(Pos.y)) || (!GetTile(round_to_int(Pos.x), round_to_int(Pos.y)) && !GetFTile(round_to_int(Pos.x), round_to_int(Pos.y))))
 		{
@@ -1270,9 +1265,10 @@ int CCollision::IntersectAir(vec2 Pos0, vec2 Pos1, vec2 *pOutCollision, vec2 *pO
 				*pOutBeforeCollision = Last;
 			if(!GetTile(round_to_int(Pos.x), round_to_int(Pos.y)) && !GetFTile(round_to_int(Pos.x), round_to_int(Pos.y)))
 				return -1;
+			else if(!GetTile(round_to_int(Pos.x), round_to_int(Pos.y)))
+				return GetTile(round_to_int(Pos.x), round_to_int(Pos.y));
 			else
-				if (!GetTile(round_to_int(Pos.x), round_to_int(Pos.y))) return GetTile(round_to_int(Pos.x), round_to_int(Pos.y));
-				else return GetFTile(round_to_int(Pos.x), round_to_int(Pos.y));
+				return GetFTile(round_to_int(Pos.x), round_to_int(Pos.y));
 		}
 		Last = Pos;
 	}
@@ -1301,6 +1297,6 @@ int CCollision::IsFCheckpoint(int Index)
 
 	int z = m_pFront[Index].m_Index;
 	if(z >= 35 && z <= 59)
-		return z-35;
+		return z - 35;
 	return -1;
 }
