@@ -6,8 +6,8 @@
 #include <engine/graphics.h>
 
 #include "editor.h"
-#include <game/generated/client_data.h>
 #include <game/client/render.h>
+#include <game/generated/client_data.h>
 #include <game/localization.h>
 
 CLayerQuads::CLayerQuads()
@@ -46,41 +46,46 @@ CQuad *CLayerQuads::NewQuad(int x, int y, int Width, int Height)
 
 	Width /= 2;
 	Height /= 2;
-	q->m_aPoints[0].x = x - Width;
-	q->m_aPoints[0].y = y - Height;
-	q->m_aPoints[1].x = x + Width;
-	q->m_aPoints[1].y = y - Height;
-	q->m_aPoints[2].x = x - Width;
-	q->m_aPoints[2].y = y + Height;
-	q->m_aPoints[3].x = x + Width;
-	q->m_aPoints[3].y = y + Height;
+	q->m_aPoints[0].x = i2fx(x - Width);
+	q->m_aPoints[0].y = i2fx(y - Height);
+	q->m_aPoints[1].x = i2fx(x + Width);
+	q->m_aPoints[1].y = i2fx(y - Height);
+	q->m_aPoints[2].x = i2fx(x - Width);
+	q->m_aPoints[2].y = i2fx(y + Height);
+	q->m_aPoints[3].x = i2fx(x + Width);
+	q->m_aPoints[3].y = i2fx(y + Height);
 
-	q->m_aPoints[4].x = x; // pivot
-	q->m_aPoints[4].y = y;
+	q->m_aPoints[4].x = i2fx(x); // pivot
+	q->m_aPoints[4].y = i2fx(y);
 
-	for(int i = 0; i < 5; i++)
-	{
-		q->m_aPoints[i].x <<= 10;
-		q->m_aPoints[i].y <<= 10;
-	}
+	q->m_aTexcoords[0].x = i2fx(0);
+	q->m_aTexcoords[0].y = i2fx(0);
 
+	q->m_aTexcoords[1].x = i2fx(1);
+	q->m_aTexcoords[1].y = i2fx(0);
 
-	q->m_aTexcoords[0].x = 0;
-	q->m_aTexcoords[0].y = 0;
+	q->m_aTexcoords[2].x = i2fx(0);
+	q->m_aTexcoords[2].y = i2fx(1);
 
-	q->m_aTexcoords[1].x = 1<<10;
-	q->m_aTexcoords[1].y = 0;
+	q->m_aTexcoords[3].x = i2fx(1);
+	q->m_aTexcoords[3].y = i2fx(1);
 
-	q->m_aTexcoords[2].x = 0;
-	q->m_aTexcoords[2].y = 1<<10;
-
-	q->m_aTexcoords[3].x = 1<<10;
-	q->m_aTexcoords[3].y = 1<<10;
-
-	q->m_aColors[0].r = 255; q->m_aColors[0].g = 255; q->m_aColors[0].b = 255; q->m_aColors[0].a = 255;
-	q->m_aColors[1].r = 255; q->m_aColors[1].g = 255; q->m_aColors[1].b = 255; q->m_aColors[1].a = 255;
-	q->m_aColors[2].r = 255; q->m_aColors[2].g = 255; q->m_aColors[2].b = 255; q->m_aColors[2].a = 255;
-	q->m_aColors[3].r = 255; q->m_aColors[3].g = 255; q->m_aColors[3].b = 255; q->m_aColors[3].a = 255;
+	q->m_aColors[0].r = 255;
+	q->m_aColors[0].g = 255;
+	q->m_aColors[0].b = 255;
+	q->m_aColors[0].a = 255;
+	q->m_aColors[1].r = 255;
+	q->m_aColors[1].g = 255;
+	q->m_aColors[1].b = 255;
+	q->m_aColors[1].a = 255;
+	q->m_aColors[2].r = 255;
+	q->m_aColors[2].g = 255;
+	q->m_aColors[2].b = 255;
+	q->m_aColors[2].a = 255;
+	q->m_aColors[3].r = 255;
+	q->m_aColors[3].g = 255;
+	q->m_aColors[3].b = 255;
+	q->m_aColors[3].a = 255;
 
 	return q;
 }
@@ -89,10 +94,10 @@ void CLayerQuads::BrushSelecting(CUIRect Rect)
 {
 	// draw selection rectangle
 	IGraphics::CLineItem Array[4] = {
-		IGraphics::CLineItem(Rect.x, Rect.y, Rect.x+Rect.w, Rect.y),
-		IGraphics::CLineItem(Rect.x+Rect.w, Rect.y, Rect.x+Rect.w, Rect.y+Rect.h),
-		IGraphics::CLineItem(Rect.x+Rect.w, Rect.y+Rect.h, Rect.x, Rect.y+Rect.h),
-		IGraphics::CLineItem(Rect.x, Rect.y+Rect.h, Rect.x, Rect.y)};
+		IGraphics::CLineItem(Rect.x, Rect.y, Rect.x + Rect.w, Rect.y),
+		IGraphics::CLineItem(Rect.x + Rect.w, Rect.y, Rect.x + Rect.w, Rect.y + Rect.h),
+		IGraphics::CLineItem(Rect.x + Rect.w, Rect.y + Rect.h, Rect.x, Rect.y + Rect.h),
+		IGraphics::CLineItem(Rect.x, Rect.y + Rect.h, Rect.x, Rect.y)};
 	Graphics()->TextureClear();
 	Graphics()->LinesBegin();
 	Graphics()->LinesDraw(Array, 4);
@@ -114,7 +119,7 @@ int CLayerQuads::BrushGrab(CLayerGroup *pBrush, CUIRect Rect)
 		float px = fx2f(q->m_aPoints[4].x);
 		float py = fx2f(q->m_aPoints[4].y);
 
-		if(px > Rect.x && px < Rect.x+Rect.w && py > Rect.y && py < Rect.y+Rect.h)
+		if(px > Rect.x && px < Rect.x + Rect.w && py > Rect.y && py < Rect.y + Rect.h)
 		{
 			CQuad n;
 			n = *q;
@@ -129,7 +134,7 @@ int CLayerQuads::BrushGrab(CLayerGroup *pBrush, CUIRect Rect)
 		}
 	}
 
-	return pGrabbed->m_lQuads.size()?1:0;
+	return pGrabbed->m_lQuads.size() ? 1 : 0;
 }
 
 void CLayerQuads::BrushPlace(CLayer *pBrush, float wx, float wy)
@@ -150,7 +155,7 @@ void CLayerQuads::BrushPlace(CLayer *pBrush, float wx, float wy)
 	m_pEditor->m_Map.m_Modified = true;
 }
 
-void Swap(CPoint& a, CPoint& b)
+void Swap(CPoint &a, CPoint &b)
 {
 	CPoint Tmp;
 	Tmp.x = a.x;
@@ -218,7 +223,8 @@ void CLayerQuads::BrushRotate(float Amount)
 
 void CLayerQuads::GetSize(float *w, float *h)
 {
-	*w = 0; *h = 0;
+	*w = 0;
+	*h = 0;
 
 	for(int i = 0; i < m_lQuads.size(); i++)
 	{
@@ -235,7 +241,7 @@ int CLayerQuads::RenderProperties(CUIRect *pToolBox)
 	// layer props
 	enum
 	{
-		PROP_IMAGE=0,
+		PROP_IMAGE = 0,
 		NUM_PROPS,
 	};
 
@@ -253,7 +259,7 @@ int CLayerQuads::RenderProperties(CUIRect *pToolBox)
 	if(Prop == PROP_IMAGE)
 	{
 		if(NewVal >= 0)
-			m_Image = NewVal%m_pEditor->m_Map.m_lImages.size();
+			m_Image = NewVal % m_pEditor->m_Map.m_lImages.size();
 		else
 			m_Image = -1;
 	}
@@ -261,7 +267,6 @@ int CLayerQuads::RenderProperties(CUIRect *pToolBox)
 	return 0;
 }
 
-
 void CLayerQuads::ModifyImageIndex(INDEX_MODIFY_FUNC Func)
 {
 	Func(&m_Image);
