@@ -5,13 +5,12 @@
 #include <engine/shared/config.h>
 
 const char *CTuningParams::ms_apNames[] =
-{
-	#define MACRO_TUNING_PARAM(Name,ScriptName,Value,Description) #ScriptName,
-	#include "tuning.h"
-	#undef MACRO_TUNING_PARAM
+	{
+#define MACRO_TUNING_PARAM(Name, ScriptName, Value, Description) #ScriptName,
+#include "tuning.h"
+#undef MACRO_TUNING_PARAM
 };
 
-
 bool CTuningParams::Set(int Index, float Value)
 {
 	if(Index < 0 || Index >= Num())
@@ -47,14 +46,14 @@ bool CTuningParams::Get(const char *pName, float *pValue)
 
 float HermiteBasis1(float v)
 {
-	return 2*v*v*v - 3*v*v+1;
+	return 2 * v * v * v - 3 * v * v + 1;
 }
 
 float VelocityRamp(float Value, float Start, float Range, float Curvature)
 {
 	if(Value < Start)
 		return 1.0f;
-	return 1.0f/powf(Curvature, (Value-Start)/Range);
+	return 1.0f / powf(Curvature, (Value - Start) / Range);
 }
 
 void CCharacterCore::Init(CWorldCore *pWorld, CCollision *pCollision, CTeamsCore *pTeams)
@@ -71,7 +70,7 @@ void CCharacterCore::Init(CWorldCore *pWorld, CCollision *pCollision, CTeamsCore
 	m_Jumps = 2;
 }
 
-void CCharacterCore::Init(CWorldCore *pWorld, CCollision *pCollision, CTeamsCore *pTeams, std::map<int, std::vector<vec2> > *pTeleOuts)
+void CCharacterCore::Init(CWorldCore *pWorld, CCollision *pCollision, CTeamsCore *pTeams, std::map<int, std::vector<vec2>> *pTeleOuts)
 {
 	m_pWorld = pWorld;
 	m_pCollision = pCollision;
@@ -87,11 +86,11 @@ void CCharacterCore::Init(CWorldCore *pWorld, CCollision *pCollision, CTeamsCore
 
 void CCharacterCore::Reset()
 {
-	m_Pos = vec2(0,0);
-	m_Vel = vec2(0,0);
+	m_Pos = vec2(0, 0);
+	m_Vel = vec2(0, 0);
 	m_NewHook = false;
-	m_HookPos = vec2(0,0);
-	m_HookDir = vec2(0,0);
+	m_HookPos = vec2(0, 0);
+	m_HookDir = vec2(0, 0);
 	m_HookTick = 0;
 	m_HookState = HOOK_IDLE;
 	m_HookedPlayer = -1;
@@ -129,9 +128,9 @@ void CCharacterCore::Tick(bool UseInput)
 
 	// get ground state
 	bool Grounded = false;
-	if(m_pCollision->CheckPoint(m_Pos.x+PhysSize/2, m_Pos.y+PhysSize/2+5))
+	if(m_pCollision->CheckPoint(m_Pos.x + PhysSize / 2, m_Pos.y + PhysSize / 2 + 5))
 		Grounded = true;
-	if(m_pCollision->CheckPoint(m_Pos.x-PhysSize/2, m_Pos.y+PhysSize/2+5))
+	if(m_pCollision->CheckPoint(m_Pos.x - PhysSize / 2, m_Pos.y + PhysSize / 2 + 5))
 		Grounded = true;
 
 	vec2 TargetDirection = normalize(vec2(m_Input.m_TargetX, m_Input.m_TargetY));
@@ -152,17 +151,17 @@ void CCharacterCore::Tick(bool UseInput)
 		if(m_Input.m_TargetX == 0)
 			a = atanf((float)m_Input.m_TargetY);
 		else
-			a = atanf((float)m_Input.m_TargetY/(float)m_Input.m_TargetX);
+			a = atanf((float)m_Input.m_TargetY / (float)m_Input.m_TargetX);
 
 		if(m_Input.m_TargetX < 0)
-			a = a+pi;
+			a = a + pi;
 
-		m_Angle = (int)(a*256.0f);
+		m_Angle = (int)(a * 256.0f);
 
 		// handle jump
 		if(m_Input.m_Jump)
 		{
-			if(!(m_Jumped&1))
+			if(!(m_Jumped & 1))
 			{
 				if(Grounded)
 				{
@@ -171,7 +170,7 @@ void CCharacterCore::Tick(bool UseInput)
 					m_Jumped |= 1;
 					m_JumpedTotal = 1;
 				}
-				else if(!(m_Jumped&2))
+				else if(!(m_Jumped & 2))
 				{
 					m_TriggeredEvents |= COREEVENT_AIR_JUMP;
 					m_Vel.y = -m_pWorld->m_Tuning[g_Config.m_ClDummy].m_AirJumpImpulse;
@@ -189,7 +188,7 @@ void CCharacterCore::Tick(bool UseInput)
 			if(m_HookState == HOOK_IDLE)
 			{
 				m_HookState = HOOK_FLYING;
-				m_HookPos = m_Pos+TargetDirection*PhysSize*1.5f;
+				m_HookPos = m_Pos + TargetDirection * PhysSize * 1.5f;
 				m_HookDir = TargetDirection;
 				m_HookedPlayer = -1;
 				m_HookTick = SERVER_TICK_SPEED * (1.25f - m_pWorld->m_Tuning[g_Config.m_ClDummy].m_HookDuration);
@@ -240,12 +239,11 @@ void CCharacterCore::Tick(bool UseInput)
 	}
 	else if(m_HookState == HOOK_FLYING)
 	{
-		vec2 NewPos = m_HookPos+m_HookDir*m_pWorld->m_Tuning[g_Config.m_ClDummy].m_HookFireSpeed;
-		if((!m_NewHook && distance(m_Pos, NewPos) > m_pWorld->m_Tuning[g_Config.m_ClDummy].m_HookLength)
-		|| (m_NewHook && distance(m_HookTeleBase, NewPos) > m_pWorld->m_Tuning[g_Config.m_ClDummy].m_HookLength))
+		vec2 NewPos = m_HookPos + m_HookDir * m_pWorld->m_Tuning[g_Config.m_ClDummy].m_HookFireSpeed;
+		if((!m_NewHook && distance(m_Pos, NewPos) > m_pWorld->m_Tuning[g_Config.m_ClDummy].m_HookLength) || (m_NewHook && distance(m_HookTeleBase, NewPos) > m_pWorld->m_Tuning[g_Config.m_ClDummy].m_HookLength))
 		{
 			m_HookState = HOOK_RETRACT_START;
-			NewPos = m_Pos + normalize(NewPos-m_Pos) * m_pWorld->m_Tuning[g_Config.m_ClDummy].m_HookLength;
+			NewPos = m_Pos + normalize(NewPos - m_Pos) * m_pWorld->m_Tuning[g_Config.m_ClDummy].m_HookLength;
 			m_pReset = true;
 		}
 
@@ -262,7 +260,7 @@ void CCharacterCore::Tick(bool UseInput)
 		{
 			if(Hit == TILE_NOHOOK)
 				GoingToRetract = true;
-			else if (Hit == TILE_TELEINHOOK)
+			else if(Hit == TILE_TELEINHOOK)
 				GoingThroughTele = true;
 			else
 				GoingToHitGround = true;
@@ -280,9 +278,9 @@ void CCharacterCore::Tick(bool UseInput)
 					continue;
 
 				vec2 ClosestPoint = closest_point_on_line(m_HookPos, NewPos, pCharCore->m_Pos);
-				if(distance(pCharCore->m_Pos, ClosestPoint) < PhysSize+2.0f)
+				if(distance(pCharCore->m_Pos, ClosestPoint) < PhysSize + 2.0f)
 				{
-					if (m_HookedPlayer == -1 || distance(m_HookPos, pCharCore->m_Pos) < Distance)
+					if(m_HookedPlayer == -1 || distance(m_HookPos, pCharCore->m_Pos) < Distance)
 					{
 						m_TriggeredEvents |= COREEVENT_HOOK_ATTACH_PLAYER;
 						m_HookState = HOOK_GRABBED;
@@ -307,14 +305,14 @@ void CCharacterCore::Tick(bool UseInput)
 				m_HookState = HOOK_RETRACT_START;
 			}
 
-			if(GoingThroughTele && m_pTeleOuts && m_pTeleOuts->size() && (*m_pTeleOuts)[teleNr-1].size())
+			if(GoingThroughTele && m_pTeleOuts && m_pTeleOuts->size() && (*m_pTeleOuts)[teleNr - 1].size())
 			{
 				m_TriggeredEvents = 0;
 				m_HookedPlayer = -1;
 
 				m_NewHook = true;
-				int RandomOut = m_pWorld->RandomOr0((*m_pTeleOuts)[teleNr-1].size());
-				m_HookPos = (*m_pTeleOuts)[teleNr-1][RandomOut]+TargetDirection*PhysSize*1.5f;
+				int RandomOut = m_pWorld->RandomOr0((*m_pTeleOuts)[teleNr - 1].size());
+				m_HookPos = (*m_pTeleOuts)[teleNr - 1][RandomOut] + TargetDirection * PhysSize * 1.5f;
 				m_HookDir = TargetDirection;
 				m_HookTeleBase = m_HookPos;
 			}
@@ -342,13 +340,13 @@ void CCharacterCore::Tick(bool UseInput)
 
 			// keep players hooked for a max of 1.5sec
 			//if(Server()->Tick() > hook_tick+(Server()->TickSpeed()*3)/2)
-				//release_hooked();
+			//release_hooked();
 		}
 
 		// don't do this hook rutine when we are hook to a player
 		if(m_HookedPlayer == -1 && distance(m_HookPos, m_Pos) > 46.0f)
 		{
-			vec2 HookVel = normalize(m_HookPos-m_Pos)*m_pWorld->m_Tuning[g_Config.m_ClDummy].m_HookDragAccel;
+			vec2 HookVel = normalize(m_HookPos - m_Pos) * m_pWorld->m_Tuning[g_Config.m_ClDummy].m_HookDragAccel;
 			// the hook as more power to drag you up then down.
 			// this makes it easier to get on top of an platform
 			if(HookVel.y > 0)
@@ -361,17 +359,16 @@ void CCharacterCore::Tick(bool UseInput)
 			else
 				HookVel.x *= 0.75f;
 
-			vec2 NewVel = m_Vel+HookVel;
+			vec2 NewVel = m_Vel + HookVel;
 
 			// check if we are under the legal limit for the hook
 			if(length(NewVel) < m_pWorld->m_Tuning[g_Config.m_ClDummy].m_HookDragSpeed || length(NewVel) < length(m_Vel))
 				m_Vel = NewVel; // no problem. apply
-
 		}
 
 		// release hook (max default hook time is 1.25 s)
 		m_HookTick++;
-		if(m_HookedPlayer != -1 && (m_HookTick > SERVER_TICK_SPEED+SERVER_TICK_SPEED/5 || !m_pWorld->m_apCharacters[m_HookedPlayer]))
+		if(m_HookedPlayer != -1 && (m_HookTick > SERVER_TICK_SPEED + SERVER_TICK_SPEED / 5 || !m_pWorld->m_apCharacters[m_HookedPlayer]))
 		{
 			m_HookedPlayer = -1;
 			m_HookState = HOOK_RETRACTED;
@@ -400,48 +397,44 @@ void CCharacterCore::Tick(bool UseInput)
 			float Distance = distance(m_Pos, pCharCore->m_Pos);
 			vec2 Dir = normalize(m_Pos - pCharCore->m_Pos);
 
-			bool CanCollide = (m_Super || pCharCore->m_Super)
-					|| (pCharCore->m_Collision && m_Collision
-						&& !m_NoCollision && !pCharCore->m_NoCollision
-						&& m_pWorld->m_Tuning[g_Config.m_ClDummy].m_PlayerCollision
-						);
+			bool CanCollide = (m_Super || pCharCore->m_Super) || (pCharCore->m_Collision && m_Collision && !m_NoCollision && !pCharCore->m_NoCollision && m_pWorld->m_Tuning[g_Config.m_ClDummy].m_PlayerCollision);
 
-			if(CanCollide && Distance < PhysSize*1.25f && Distance > 0.0f)
+			if(CanCollide && Distance < PhysSize * 1.25f && Distance > 0.0f)
 			{
-				float a = (PhysSize*1.45f - Distance);
+				float a = (PhysSize * 1.45f - Distance);
 				float Velocity = 0.5f;
 
 				// make sure that we don't add excess force by checking the
 				// direction against the current velocity. if not zero.
-				if (length(m_Vel) > 0.0001)
-					Velocity = 1-(dot(normalize(m_Vel), Dir)+1)/2;
+				if(length(m_Vel) > 0.0001)
+					Velocity = 1 - (dot(normalize(m_Vel), Dir) + 1) / 2;
 
-				m_Vel += Dir*a*(Velocity*0.75f);
+				m_Vel += Dir * a * (Velocity * 0.75f);
 				m_Vel *= 0.85f;
 			}
 
 			// handle hook influence
 			if(m_Hook && m_HookedPlayer == i && m_pWorld->m_Tuning[g_Config.m_ClDummy].m_PlayerHooking)
 			{
-				if(Distance > PhysSize*1.50f) // TODO: fix tweakable variable
+				if(Distance > PhysSize * 1.50f) // TODO: fix tweakable variable
 				{
-					float Accel = m_pWorld->m_Tuning[g_Config.m_ClDummy].m_HookDragAccel * (Distance/m_pWorld->m_Tuning[g_Config.m_ClDummy].m_HookLength);
+					float Accel = m_pWorld->m_Tuning[g_Config.m_ClDummy].m_HookDragAccel * (Distance / m_pWorld->m_Tuning[g_Config.m_ClDummy].m_HookLength);
 					float DragSpeed = m_pWorld->m_Tuning[g_Config.m_ClDummy].m_HookDragSpeed;
 
 					vec2 Temp;
 					// add force to the hooked player
-					Temp.x = SaturatedAdd(-DragSpeed, DragSpeed, pCharCore->m_Vel.x, Accel*Dir.x*1.5f);
-					Temp.y = SaturatedAdd(-DragSpeed, DragSpeed, pCharCore->m_Vel.y, Accel*Dir.y*1.5f);
+					Temp.x = SaturatedAdd(-DragSpeed, DragSpeed, pCharCore->m_Vel.x, Accel * Dir.x * 1.5f);
+					Temp.y = SaturatedAdd(-DragSpeed, DragSpeed, pCharCore->m_Vel.y, Accel * Dir.y * 1.5f);
 					pCharCore->m_Vel = ClampVel(pCharCore->m_MoveRestrictions, Temp);
 					// add a little bit force to the guy who has the grip
-					Temp.x = SaturatedAdd(-DragSpeed, DragSpeed, m_Vel.x, -Accel*Dir.x*0.25f);
-					Temp.y = SaturatedAdd(-DragSpeed, DragSpeed, m_Vel.y, -Accel*Dir.y*0.25f);
+					Temp.x = SaturatedAdd(-DragSpeed, DragSpeed, m_Vel.x, -Accel * Dir.x * 0.25f);
+					Temp.y = SaturatedAdd(-DragSpeed, DragSpeed, m_Vel.y, -Accel * Dir.y * 0.25f);
 					m_Vel = ClampVel(m_MoveRestrictions, Temp);
 				}
 			}
 		}
 
-		if (m_HookState != HOOK_FLYING)
+		if(m_HookState != HOOK_FLYING)
 		{
 			m_NewHook = false;
 		}
@@ -454,9 +447,9 @@ void CCharacterCore::Tick(bool UseInput)
 
 void CCharacterCore::Move()
 {
-	float RampValue = VelocityRamp(length(m_Vel)*50, m_pWorld->m_Tuning[g_Config.m_ClDummy].m_VelrampStart, m_pWorld->m_Tuning[g_Config.m_ClDummy].m_VelrampRange, m_pWorld->m_Tuning[g_Config.m_ClDummy].m_VelrampCurvature);
+	float RampValue = VelocityRamp(length(m_Vel) * 50, m_pWorld->m_Tuning[g_Config.m_ClDummy].m_VelrampStart, m_pWorld->m_Tuning[g_Config.m_ClDummy].m_VelrampRange, m_pWorld->m_Tuning[g_Config.m_ClDummy].m_VelrampCurvature);
 
-	m_Vel.x = m_Vel.x*RampValue;
+	m_Vel.x = m_Vel.x * RampValue;
 
 	vec2 NewPos = m_Pos;
 
@@ -474,22 +467,22 @@ void CCharacterCore::Move()
 	else
 		m_LeftWall = true;
 
-	m_Vel.x = m_Vel.x*(1.0f/RampValue);
+	m_Vel.x = m_Vel.x * (1.0f / RampValue);
 
 	if(m_pWorld && (m_Super || (m_pWorld->m_Tuning[g_Config.m_ClDummy].m_PlayerCollision && m_Collision && !m_NoCollision && !m_Solo)))
 	{
 		// check player collision
 		float Distance = distance(m_Pos, NewPos);
-		int End = Distance+1;
+		int End = Distance + 1;
 		vec2 LastPos = m_Pos;
 		for(int i = 0; i < End; i++)
 		{
-			float a = i/Distance;
+			float a = i / Distance;
 			vec2 Pos = mix(m_Pos, NewPos, a);
 			for(int p = 0; p < MAX_CLIENTS; p++)
 			{
 				CCharacterCore *pCharCore = m_pWorld->m_apCharacters[p];
-				if(!pCharCore || pCharCore == this )
+				if(!pCharCore || pCharCore == this)
 					continue;
 				if((!(pCharCore->m_Super || m_Super) && (m_Solo || pCharCore->m_Solo || !pCharCore->m_Collision || pCharCore->m_NoCollision || (m_Id != -1 && !m_pTeams->CanCollide(m_Id, p)))))
 					continue;
@@ -515,14 +508,14 @@ void CCharacterCore::Write(CNetObj_CharacterCore *pObjCore)
 	pObjCore->m_X = round_to_int(m_Pos.x);
 	pObjCore->m_Y = round_to_int(m_Pos.y);
 
-	pObjCore->m_VelX = round_to_int(m_Vel.x*256.0f);
-	pObjCore->m_VelY = round_to_int(m_Vel.y*256.0f);
+	pObjCore->m_VelX = round_to_int(m_Vel.x * 256.0f);
+	pObjCore->m_VelY = round_to_int(m_Vel.y * 256.0f);
 	pObjCore->m_HookState = m_HookState;
 	pObjCore->m_HookTick = m_HookTick;
 	pObjCore->m_HookX = round_to_int(m_HookPos.x);
 	pObjCore->m_HookY = round_to_int(m_HookPos.y);
-	pObjCore->m_HookDx = round_to_int(m_HookDir.x*256.0f);
-	pObjCore->m_HookDy = round_to_int(m_HookDir.y*256.0f);
+	pObjCore->m_HookDx = round_to_int(m_HookDir.x * 256.0f);
+	pObjCore->m_HookDy = round_to_int(m_HookDir.y * 256.0f);
 	pObjCore->m_HookedPlayer = m_HookedPlayer;
 	pObjCore->m_Jumped = m_Jumped;
 	pObjCore->m_Direction = m_Direction;
@@ -533,14 +526,14 @@ void CCharacterCore::Read(const CNetObj_CharacterCore *pObjCore)
 {
 	m_Pos.x = pObjCore->m_X;
 	m_Pos.y = pObjCore->m_Y;
-	m_Vel.x = pObjCore->m_VelX/256.0f;
-	m_Vel.y = pObjCore->m_VelY/256.0f;
+	m_Vel.x = pObjCore->m_VelX / 256.0f;
+	m_Vel.y = pObjCore->m_VelY / 256.0f;
 	m_HookState = pObjCore->m_HookState;
 	m_HookTick = pObjCore->m_HookTick;
 	m_HookPos.x = pObjCore->m_HookX;
 	m_HookPos.y = pObjCore->m_HookY;
-	m_HookDir.x = pObjCore->m_HookDx/256.0f;
-	m_HookDir.y = pObjCore->m_HookDy/256.0f;
+	m_HookDir.x = pObjCore->m_HookDx / 256.0f;
+	m_HookDir.y = pObjCore->m_HookDy / 256.0f;
 	m_HookedPlayer = pObjCore->m_HookedPlayer;
 	m_Jumped = pObjCore->m_Jumped;
 	m_Direction = pObjCore->m_Direction;
