@@ -9,7 +9,7 @@
 enum
 {
 	// TODO(Shereef Marzouk): fix this for vanilla, make use of LAYERTYPE_GAME instead of using m_game variable in the editor.
-	LAYERTYPE_INVALID=0,
+	LAYERTYPE_INVALID = 0,
 	LAYERTYPE_GAME,
 	LAYERTYPE_TILES,
 	LAYERTYPE_QUADS,
@@ -21,7 +21,7 @@ enum
 	LAYERTYPE_SOUNDS_DEPRECATED, // deprecated! do not use this, this is just for compatibility reasons
 	LAYERTYPE_SOUNDS,
 
-	MAPITEMTYPE_VERSION=0,
+	MAPITEMTYPE_VERSION = 0,
 	MAPITEMTYPE_INFO,
 	MAPITEMTYPE_IMAGE,
 	MAPITEMTYPE_ENVELOPE,
@@ -33,8 +33,7 @@ enum
 	// format with UUIDs. See src/engine/shared/datafile.cpp for some of
 	// the implementation.
 
-
-	CURVETYPE_STEP=0,
+	CURVETYPE_STEP = 0,
 	CURVETYPE_LINEAR,
 	CURVETYPE_SLOW,
 	CURVETYPE_FAST,
@@ -43,7 +42,7 @@ enum
 
 	// game layer tiles
 	// TODO define which Layer uses which tiles (needed for mapeditor)
-	ENTITY_NULL=0,
+	ENTITY_NULL = 0,
 	ENTITY_SPAWN,
 	ENTITY_SPAWN_RED,
 	ENTITY_SPAWN_BLUE,
@@ -74,7 +73,7 @@ enum
 	ENTITY_LASER_O_NORMAL,
 	ENTITY_LASER_O_FAST,
 	//DDRace - Plasma
-	ENTITY_PLASMAE=29,
+	ENTITY_PLASMAE = 29,
 	ENTITY_PLASMAF,
 	ENTITY_PLASMA,
 	ENTITY_PLASMAU,
@@ -82,7 +81,7 @@ enum
 	ENTITY_CRAZY_SHOTGUN_EX,
 	ENTITY_CRAZY_SHOTGUN,
 	//DDRace - Draggers
-	ENTITY_DRAGGER_WEAK=42,
+	ENTITY_DRAGGER_WEAK = 42,
 	ENTITY_DRAGGER_NORMAL,
 	ENTITY_DRAGGER_STRONG,
 	//Draggers Behind Walls
@@ -90,12 +89,12 @@ enum
 	ENTITY_DRAGGER_NORMAL_NW,
 	ENTITY_DRAGGER_STRONG_NW,
 	//Doors
-	ENTITY_DOOR=49,
+	ENTITY_DOOR = 49,
 	//End Of Lower Tiles
 	NUM_ENTITIES,
 	//Start From Top Left
 	//Tile Controllers
-	TILE_AIR=0,
+	TILE_AIR = 0,
 	TILE_SOLID,
 	TILE_DEATH,
 	TILE_NOHOOK,
@@ -111,12 +110,12 @@ enum
 	TILE_TELEINWEAPON,
 	TILE_TELEINHOOK,
 	TILE_WALLJUMP = 16,
-	TILE_EHOOK_START,
-	TILE_EHOOK_END,
-	TILE_HIT_START,
-	TILE_HIT_END,
-	TILE_SOLO_START,
-	TILE_SOLO_END,
+	TILE_EHOOK_ENABLE,
+	TILE_EHOOK_DISABLE,
+	TILE_HIT_ENABLE,
+	TILE_HIT_DISABLE,
+	TILE_SOLO_ENABLE,
+	TILE_SOLO_DISABLE,
 	//Switches
 	TILE_SWITCHTIMEDOPEN = 22,
 	TILE_SWITCHTIMEDCLOSE,
@@ -129,8 +128,8 @@ enum
 	TILE_TELECHECKOUT,
 	TILE_TELECHECKIN,
 	TILE_REFILL_JUMPS = 32,
-	TILE_BEGIN,
-	TILE_END,
+	TILE_START,
+	TILE_FINISH,
 	TILE_CHECKPOINT_FIRST = 35,
 	TILE_CHECKPOINT_LAST = 59,
 	TILE_STOP = 60,
@@ -141,27 +140,27 @@ enum
 	TILE_CP_F,
 	TILE_THROUGH_ALL,
 	TILE_THROUGH_DIR,
-	TILE_TUNE1,
+	TILE_TUNE,
 	TILE_OLDLASER = 71,
 	TILE_NPC,
 	TILE_EHOOK,
 	TILE_NOHIT,
 	TILE_NPH,
 	TILE_UNLOCK_TEAM,
-	TILE_PENALTY = 79,
-	TILE_NPC_END = 88,
-	TILE_SUPER_END,
-	TILE_JETPACK_END,
-	TILE_NPH_END,
-	TILE_BONUS = 95,
+	TILE_ADD_TIME = 79,
+	TILE_NPC_DISABLE = 88,
+	TILE_UNLIMITED_JUMPS_DISABLE,
+	TILE_JETPACK_DISABLE,
+	TILE_NPH_DISABLE,
+	TILE_SUBSTRACT_TIME = 95,
 	TILE_TELE_GUN_ENABLE = 96,
 	TILE_TELE_GUN_DISABLE = 97,
 	TILE_ALLOW_TELE_GUN = 98,
 	TILE_ALLOW_BLUE_TELE_GUN = 99,
-	TILE_NPC_START = 104,
-	TILE_SUPER_START,
-	TILE_JETPACK_START,
-	TILE_NPH_START,
+	TILE_NPC_ENABLE = 104,
+	TILE_UNLIMITED_JUMPS_ENABLE,
+	TILE_JETPACK_ENABLE,
+	TILE_NPH_ENABLE,
 	TILE_TELE_GRENADE_ENABLE = 112,
 	TILE_TELE_GRENADE_DISABLE = 113,
 	TILE_TELE_LASER_ENABLE = 128,
@@ -178,7 +177,7 @@ enum
 	TILE_ENTITIES_OFF_2,
 	//End of higher tiles
 	//Layers
-	LAYER_GAME=0,
+	LAYER_GAME = 0,
 	LAYER_FRONT,
 	LAYER_TELE,
 	LAYER_SPEEDUP,
@@ -186,25 +185,25 @@ enum
 	LAYER_TUNE,
 	NUM_LAYERS,
 	//Flags
-	TILEFLAG_VFLIP=1,
-	TILEFLAG_HFLIP=2,
-	TILEFLAG_OPAQUE=4,
-	TILEFLAG_ROTATE=8,
+	TILEFLAG_VFLIP = 1,
+	TILEFLAG_HFLIP = 2,
+	TILEFLAG_OPAQUE = 4,
+	TILEFLAG_ROTATE = 8,
 	//Rotation
 	ROTATION_0 = 0,
 	ROTATION_90 = TILEFLAG_ROTATE,
-	ROTATION_180 = (TILEFLAG_VFLIP|TILEFLAG_HFLIP),
-	ROTATION_270 = (TILEFLAG_VFLIP|TILEFLAG_HFLIP|TILEFLAG_ROTATE),
+	ROTATION_180 = (TILEFLAG_VFLIP | TILEFLAG_HFLIP),
+	ROTATION_270 = (TILEFLAG_VFLIP | TILEFLAG_HFLIP | TILEFLAG_ROTATE),
 
-	LAYERFLAG_DETAIL=1,
-	TILESLAYERFLAG_GAME=1,
-	TILESLAYERFLAG_TELE=2,
-	TILESLAYERFLAG_SPEEDUP=4,
-	TILESLAYERFLAG_FRONT=8,
-	TILESLAYERFLAG_SWITCH=16,
-	TILESLAYERFLAG_TUNE=32,
+	LAYERFLAG_DETAIL = 1,
+	TILESLAYERFLAG_GAME = 1,
+	TILESLAYERFLAG_TELE = 2,
+	TILESLAYERFLAG_SPEEDUP = 4,
+	TILESLAYERFLAG_FRONT = 8,
+	TILESLAYERFLAG_SWITCH = 16,
+	TILESLAYERFLAG_TUNE = 32,
 
-	ENTITY_OFFSET=255-16*4,
+	ENTITY_OFFSET = 255 - 16 * 4,
 };
 
 struct CPoint
@@ -246,12 +245,12 @@ struct CMapItemInfo
 	int m_MapVersion;
 	int m_Credits;
 	int m_License;
-} ;
+};
 
 struct CMapItemInfoSettings : CMapItemInfo
 {
 	int m_Settings;
-} ;
+};
 
 struct CMapItemImage
 {
@@ -261,7 +260,7 @@ struct CMapItemImage
 	int m_External;
 	int m_ImageName;
 	int m_ImageData;
-} ;
+};
 
 struct CMapItemGroup_v1
 {
@@ -273,12 +272,14 @@ struct CMapItemGroup_v1
 
 	int m_StartLayer;
 	int m_NumLayers;
-} ;
-
+};
 
 struct CMapItemGroup : public CMapItemGroup_v1
 {
-	enum { CURRENT_VERSION=3 };
+	enum
+	{
+		CURRENT_VERSION = 3
+	};
 
 	int m_UseClipping;
 	int m_ClipX;
@@ -287,14 +288,14 @@ struct CMapItemGroup : public CMapItemGroup_v1
 	int m_ClipH;
 
 	int m_aName[3];
-} ;
+};
 
 struct CMapItemLayer
 {
 	int m_Version;
 	int m_Type;
 	int m_Flags;
-} ;
+};
 
 struct CMapItemLayerTilemap
 {
@@ -321,7 +322,7 @@ struct CMapItemLayerTilemap
 	int m_Front;
 	int m_Switch;
 	int m_Tune;
-} ;
+};
 
 struct CMapItemLayerQuads
 {
@@ -333,12 +334,12 @@ struct CMapItemLayerQuads
 	int m_Image;
 
 	int m_aName[3];
-} ;
+};
 
 struct CMapItemVersion
 {
 	int m_Version;
-} ;
+};
 
 struct CEnvPoint
 {
@@ -347,7 +348,7 @@ struct CEnvPoint
 	int m_aValues[4]; // 1-4 depending on envelope (22.10 fixed point)
 
 	bool operator<(const CEnvPoint &Other) { return m_Time < Other.m_Time; }
-} ;
+};
 
 struct CMapItemEnvelope_v1
 {
@@ -356,11 +357,14 @@ struct CMapItemEnvelope_v1
 	int m_StartPoint;
 	int m_NumPoints;
 	int m_aName[8];
-} ;
+};
 
 struct CMapItemEnvelope : public CMapItemEnvelope_v1
 {
-	enum { CURRENT_VERSION=2 };
+	enum
+	{
+		CURRENT_VERSION = 2
+	};
 	int m_Synchronized;
 };
 
@@ -410,7 +414,10 @@ struct CSoundSource
 
 struct CMapItemLayerSounds
 {
-	enum { CURRENT_VERSION=2 };
+	enum
+	{
+		CURRENT_VERSION = 2
+	};
 
 	CMapItemLayer m_Layer;
 	int m_Version;
@@ -431,7 +438,7 @@ struct CMapItemSound
 	int m_SoundName;
 	int m_SoundData;
 	int m_SoundDataSize;
-} ;
+};
 
 // DDRace
 
@@ -475,7 +482,6 @@ public:
 	unsigned char m_Type;
 };
 
-
 bool IsValidGameTile(int Index);
 bool IsValidFrontTile(int Index);
 bool IsValidTeleTile(int Index);
@@ -484,5 +490,6 @@ bool IsValidSwitchTile(int Index);
 bool IsValidTuneTile(int Index);
 bool IsValidEntity(int Index);
 bool IsRotatableTile(int Index);
+bool IsCreditsTile(int TileIndex);
 
 #endif
