@@ -1,16 +1,16 @@
 /* (c) Shereef Marzouk. See "licence DDRace.txt" and the readme.txt in the root of the distribution for more information. */
+#include "dragger.h"
 #include <engine/config.h>
 #include <engine/server.h>
 #include <engine/shared/config.h>
 #include <game/generated/protocol.h>
 #include <game/server/gamecontext.h>
-#include <game/server/teams.h>
 #include <game/server/gamemodes/DDRace.h>
-#include "dragger.h"
+#include <game/server/teams.h>
 
 CDragger::CDragger(CGameWorld *pGameWorld, vec2 Pos, float Strength, bool NW,
-		int CaughtTeam, int Layer, int Number) :
-		CEntity(pGameWorld, CGameWorld::ENTTYPE_LASER)
+	int CaughtTeam, int Layer, int Number) :
+	CEntity(pGameWorld, CGameWorld::ENTTYPE_LASER)
 {
 	m_Layer = Layer;
 	m_Number = Number;
@@ -21,7 +21,7 @@ CDragger::CDragger(CGameWorld *pGameWorld, vec2 Pos, float Strength, bool NW,
 	m_CaughtTeam = CaughtTeam;
 	GameWorld()->InsertEntity(this);
 
-	for (int i = 0; i < MAX_CLIENTS; i++)
+	for(int i = 0; i < MAX_CLIENTS; i++)
 	{
 		m_SoloIDs[i] = -1;
 	}
@@ -29,52 +29,48 @@ CDragger::CDragger(CGameWorld *pGameWorld, vec2 Pos, float Strength, bool NW,
 
 void CDragger::Move()
 {
-	if (m_Target && (!m_Target->IsAlive() || (m_Target->IsAlive()
-			&& (m_Target->m_Super || m_Target->IsPaused()
-					|| (m_Layer == LAYER_SWITCH && m_Number
-							&& !GameServer()->Collision()->m_pSwitchers[m_Number].m_Status[m_Target->Team()])))))
+	if(m_Target && (!m_Target->IsAlive() || (m_Target->IsAlive() && (m_Target->m_Super || m_Target->IsPaused() || (m_Layer == LAYER_SWITCH && m_Number && !GameServer()->Collision()->m_pSwitchers[m_Number].m_Status[m_Target->Team()])))))
 		m_Target = 0;
 
 	mem_zero(m_SoloEnts, sizeof(m_SoloEnts));
 	CCharacter *TempEnts[MAX_CLIENTS];
 
 	int Num = GameServer()->m_World.FindEntities(m_Pos, g_Config.m_SvDraggerRange,
-			(CEntity**) m_SoloEnts, MAX_CLIENTS, CGameWorld::ENTTYPE_CHARACTER);
+		(CEntity **)m_SoloEnts, MAX_CLIENTS, CGameWorld::ENTTYPE_CHARACTER);
 	mem_copy(TempEnts, m_SoloEnts, sizeof(TempEnts));
 
 	int Id = -1;
 	int MinLen = 0;
 	CCharacter *Temp;
-	for (int i = 0; i < Num; i++)
+	for(int i = 0; i < Num; i++)
 	{
 		Temp = m_SoloEnts[i];
-		if (Temp->Team() != m_CaughtTeam)
+		if(Temp->Team() != m_CaughtTeam)
 		{
 			m_SoloEnts[i] = 0;
 			continue;
 		}
-		if (m_Layer == LAYER_SWITCH && m_Number
-				&& !GameServer()->Collision()->m_pSwitchers[m_Number].m_Status[Temp->Team()])
+		if(m_Layer == LAYER_SWITCH && m_Number && !GameServer()->Collision()->m_pSwitchers[m_Number].m_Status[Temp->Team()])
 		{
 			m_SoloEnts[i] = 0;
 			continue;
 		}
 		int Res =
-				m_NW ? GameServer()->Collision()->IntersectNoLaserNW(m_Pos,
-								Temp->m_Pos, 0, 0) :
-						GameServer()->Collision()->IntersectNoLaser(m_Pos,
-								Temp->m_Pos, 0, 0);
+			m_NW ? GameServer()->Collision()->IntersectNoLaserNW(m_Pos,
+				       Temp->m_Pos, 0, 0) :
+			       GameServer()->Collision()->IntersectNoLaser(m_Pos,
+				       Temp->m_Pos, 0, 0);
 
-		if (Res == 0)
+		if(Res == 0)
 		{
 			int Len = length(Temp->m_Pos - m_Pos);
-			if (MinLen == 0 || MinLen > Len)
+			if(MinLen == 0 || MinLen > Len)
 			{
 				MinLen = Len;
 				Id = i;
 			}
 
-			if (!Temp->Teams()->m_Core.GetSolo(Temp->GetPlayer()->GetCID()))
+			if(!Temp->Teams()->m_Core.GetSolo(Temp->GetPlayer()->GetCID()))
 				m_SoloEnts[i] = 0;
 		}
 		else
@@ -83,14 +79,14 @@ void CDragger::Move()
 		}
 	}
 
-	if (!m_Target)
+	if(!m_Target)
 		m_Target = Id != -1 ? TempEnts[Id] : 0;
 
-	if (m_Target)
+	if(m_Target)
 	{
-		for (int i = 0; i < MAX_CLIENTS; i++)
+		for(int i = 0; i < MAX_CLIENTS; i++)
 		{
-			if (m_SoloEnts[i] == m_Target)
+			if(m_SoloEnts[i] == m_Target)
 				m_SoloEnts[i] = 0;
 		}
 	}
@@ -98,34 +94,34 @@ void CDragger::Move()
 
 void CDragger::Drag()
 {
-	if (m_Target)
+	if(m_Target)
 	{
 		CCharacter *Target = m_Target;
 
-		for (int i = -1; i < MAX_CLIENTS; i++)
+		for(int i = -1; i < MAX_CLIENTS; i++)
 		{
-			if (i >= 0)
+			if(i >= 0)
 				Target = m_SoloEnts[i];
 
-			if (!Target)
+			if(!Target)
 				continue;
 
 			int Res = 0;
-			if (!m_NW)
+			if(!m_NW)
 				Res = GameServer()->Collision()->IntersectNoLaser(m_Pos,
-						Target->m_Pos, 0, 0);
+					Target->m_Pos, 0, 0);
 			else
 				Res = GameServer()->Collision()->IntersectNoLaserNW(m_Pos,
-						Target->m_Pos, 0, 0);
-			if (Res || length(m_Pos - Target->m_Pos) > g_Config.m_SvDraggerRange)
+					Target->m_Pos, 0, 0);
+			if(Res || length(m_Pos - Target->m_Pos) > g_Config.m_SvDraggerRange)
 			{
 				Target = 0;
-				if (i == -1)
+				if(i == -1)
 					m_Target = 0;
 				else
 					m_SoloEnts[i] = 0;
 			}
-			else if (length(m_Pos - Target->m_Pos) > 28)
+			else if(length(m_Pos - Target->m_Pos) > 28)
 			{
 				vec2 Temp = Target->Core()->m_Vel + (normalize(m_Pos - Target->m_Pos) * m_Strength);
 				Target->Core()->m_Vel = ClampVel(Target->m_MoveRestrictions, Temp);
@@ -141,16 +137,15 @@ void CDragger::Reset()
 
 void CDragger::Tick()
 {
-	if (((CGameControllerDDRace*) GameServer()->m_pController)->m_Teams.GetTeamState(
-			m_CaughtTeam) == CGameTeams::TEAMSTATE_EMPTY)
+	if(((CGameControllerDDRace *)GameServer()->m_pController)->m_Teams.GetTeamState(m_CaughtTeam) == CGameTeams::TEAMSTATE_EMPTY)
 		return;
-	if (Server()->Tick() % int(Server()->TickSpeed() * 0.15f) == 0)
+	if(Server()->Tick() % int(Server()->TickSpeed() * 0.15f) == 0)
 	{
 		int Flags;
 		m_EvalTick = Server()->Tick();
 		int index = GameServer()->Collision()->IsMover(m_Pos.x, m_Pos.y,
-				&Flags);
-		if (index)
+			&Flags);
+		if(index)
 		{
 			m_Core = GameServer()->Collision()->CpSpeed(index, Flags);
 		}
@@ -159,20 +154,18 @@ void CDragger::Tick()
 	}
 	Drag();
 	return;
-
 }
 
 void CDragger::Snap(int SnappingClient)
 {
-	if (((CGameControllerDDRace*) GameServer()->m_pController)->m_Teams.GetTeamState(
-			m_CaughtTeam) == CGameTeams::TEAMSTATE_EMPTY)
+	if(((CGameControllerDDRace *)GameServer()->m_pController)->m_Teams.GetTeamState(m_CaughtTeam) == CGameTeams::TEAMSTATE_EMPTY)
 		return;
 
 	CCharacter *Target = m_Target;
 
-	for (int i = 0; i < MAX_CLIENTS; i++)
+	for(int i = 0; i < MAX_CLIENTS; i++)
 	{
-		if (m_SoloIDs[i] == -1)
+		if(m_SoloIDs[i] == -1)
 			break;
 
 		Server()->SnapFreeID(m_SoloIDs[i]);
@@ -181,76 +174,69 @@ void CDragger::Snap(int SnappingClient)
 
 	int pos = 0;
 
-	for (int i = -1; i < MAX_CLIENTS; i++)
+	for(int i = -1; i < MAX_CLIENTS; i++)
 	{
-		if (i >= 0)
+		if(i >= 0)
 		{
 			Target = m_SoloEnts[i];
 
-			if (!Target)
+			if(!Target)
 				continue;
 		}
 
-		if (Target)
+		if(Target)
 		{
-			if (NetworkClipped(SnappingClient, m_Pos)
-					&& NetworkClipped(SnappingClient, Target->m_Pos))
+			if(NetworkClipped(SnappingClient, m_Pos) && NetworkClipped(SnappingClient, Target->m_Pos))
 				continue;
 		}
-		else if (NetworkClipped(SnappingClient, m_Pos))
+		else if(NetworkClipped(SnappingClient, m_Pos))
 			continue;
 
-		CCharacter * Char = GameServer()->GetPlayerChar(SnappingClient);
+		CCharacter *Char = GameServer()->GetPlayerChar(SnappingClient);
 
-		if(SnappingClient > -1 && (GameServer()->m_apPlayers[SnappingClient]->GetTeam() == -1
-					|| GameServer()->m_apPlayers[SnappingClient]->IsPaused())
-				&& GameServer()->m_apPlayers[SnappingClient]->m_SpectatorID != SPEC_FREEVIEW)
+		if(SnappingClient > -1 && (GameServer()->m_apPlayers[SnappingClient]->GetTeam() == -1 || GameServer()->m_apPlayers[SnappingClient]->IsPaused()) && GameServer()->m_apPlayers[SnappingClient]->m_SpectatorID != SPEC_FREEVIEW)
 			Char = GameServer()->GetPlayerChar(GameServer()->m_apPlayers[SnappingClient]->m_SpectatorID);
 
 		int Tick = (Server()->Tick() % Server()->TickSpeed()) % 11;
-		if (Char && Char->IsAlive()
-				&& (m_Layer == LAYER_SWITCH && m_Number
-						&& !GameServer()->Collision()->m_pSwitchers[m_Number].m_Status[Char->Team()]
-						&& (!Tick)))
+		if(Char && Char->IsAlive() && (m_Layer == LAYER_SWITCH && m_Number && !GameServer()->Collision()->m_pSwitchers[m_Number].m_Status[Char->Team()] && (!Tick)))
 			continue;
-		if (Char && Char->IsAlive())
+		if(Char && Char->IsAlive())
 		{
-			if (Char->Team() != m_CaughtTeam)
+			if(Char->Team() != m_CaughtTeam)
 				continue;
 		}
 		else
 		{
 			// send to spectators only active draggers and some inactive from team 0
-			if (!((Target && Target->IsAlive()) || m_CaughtTeam == 0))
+			if(!((Target && Target->IsAlive()) || m_CaughtTeam == 0))
 				continue;
 		}
 
-		if (Char && Char->IsAlive() && Target && Target->IsAlive() && Target->GetPlayer()->GetCID() != Char->GetPlayer()->GetCID() && !Char->GetPlayer()->m_ShowOthers &&
-			(Char->Teams()->m_Core.GetSolo(SnappingClient) || Char->Teams()->m_Core.GetSolo(Target->GetPlayer()->GetCID())))
+		if(Char && Char->IsAlive() && Target && Target->IsAlive() && Target->GetPlayer()->GetCID() != Char->GetPlayer()->GetCID() && (Char->GetPlayer()->m_ShowOthers == 0 || (Char->GetPlayer()->m_ShowOthers == 2 && (Char->Teams()->m_Core.GetSolo(SnappingClient) || Char->Teams()->m_Core.GetSolo(Target->GetPlayer()->GetCID())))))
 		{
 			continue;
 		}
 
 		CNetObj_Laser *obj;
 
-		if (i == -1)
+		if(i == -1)
 		{
 			obj = static_cast<CNetObj_Laser *>(Server()->SnapNewItem(
-					NETOBJTYPE_LASER, m_ID, sizeof(CNetObj_Laser)));
+				NETOBJTYPE_LASER, m_ID, sizeof(CNetObj_Laser)));
 		}
 		else
 		{
 			m_SoloIDs[pos] = Server()->SnapNewID();
 			obj = static_cast<CNetObj_Laser *>(Server()->SnapNewItem( // TODO: Have to free IDs again?
-					NETOBJTYPE_LASER, m_SoloIDs[pos], sizeof(CNetObj_Laser)));
+				NETOBJTYPE_LASER, m_SoloIDs[pos], sizeof(CNetObj_Laser)));
 			pos++;
 		}
 
-		if (!obj)
+		if(!obj)
 			continue;
 		obj->m_X = (int)m_Pos.x;
 		obj->m_Y = (int)m_Pos.y;
-		if (Target)
+		if(Target)
 		{
 			obj->m_FromX = (int)Target->m_Pos.x;
 			obj->m_FromY = (int)Target->m_Pos.y;
@@ -262,18 +248,18 @@ void CDragger::Snap(int SnappingClient)
 		}
 
 		int StartTick = m_EvalTick;
-		if (StartTick < Server()->Tick() - 4)
+		if(StartTick < Server()->Tick() - 4)
 			StartTick = Server()->Tick() - 4;
-		else if (StartTick > Server()->Tick())
+		else if(StartTick > Server()->Tick())
 			StartTick = Server()->Tick();
 		obj->m_StartTick = StartTick;
 	}
 }
 
 CDraggerTeam::CDraggerTeam(CGameWorld *pGameWorld, vec2 Pos, float Strength,
-		bool NW, int Layer, int Number)
+	bool NW, int Layer, int Number)
 {
-	for (int i = 0; i < MAX_CLIENTS; ++i)
+	for(int i = 0; i < MAX_CLIENTS; ++i)
 	{
 		m_Draggers[i] = new CDragger(pGameWorld, Pos, Strength, NW, i, Layer, Number);
 	}
