@@ -1,17 +1,17 @@
 /* (c) Shereef Marzouk. See "licence DDRace.txt" and the readme.txt in the root of the distribution for more information. */
-#include <engine/server.h>
+#include "plasma.h"
 #include <engine/config.h>
+#include <engine/server.h>
 #include <game/generated/protocol.h>
 #include <game/server/gamecontext.h>
-#include <game/server/teams.h>
 #include <game/server/gamemodes/DDRace.h>
-#include "plasma.h"
+#include <game/server/teams.h>
 
-const float ACCEL = 1.1f;
+const float PLASMA_ACCEL = 1.1f;
 
 CPlasma::CPlasma(CGameWorld *pGameWorld, vec2 Pos, vec2 Dir, bool Freeze,
-		bool Explosive, int ResponsibleTeam) :
-		CEntity(pGameWorld, CGameWorld::ENTTYPE_LASER)
+	bool Explosive, int ResponsibleTeam) :
+	CEntity(pGameWorld, CGameWorld::ENTTYPE_LASER)
 {
 	m_Pos = Pos;
 	m_Core = Dir;
@@ -27,16 +27,16 @@ bool CPlasma::HitCharacter()
 {
 	vec2 To2;
 	CCharacter *Hit = GameServer()->m_World.IntersectCharacter(m_Pos,
-			m_Pos + m_Core, 0.0f, To2);
-	if (!Hit)
+		m_Pos + m_Core, 0.0f, To2);
+	if(!Hit)
 		return false;
 
-	if (Hit->Team() != m_ResponsibleTeam)
+	if(Hit->Team() != m_ResponsibleTeam)
 		return false;
 	m_Freeze ? Hit->Freeze() : Hit->UnFreeze();
-	if (m_Explosive)
+	if(m_Explosive)
 		GameServer()->CreateExplosion(m_Pos, -1, WEAPON_GRENADE, true,
-				m_ResponsibleTeam, Hit->Teams()->TeamMask(m_ResponsibleTeam));
+			m_ResponsibleTeam, Hit->Teams()->TeamMask(m_ResponsibleTeam));
 	GameServer()->m_World.DestroyEntity(this);
 	return true;
 }
@@ -44,7 +44,7 @@ bool CPlasma::HitCharacter()
 void CPlasma::Move()
 {
 	m_Pos += m_Core;
-	m_Core *= ACCEL;
+	m_Core *= PLASMA_ACCEL;
 }
 
 void CPlasma::Reset()
@@ -54,7 +54,7 @@ void CPlasma::Reset()
 
 void CPlasma::Tick()
 {
-	if (m_LifeTime == 0)
+	if(m_LifeTime == 0)
 	{
 		Reset();
 		return;
@@ -65,56 +65,43 @@ void CPlasma::Tick()
 
 	int Res = 0;
 	Res = GameServer()->Collision()->IntersectNoLaser(m_Pos, m_Pos + m_Core, 0,
-			0);
-	if (Res)
+		0);
+	if(Res)
 	{
-		if (m_Explosive)
+		if(m_Explosive)
 			GameServer()->CreateExplosion(
-					m_Pos,
-					-1,
-					WEAPON_GRENADE,
-					true,
-					m_ResponsibleTeam,
-					((CGameControllerDDRace*) GameServer()->m_pController)->m_Teams.TeamMask(
-							m_ResponsibleTeam));
+				m_Pos,
+				-1,
+				WEAPON_GRENADE,
+				true,
+				m_ResponsibleTeam,
+				((CGameControllerDDRace *)GameServer()->m_pController)->m_Teams.TeamMask(m_ResponsibleTeam));
 		Reset();
 	}
-
 }
 
 void CPlasma::Snap(int SnappingClient)
 {
-	if (NetworkClipped(SnappingClient))
+	if(NetworkClipped(SnappingClient))
 		return;
-	CCharacter* SnapChar = GameServer()->GetPlayerChar(SnappingClient);
-	CPlayer* SnapPlayer = SnappingClient > -1 ? GameServer()->m_apPlayers[SnappingClient] : 0;
+	CCharacter *SnapChar = GameServer()->GetPlayerChar(SnappingClient);
+	CPlayer *SnapPlayer = SnappingClient > -1 ? GameServer()->m_apPlayers[SnappingClient] : 0;
 	int Tick = (Server()->Tick() % Server()->TickSpeed()) % 11;
 
-	if (SnapChar && SnapChar->IsAlive()
-			&& (m_Layer == LAYER_SWITCH
-					&& !GameServer()->Collision()->m_pSwitchers[m_Number].m_Status[SnapChar->Team()])
-			&& (!Tick))
+	if(SnapChar && SnapChar->IsAlive() && (m_Layer == LAYER_SWITCH && !GameServer()->Collision()->m_pSwitchers[m_Number].m_Status[SnapChar->Team()]) && (!Tick))
 		return;
 
-	if(SnapPlayer && (SnapPlayer->GetTeam() == TEAM_SPECTATORS || SnapPlayer->IsPaused()) && SnapPlayer->m_SpectatorID != -1
-		&& GameServer()->GetPlayerChar(SnapPlayer->m_SpectatorID)
-		&& GameServer()->GetPlayerChar(SnapPlayer->m_SpectatorID)->Team() != m_ResponsibleTeam
-		&& !SnapPlayer->m_ShowOthers)
+	if(SnapPlayer && (SnapPlayer->GetTeam() == TEAM_SPECTATORS || SnapPlayer->IsPaused()) && SnapPlayer->m_SpectatorID != -1 && GameServer()->GetPlayerChar(SnapPlayer->m_SpectatorID) && GameServer()->GetPlayerChar(SnapPlayer->m_SpectatorID)->Team() != m_ResponsibleTeam && SnapPlayer->m_ShowOthers != 1)
 		return;
 
-	if(SnapPlayer && SnapPlayer->GetTeam() != TEAM_SPECTATORS && !SnapPlayer->IsPaused() && SnapChar
-		&& SnapChar && SnapChar->Team() != m_ResponsibleTeam
-		&& !SnapPlayer->m_ShowOthers)
+	if(SnapPlayer && SnapPlayer->GetTeam() != TEAM_SPECTATORS && !SnapPlayer->IsPaused() && SnapChar && SnapChar && SnapChar->Team() != m_ResponsibleTeam && SnapPlayer->m_ShowOthers != 1)
 		return;
 
-	if(SnapPlayer && (SnapPlayer->GetTeam() == TEAM_SPECTATORS || SnapPlayer->IsPaused()) && SnapPlayer->m_SpectatorID == -1
-		&& SnapChar
-		&& SnapChar->Team() != m_ResponsibleTeam
-		&& SnapPlayer->m_SpecTeam)
+	if(SnapPlayer && (SnapPlayer->GetTeam() == TEAM_SPECTATORS || SnapPlayer->IsPaused()) && SnapPlayer->m_SpectatorID == -1 && SnapChar && SnapChar->Team() != m_ResponsibleTeam && SnapPlayer->m_SpecTeam)
 		return;
 
 	CNetObj_Laser *pObj = static_cast<CNetObj_Laser *>(Server()->SnapNewItem(
-			NETOBJTYPE_LASER, m_ID, sizeof(CNetObj_Laser)));
+		NETOBJTYPE_LASER, m_ID, sizeof(CNetObj_Laser)));
 
 	if(!pObj)
 		return;
