@@ -1,29 +1,27 @@
 /* (c) Magnus Auvinen. See licence.txt in the root of the distribution for more information. */
 /* If you are missing that file, acquire a complete release at teeworlds.com.                */
+#include "projectile.h"
 #include <game/generated/protocol.h>
 #include <game/server/gamecontext.h>
 #include <game/server/gamemodes/DDRace.h>
-#include "projectile.h"
 
 #include <engine/shared/config.h>
 #include <game/server/teams.h>
 
-CProjectile::CProjectile
-	(
-		CGameWorld *pGameWorld,
-		int Type,
-		int Owner,
-		vec2 Pos,
-		vec2 Dir,
-		int Span,
-		bool Freeze,
-		bool Explosive,
-		float Force,
-		int SoundImpact,
-		int Layer,
-		int Number
-	)
-: CEntity(pGameWorld, CGameWorld::ENTTYPE_PROJECTILE)
+CProjectile::CProjectile(
+	CGameWorld *pGameWorld,
+	int Type,
+	int Owner,
+	vec2 Pos,
+	vec2 Dir,
+	int Span,
+	bool Freeze,
+	bool Explosive,
+	float Force,
+	int SoundImpact,
+	int Layer,
+	int Number) :
+	CEntity(pGameWorld, CGameWorld::ENTTYPE_PROJECTILE)
 {
 	m_Type = Type;
 	m_Pos = Pos;
@@ -58,46 +56,46 @@ vec2 CProjectile::GetPos(float Time)
 
 	switch(m_Type)
 	{
-		case WEAPON_GRENADE:
-			if (!m_TuneZone)
-			{
-				Curvature = GameServer()->Tuning()->m_GrenadeCurvature;
-				Speed = GameServer()->Tuning()->m_GrenadeSpeed;
-			}
-			else
-			{
-				Curvature = GameServer()->TuningList()[m_TuneZone].m_GrenadeCurvature;
-				Speed = GameServer()->TuningList()[m_TuneZone].m_GrenadeSpeed;
-			}
+	case WEAPON_GRENADE:
+		if(!m_TuneZone)
+		{
+			Curvature = GameServer()->Tuning()->m_GrenadeCurvature;
+			Speed = GameServer()->Tuning()->m_GrenadeSpeed;
+		}
+		else
+		{
+			Curvature = GameServer()->TuningList()[m_TuneZone].m_GrenadeCurvature;
+			Speed = GameServer()->TuningList()[m_TuneZone].m_GrenadeSpeed;
+		}
 
-			break;
+		break;
 
-		case WEAPON_SHOTGUN:
-			if (!m_TuneZone)
-			{
-				Curvature = GameServer()->Tuning()->m_ShotgunCurvature;
-				Speed = GameServer()->Tuning()->m_ShotgunSpeed;
-			}
-			else
-			{
-				Curvature = GameServer()->TuningList()[m_TuneZone].m_ShotgunCurvature;
-				Speed = GameServer()->TuningList()[m_TuneZone].m_ShotgunSpeed;
-			}
+	case WEAPON_SHOTGUN:
+		if(!m_TuneZone)
+		{
+			Curvature = GameServer()->Tuning()->m_ShotgunCurvature;
+			Speed = GameServer()->Tuning()->m_ShotgunSpeed;
+		}
+		else
+		{
+			Curvature = GameServer()->TuningList()[m_TuneZone].m_ShotgunCurvature;
+			Speed = GameServer()->TuningList()[m_TuneZone].m_ShotgunSpeed;
+		}
 
-			break;
+		break;
 
-		case WEAPON_GUN:
-			if (!m_TuneZone)
-			{
-				Curvature = GameServer()->Tuning()->m_GunCurvature;
-				Speed = GameServer()->Tuning()->m_GunSpeed;
-			}
-			else
-			{
-				Curvature = GameServer()->TuningList()[m_TuneZone].m_GunCurvature;
-				Speed = GameServer()->TuningList()[m_TuneZone].m_GunSpeed;
-			}
-			break;
+	case WEAPON_GUN:
+		if(!m_TuneZone)
+		{
+			Curvature = GameServer()->Tuning()->m_GunCurvature;
+			Speed = GameServer()->Tuning()->m_GunSpeed;
+		}
+		else
+		{
+			Curvature = GameServer()->TuningList()[m_TuneZone].m_GunCurvature;
+			Speed = GameServer()->TuningList()[m_TuneZone].m_GunSpeed;
+		}
+		break;
 	}
 
 	return CalcPos(m_Pos, m_Direction, Curvature, Speed, Time);
@@ -105,8 +103,8 @@ vec2 CProjectile::GetPos(float Time)
 
 void CProjectile::Tick()
 {
-	float Pt = (Server()->Tick()-m_StartTick-1)/(float)Server()->TickSpeed();
-	float Ct = (Server()->Tick()-m_StartTick)/(float)Server()->TickSpeed();
+	float Pt = (Server()->Tick() - m_StartTick - 1) / (float)Server()->TickSpeed();
+	float Ct = (Server()->Tick() - m_StartTick) / (float)Server()->TickSpeed();
 	vec2 PrevPos = GetPos(Pt);
 	vec2 CurPos = GetPos(Ct);
 	vec2 ColPos;
@@ -119,38 +117,36 @@ void CProjectile::Tick()
 
 	CCharacter *pTargetChr = 0;
 
-	if(pOwnerChar ? !(pOwnerChar->m_Hit&CCharacter::DISABLE_HIT_GRENADE) : g_Config.m_SvHit)
+	if(pOwnerChar ? !(pOwnerChar->m_Hit & CCharacter::DISABLE_HIT_GRENADE) : g_Config.m_SvHit)
 		pTargetChr = GameServer()->m_World.IntersectCharacter(PrevPos, ColPos, m_Freeze ? 1.0f : 6.0f, ColPos, pOwnerChar, m_Owner);
 
 	if(m_LifeSpan > -1)
 		m_LifeSpan--;
 
-	int64_t TeamMask = -1LL;
+	int64 TeamMask = -1LL;
 	bool IsWeaponCollide = false;
-	if
-	(
-			pOwnerChar &&
-			pTargetChr &&
-			pOwnerChar->IsAlive() &&
-			pTargetChr->IsAlive() &&
-			!pTargetChr->CanCollide(m_Owner)
-			)
+	if(
+		pOwnerChar &&
+		pTargetChr &&
+		pOwnerChar->IsAlive() &&
+		pTargetChr->IsAlive() &&
+		!pTargetChr->CanCollide(m_Owner))
 	{
-			IsWeaponCollide = true;
+		IsWeaponCollide = true;
 	}
-	if (pOwnerChar && pOwnerChar->IsAlive())
+	if(pOwnerChar && pOwnerChar->IsAlive())
 	{
 		TeamMask = pOwnerChar->Teams()->TeamMask(pOwnerChar->Team(), -1, m_Owner);
 	}
-	else if (m_Owner >= 0 && (m_Type != WEAPON_GRENADE || g_Config.m_SvDestroyBulletsOnDeath))
+	else if(m_Owner >= 0 && (m_Type != WEAPON_GRENADE || g_Config.m_SvDestroyBulletsOnDeath))
 	{
 		GameServer()->m_World.DestroyEntity(this);
 		return;
 	}
 
-	if( ((pTargetChr && (pOwnerChar ? !(pOwnerChar->m_Hit&CCharacter::DISABLE_HIT_GRENADE) : g_Config.m_SvHit || m_Owner == -1 || pTargetChr == pOwnerChar)) || Collide || GameLayerClipped(CurPos)) && !IsWeaponCollide)
+	if(((pTargetChr && (pOwnerChar ? !(pOwnerChar->m_Hit & CCharacter::DISABLE_HIT_GRENADE) : g_Config.m_SvHit || m_Owner == -1 || pTargetChr == pOwnerChar)) || Collide || GameLayerClipped(CurPos)) && !IsWeaponCollide)
 	{
-		if(m_Explosive/*??*/ && (!pTargetChr || (pTargetChr && (!m_Freeze || (m_Type == WEAPON_SHOTGUN && Collide)))))
+		if(m_Explosive /*??*/ && (!pTargetChr || (pTargetChr && (!m_Freeze || (m_Type == WEAPON_SHOTGUN && Collide)))))
 		{
 			int Number = 1;
 			if(GameServer()->EmulateBug(BUG_GRENADE_DOUBLEEXPLOSION) && m_LifeSpan == -1)
@@ -160,21 +156,21 @@ void CProjectile::Tick()
 			for(int i = 0; i < Number; i++)
 			{
 				GameServer()->CreateExplosion(ColPos, m_Owner, m_Type, m_Owner == -1, (!pTargetChr ? -1 : pTargetChr->Team()),
-				(m_Owner != -1)? TeamMask : -1LL);
+					(m_Owner != -1) ? TeamMask : -1LL);
 				GameServer()->CreateSound(ColPos, m_SoundImpact,
-				(m_Owner != -1)? TeamMask : -1LL);
+					(m_Owner != -1) ? TeamMask : -1LL);
 			}
 		}
 		else if(m_Freeze)
 		{
 			CCharacter *apEnts[MAX_CLIENTS];
-			int Num = GameWorld()->FindEntities(CurPos, 1.0f, (CEntity**)apEnts, MAX_CLIENTS, CGameWorld::ENTTYPE_CHARACTER);
+			int Num = GameWorld()->FindEntities(CurPos, 1.0f, (CEntity **)apEnts, MAX_CLIENTS, CGameWorld::ENTTYPE_CHARACTER);
 			for(int i = 0; i < Num; ++i)
 				if(apEnts[i] && (m_Layer != LAYER_SWITCH || (m_Layer == LAYER_SWITCH && GameServer()->Collision()->m_pSwitchers[m_Number].m_Status[apEnts[i]->Team()])))
 					apEnts[i]->Freeze();
 		}
 
-		if (pOwnerChar && ColPos && !GameLayerClipped(ColPos) &&
+		if(pOwnerChar && ColPos && !GameLayerClipped(ColPos) &&
 			((m_Type == WEAPON_GRENADE && pOwnerChar->HasTelegunGrenade()) || (m_Type == WEAPON_GUN && pOwnerChar->HasTelegunGun())))
 		{
 			int MapIndex = GameServer()->Collision()->GetPureMapIndex(pTargetChr ? pTargetChr->m_Pos : ColPos);
@@ -182,7 +178,8 @@ void CProjectile::Tick()
 			bool IsSwitchTeleGun = GameServer()->Collision()->IsSwitch(MapIndex) == TILE_ALLOW_TELE_GUN;
 			bool IsBlueSwitchTeleGun = GameServer()->Collision()->IsSwitch(MapIndex) == TILE_ALLOW_BLUE_TELE_GUN;
 
-			if(IsSwitchTeleGun || IsBlueSwitchTeleGun) {
+			if(IsSwitchTeleGun || IsBlueSwitchTeleGun)
+			{
 				// Delay specifies which weapon the tile should work for.
 				// Delay = 0 means all.
 				int delay = GameServer()->Collision()->GetSwitchDelay(MapIndex);
@@ -195,21 +192,17 @@ void CProjectile::Tick()
 					IsSwitchTeleGun = IsBlueSwitchTeleGun = false;
 			}
 
-			if (TileFIndex == TILE_ALLOW_TELE_GUN
-				|| TileFIndex == TILE_ALLOW_BLUE_TELE_GUN
-				|| IsSwitchTeleGun
-				|| IsBlueSwitchTeleGun
-				|| pTargetChr)
+			if(TileFIndex == TILE_ALLOW_TELE_GUN || TileFIndex == TILE_ALLOW_BLUE_TELE_GUN || IsSwitchTeleGun || IsBlueSwitchTeleGun || pTargetChr)
 			{
 				bool Found;
 				vec2 PossiblePos;
 
-				if (!Collide)
+				if(!Collide)
 					Found = GetNearestAirPosPlayer(pTargetChr->m_Pos, &PossiblePos);
 				else
 					Found = GetNearestAirPos(NewPos, CurPos, &PossiblePos);
 
-				if (Found && PossiblePos)
+				if(Found && PossiblePos)
 				{
 					pOwnerChar->m_TeleGunPos = PossiblePos;
 					pOwnerChar->m_TeleGunTeleport = true;
@@ -221,26 +214,26 @@ void CProjectile::Tick()
 		if(Collide && m_Bouncing != 0)
 		{
 			m_StartTick = Server()->Tick();
-			m_Pos = NewPos+(-(m_Direction*4));
-			if (m_Bouncing == 1)
+			m_Pos = NewPos + (-(m_Direction * 4));
+			if(m_Bouncing == 1)
 				m_Direction.x = -m_Direction.x;
 			else if(m_Bouncing == 2)
 				m_Direction.y = -m_Direction.y;
-			if (fabs(m_Direction.x) < 1e-6)
+			if(fabs(m_Direction.x) < 1e-6)
 				m_Direction.x = 0;
-			if (fabs(m_Direction.y) < 1e-6)
+			if(fabs(m_Direction.y) < 1e-6)
 				m_Direction.y = 0;
 			m_Pos += m_Direction;
 		}
-		else if (m_Type == WEAPON_GUN)
+		else if(m_Type == WEAPON_GUN)
 		{
-			GameServer()->CreateDamageInd(CurPos, -atan2(m_Direction.x, m_Direction.y), 10, (m_Owner != -1)? TeamMask : -1LL);
+			GameServer()->CreateDamageInd(CurPos, -atan2(m_Direction.x, m_Direction.y), 10, (m_Owner != -1) ? TeamMask : -1LL);
 			GameServer()->m_World.DestroyEntity(this);
 			return;
 		}
 		else
 		{
-			if (!m_Freeze)
+			if(!m_Freeze)
 			{
 				GameServer()->m_World.DestroyEntity(this);
 				return;
@@ -254,16 +247,16 @@ void CProjectile::Tick()
 			if(m_Owner >= 0)
 				pOwnerChar = GameServer()->GetPlayerChar(m_Owner);
 
-			int64_t TeamMask = -1LL;
-			if (pOwnerChar && pOwnerChar->IsAlive())
+			int64 TeamMask = -1LL;
+			if(pOwnerChar && pOwnerChar->IsAlive())
 			{
-					TeamMask = pOwnerChar->Teams()->TeamMask(pOwnerChar->Team(), -1, m_Owner);
+				TeamMask = pOwnerChar->Teams()->TeamMask(pOwnerChar->Team(), -1, m_Owner);
 			}
 
 			GameServer()->CreateExplosion(ColPos, m_Owner, m_Type, m_Owner == -1, (!pOwnerChar ? -1 : pOwnerChar->Team()),
-			(m_Owner != -1)? TeamMask : -1LL);
+				(m_Owner != -1) ? TeamMask : -1LL);
 			GameServer()->CreateSound(ColPos, m_SoundImpact,
-			(m_Owner != -1)? TeamMask : -1LL);
+				(m_Owner != -1) ? TeamMask : -1LL);
 		}
 		GameServer()->m_World.DestroyEntity(this);
 		return;
@@ -271,15 +264,15 @@ void CProjectile::Tick()
 
 	int x = GameServer()->Collision()->GetIndex(PrevPos, CurPos);
 	int z;
-	if (g_Config.m_SvOldTeleportWeapons)
+	if(g_Config.m_SvOldTeleportWeapons)
 		z = GameServer()->Collision()->IsTeleport(x);
 	else
 		z = GameServer()->Collision()->IsTeleportWeapon(x);
 	CGameControllerDDRace *pControllerDDRace = (CGameControllerDDRace *)GameServer()->m_pController;
-	if (z && pControllerDDRace->m_TeleOuts[z-1].size())
+	if(z && pControllerDDRace->m_TeleOuts[z - 1].size())
 	{
-		int TeleOut = GameServer()->m_World.m_Core.RandomOr0(pControllerDDRace->m_TeleOuts[z-1].size());
-		m_Pos = pControllerDDRace->m_TeleOuts[z-1][TeleOut];
+		int TeleOut = GameServer()->m_World.m_Core.RandomOr0(pControllerDDRace->m_TeleOuts[z - 1].size());
+		m_Pos = pControllerDDRace->m_TeleOuts[z - 1][TeleOut];
 		m_StartTick = Server()->Tick();
 	}
 }
@@ -293,32 +286,32 @@ void CProjectile::FillInfo(CNetObj_Projectile *pProj)
 {
 	pProj->m_X = (int)m_Pos.x;
 	pProj->m_Y = (int)m_Pos.y;
-	pProj->m_VelX = (int)(m_Direction.x*100.0f);
-	pProj->m_VelY = (int)(m_Direction.y*100.0f);
+	pProj->m_VelX = (int)(m_Direction.x * 100.0f);
+	pProj->m_VelY = (int)(m_Direction.y * 100.0f);
 	pProj->m_StartTick = m_StartTick;
 	pProj->m_Type = m_Type;
 }
 
 void CProjectile::Snap(int SnappingClient)
 {
-	float Ct = (Server()->Tick()-m_StartTick)/(float)Server()->TickSpeed();
+	float Ct = (Server()->Tick() - m_StartTick) / (float)Server()->TickSpeed();
 
 	if(NetworkClipped(SnappingClient, GetPos(Ct)))
 		return;
 
-	CCharacter* pSnapChar = GameServer()->GetPlayerChar(SnappingClient);
-	int Tick = (Server()->Tick()%Server()->TickSpeed())%((m_Explosive)?6:20);
-	if (pSnapChar && pSnapChar->IsAlive() && (m_Layer == LAYER_SWITCH && !GameServer()->Collision()->m_pSwitchers[m_Number].m_Status[pSnapChar->Team()] && (!Tick)))
+	CCharacter *pSnapChar = GameServer()->GetPlayerChar(SnappingClient);
+	int Tick = (Server()->Tick() % Server()->TickSpeed()) % ((m_Explosive) ? 6 : 20);
+	if(pSnapChar && pSnapChar->IsAlive() && (m_Layer == LAYER_SWITCH && !GameServer()->Collision()->m_pSwitchers[m_Number].m_Status[pSnapChar->Team()] && (!Tick)))
 		return;
 
 	CCharacter *pOwnerChar = 0;
-	int64_t TeamMask = -1LL;
+	int64 TeamMask = -1LL;
 
 	if(m_Owner >= 0)
 		pOwnerChar = GameServer()->GetPlayerChar(m_Owner);
 
-	if (pOwnerChar && pOwnerChar->IsAlive())
-			TeamMask = pOwnerChar->Teams()->TeamMask(pOwnerChar->Team(), -1, m_Owner);
+	if(pOwnerChar && pOwnerChar->IsAlive())
+		TeamMask = pOwnerChar->Teams()->TeamMask(pOwnerChar->Team(), -1, m_Owner);
 
 	if(m_Owner != -1 && !CmaskIsSet(TeamMask, SnappingClient))
 		return;
@@ -342,8 +335,8 @@ void CProjectile::SetBouncing(int Value)
 
 void CProjectile::FillExtraInfo(CNetObj_Projectile *pProj)
 {
-	const int MaxPos = 0x7fffffff/100;
-	if(abs((int)m_Pos.y)+1 >= MaxPos || abs((int)m_Pos.x)+1 >= MaxPos)
+	const int MaxPos = 0x7fffffff / 100;
+	if(abs((int)m_Pos.y) + 1 >= MaxPos || abs((int)m_Pos.x) + 1 >= MaxPos)
 	{
 		//If the modified data would be too large to fit in an integer, send normal data instead
 		FillInfo(pProj);
@@ -353,15 +346,15 @@ void CProjectile::FillExtraInfo(CNetObj_Projectile *pProj)
 	float Angle = -atan2f(m_Direction.x, m_Direction.y);
 
 	int Data = 0;
-	Data |= (abs(m_Owner) & 255)<<0;
+	Data |= (abs(m_Owner) & 255) << 0;
 	if(m_Owner < 0)
-		Data |= 1<<8;
-	Data |= 1<<9; //This bit tells the client to use the extra info
-	Data |= (m_Bouncing & 3)<<10;
+		Data |= 1 << 8;
+	Data |= 1 << 9; //This bit tells the client to use the extra info
+	Data |= (m_Bouncing & 3) << 10;
 	if(m_Explosive)
-		Data |= 1<<12;
+		Data |= 1 << 12;
 	if(m_Freeze)
-		Data |= 1<<13;
+		Data |= 1 << 13;
 
 	pProj->m_X = (int)(m_Pos.x * 100.0f);
 	pProj->m_Y = (int)(m_Pos.y * 100.0f);
