@@ -12,7 +12,7 @@ CEntity::CEntity(CGameWorld *pGameWorld, int ObjType)
 	m_pGameWorld = pGameWorld;
 
 	m_ObjType = ObjType;
-	m_Pos = vec2(0,0);
+	m_Pos = vec2(0, 0);
 	m_ProximityRadius = 0;
 
 	m_MarkedForDestroy = false;
@@ -38,8 +38,8 @@ int CEntity::NetworkClipped(int SnappingClient, vec2 CheckPos)
 	if(SnappingClient == -1)
 		return 0;
 
-	float dx = GameServer()->m_apPlayers[SnappingClient]->m_ViewPos.x-CheckPos.x;
-	float dy = GameServer()->m_apPlayers[SnappingClient]->m_ViewPos.y-CheckPos.y;
+	float dx = GameServer()->m_apPlayers[SnappingClient]->m_ViewPos.x - CheckPos.x;
+	float dy = GameServer()->m_apPlayers[SnappingClient]->m_ViewPos.y - CheckPos.y;
 
 	if(absolute(dx) > 1000.0f || absolute(dy) > 800.0f)
 		return 1;
@@ -51,11 +51,13 @@ int CEntity::NetworkClipped(int SnappingClient, vec2 CheckPos)
 
 bool CEntity::GameLayerClipped(vec2 CheckPos)
 {
-	return round_to_int(CheckPos.x)/32 < -200 || round_to_int(CheckPos.x)/32 > GameServer()->Collision()->GetWidth()+200 ||
-			round_to_int(CheckPos.y)/32 < -200 || round_to_int(CheckPos.y)/32 > GameServer()->Collision()->GetHeight()+200 ? true : false;
+	return round_to_int(CheckPos.x) / 32 < -200 || round_to_int(CheckPos.x) / 32 > GameServer()->Collision()->GetWidth() + 200 ||
+			       round_to_int(CheckPos.y) / 32 < -200 || round_to_int(CheckPos.y) / 32 > GameServer()->Collision()->GetHeight() + 200 ?
+		       true :
+		       false;
 }
 
-bool CEntity::GetNearestAirPos(vec2 Pos, vec2 PrevPos, vec2* pOutPos)
+bool CEntity::GetNearestAirPos(vec2 Pos, vec2 PrevPos, vec2 *pOutPos)
 {
 	for(int k = 0; k < 16 && GameServer()->Collision()->CheckPoint(Pos); k++)
 	{
@@ -66,27 +68,27 @@ bool CEntity::GetNearestAirPos(vec2 Pos, vec2 PrevPos, vec2* pOutPos)
 	vec2 BlockCenter = vec2(round_to_int(Pos.x), round_to_int(Pos.y)) - PosInBlock + vec2(16.0f, 16.0f);
 
 	*pOutPos = vec2(BlockCenter.x + (PosInBlock.x < 16 ? -2.0f : 1.0f), Pos.y);
-	if (!GameServer()->Collision()->TestBox(*pOutPos, vec2(28.0f, 28.0f)))
+	if(!GameServer()->Collision()->TestBox(*pOutPos, vec2(28.0f, 28.0f)))
 		return true;
 
 	*pOutPos = vec2(Pos.x, BlockCenter.y + (PosInBlock.y < 16 ? -2.0f : 1.0f));
-	if (!GameServer()->Collision()->TestBox(*pOutPos, vec2(28.0f, 28.0f)))
+	if(!GameServer()->Collision()->TestBox(*pOutPos, vec2(28.0f, 28.0f)))
 		return true;
 
 	*pOutPos = vec2(BlockCenter.x + (PosInBlock.x < 16 ? -2.0f : 1.0f),
-                    BlockCenter.y + (PosInBlock.y < 16 ? -2.0f : 1.0f));
-	if (!GameServer()->Collision()->TestBox(*pOutPos, vec2(28.0f, 28.0f)))
+		BlockCenter.y + (PosInBlock.y < 16 ? -2.0f : 1.0f));
+	if(!GameServer()->Collision()->TestBox(*pOutPos, vec2(28.0f, 28.0f)))
 		return true;
 
 	return false;
 }
 
-bool CEntity::GetNearestAirPosPlayer(vec2 PlayerPos, vec2* OutPos)
+bool CEntity::GetNearestAirPosPlayer(vec2 PlayerPos, vec2 *OutPos)
 {
-	for (int dist = 5; dist >= -1; dist--)
+	for(int dist = 5; dist >= -1; dist--)
 	{
 		*OutPos = vec2(PlayerPos.x, PlayerPos.y - dist);
-		if (!GameServer()->Collision()->TestBox(*OutPos, vec2(28.0f, 28.0f)))
+		if(!GameServer()->Collision()->TestBox(*OutPos, vec2(28.0f, 28.0f)))
 		{
 			return true;
 		}
