@@ -4,26 +4,30 @@
 #define GAME_SERVER_GAMECONTEXT_H
 
 #include <engine/antibot.h>
-#include <engine/server.h>
 #include <engine/console.h>
+#include <engine/server.h>
 #include <engine/shared/memheap.h>
 
 #include <game/layers.h>
 #include <game/mapbugs.h>
 #include <game/voting.h>
 
+#include <base/tl/array.h>
+#include <base/tl/string.h>
+
 #include "eventhandler.h"
 #include "gamecontroller.h"
 #include "gameworld.h"
 #include "player.h"
 #include "teehistorian.h"
 
-#include "score.h"
+#include <memory>
+
 #ifdef _MSC_VER
 typedef __int32 int32_t;
 typedef unsigned __int32 uint32_t;
-typedef __int64 int64_t;
-typedef unsigned __int64 uint64_t;
+typedef __int64 int64;
+typedef unsigned __int64 uint64;
 #else
 #include <stdint.h>
 #endif
@@ -54,6 +58,7 @@ enum
 	NUM_TUNEZONES = 256
 };
 
+class CScore;
 class IConsole;
 class IEngine;
 class IStorage;
@@ -73,6 +78,7 @@ class CGameContext : public IGameServer
 	CNetObjHandler m_NetObjHandler;
 	CTuningParams m_Tuning;
 	CTuningParams m_aTuningList[NUM_TUNEZONES];
+	array<string> m_aCensorlist;
 
 	bool m_TeeHistorianActive;
 	CTeeHistorian m_TeeHistorian;
@@ -118,6 +124,7 @@ class CGameContext : public IGameServer
 	void Construct(int Resetting);
 
 	bool m_Resetting;
+
 public:
 	IServer *Server() const { return m_pServer; }
 	IConsole *Console() { return m_pConsole; }
@@ -146,17 +153,19 @@ public:
 	bool EmulateBug(int Bug);
 
 	// voting
-	void StartVote(const char *pDesc, const char *pCommand, const char *pReason);
+	void StartVote(const char *pDesc, const char *pCommand, const char *pReason, const char *pSixupDesc);
 	void EndVote();
 	void SendVoteSet(int ClientID);
 	void SendVoteStatus(int ClientID, int Total, int Yes, int No);
 	void AbortVoteKickOnDisconnect(int ClientID);
 
 	int m_VoteCreator;
+	int m_VoteType;
 	int64 m_VoteCloseTime;
 	bool m_VoteUpdate;
 	int m_VotePos;
 	char m_aVoteDescription[VOTE_DESC_LENGTH];
+	char m_aSixupVoteDescription[VOTE_DESC_LENGTH];
 	char m_aVoteCommand[VOTE_CMD_LENGTH];
 	char m_aVoteReason[VOTE_REASON_LENGTH];
 	int m_NumVoteOptions;
@@ -169,39 +178,39 @@ public:
 
 	enum
 	{
-		VOTE_ENFORCE_UNKNOWN=0,
+		VOTE_ENFORCE_UNKNOWN = 0,
 		VOTE_ENFORCE_NO,
 		VOTE_ENFORCE_YES,
+		VOTE_ENFORCE_ABORT,
 	};
 	CHeap *m_pVoteOptionHeap;
 	CVoteOptionServer *m_pVoteOptionFirst;
 	CVoteOptionServer *m_pVoteOptionLast;
 
 	// helper functions
-	void CreateDamageInd(vec2 Pos, float AngleMod, int Amount, int64_t Mask=-1);
-	void CreateExplosion(vec2 Pos, int Owner, int Weapon, bool NoDamage, int ActivatedTeam, int64_t Mask);
-	void CreateHammerHit(vec2 Pos, int64_t Mask=-1);
-	void CreatePlayerSpawn(vec2 Pos, int64_t Mask=-1);
-	void CreateDeath(vec2 Pos, int Who, int64_t Mask=-1);
-	void CreateSound(vec2 Pos, int Sound, int64_t Mask=-1);
-	void CreateSoundGlobal(int Sound, int Target=-1);
-
+	void CreateDamageInd(vec2 Pos, float AngleMod, int Amount, int64 Mask = -1);
+	void CreateExplosion(vec2 Pos, int Owner, int Weapon, bool NoDamage, int ActivatedTeam, int64 Mask);
+	void CreateHammerHit(vec2 Pos, int64 Mask = -1);
+	void CreatePlayerSpawn(vec2 Pos, int64 Mask = -1);
+	void CreateDeath(vec2 Pos, int Who, int64 Mask = -1);
+	void CreateSound(vec2 Pos, int Sound, int64 Mask = -1);
+	void CreateSoundGlobal(int Sound, int Target = -1);
 
 	enum
 	{
-		CHAT_ALL=-2,
-		CHAT_SPEC=-1,
-		CHAT_RED=0,
-		CHAT_BLUE=1,
-		CHAT_WHISPER_SEND=2,
-		CHAT_WHISPER_RECV=3,
+		CHAT_ALL = -2,
+		CHAT_SPEC = -1,
+		CHAT_RED = 0,
+		CHAT_BLUE = 1,
+		CHAT_WHISPER_SEND = 2,
+		CHAT_WHISPER_RECV = 3,
 
-		CHAT_SIX=1<<0,
-		CHAT_SIXUP=1<<1,
+		CHAT_SIX = 1 << 0,
+		CHAT_SIXUP = 1 << 1,
 	};
 
 	// network
-	void CallVote(int ClientID, const char *aDesc, const char *aCmd, const char *pReason, const char *aChatmsg);
+	void CallVote(int ClientID, const char *aDesc, const char *aCmd, const char *pReason, const char *aChatmsg, const char *pSixupDesc = 0);
 	void SendChatTarget(int To, const char *pText, int Flags = CHAT_SIX | CHAT_SIXUP);
 	void SendChatTeam(int Team, const char *pText);
 	void SendChat(int ClientID, int Team, const char *pText, int SpamProtectionClientID = -1, int Flags = CHAT_SIX | CHAT_SIXUP);
@@ -209,7 +218,7 @@ public:
 	void SendWeaponPickup(int ClientID, int Weapon);
 	void SendBroadcast(const char *pText, int ClientID, bool IsImportant = true);
 
-	void List(int ClientID, const char* filter);
+	void List(int ClientID, const char *filter);
 
 	//
 	void CheckPureTuning();
@@ -225,7 +234,7 @@ public:
 	virtual void OnInit();
 	virtual void OnConsoleInit();
 	virtual void OnMapChange(char *pNewMapName, int MapNameSize);
-	virtual void OnShutdown(bool FullShutdown = false);
+	virtual void OnShutdown();
 
 	virtual void OnTick();
 	virtual void OnPreSnap();
@@ -233,6 +242,7 @@ public:
 	virtual void OnPostSnap();
 
 	void *PreProcessMsg(int *MsgID, CUnpacker *pUnpacker, int ClientID);
+	void CensorMessage(char *pCensoredMessage, const char *pMessage, int Size);
 	virtual void OnMessage(int MsgID, CUnpacker *pUnpacker, int ClientID);
 
 	virtual void OnClientConnected(int ClientID);
@@ -274,9 +284,8 @@ public:
 	std::shared_ptr<CScoreRandomMapResult> m_SqlRandomMapResult;
 
 private:
-
 	bool m_VoteWillPass;
-	class IScore *m_pScore;
+	class CScore *m_pScore;
 
 	//DDRace Console Commands
 
@@ -382,8 +391,8 @@ private:
 
 	enum
 	{
-		MAX_MUTES=32,
-		MAX_VOTE_MUTES=32,
+		MAX_MUTES = 32,
+		MAX_VOTE_MUTES = 32,
 	};
 	struct CMute
 	{
@@ -409,20 +418,29 @@ private:
 
 public:
 	CLayers *Layers() { return &m_Layers; }
-	class IScore *Score() { return m_pScore; }
-	bool m_VoteKick;
-	bool m_VoteSpec;
-	int m_VoteVictim;
+	class CScore *Score() { return m_pScore; }
+
 	enum
 	{
 		VOTE_ENFORCE_NO_ADMIN = VOTE_ENFORCE_YES + 1,
-		VOTE_ENFORCE_YES_ADMIN
+		VOTE_ENFORCE_YES_ADMIN,
+
+		VOTE_TYPE_UNKNOWN = 0,
+		VOTE_TYPE_OPTION,
+		VOTE_TYPE_KICK,
+		VOTE_TYPE_SPECTATE,
 	};
+	int m_VoteVictim;
 	int m_VoteEnforcer;
+
+	inline bool IsOptionVote() const { return m_VoteType == VOTE_TYPE_OPTION; };
+	inline bool IsKickVote() const { return m_VoteType == VOTE_TYPE_KICK; };
+	inline bool IsSpecVote() const { return m_VoteType == VOTE_TYPE_SPECTATE; };
+
 	void SendRecord(int ClientID);
 	static void SendChatResponse(const char *pLine, void *pUser, bool Highlighted = false);
 	static void SendChatResponseAll(const char *pLine, void *pUser);
-	virtual void OnSetAuthed(int ClientID,int Level);
+	virtual void OnSetAuthed(int ClientID, int Level);
 	virtual bool PlayerCollision();
 	virtual bool PlayerHooking();
 	virtual float PlayerJetpack();
@@ -433,9 +451,9 @@ public:
 	int m_ChatPrintCBIndex;
 };
 
-inline int64_t CmaskAll() { return -1LL; }
-inline int64_t CmaskOne(int ClientID) { return 1LL<<ClientID; }
-inline int64_t CmaskUnset(int64_t Mask, int ClientID) { return Mask^CmaskOne(ClientID); }
-inline int64_t CmaskAllExceptOne(int ClientID) { return CmaskUnset(CmaskAll(), ClientID); }
-inline bool CmaskIsSet(int64_t Mask, int ClientID) { return (Mask&CmaskOne(ClientID)) != 0; }
+inline int64 CmaskAll() { return -1LL; }
+inline int64 CmaskOne(int ClientID) { return 1LL << ClientID; }
+inline int64 CmaskUnset(int64 Mask, int ClientID) { return Mask ^ CmaskOne(ClientID); }
+inline int64 CmaskAllExceptOne(int ClientID) { return CmaskUnset(CmaskAll(), ClientID); }
+inline bool CmaskIsSet(int64 Mask, int ClientID) { return (Mask & CmaskOne(ClientID)) != 0; }
 #endif
