@@ -6,18 +6,17 @@
 #include <game/generated/protocol.h>
 
 #include "entities/pickup.h"
-#include "gamecontroller.h"
 #include "gamecontext.h"
+#include "gamecontroller.h"
 
-#include "entities/light.h"
+#include "entities/door.h"
 #include "entities/dragger.h"
 #include "entities/gun.h"
-#include "entities/projectile.h"
+#include "entities/light.h"
 #include "entities/plasma.h"
-#include "entities/door.h"
+#include "entities/projectile.h"
 #include <game/layers.h>
 
-
 IGameController::IGameController(class CGameContext *pGameServer)
 {
 	m_pGameServer = pGameServer;
@@ -59,7 +58,7 @@ float IGameController::EvaluateSpawnPos(CSpawnEval *pEval, vec2 Pos)
 			Scoremod = 0.5f;
 
 		float d = distance(Pos, pC->m_Pos);
-		Score += Scoremod * (d == 0 ? 1000000000.0f : 1.0f/d);
+		Score += Scoremod * (d == 0 ? 1000000000.0f : 1.0f / d);
 	}
 
 	return Score;
@@ -72,8 +71,8 @@ void IGameController::EvaluateSpawnType(CSpawnEval *pEval, int Type)
 	{
 		// check if the position is occupado
 		CCharacter *aEnts[MAX_CLIENTS];
-		int Num = GameServer()->m_World.FindEntities(m_aaSpawnPoints[Type][i], 64, (CEntity**)aEnts, MAX_CLIENTS, CGameWorld::ENTTYPE_CHARACTER);
-		vec2 Positions[5] = { vec2(0.0f, 0.0f), vec2(-32.0f, 0.0f), vec2(0.0f, -32.0f), vec2(32.0f, 0.0f), vec2(0.0f, 32.0f) };	// start, left, up, right, down
+		int Num = GameServer()->m_World.FindEntities(m_aaSpawnPoints[Type][i], 64, (CEntity **)aEnts, MAX_CLIENTS, CGameWorld::ENTTYPE_CHARACTER);
+		vec2 Positions[5] = {vec2(0.0f, 0.0f), vec2(-32.0f, 0.0f), vec2(0.0f, -32.0f), vec2(32.0f, 0.0f), vec2(0.0f, 32.0f)}; // start, left, up, right, down
 		int Result = -1;
 		for(int Index = 0; Index < 5 && Result == -1; ++Index)
 		{
@@ -81,17 +80,17 @@ void IGameController::EvaluateSpawnType(CSpawnEval *pEval, int Type)
 			if(!GameServer()->m_World.m_Core.m_Tuning[0].m_PlayerCollision)
 				break;
 			for(int c = 0; c < Num; ++c)
-				if(GameServer()->Collision()->CheckPoint(m_aaSpawnPoints[Type][i]+Positions[Index]) ||
-					distance(aEnts[c]->m_Pos, m_aaSpawnPoints[Type][i]+Positions[Index]) <= aEnts[c]->m_ProximityRadius)
+				if(GameServer()->Collision()->CheckPoint(m_aaSpawnPoints[Type][i] + Positions[Index]) ||
+					distance(aEnts[c]->m_Pos, m_aaSpawnPoints[Type][i] + Positions[Index]) <= aEnts[c]->m_ProximityRadius)
 				{
 					Result = -1;
 					break;
 				}
 		}
 		if(Result == -1)
-			continue;	// try next spawn point
+			continue; // try next spawn point
 
-		vec2 P = m_aaSpawnPoints[Type][i]+Positions[Result];
+		vec2 P = m_aaSpawnPoints[Type][i] + Positions[Result];
 		float S = EvaluateSpawnPos(pEval, P);
 		if(!pEval->m_Got || pEval->m_Score > S)
 		{
@@ -120,24 +119,24 @@ bool IGameController::CanSpawn(int Team, vec2 *pOutPos)
 
 bool IGameController::OnEntity(int Index, vec2 Pos, int Layer, int Flags, int Number)
 {
-	if (Index < 0)
+	if(Index < 0)
 		return false;
 
 	int Type = -1;
 	int SubType = 0;
 
-	int x,y;
-	x=(Pos.x-16.0f)/32.0f;
-	y=(Pos.y-16.0f)/32.0f;
+	int x, y;
+	x = (Pos.x - 16.0f) / 32.0f;
+	y = (Pos.y - 16.0f) / 32.0f;
 	int sides[8];
-	sides[0]=GameServer()->Collision()->Entity(x,y+1, Layer);
-	sides[1]=GameServer()->Collision()->Entity(x+1,y+1, Layer);
-	sides[2]=GameServer()->Collision()->Entity(x+1,y, Layer);
-	sides[3]=GameServer()->Collision()->Entity(x+1,y-1, Layer);
-	sides[4]=GameServer()->Collision()->Entity(x,y-1, Layer);
-	sides[5]=GameServer()->Collision()->Entity(x-1,y-1, Layer);
-	sides[6]=GameServer()->Collision()->Entity(x-1,y, Layer);
-	sides[7]=GameServer()->Collision()->Entity(x-1,y+1, Layer);
+	sides[0] = GameServer()->Collision()->Entity(x, y + 1, Layer);
+	sides[1] = GameServer()->Collision()->Entity(x + 1, y + 1, Layer);
+	sides[2] = GameServer()->Collision()->Entity(x + 1, y, Layer);
+	sides[3] = GameServer()->Collision()->Entity(x + 1, y - 1, Layer);
+	sides[4] = GameServer()->Collision()->Entity(x, y - 1, Layer);
+	sides[5] = GameServer()->Collision()->Entity(x - 1, y - 1, Layer);
+	sides[6] = GameServer()->Collision()->Entity(x - 1, y, Layer);
+	sides[7] = GameServer()->Collision()->Entity(x - 1, y + 1, Layer);
 
 	if(Index == ENTITY_SPAWN)
 		m_aaSpawnPoints[0][m_aNumSpawnPoints[0]++] = Pos;
@@ -148,16 +147,15 @@ bool IGameController::OnEntity(int Index, vec2 Pos, int Layer, int Flags, int Nu
 
 	else if(Index == ENTITY_DOOR)
 	{
-		for(int i = 0; i < 8;i++)
+		for(int i = 0; i < 8; i++)
 		{
-			if (sides[i] >= ENTITY_LASER_SHORT && sides[i] <= ENTITY_LASER_LONG)
+			if(sides[i] >= ENTITY_LASER_SHORT && sides[i] <= ENTITY_LASER_LONG)
 			{
-				new CDoor
-				(
+				new CDoor(
 					&GameServer()->m_World, //GameWorld
 					Pos, //Pos
 					pi / 4 * i, //Rotation
-					32 * 3 + 32 *(sides[i] - ENTITY_LASER_SHORT) * 3, //Length
+					32 * 3 + 32 * (sides[i] - ENTITY_LASER_SHORT) * 3, //Length
 					Number //Number
 				);
 			}
@@ -175,8 +173,7 @@ bool IGameController::OnEntity(int Index, vec2 Pos, int Layer, int Flags, int Nu
 		else
 			Dir = 3;
 		float Deg = Dir * (pi / 2);
-		CProjectile *bullet = new CProjectile
-			(
+		CProjectile *bullet = new CProjectile(
 			&GameServer()->m_World,
 			WEAPON_SHOTGUN, //Type
 			-1, //Owner
@@ -186,26 +183,24 @@ bool IGameController::OnEntity(int Index, vec2 Pos, int Layer, int Flags, int Nu
 			true, //Freeze
 			true, //Explosive
 			0, //Force
-			(g_Config.m_SvShotgunBulletSound)?SOUND_GRENADE_EXPLODE:-1,//SoundImpact
+			(g_Config.m_SvShotgunBulletSound) ? SOUND_GRENADE_EXPLODE : -1, //SoundImpact
 			Layer,
-			Number
-			);
+			Number);
 		bullet->SetBouncing(2 - (Dir % 2));
 	}
 	else if(Index == ENTITY_CRAZY_SHOTGUN)
 	{
 		int Dir;
 		if(!Flags)
-			Dir=0;
+			Dir = 0;
 		else if(Flags == (TILEFLAG_ROTATE))
 			Dir = 1;
-		else if(Flags == (TILEFLAG_VFLIP|TILEFLAG_HFLIP))
+		else if(Flags == (TILEFLAG_VFLIP | TILEFLAG_HFLIP))
 			Dir = 2;
 		else
 			Dir = 3;
-		float Deg = Dir * ( pi / 2);
-		CProjectile *bullet = new CProjectile
-			(
+		float Deg = Dir * (pi / 2);
+		CProjectile *bullet = new CProjectile(
 			&GameServer()->m_World,
 			WEAPON_SHOTGUN, //Type
 			-1, //Owner
@@ -217,8 +212,7 @@ bool IGameController::OnEntity(int Index, vec2 Pos, int Layer, int Flags, int Nu
 			0,
 			SOUND_GRENADE_EXPLODE,
 			Layer,
-			Number
-			);
+			Number);
 		bullet->SetBouncing(2 - (Dir % 2));
 	}
 
@@ -249,19 +243,19 @@ bool IGameController::OnEntity(int Index, vec2 Pos, int Layer, int Flags, int Nu
 	else if(Index >= ENTITY_LASER_FAST_CCW && Index <= ENTITY_LASER_FAST_CW)
 	{
 		int sides2[8];
-		sides2[0]=GameServer()->Collision()->Entity(x, y + 2, Layer);
-		sides2[1]=GameServer()->Collision()->Entity(x + 2, y + 2, Layer);
-		sides2[2]=GameServer()->Collision()->Entity(x + 2, y, Layer);
-		sides2[3]=GameServer()->Collision()->Entity(x + 2, y - 2, Layer);
-		sides2[4]=GameServer()->Collision()->Entity(x,y - 2, Layer);
-		sides2[5]=GameServer()->Collision()->Entity(x - 2, y - 2, Layer);
-		sides2[6]=GameServer()->Collision()->Entity(x - 2, y, Layer);
-		sides2[7]=GameServer()->Collision()->Entity(x - 2, y + 2, Layer);
+		sides2[0] = GameServer()->Collision()->Entity(x, y + 2, Layer);
+		sides2[1] = GameServer()->Collision()->Entity(x + 2, y + 2, Layer);
+		sides2[2] = GameServer()->Collision()->Entity(x + 2, y, Layer);
+		sides2[3] = GameServer()->Collision()->Entity(x + 2, y - 2, Layer);
+		sides2[4] = GameServer()->Collision()->Entity(x, y - 2, Layer);
+		sides2[5] = GameServer()->Collision()->Entity(x - 2, y - 2, Layer);
+		sides2[6] = GameServer()->Collision()->Entity(x - 2, y, Layer);
+		sides2[7] = GameServer()->Collision()->Entity(x - 2, y + 2, Layer);
 
 		float AngularSpeed = 0.0f;
-		int Ind=Index-ENTITY_LASER_STOP;
+		int Ind = Index - ENTITY_LASER_STOP;
 		int M;
-		if( Ind < 0)
+		if(Ind < 0)
 		{
 			Ind = -Ind;
 			M = 1;
@@ -271,7 +265,6 @@ bool IGameController::OnEntity(int Index, vec2 Pos, int Layer, int Flags, int Nu
 		else
 			M = -1;
 
-
 		if(Ind == 0)
 			AngularSpeed = 0.0f;
 		else if(Ind == 1)
@@ -282,7 +275,7 @@ bool IGameController::OnEntity(int Index, vec2 Pos, int Layer, int Flags, int Nu
 			AngularSpeed = pi / 90;
 		AngularSpeed *= M;
 
-		for(int i=0; i<8;i++)
+		for(int i = 0; i < 8; i++)
 		{
 			if(sides[i] >= ENTITY_LASER_SHORT && sides[i] <= ENTITY_LASER_LONG)
 			{
@@ -302,7 +295,6 @@ bool IGameController::OnEntity(int Index, vec2 Pos, int Layer, int Flags, int Nu
 					Lgt->m_CurveLength = Lgt->m_Length;
 			}
 		}
-
 	}
 	else if(Index >= ENTITY_DRAGGER_WEAK && Index <= ENTITY_DRAGGER_STRONG)
 	{
@@ -374,7 +366,7 @@ void IGameController::StartRound()
 	m_ForceBalanced = false;
 	Server()->DemoRecorder_HandleAutoStart();
 	char aBuf[256];
-	str_format(aBuf, sizeof(aBuf), "start round type='%s' teamplay='%d'", m_pGameType, m_GameFlags&GAMEFLAG_TEAMS);
+	str_format(aBuf, sizeof(aBuf), "start round type='%s' teamplay='%d'", m_pGameType, m_GameFlags & GAMEFLAG_TEAMS);
 	GameServer()->Console()->Print(IConsole::OUTPUT_LEVEL_DEBUG, "game", aBuf);
 }
 
@@ -410,7 +402,7 @@ void IGameController::DoWarmup(int Seconds)
 	if(Seconds < 0)
 		m_Warmup = 0;
 	else
-		m_Warmup = Seconds*Server()->TickSpeed();
+		m_Warmup = Seconds * Server()->TickSpeed();
 }
 
 bool IGameController::IsForceBalanced()
@@ -418,7 +410,6 @@ bool IGameController::IsForceBalanced()
 	return false;
 }
 
-
 bool IGameController::CanBeMovedOnBalance(int ClientID)
 {
 	return true;
@@ -437,7 +428,7 @@ void IGameController::Tick()
 	if(m_GameOverTick != -1)
 	{
 		// game over.. wait for restart
-		if(Server()->Tick() > m_GameOverTick+Server()->TickSpeed()*10)
+		if(Server()->Tick() > m_GameOverTick + Server()->TickSpeed() * 10)
 		{
 			StartRound();
 			m_RoundCount++;
@@ -448,43 +439,43 @@ void IGameController::Tick()
 	{
 		for(int i = 0; i < MAX_CLIENTS; ++i)
 		{
-		#ifdef CONF_DEBUG
+#ifdef CONF_DEBUG
 			if(g_Config.m_DbgDummies)
 			{
-				if(i >= MAX_CLIENTS-g_Config.m_DbgDummies)
+				if(i >= MAX_CLIENTS - g_Config.m_DbgDummies)
 					break;
 			}
-		#endif
+#endif
 			if(GameServer()->m_apPlayers[i] && GameServer()->m_apPlayers[i]->GetTeam() != TEAM_SPECTATORS && Server()->GetAuthedState(i) == AUTHED_NO)
 			{
-				if(Server()->Tick() > GameServer()->m_apPlayers[i]->m_LastActionTick+g_Config.m_SvInactiveKickTime*Server()->TickSpeed()*60)
+				if(Server()->Tick() > GameServer()->m_apPlayers[i]->m_LastActionTick + g_Config.m_SvInactiveKickTime * Server()->TickSpeed() * 60)
 				{
 					switch(g_Config.m_SvInactiveKick)
 					{
 					case 0:
-						{
-							// move player to spectator
-							GameServer()->m_apPlayers[i]->SetTeam(TEAM_SPECTATORS);
-						}
-						break;
+					{
+						// move player to spectator
+						GameServer()->m_apPlayers[i]->SetTeam(TEAM_SPECTATORS);
+					}
+					break;
 					case 1:
-						{
-							// move player to spectator if the reserved slots aren't filled yet, kick him otherwise
-							int Spectators = 0;
-							for(int j = 0; j < MAX_CLIENTS; ++j)
-								if(GameServer()->m_apPlayers[j] && GameServer()->m_apPlayers[j]->GetTeam() == TEAM_SPECTATORS)
-									++Spectators;
-							if(Spectators >= g_Config.m_SvSpectatorSlots)
-								Server()->Kick(i, "Kicked for inactivity");
-							else
-								GameServer()->m_apPlayers[i]->SetTeam(TEAM_SPECTATORS);
-						}
-						break;
-					case 2:
-						{
-							// kick the player
+					{
+						// move player to spectator if the reserved slots aren't filled yet, kick him otherwise
+						int Spectators = 0;
+						for(int j = 0; j < MAX_CLIENTS; ++j)
+							if(GameServer()->m_apPlayers[j] && GameServer()->m_apPlayers[j]->GetTeam() == TEAM_SPECTATORS)
+								++Spectators;
+						if(Spectators >= g_Config.m_SvSpectatorSlots)
 							Server()->Kick(i, "Kicked for inactivity");
-						}
+						else
+							GameServer()->m_apPlayers[i]->SetTeam(TEAM_SPECTATORS);
+					}
+					break;
+					case 2:
+					{
+						// kick the player
+						Server()->Kick(i, "Kicked for inactivity");
+					}
 					}
 				}
 			}
@@ -510,7 +501,7 @@ void IGameController::Snap(int SnappingClient)
 	pGameInfoObj->m_WarmupTimer = m_Warmup;
 
 	pGameInfoObj->m_RoundNum = 0;
-	pGameInfoObj->m_RoundCurrent = m_RoundCount+1;
+	pGameInfoObj->m_RoundCurrent = m_RoundCount + 1;
 
 	CCharacter *pChr;
 	CPlayer *pPlayer = SnappingClient > -1 ? GameServer()->m_apPlayers[SnappingClient] : 0;
@@ -518,9 +509,7 @@ void IGameController::Snap(int SnappingClient)
 
 	if(pPlayer && (pPlayer->m_TimerType == CPlayer::TIMERTYPE_GAMETIMER || pPlayer->m_TimerType == CPlayer::TIMERTYPE_GAMETIMER_AND_BROADCAST) && pPlayer->GetClientVersion() >= VERSION_DDNET_GAMETICK)
 	{
-		if((pPlayer->GetTeam() == -1 || pPlayer->IsPaused())
-			&& pPlayer->m_SpectatorID != SPEC_FREEVIEW
-			&& (pPlayer2 = GameServer()->m_apPlayers[pPlayer->m_SpectatorID]))
+		if((pPlayer->GetTeam() == -1 || pPlayer->IsPaused()) && pPlayer->m_SpectatorID != SPEC_FREEVIEW && (pPlayer2 = GameServer()->m_apPlayers[pPlayer->m_SpectatorID]))
 		{
 			if((pChr = pPlayer2->GetCharacter()) && pChr->m_DDRaceState == DDRACE_STARTED)
 			{
@@ -539,24 +528,25 @@ void IGameController::Snap(int SnappingClient)
 	if(!pGameInfoEx)
 		return;
 
-	pGameInfoEx->m_Flags = 0
-		| GAMEINFOFLAG_TIMESCORE
-		| GAMEINFOFLAG_GAMETYPE_RACE
-		| GAMEINFOFLAG_GAMETYPE_DDRACE
-		| GAMEINFOFLAG_GAMETYPE_DDNET
-		| GAMEINFOFLAG_UNLIMITED_AMMO
-		| GAMEINFOFLAG_RACE_RECORD_MESSAGE
-		| GAMEINFOFLAG_ALLOW_EYE_WHEEL
-		| GAMEINFOFLAG_ALLOW_HOOK_COLL
-		| GAMEINFOFLAG_ALLOW_ZOOM
-		| GAMEINFOFLAG_BUG_DDRACE_GHOST
-		| GAMEINFOFLAG_BUG_DDRACE_INPUT
-		| GAMEINFOFLAG_PREDICT_DDRACE
-		| GAMEINFOFLAG_PREDICT_DDRACE_TILES
-		| GAMEINFOFLAG_ENTITIES_DDNET
-		| GAMEINFOFLAG_ENTITIES_DDRACE
-		| GAMEINFOFLAG_ENTITIES_RACE
-		| GAMEINFOFLAG_RACE;
+	pGameInfoEx->m_Flags =
+		GAMEINFOFLAG_TIMESCORE |
+		GAMEINFOFLAG_GAMETYPE_RACE |
+		GAMEINFOFLAG_GAMETYPE_DDRACE |
+		GAMEINFOFLAG_GAMETYPE_DDNET |
+		GAMEINFOFLAG_UNLIMITED_AMMO |
+		GAMEINFOFLAG_RACE_RECORD_MESSAGE |
+		GAMEINFOFLAG_ALLOW_EYE_WHEEL |
+		GAMEINFOFLAG_ALLOW_HOOK_COLL |
+		GAMEINFOFLAG_ALLOW_ZOOM |
+		GAMEINFOFLAG_BUG_DDRACE_GHOST |
+		GAMEINFOFLAG_BUG_DDRACE_INPUT |
+		GAMEINFOFLAG_PREDICT_DDRACE |
+		GAMEINFOFLAG_PREDICT_DDRACE_TILES |
+		GAMEINFOFLAG_ENTITIES_DDNET |
+		GAMEINFOFLAG_ENTITIES_DDRACE |
+		GAMEINFOFLAG_ENTITIES_RACE |
+		GAMEINFOFLAG_RACE;
+	pGameInfoEx->m_Flags2 = 0;
 	pGameInfoEx->m_Version = GAMEINFO_CURVERSION;
 
 	if(Server()->IsSixup(SnappingClient))
@@ -594,7 +584,7 @@ int IGameController::GetAutoTeam(int NotThisID)
 		return 0;
 #endif
 
-	int aNumplayers[2] = {0,0};
+	int aNumplayers[2] = {0, 0};
 	for(int i = 0; i < MAX_CLIENTS; i++)
 	{
 		if(GameServer()->m_apPlayers[i] && i != NotThisID)
@@ -616,7 +606,7 @@ bool IGameController::CanJoinTeam(int Team, int NotThisID)
 	if(Team == TEAM_SPECTATORS || (GameServer()->m_apPlayers[NotThisID] && GameServer()->m_apPlayers[NotThisID]->GetTeam() != TEAM_SPECTATORS))
 		return true;
 
-	int aNumplayers[2] = {0,0};
+	int aNumplayers[2] = {0, 0};
 	for(int i = 0; i < MAX_CLIENTS; i++)
 	{
 		if(GameServer()->m_apPlayers[i] && i != NotThisID)
@@ -626,7 +616,7 @@ bool IGameController::CanJoinTeam(int Team, int NotThisID)
 		}
 	}
 
-	return (aNumplayers[0] + aNumplayers[1]) < Server()->MaxClients()-g_Config.m_SvSpectatorSlots;
+	return (aNumplayers[0] + aNumplayers[1]) < Server()->MaxClients() - g_Config.m_SvSpectatorSlots;
 }
 
 int IGameController::ClampTeam(int Team)
