@@ -5,9 +5,9 @@
 
 // this include should perhaps be removed
 #include "entities/character.h"
+#include "gamecontext.h"
 #include "score.h"
 #include "teeinfo.h"
-#include "gamecontext.h"
 #include <memory>
 
 // player object
@@ -25,8 +25,8 @@ public:
 
 	void TryRespawn();
 	void Respawn(bool WeakHook = false); // with WeakHook == true the character will be spawned after all calls of Tick from other Players
-	CCharacter* ForceSpawn(vec2 Pos); // required for loading savegames
-	void SetTeam(int Team, bool DoChatMsg=true);
+	CCharacter *ForceSpawn(vec2 Pos); // required for loading savegames
+	void SetTeam(int Team, bool DoChatMsg = true);
 	int GetTeam() const { return m_Team; };
 	int GetCID() const { return m_ClientID; };
 	int GetClientVersion() const;
@@ -134,15 +134,15 @@ private:
 public:
 	enum
 	{
-		PAUSE_NONE=0,
+		PAUSE_NONE = 0,
 		PAUSE_PAUSED,
 		PAUSE_SPEC
 	};
 
 	enum
 	{
-		TIMERTYPE_DEFAULT=-1,
-		TIMERTYPE_GAMETIMER=0,
+		TIMERTYPE_DEFAULT = -1,
+		TIMERTYPE_GAMETIMER = 0,
 		TIMERTYPE_BROADCAST,
 		TIMERTYPE_GAMETIMER_AND_BROADCAST,
 		TIMERTYPE_SIXUP,
@@ -161,7 +161,7 @@ public:
 	bool IsPlaying();
 	int64 m_Last_KickVote;
 	int64 m_Last_Team;
-	bool m_ShowOthers;
+	int m_ShowOthers;
 	bool m_ShowAll;
 	vec2 m_ShowDistance;
 	bool m_SpecTeam;
