@@ -1,10 +1,10 @@
 #include "save.h"
 
-#include <new>
 #include <cstdio>
+#include <new>
 
-#include "teams.h"
 #include "gamemodes/DDRace.h"
+#include "teams.h"
 #include <engine/shared/config.h>
 
 CSaveTee::CSaveTee()
@@ -27,7 +27,7 @@ void CSaveTee::save(CCharacter *pChr)
 	m_TeeFinished = pChr->Teams()->TeeFinished(m_ClientID);
 	m_IsSolo = pChr->m_Solo;
 
-	for(int i = 0; i< NUM_WEAPONS; i++)
+	for(int i = 0; i < NUM_WEAPONS; i++)
 	{
 		m_aWeapons[i].m_AmmoRegenStart = pChr->m_aWeapons[i].m_AmmoRegenStart;
 		m_aWeapons[i].m_Ammo = pChr->m_aWeapons[i].m_Ammo;
@@ -93,6 +93,15 @@ void CSaveTee::save(CCharacter *pChr)
 	m_HookTick = pChr->m_Core.m_HookTick;
 
 	m_HookState = pChr->m_Core.m_HookState;
+	m_HookedPlayer = pChr->m_Core.m_HookedPlayer;
+	m_NewHook = pChr->m_Core.m_NewHook != 0;
+
+	m_InputDirection = pChr->m_SavedInput.m_Direction;
+	m_InputJump = pChr->m_SavedInput.m_Jump;
+	m_InputFire = pChr->m_SavedInput.m_Fire;
+	m_InputHook = pChr->m_SavedInput.m_Hook;
+
+	m_ReloadTimer = pChr->m_ReloadTimer;
 
 	FormatUuid(pChr->GameServer()->GameUuid(), m_aGameUuid, sizeof(m_aGameUuid));
 }
@@ -107,7 +116,7 @@ void CSaveTee::load(CCharacter *pChr, int Team)
 	pChr->Teams()->SetForceCharacterTeam(pChr->m_pPlayer->GetCID(), Team);
 	pChr->Teams()->SetFinished(pChr->m_pPlayer->GetCID(), m_TeeFinished);
 
-	for(int i = 0; i< NUM_WEAPONS; i++)
+	for(int i = 0; i < NUM_WEAPONS; i++)
 	{
 		pChr->m_aWeapons[i].m_AmmoRegenStart = m_aWeapons[i].m_AmmoRegenStart;
 		// m_Ammo not used anymore for tracking freeze following https://github.com/ddnet/ddnet/pull/2086
@@ -144,7 +153,7 @@ void CSaveTee::load(CCharacter *pChr, int Team)
 	if(m_CpTime)
 		pChr->m_CpTick = pChr->Server()->Tick() - m_CpTime;
 
-	pChr->m_CpActive  = m_CpActive;
+	pChr->m_CpActive = m_CpActive;
 	pChr->m_CpLastBroadcast = m_CpLastBroadcast;
 
 	for(int i = 0; i < 25; i++)
@@ -171,15 +180,23 @@ void CSaveTee::load(CCharacter *pChr, int Team)
 
 	pChr->m_Core.m_HookTick = m_HookTick;
 
-	if(m_HookState == HOOK_GRABBED)
+	pChr->m_Core.m_HookState = m_HookState;
+	if(m_HookedPlayer != -1 && pChr->Teams()->m_Core.Team(m_HookedPlayer) != Team)
 	{
-		pChr->m_Core.m_HookState = HOOK_FLYING;
 		pChr->m_Core.m_HookedPlayer = -1;
+		pChr->m_Core.m_HookState = HOOK_FLYING;
 	}
 	else
 	{
-		pChr->m_Core.m_HookState = m_HookState;
+		pChr->m_Core.m_HookedPlayer = m_HookedPlayer;
 	}
+	pChr->m_Core.m_NewHook = m_NewHook;
+	pChr->m_SavedInput.m_Direction = m_InputDirection;
+	pChr->m_SavedInput.m_Jump = m_InputJump;
+	pChr->m_SavedInput.m_Fire = m_InputFire;
+	pChr->m_SavedInput.m_Hook = m_InputHook;
+
+	pChr->m_ReloadTimer = m_ReloadTimer;
 
 	pChr->SetSolo(m_IsSolo);
 
@@ -188,132 +205,155 @@ void CSaveTee::load(CCharacter *pChr, int Team)
 	pChr->SetRescue();
 }
 
-char* CSaveTee::GetString()
+char *CSaveTee::GetString(const CSaveTeam *pTeam)
 {
 	// Add time penalty of 60 seconds (only to the database)
 	int Time = m_Time + 60 * SERVER_TICK_SPEED;
 
+	int HookedPlayer = -1;
+	if(m_HookedPlayer != -1)
+	{
+		for(int n = 0; n < pTeam->GetMembersCount(); n++)
+		{
+			if(m_HookedPlayer == pTeam->m_pSavedTees[n].GetClientID())
+			{
+				HookedPlayer = n;
+				break;
+			}
+		}
+	}
+
 	str_format(m_aString, sizeof(m_aString),
-			"%s\t%d\t%d\t%d\t%d\t%d\t"
-			// weapons
-			"%d\t%d\t%d\t%d\t"
-			"%d\t%d\t%d\t%d\t"
-			"%d\t%d\t%d\t%d\t"
-			"%d\t%d\t%d\t%d\t"
-			"%d\t%d\t%d\t%d\t"
-			"%d\t%d\t%d\t%d\t"
-			"%d\t%d\t"
-			// tee stats
-			"%d\t%d\t%d\t%d\t%d\t%d\t%d\t" // m_SuperJump
-			"%d\t%d\t%d\t%d\t%d\t%d\t%d\t" // m_DDRaceState
-			"%d\t%d\t%d\t%d\t" // m_Pos.x
-			"%d\t%d\t"  // m_TeleCheckpoint
-			"%d\t%d\t%f\t%f\t" // m_CorePos.x
-			"%d\t%d\t%d\t%d\t" // m_ActiveWeapon
-			"%d\t%d\t%f\t%f\t" // m_HookPos.x
-			"%d\t%d\t%d\t%d\t" // m_HookTeleBase.x
-			// time checkpoints
-			"%d\t%d\t%d\t"
-			"%f\t%f\t%f\t%f\t%f\t"
-			"%f\t%f\t%f\t%f\t%f\t"
-			"%f\t%f\t%f\t%f\t%f\t"
-			"%f\t%f\t%f\t%f\t%f\t"
-			"%f\t%f\t%f\t%f\t%f\t"
-			"%d\t"
-			"%d\t%d\t%d\t"
-			"%s",
-			m_aName, m_Alive, m_Paused, m_NeededFaketuning, m_TeeFinished, m_IsSolo,
-			// weapons
-			m_aWeapons[0].m_AmmoRegenStart, m_aWeapons[0].m_Ammo, m_aWeapons[0].m_Ammocost, m_aWeapons[0].m_Got,
-			m_aWeapons[1].m_AmmoRegenStart, m_aWeapons[1].m_Ammo, m_aWeapons[1].m_Ammocost, m_aWeapons[1].m_Got,
-			m_aWeapons[2].m_AmmoRegenStart, m_aWeapons[2].m_Ammo, m_aWeapons[2].m_Ammocost, m_aWeapons[2].m_Got,
-			m_aWeapons[3].m_AmmoRegenStart, m_aWeapons[3].m_Ammo, m_aWeapons[3].m_Ammocost, m_aWeapons[3].m_Got,
-			m_aWeapons[4].m_AmmoRegenStart, m_aWeapons[4].m_Ammo, m_aWeapons[4].m_Ammocost, m_aWeapons[4].m_Got,
-			m_aWeapons[5].m_AmmoRegenStart, m_aWeapons[5].m_Ammo, m_aWeapons[5].m_Ammocost, m_aWeapons[5].m_Got,
-			m_LastWeapon, m_QueuedWeapon,
-			// tee states
-			m_SuperJump, m_Jetpack, m_NinjaJetpack, m_FreezeTime, m_FreezeTick, m_DeepFreeze, m_EndlessHook,
-			m_DDRaceState, m_Hit, m_Collision, m_TuneZone, m_TuneZoneOld, m_Hook, Time,
-			(int)m_Pos.x, (int)m_Pos.y, (int)m_PrevPos.x, (int)m_PrevPos.y,
-			m_TeleCheckpoint, m_LastPenalty,
-			(int)m_CorePos.x, (int)m_CorePos.y, m_Vel.x, m_Vel.y,
-			m_ActiveWeapon, m_Jumped, m_JumpedTotal, m_Jumps,
-			(int)m_HookPos.x, (int)m_HookPos.y, m_HookDir.x, m_HookDir.y,
-			(int)m_HookTeleBase.x, (int)m_HookTeleBase.y, m_HookTick, m_HookState,
-			// time checkpoints
-			m_CpTime, m_CpActive, m_CpLastBroadcast,
-			m_aCpCurrent[0], m_aCpCurrent[1], m_aCpCurrent[2], m_aCpCurrent[3], m_aCpCurrent[4],
-			m_aCpCurrent[5], m_aCpCurrent[6], m_aCpCurrent[7], m_aCpCurrent[8], m_aCpCurrent[9],
-			m_aCpCurrent[10], m_aCpCurrent[11], m_aCpCurrent[12], m_aCpCurrent[13], m_aCpCurrent[14],
-			m_aCpCurrent[15], m_aCpCurrent[16], m_aCpCurrent[17], m_aCpCurrent[18], m_aCpCurrent[19],
-			m_aCpCurrent[20], m_aCpCurrent[21], m_aCpCurrent[22], m_aCpCurrent[23], m_aCpCurrent[24],
-			m_NotEligibleForFinish,
-			m_HasTelegunGun, m_HasTelegunLaser, m_HasTelegunGrenade,
-			m_aGameUuid
-	);
+		"%s\t%d\t%d\t%d\t%d\t%d\t"
+		// weapons
+		"%d\t%d\t%d\t%d\t"
+		"%d\t%d\t%d\t%d\t"
+		"%d\t%d\t%d\t%d\t"
+		"%d\t%d\t%d\t%d\t"
+		"%d\t%d\t%d\t%d\t"
+		"%d\t%d\t%d\t%d\t"
+		"%d\t%d\t"
+		// tee stats
+		"%d\t%d\t%d\t%d\t%d\t%d\t%d\t" // m_SuperJump
+		"%d\t%d\t%d\t%d\t%d\t%d\t%d\t" // m_DDRaceState
+		"%d\t%d\t%d\t%d\t" // m_Pos.x
+		"%d\t%d\t" // m_TeleCheckpoint
+		"%d\t%d\t%f\t%f\t" // m_CorePos.x
+		"%d\t%d\t%d\t%d\t" // m_ActiveWeapon
+		"%d\t%d\t%f\t%f\t" // m_HookPos.x
+		"%d\t%d\t%d\t%d\t" // m_HookTeleBase.x
+		// time checkpoints
+		"%d\t%d\t%d\t"
+		"%f\t%f\t%f\t%f\t%f\t"
+		"%f\t%f\t%f\t%f\t%f\t"
+		"%f\t%f\t%f\t%f\t%f\t"
+		"%f\t%f\t%f\t%f\t%f\t"
+		"%f\t%f\t%f\t%f\t%f\t"
+		"%d\t"
+		"%d\t%d\t%d\t"
+		"%s\t"
+		"%d\t%d\t"
+		"%d\t%d\t%d\t%d\t"
+		"%d",
+		m_aName, m_Alive, m_Paused, m_NeededFaketuning, m_TeeFinished, m_IsSolo,
+		// weapons
+		m_aWeapons[0].m_AmmoRegenStart, m_aWeapons[0].m_Ammo, m_aWeapons[0].m_Ammocost, m_aWeapons[0].m_Got,
+		m_aWeapons[1].m_AmmoRegenStart, m_aWeapons[1].m_Ammo, m_aWeapons[1].m_Ammocost, m_aWeapons[1].m_Got,
+		m_aWeapons[2].m_AmmoRegenStart, m_aWeapons[2].m_Ammo, m_aWeapons[2].m_Ammocost, m_aWeapons[2].m_Got,
+		m_aWeapons[3].m_AmmoRegenStart, m_aWeapons[3].m_Ammo, m_aWeapons[3].m_Ammocost, m_aWeapons[3].m_Got,
+		m_aWeapons[4].m_AmmoRegenStart, m_aWeapons[4].m_Ammo, m_aWeapons[4].m_Ammocost, m_aWeapons[4].m_Got,
+		m_aWeapons[5].m_AmmoRegenStart, m_aWeapons[5].m_Ammo, m_aWeapons[5].m_Ammocost, m_aWeapons[5].m_Got,
+		m_LastWeapon, m_QueuedWeapon,
+		// tee states
+		m_SuperJump, m_Jetpack, m_NinjaJetpack, m_FreezeTime, m_FreezeTick, m_DeepFreeze, m_EndlessHook,
+		m_DDRaceState, m_Hit, m_Collision, m_TuneZone, m_TuneZoneOld, m_Hook, Time,
+		(int)m_Pos.x, (int)m_Pos.y, (int)m_PrevPos.x, (int)m_PrevPos.y,
+		m_TeleCheckpoint, m_LastPenalty,
+		(int)m_CorePos.x, (int)m_CorePos.y, m_Vel.x, m_Vel.y,
+		m_ActiveWeapon, m_Jumped, m_JumpedTotal, m_Jumps,
+		(int)m_HookPos.x, (int)m_HookPos.y, m_HookDir.x, m_HookDir.y,
+		(int)m_HookTeleBase.x, (int)m_HookTeleBase.y, m_HookTick, m_HookState,
+		// time checkpoints
+		m_CpTime, m_CpActive, m_CpLastBroadcast,
+		m_aCpCurrent[0], m_aCpCurrent[1], m_aCpCurrent[2], m_aCpCurrent[3], m_aCpCurrent[4],
+		m_aCpCurrent[5], m_aCpCurrent[6], m_aCpCurrent[7], m_aCpCurrent[8], m_aCpCurrent[9],
+		m_aCpCurrent[10], m_aCpCurrent[11], m_aCpCurrent[12], m_aCpCurrent[13], m_aCpCurrent[14],
+		m_aCpCurrent[15], m_aCpCurrent[16], m_aCpCurrent[17], m_aCpCurrent[18], m_aCpCurrent[19],
+		m_aCpCurrent[20], m_aCpCurrent[21], m_aCpCurrent[22], m_aCpCurrent[23], m_aCpCurrent[24],
+		m_NotEligibleForFinish,
+		m_HasTelegunGun, m_HasTelegunLaser, m_HasTelegunGrenade,
+		m_aGameUuid,
+		HookedPlayer, m_NewHook,
+		m_InputDirection, m_InputJump, m_InputFire, m_InputHook,
+		m_ReloadTimer);
 	return m_aString;
 }
 
-int CSaveTee::LoadString(const char* String)
+int CSaveTee::FromString(const char *String)
 {
 	int Num;
 	Num = sscanf(String,
-			"%[^\t]\t%d\t%d\t%d\t%d\t%d\t"
-			// weapons
-			"%d\t%d\t%d\t%d\t"
-			"%d\t%d\t%d\t%d\t"
-			"%d\t%d\t%d\t%d\t"
-			"%d\t%d\t%d\t%d\t"
-			"%d\t%d\t%d\t%d\t"
-			"%d\t%d\t%d\t%d\t"
-			"%d\t%d\t"
-			// tee states
-			"%d\t%d\t%d\t%d\t%d\t%d\t%d\t" // m_SuperJump
-			"%d\t%d\t%d\t%d\t%d\t%d\t%d\t" // m_DDRaceState
-			"%f\t%f\t%f\t%f\t" // m_Pos.x
-			"%d\t%d\t" // m_TeleCheckpoint
-			"%f\t%f\t%f\t%f\t" // m_CorePos.x
-			"%d\t%d\t%d\t%d\t" // m_ActiveWeapon
-			"%f\t%f\t%f\t%f\t" // m_HookPos.x
-			"%f\t%f\t%d\t%d\t" // m_HookTeleBase.x
-			// time checkpoints
-			"%d\t%d\t%d\t"
-			"%f\t%f\t%f\t%f\t%f\t"
-			"%f\t%f\t%f\t%f\t%f\t"
-			"%f\t%f\t%f\t%f\t%f\t"
-			"%f\t%f\t%f\t%f\t%f\t"
-			"%f\t%f\t%f\t%f\t%f\t"
-			"%d\t"
-			"%d\t%d\t%d\t"
-			"%*s", // discard the game uuid
-			m_aName, &m_Alive, &m_Paused, &m_NeededFaketuning, &m_TeeFinished, &m_IsSolo,
-			// weapons
-			&m_aWeapons[0].m_AmmoRegenStart, &m_aWeapons[0].m_Ammo, &m_aWeapons[0].m_Ammocost, &m_aWeapons[0].m_Got,
-			&m_aWeapons[1].m_AmmoRegenStart, &m_aWeapons[1].m_Ammo, &m_aWeapons[1].m_Ammocost, &m_aWeapons[1].m_Got,
-			&m_aWeapons[2].m_AmmoRegenStart, &m_aWeapons[2].m_Ammo, &m_aWeapons[2].m_Ammocost, &m_aWeapons[2].m_Got,
-			&m_aWeapons[3].m_AmmoRegenStart, &m_aWeapons[3].m_Ammo, &m_aWeapons[3].m_Ammocost, &m_aWeapons[3].m_Got,
-			&m_aWeapons[4].m_AmmoRegenStart, &m_aWeapons[4].m_Ammo, &m_aWeapons[4].m_Ammocost, &m_aWeapons[4].m_Got,
-			&m_aWeapons[5].m_AmmoRegenStart, &m_aWeapons[5].m_Ammo, &m_aWeapons[5].m_Ammocost, &m_aWeapons[5].m_Got,
-			&m_LastWeapon, &m_QueuedWeapon,
-			// tee states
-			&m_SuperJump, &m_Jetpack, &m_NinjaJetpack, &m_FreezeTime, &m_FreezeTick, &m_DeepFreeze, &m_EndlessHook,
-			&m_DDRaceState, &m_Hit, &m_Collision, &m_TuneZone, &m_TuneZoneOld, &m_Hook, &m_Time,
-			&m_Pos.x, &m_Pos.y, &m_PrevPos.x, &m_PrevPos.y,
-			&m_TeleCheckpoint, &m_LastPenalty,
-			&m_CorePos.x, &m_CorePos.y, &m_Vel.x, &m_Vel.y,
-			&m_ActiveWeapon, &m_Jumped, &m_JumpedTotal, &m_Jumps,
-			&m_HookPos.x, &m_HookPos.y, &m_HookDir.x, &m_HookDir.y,
-			&m_HookTeleBase.x, &m_HookTeleBase.y, &m_HookTick, &m_HookState,
-			// time checkpoints
-			&m_CpTime, &m_CpActive, &m_CpLastBroadcast,
-			&m_aCpCurrent[0], &m_aCpCurrent[1], &m_aCpCurrent[2], &m_aCpCurrent[3], &m_aCpCurrent[4],
-			&m_aCpCurrent[5], &m_aCpCurrent[6], &m_aCpCurrent[7], &m_aCpCurrent[8], &m_aCpCurrent[9],
-			&m_aCpCurrent[10], &m_aCpCurrent[11], &m_aCpCurrent[12], &m_aCpCurrent[13], &m_aCpCurrent[14],
-			&m_aCpCurrent[15], &m_aCpCurrent[16], &m_aCpCurrent[17], &m_aCpCurrent[18], &m_aCpCurrent[19],
-			&m_aCpCurrent[20], &m_aCpCurrent[21], &m_aCpCurrent[22], &m_aCpCurrent[23], &m_aCpCurrent[24],
-			&m_NotEligibleForFinish,
-			&m_HasTelegunGun, &m_HasTelegunLaser, &m_HasTelegunGrenade
-	);
+		"%[^\t]\t%d\t%d\t%d\t%d\t%d\t"
+		// weapons
+		"%d\t%d\t%d\t%d\t"
+		"%d\t%d\t%d\t%d\t"
+		"%d\t%d\t%d\t%d\t"
+		"%d\t%d\t%d\t%d\t"
+		"%d\t%d\t%d\t%d\t"
+		"%d\t%d\t%d\t%d\t"
+		"%d\t%d\t"
+		// tee states
+		"%d\t%d\t%d\t%d\t%d\t%d\t%d\t" // m_SuperJump
+		"%d\t%d\t%d\t%d\t%d\t%d\t%d\t" // m_DDRaceState
+		"%f\t%f\t%f\t%f\t" // m_Pos.x
+		"%d\t%d\t" // m_TeleCheckpoint
+		"%f\t%f\t%f\t%f\t" // m_CorePos.x
+		"%d\t%d\t%d\t%d\t" // m_ActiveWeapon
+		"%f\t%f\t%f\t%f\t" // m_HookPos.x
+		"%f\t%f\t%d\t%d\t" // m_HookTeleBase.x
+		// time checkpoints
+		"%d\t%d\t%d\t"
+		"%f\t%f\t%f\t%f\t%f\t"
+		"%f\t%f\t%f\t%f\t%f\t"
+		"%f\t%f\t%f\t%f\t%f\t"
+		"%f\t%f\t%f\t%f\t%f\t"
+		"%f\t%f\t%f\t%f\t%f\t"
+		"%d\t"
+		"%d\t%d\t%d\t"
+		"%*s\t" // discard the game uuid
+		"%d\t%d"
+		"%d\t%d\t%d\t%d\t"
+		"%d",
+		m_aName, &m_Alive, &m_Paused, &m_NeededFaketuning, &m_TeeFinished, &m_IsSolo,
+		// weapons
+		&m_aWeapons[0].m_AmmoRegenStart, &m_aWeapons[0].m_Ammo, &m_aWeapons[0].m_Ammocost, &m_aWeapons[0].m_Got,
+		&m_aWeapons[1].m_AmmoRegenStart, &m_aWeapons[1].m_Ammo, &m_aWeapons[1].m_Ammocost, &m_aWeapons[1].m_Got,
+		&m_aWeapons[2].m_AmmoRegenStart, &m_aWeapons[2].m_Ammo, &m_aWeapons[2].m_Ammocost, &m_aWeapons[2].m_Got,
+		&m_aWeapons[3].m_AmmoRegenStart, &m_aWeapons[3].m_Ammo, &m_aWeapons[3].m_Ammocost, &m_aWeapons[3].m_Got,
+		&m_aWeapons[4].m_AmmoRegenStart, &m_aWeapons[4].m_Ammo, &m_aWeapons[4].m_Ammocost, &m_aWeapons[4].m_Got,
+		&m_aWeapons[5].m_AmmoRegenStart, &m_aWeapons[5].m_Ammo, &m_aWeapons[5].m_Ammocost, &m_aWeapons[5].m_Got,
+		&m_LastWeapon, &m_QueuedWeapon,
+		// tee states
+		&m_SuperJump, &m_Jetpack, &m_NinjaJetpack, &m_FreezeTime, &m_FreezeTick, &m_DeepFreeze, &m_EndlessHook,
+		&m_DDRaceState, &m_Hit, &m_Collision, &m_TuneZone, &m_TuneZoneOld, &m_Hook, &m_Time,
+		&m_Pos.x, &m_Pos.y, &m_PrevPos.x, &m_PrevPos.y,
+		&m_TeleCheckpoint, &m_LastPenalty,
+		&m_CorePos.x, &m_CorePos.y, &m_Vel.x, &m_Vel.y,
+		&m_ActiveWeapon, &m_Jumped, &m_JumpedTotal, &m_Jumps,
+		&m_HookPos.x, &m_HookPos.y, &m_HookDir.x, &m_HookDir.y,
+		&m_HookTeleBase.x, &m_HookTeleBase.y, &m_HookTick, &m_HookState,
+		// time checkpoints
+		&m_CpTime, &m_CpActive, &m_CpLastBroadcast,
+		&m_aCpCurrent[0], &m_aCpCurrent[1], &m_aCpCurrent[2], &m_aCpCurrent[3], &m_aCpCurrent[4],
+		&m_aCpCurrent[5], &m_aCpCurrent[6], &m_aCpCurrent[7], &m_aCpCurrent[8], &m_aCpCurrent[9],
+		&m_aCpCurrent[10], &m_aCpCurrent[11], &m_aCpCurrent[12], &m_aCpCurrent[13], &m_aCpCurrent[14],
+		&m_aCpCurrent[15], &m_aCpCurrent[16], &m_aCpCurrent[17], &m_aCpCurrent[18], &m_aCpCurrent[19],
+		&m_aCpCurrent[20], &m_aCpCurrent[21], &m_aCpCurrent[22], &m_aCpCurrent[23], &m_aCpCurrent[24],
+		&m_NotEligibleForFinish,
+		&m_HasTelegunGun, &m_HasTelegunLaser, &m_HasTelegunGrenade,
+		&m_HookedPlayer, &m_NewHook,
+		&m_InputDirection, &m_InputJump, &m_InputFire, &m_InputHook,
+		&m_ReloadTimer);
 	switch(Num) // Don't forget to update this when you save / load more / less.
 	{
 	case 96:
@@ -325,6 +365,17 @@ int CSaveTee::LoadString(const char* String)
 		m_HasTelegunGun = 0;
 		// fall through
 	case 100:
+		m_HookedPlayer = -1;
+		m_NewHook = false;
+		if(m_HookState == HOOK_GRABBED)
+			m_HookState = HOOK_FLYING;
+		m_InputDirection = 0;
+		m_InputJump = 0;
+		m_InputFire = 0;
+		m_InputHook = 0;
+		m_ReloadTimer = 0;
+		// fall through
+	case 107:
 		return 0;
 	default:
 		dbg_msg("load", "failed to load tee-string");
@@ -333,7 +384,14 @@ int CSaveTee::LoadString(const char* String)
 	}
 }
 
-CSaveTeam::CSaveTeam(IGameController* Controller)
+void CSaveTee::LoadHookedPlayer(const CSaveTeam *pTeam)
+{
+	if(m_HookedPlayer == -1)
+		return;
+	m_HookedPlayer = pTeam->m_pSavedTees[m_HookedPlayer].GetClientID();
+}
+
+CSaveTeam::CSaveTeam(IGameController *Controller)
 {
 	m_pController = Controller;
 	m_pSwitchers = 0;
@@ -352,7 +410,7 @@ int CSaveTeam::save(int Team)
 {
 	if(g_Config.m_SvTeam == 3 || (Team > 0 && Team < MAX_CLIENTS))
 	{
-		CGameTeams* Teams = &(((CGameControllerDDRace*)m_pController)->m_Teams);
+		CGameTeams *Teams = &(((CGameControllerDDRace *)m_pController)->m_Teams);
 
 		m_MembersCount = Teams->Count(Team);
 		if(m_MembersCount <= 0)
@@ -373,23 +431,24 @@ int CSaveTeam::save(int Team)
 
 		m_pSavedTees = new CSaveTee[m_MembersCount];
 		int j = 0;
-		for (int i = 0; i < MAX_CLIENTS; i++)
+		CCharacter *p = (CCharacter *)m_pController->GameServer()->m_World.FindFirst(CGameWorld::ENTTYPE_CHARACTER);
+		for(; p; p = (CCharacter *)p->TypeNext())
 		{
-			if(Teams->m_Core.Team(i) == Team)
-			{
-				if(m_pController->GameServer()->m_apPlayers[i] && m_pController->GameServer()->m_apPlayers[i]->GetCharacter())
-					m_pSavedTees[j].save(m_pController->GameServer()->m_apPlayers[i]->GetCharacter());
-				else
-					return 3;
-				j++;
-			}
+			if(Teams->m_Core.Team(p->GetPlayer()->GetCID()) != Team)
+				continue;
+			if(m_MembersCount == j)
+				return 3;
+			m_pSavedTees[j].save(p);
+			j++;
 		}
+		if(m_MembersCount != j)
+			return 3;
 
 		if(m_pController->GameServer()->Collision()->m_NumSwitchers)
 		{
-			m_pSwitchers = new SSimpleSwitchers[m_pController->GameServer()->Collision()->m_NumSwitchers+1];
+			m_pSwitchers = new SSimpleSwitchers[m_pController->GameServer()->Collision()->m_NumSwitchers + 1];
 
-			for(int i=1; i < m_pController->GameServer()->Collision()->m_NumSwitchers+1; i++)
+			for(int i = 1; i < m_pController->GameServer()->Collision()->m_NumSwitchers + 1; i++)
 			{
 				m_pSwitchers[i].m_Status = m_pController->GameServer()->Collision()->m_pSwitchers[i].m_Status[Team];
 				if(m_pController->GameServer()->Collision()->m_pSwitchers[i].m_EndTick[Team])
@@ -409,49 +468,49 @@ bool CSaveTeam::HandleSaveError(int Result, int ClientID, CGameContext *pGameCon
 {
 	switch(Result)
 	{
-		case 0:
-			return false;
-		case 1:
-			pGameContext->SendChatTarget(ClientID, "You have to be in a team (from 1-63)");
-			break;
-		case 2:
-			pGameContext->SendChatTarget(ClientID, "Could not find your Team");
-			break;
-		case 3:
-			pGameContext->SendChatTarget(ClientID, "Unable to find all Characters");
-			break;
-		case 4:
-			pGameContext->SendChatTarget(ClientID, "Your team has not started yet");
-			break;
-		default: // this state should never be reached
-			pGameContext->SendChatTarget(ClientID, "Unknown error while saving");
-			break;
+	case 0:
+		return false;
+	case 1:
+		pGameContext->SendChatTarget(ClientID, "You have to be in a team (from 1-63)");
+		break;
+	case 2:
+		pGameContext->SendChatTarget(ClientID, "Could not find your Team");
+		break;
+	case 3:
+		pGameContext->SendChatTarget(ClientID, "Unable to find all Characters");
+		break;
+	case 4:
+		pGameContext->SendChatTarget(ClientID, "Your team has not started yet");
+		break;
+	default: // this state should never be reached
+		pGameContext->SendChatTarget(ClientID, "Unknown error while saving");
+		break;
 	}
 	return true;
 }
 
-void CSaveTeam::load(int Team)
+void CSaveTeam::load(int Team, bool KeepCurrentWeakStrong)
 {
-	CGameTeams* pTeams = &(((CGameControllerDDRace*)m_pController)->m_Teams);
+	CGameTeams *pTeams = &(((CGameControllerDDRace *)m_pController)->m_Teams);
 
 	pTeams->ChangeTeamState(Team, m_TeamState);
 	pTeams->SetTeamLock(Team, m_TeamLocked);
 	if(m_Practice)
 		pTeams->EnablePractice(Team);
 
-	for (int i = 0; i < m_MembersCount; i++)
+	for(int i = m_MembersCount; i-- > 0;)
 	{
 		int ClientID = m_pSavedTees[i].GetClientID();
 		if(m_pController->GameServer()->m_apPlayers[ClientID] && pTeams->m_Core.Team(ClientID) == Team)
 		{
-			CCharacter *pChr = MatchCharacter(m_pSavedTees[i].GetClientID(), i);
+			CCharacter *pChr = MatchCharacter(m_pSavedTees[i].GetClientID(), i, KeepCurrentWeakStrong);
 			m_pSavedTees[i].load(pChr, Team);
 		}
 	}
 
 	if(m_pController->GameServer()->Collision()->m_NumSwitchers)
 	{
-		for(int i=1; i < m_pController->GameServer()->Collision()->m_NumSwitchers+1; i++)
+		for(int i = 1; i < m_pController->GameServer()->Collision()->m_NumSwitchers + 1; i++)
 		{
 			m_pController->GameServer()->Collision()->m_pSwitchers[i].m_Status[Team] = m_pSwitchers[i].m_Status;
 			if(m_pSwitchers[i].m_EndTime)
@@ -461,28 +520,31 @@ void CSaveTeam::load(int Team)
 	}
 }
 
-CCharacter* CSaveTeam::MatchCharacter(int ClientID, int SaveID)
+CCharacter *CSaveTeam::MatchCharacter(int ClientID, int SaveID, bool KeepCurrentCharacter)
 {
-	if(m_pController->GameServer()->m_apPlayers[ClientID]->GetCharacter())
+	if(KeepCurrentCharacter && m_pController->GameServer()->m_apPlayers[ClientID]->GetCharacter())
+	{
+		// keep old character to retain current weak/strong order
 		return m_pController->GameServer()->m_apPlayers[ClientID]->GetCharacter();
-	else
-		return m_pController->GameServer()->m_apPlayers[ClientID]->ForceSpawn(m_pSavedTees[SaveID].GetPos());
+	}
+	m_pController->GameServer()->m_apPlayers[ClientID]->KillCharacter(WEAPON_GAME);
+	return m_pController->GameServer()->m_apPlayers[ClientID]->ForceSpawn(m_pSavedTees[SaveID].GetPos());
 }
 
-char* CSaveTeam::GetString()
+char *CSaveTeam::GetString()
 {
 	str_format(m_aString, sizeof(m_aString), "%d\t%d\t%d\t%d\t%d", m_TeamState, m_MembersCount, m_NumSwitchers, m_TeamLocked, m_Practice);
 
 	for(int i = 0; i < m_MembersCount; i++)
 	{
 		char aBuf[1024];
-		str_format(aBuf, sizeof(aBuf), "\n%s", m_pSavedTees[i].GetString());
+		str_format(aBuf, sizeof(aBuf), "\n%s", m_pSavedTees[i].GetString(this));
 		str_append(m_aString, aBuf, sizeof(m_aString));
 	}
 
 	if(m_pSwitchers && m_NumSwitchers)
 	{
-		for(int i=1; i < m_NumSwitchers+1; i++)
+		for(int i = 1; i < m_NumSwitchers + 1; i++)
 		{
 			char aBuf[64];
 			str_format(aBuf, sizeof(aBuf), "\n%d\t%d\t%d", m_pSwitchers[i].m_Status, m_pSwitchers[i].m_EndTime, m_pSwitchers[i].m_Type);
@@ -493,20 +555,20 @@ char* CSaveTeam::GetString()
 	return m_aString;
 }
 
-int CSaveTeam::LoadString(const char* String)
+int CSaveTeam::FromString(const char *String)
 {
 	char TeamStats[MAX_CLIENTS];
 	char Switcher[64];
 	char SaveTee[1024];
 
-	char* CopyPos;
+	char *CopyPos;
 	unsigned int Pos = 0;
 	unsigned int LastPos = 0;
 	unsigned int StrSize;
 
 	str_copy(m_aString, String, sizeof(m_aString));
 
-	while (m_aString[Pos] != '\n' && Pos < sizeof(m_aString) && m_aString[Pos]) // find next \n or \0
+	while(m_aString[Pos] != '\n' && Pos < sizeof(m_aString) && m_aString[Pos]) // find next \n or \0
 		Pos++;
 
 	CopyPos = m_aString + LastPos;
@@ -529,15 +591,15 @@ int CSaveTeam::LoadString(const char* String)
 		int Num = sscanf(TeamStats, "%d\t%d\t%d\t%d\t%d", &m_TeamState, &m_MembersCount, &m_NumSwitchers, &m_TeamLocked, &m_Practice);
 		switch(Num) // Don't forget to update this when you save / load more / less.
 		{
-			case 4:
-				m_Practice = false;
-				// fallthrough
-			case 5:
-				break;
-			default:
-				dbg_msg("load", "failed to load teamstats");
-				dbg_msg("load", "loaded %d vars", Num);
-				return Num + 1; // never 0 here
+		case 4:
+			m_Practice = false;
+			// fallthrough
+		case 5:
+			break;
+		default:
+			dbg_msg("load", "failed to load teamstats");
+			dbg_msg("load", "loaded %d vars", Num);
+			return Num + 1; // never 0 here
 		}
 	}
 	else
@@ -548,16 +610,16 @@ int CSaveTeam::LoadString(const char* String)
 
 	if(m_pSavedTees)
 	{
-		delete [] m_pSavedTees;
+		delete[] m_pSavedTees;
 		m_pSavedTees = 0;
 	}
 
 	if(m_MembersCount)
 		m_pSavedTees = new CSaveTee[m_MembersCount];
 
-	for (int n = 0; n < m_MembersCount; n++)
+	for(int n = 0; n < m_MembersCount; n++)
 	{
-		while (m_aString[Pos] != '\n' && Pos < sizeof(m_aString) && m_aString[Pos]) // find next \n or \0
+		while(m_aString[Pos] != '\n' && Pos < sizeof(m_aString) && m_aString[Pos]) // find next \n or \0
 			Pos++;
 
 		CopyPos = m_aString + LastPos;
@@ -577,11 +639,11 @@ int CSaveTeam::LoadString(const char* String)
 		if(StrSize < sizeof(SaveTee))
 		{
 			str_copy(SaveTee, CopyPos, StrSize);
-			int Num = m_pSavedTees[n].LoadString(SaveTee);
+			int Num = m_pSavedTees[n].FromString(SaveTee);
 			if(Num)
 			{
 				dbg_msg("load", "failed to load tee");
-				dbg_msg("load", "loaded %d vars", Num-1);
+				dbg_msg("load", "loaded %d vars", Num - 1);
 				return 1;
 			}
 		}
@@ -594,48 +656,48 @@ int CSaveTeam::LoadString(const char* String)
 
 	if(m_pSwitchers)
 	{
-		delete [] m_pSwitchers;
+		delete[] m_pSwitchers;
 		m_pSwitchers = 0;
 	}
 
 	if(m_NumSwitchers)
-		m_pSwitchers = new SSimpleSwitchers[m_NumSwitchers+1];
+		m_pSwitchers = new SSimpleSwitchers[m_NumSwitchers + 1];
 
-	for (int n = 1; n < m_NumSwitchers+1; n++)
+	for(int n = 1; n < m_NumSwitchers + 1; n++)
+	{
+		while(m_aString[Pos] != '\n' && Pos < sizeof(m_aString) && m_aString[Pos]) // find next \n or \0
+			Pos++;
+
+		CopyPos = m_aString + LastPos;
+		StrSize = Pos - LastPos + 1;
+		if(m_aString[Pos] == '\n')
 		{
-			while (m_aString[Pos] != '\n' && Pos < sizeof(m_aString) && m_aString[Pos]) // find next \n or \0
-				Pos++;
+			Pos++; // skip \n
+			LastPos = Pos;
+		}
 
-			CopyPos = m_aString + LastPos;
-			StrSize = Pos - LastPos + 1;
-			if(m_aString[Pos] == '\n')
-			{
-				Pos++; // skip \n
-				LastPos = Pos;
-			}
+		if(StrSize <= 0)
+		{
+			dbg_msg("load", "savegame: wrong format (couldn't load switcher)");
+			return 1;
+		}
 
-			if(StrSize <= 0)
+		if(StrSize < sizeof(Switcher))
+		{
+			str_copy(Switcher, CopyPos, StrSize);
+			int Num = sscanf(Switcher, "%d\t%d\t%d", &(m_pSwitchers[n].m_Status), &(m_pSwitchers[n].m_EndTime), &(m_pSwitchers[n].m_Type));
+			if(Num != 3)
 			{
-				dbg_msg("load", "savegame: wrong format (couldn't load switcher)");
-				return 1;
-			}
-
-			if(StrSize < sizeof(Switcher))
-			{
-				str_copy(Switcher, CopyPos, StrSize);
-				int Num = sscanf(Switcher, "%d\t%d\t%d", &(m_pSwitchers[n].m_Status), &(m_pSwitchers[n].m_EndTime), &(m_pSwitchers[n].m_Type));
-				if(Num != 3)
-				{
-					dbg_msg("load", "failed to load switcher");
-					dbg_msg("load", "loaded %d vars", Num-1);
-				}
-			}
-			else
-			{
-				dbg_msg("load", "savegame: wrong format (couldn't load switcher, too big)");
-				return 1;
+				dbg_msg("load", "failed to load switcher");
+				dbg_msg("load", "loaded %d vars", Num - 1);
 			}
 		}
+		else
+		{
+			dbg_msg("load", "savegame: wrong format (couldn't load switcher, too big)");
+			return 1;
+		}
+	}
 
 	return 0;
 }
@@ -674,6 +736,7 @@ bool CSaveTeam::MatchPlayers(const char (*paNames)[MAX_NAME_LENGTH], const int *
 			{
 				m_pSavedTees[i].SetClientID(pClientID[j]);
 				Found = true;
+				break;
 			}
 		}
 		if(!Found)
@@ -682,5 +745,8 @@ bool CSaveTeam::MatchPlayers(const char (*paNames)[MAX_NAME_LENGTH], const int *
 			return false;
 		}
 	}
+	// match hook to correct ClientID
+	for(int n = 0; n < m_MembersCount; n++)
+		m_pSavedTees[n].LoadHookedPlayer(this);
 	return true;
 }
