@@ -1,11 +1,11 @@
 /* (c) Shereef Marzouk. See "licence DDRace.txt" and the readme.txt in the root of the distribution for more information. */
 #include "teams.h"
-#include "teehistorian.h"
 #include "score.h"
+#include "teehistorian.h"
 #include <engine/shared/config.h>
 
 CGameTeams::CGameTeams(CGameContext *pGameContext) :
-		m_pGameContext(pGameContext)
+	m_pGameContext(pGameContext)
 {
 	Reset();
 }
@@ -13,7 +13,7 @@ CGameTeams::CGameTeams(CGameContext *pGameContext) :
 void CGameTeams::Reset()
 {
 	m_Core.Reset();
-	for (int i = 0; i < MAX_CLIENTS; ++i)
+	for(int i = 0; i < MAX_CLIENTS; ++i)
 	{
 		m_TeamState[i] = TEAMSTATE_EMPTY;
 		m_TeeFinished[i] = false;
@@ -25,16 +25,29 @@ void CGameTeams::Reset()
 	}
 }
 
+void CGameTeams::ResetSwitchers(int Team)
+{
+	if(GameServer()->Collision()->m_NumSwitchers > 0)
+	{
+		for(int i = 0; i < GameServer()->Collision()->m_NumSwitchers + 1; ++i)
+		{
+			GameServer()->Collision()->m_pSwitchers[i].m_Status[Team] = GameServer()->Collision()->m_pSwitchers[i].m_Initial;
+			GameServer()->Collision()->m_pSwitchers[i].m_EndTick[Team] = 0;
+			GameServer()->Collision()->m_pSwitchers[i].m_Type[Team] = TILE_SWITCHOPEN;
+		}
+	}
+}
+
 void CGameTeams::OnCharacterStart(int ClientID)
 {
 	int Tick = Server()->Tick();
-	CCharacter* pStartingChar = Character(ClientID);
+	CCharacter *pStartingChar = Character(ClientID);
 	if(!pStartingChar)
 		return;
-	if(m_Core.Team(ClientID) != TEAM_FLOCK && pStartingChar->m_DDRaceState == DDRACE_FINISHED)
+	if((g_Config.m_SvTeam == 3 || m_Core.Team(ClientID) != TEAM_FLOCK) && pStartingChar->m_DDRaceState == DDRACE_FINISHED)
 		return;
-	if(m_Core.Team(ClientID) == TEAM_FLOCK
-			|| m_Core.Team(ClientID) == TEAM_SUPER)
+	if(g_Config.m_SvTeam != 3 &&
+		(m_Core.Team(ClientID) == TEAM_FLOCK || m_Core.Team(ClientID) == TEAM_SUPER))
 	{
 		pStartingChar->m_DDRaceState = DDRACE_STARTED;
 		pStartingChar->m_StartTime = Tick;
@@ -45,7 +58,7 @@ void CGameTeams::OnCharacterStart(int ClientID)
 	{
 		if(m_Core.Team(ClientID) != m_Core.Team(i))
 			continue;
-		CPlayer* pPlayer = GetPlayer(i);
+		CPlayer *pPlayer = GetPlayer(i);
 		if(!pPlayer || !pPlayer->IsPlaying())
 			continue;
 		if(GetDDRaceState(pPlayer) != DDRACE_FINISHED)
@@ -54,27 +67,25 @@ void CGameTeams::OnCharacterStart(int ClientID)
 		Waiting = true;
 		pStartingChar->m_DDRaceState = DDRACE_NONE;
 
-		if(m_LastChat[ClientID] + Server()->TickSpeed()
-				+ g_Config.m_SvChatDelay < Tick)
+		if(m_LastChat[ClientID] + Server()->TickSpeed() + g_Config.m_SvChatDelay < Tick)
 		{
 			char aBuf[128];
 			str_format(
-					aBuf,
-					sizeof(aBuf),
-					"%s has finished and didn't go through start yet, wait for him or join another team.",
-					Server()->ClientName(i));
+				aBuf,
+				sizeof(aBuf),
+				"%s has finished and didn't go through start yet, wait for him or join another team.",
+				Server()->ClientName(i));
 			GameServer()->SendChatTarget(ClientID, aBuf);
 			m_LastChat[ClientID] = Tick;
 		}
-		if(m_LastChat[i] + Server()->TickSpeed()
-				+ g_Config.m_SvChatDelay < Tick)
+		if(m_LastChat[i] + Server()->TickSpeed() + g_Config.m_SvChatDelay < Tick)
 		{
 			char aBuf[128];
 			str_format(
-					aBuf,
-					sizeof(aBuf),
-					"%s wants to start a new round, kill or walk to start.",
-					Server()->ClientName(ClientID));
+				aBuf,
+				sizeof(aBuf),
+				"%s wants to start a new round, kill or walk to start.",
+				Server()->ClientName(ClientID));
 			GameServer()->SendChatTarget(i, aBuf);
 			m_LastChat[i] = Tick;
 		}
@@ -88,13 +99,12 @@ void CGameTeams::OnCharacterStart(int ClientID)
 
 		char aBuf[512];
 		str_format(
-				aBuf,
-				sizeof(aBuf),
-				"Team %d started with %d player%s: ",
-				m_Core.Team(ClientID),
-				NumPlayers,
-				NumPlayers == 1 ? "" : "s");
-
+			aBuf,
+			sizeof(aBuf),
+			"Team %d started with %d player%s: ",
+			m_Core.Team(ClientID),
+			NumPlayers,
+			NumPlayers == 1 ? "" : "s");
 
 		bool First = true;
 
@@ -102,7 +112,7 @@ void CGameTeams::OnCharacterStart(int ClientID)
 		{
 			if(m_Core.Team(ClientID) == m_Core.Team(i))
 			{
-				CPlayer* pPlayer = GetPlayer(i);
+				CPlayer *pPlayer = GetPlayer(i);
 				// TODO: THE PROBLEM IS THAT THERE IS NO CHARACTER SO START TIME CAN'T BE SET!
 				if(pPlayer && (pPlayer->IsPlaying() || TeamLocked(m_Core.Team(ClientID))))
 				{
@@ -123,7 +133,7 @@ void CGameTeams::OnCharacterStart(int ClientID)
 		{
 			for(int i = 0; i < MAX_CLIENTS; ++i)
 			{
-				CPlayer* pPlayer = GetPlayer(i);
+				CPlayer *pPlayer = GetPlayer(i);
 				if(m_Core.Team(ClientID) == m_Core.Team(i) && pPlayer && (pPlayer->IsPlaying() || TeamLocked(m_Core.Team(ClientID))))
 				{
 					GameServer()->SendChatTarget(i, aBuf);
@@ -135,15 +145,13 @@ void CGameTeams::OnCharacterStart(int ClientID)
 
 void CGameTeams::OnCharacterFinish(int ClientID)
 {
-	if (m_Core.Team(ClientID) == TEAM_FLOCK
-			|| m_Core.Team(ClientID) == TEAM_SUPER)
+	if((m_Core.Team(ClientID) == TEAM_FLOCK && g_Config.m_SvTeam != 3) || m_Core.Team(ClientID) == TEAM_SUPER)
 	{
-		CPlayer* pPlayer = GetPlayer(ClientID);
-		if (pPlayer && pPlayer->IsPlaying())
+		CPlayer *pPlayer = GetPlayer(ClientID);
+		if(pPlayer && pPlayer->IsPlaying())
 		{
-			float Time = (float)(Server()->Tick() - GetStartTime(pPlayer))
-					/ ((float)Server()->TickSpeed());
-			if (Time < 0.000001f)
+			float Time = (float)(Server()->Tick() - GetStartTime(pPlayer)) / ((float)Server()->TickSpeed());
+			if(Time < 0.000001f)
 				return;
 			char aTimestamp[TIMESTAMP_STR_LENGTH];
 			str_timestamp_format(aTimestamp, sizeof(aTimestamp), FORMAT_SPACE); // 2019-04-02 19:41:58
@@ -161,17 +169,17 @@ void CGameTeams::OnCharacterFinish(int ClientID)
 
 void CGameTeams::CheckTeamFinished(int Team)
 {
-	if (TeamFinished(Team))
+	if(TeamFinished(Team))
 	{
 		CPlayer *TeamPlayers[MAX_CLIENTS];
 		unsigned int PlayersCount = 0;
 
-		for (int i = 0; i < MAX_CLIENTS; ++i)
+		for(int i = 0; i < MAX_CLIENTS; ++i)
 		{
-			if (Team == m_Core.Team(i))
+			if(Team == m_Core.Team(i))
 			{
-				CPlayer* pPlayer = GetPlayer(i);
-				if (pPlayer && pPlayer->IsPlaying())
+				CPlayer *pPlayer = GetPlayer(i);
+				if(pPlayer && pPlayer->IsPlaying())
 				{
 					m_TeeFinished[i] = false;
 
@@ -180,11 +188,10 @@ void CGameTeams::CheckTeamFinished(int Team)
 			}
 		}
 
-		if (PlayersCount > 0)
+		if(PlayersCount > 0)
 		{
-			float Time = (float)(Server()->Tick() - GetStartTime(TeamPlayers[0]))
-					/ ((float)Server()->TickSpeed());
-			if (Time < 0.000001f)
+			float Time = (float)(Server()->Tick() - GetStartTime(TeamPlayers[0])) / ((float)Server()->TickSpeed());
+			if(Time < 0.000001f)
 			{
 				return;
 			}
@@ -217,7 +224,7 @@ void CGameTeams::CheckTeamFinished(int Team)
 			char aTimestamp[TIMESTAMP_STR_LENGTH];
 			str_timestamp_format(aTimestamp, sizeof(aTimestamp), FORMAT_SPACE); // 2019-04-02 19:41:58
 
-			for (unsigned int i = 0; i < PlayersCount; ++i)
+			for(unsigned int i = 0; i < PlayersCount; ++i)
 				OnFinish(TeamPlayers[i], Time, aTimestamp);
 			ChangeTeamState(Team, TEAMSTATE_FINISHED); //TODO: Make it better
 			//ChangeTeamState(Team, TEAMSTATE_OPEN);
@@ -229,31 +236,29 @@ void CGameTeams::CheckTeamFinished(int Team)
 bool CGameTeams::SetCharacterTeam(int ClientID, int Team)
 {
 	//Check on wrong parameters. +1 for TEAM_SUPER
-	if (ClientID < 0 || ClientID >= MAX_CLIENTS || Team < 0
-			|| Team >= MAX_CLIENTS + 1)
+	if(ClientID < 0 || ClientID >= MAX_CLIENTS || Team < 0 || Team >= MAX_CLIENTS + 1)
 		return false;
 	//You can join to TEAM_SUPER at any time, but any other group you cannot if it started
-	if (Team != TEAM_SUPER && m_TeamState[Team] > TEAMSTATE_OPEN)
+	if(Team != TEAM_SUPER && m_TeamState[Team] > TEAMSTATE_OPEN)
 		return false;
 	//No need to switch team if you there
-	if (m_Core.Team(ClientID) == Team)
+	if(m_Core.Team(ClientID) == Team)
 		return false;
-	if (!Character(ClientID))
+	if(!Character(ClientID))
 		return false;
 	//You cannot be in TEAM_SUPER if you not super
-	if (Team == TEAM_SUPER && !Character(ClientID)->m_Super)
+	if(Team == TEAM_SUPER && !Character(ClientID)->m_Super)
 		return false;
 	//if you begin race
-	if (Character(ClientID)->m_DDRaceState != DDRACE_NONE && Team != TEAM_SUPER)
+	if(Character(ClientID)->m_DDRaceState != DDRACE_NONE && Team != TEAM_SUPER)
 		return false;
 	//No cheating through noob filter with practice and then leaving team
-	if (m_Practice[m_Core.Team(ClientID)])
+	if(m_Practice[m_Core.Team(ClientID)])
 		return false;
 
 	//you can not join a team which is currently in the process of saving,
 	//because the save-process can fail and then the team is reset into the game
-	if((Team != TEAM_SUPER && GetSaving(Team))
-			|| (m_Core.Team(ClientID) != TEAM_SUPER && GetSaving(m_Core.Team(ClientID))))
+	if((Team != TEAM_SUPER && GetSaving(Team)) || (m_Core.Team(ClientID) != TEAM_SUPER && GetSaving(m_Core.Team(ClientID))))
 		return false;
 	SetForceCharacterTeam(ClientID, Team);
 
@@ -263,7 +268,7 @@ bool CGameTeams::SetCharacterTeam(int ClientID, int Team)
 
 void CGameTeams::SetForceCharacterTeam(int ClientID, int Team)
 {
-	if (Team != m_Core.Team(ClientID))
+	if(Team != m_Core.Team(ClientID))
 		ForceLeaveTeam(ClientID);
 	else
 		m_TeeFinished[ClientID] = false;
@@ -272,7 +277,7 @@ void CGameTeams::SetForceCharacterTeam(int ClientID, int Team)
 
 	m_Core.Team(ClientID, Team);
 
-	if (OldTeam != Team)
+	if(OldTeam != Team)
 	{
 		for(int LoopClientID = 0; LoopClientID < MAX_CLIENTS; ++LoopClientID)
 			if(GetPlayer(LoopClientID))
@@ -282,19 +287,12 @@ void CGameTeams::SetForceCharacterTeam(int ClientID, int Team)
 			GetPlayer(ClientID)->m_VotedForPractice = false;
 	}
 
-	if (Team != TEAM_SUPER && (m_TeamState[Team] == TEAMSTATE_EMPTY || m_TeamLocked[Team]))
+	if(Team != TEAM_SUPER && (m_TeamState[Team] == TEAMSTATE_EMPTY || m_TeamLocked[Team]))
 	{
-		if (!m_TeamLocked[Team])
+		if(!m_TeamLocked[Team])
 			ChangeTeamState(Team, TEAMSTATE_OPEN);
 
-		if (GameServer()->Collision()->m_NumSwitchers > 0) {
-			for (int i = 0; i < GameServer()->Collision()->m_NumSwitchers+1; ++i)
-			{
-				GameServer()->Collision()->m_pSwitchers[i].m_Status[Team] = GameServer()->Collision()->m_pSwitchers[i].m_Initial;
-				GameServer()->Collision()->m_pSwitchers[i].m_EndTick[Team] = 0;
-				GameServer()->Collision()->m_pSwitchers[i].m_Type[Team] = TILE_SWITCHOPEN;
-			}
-		}
+		ResetSwitchers(Team);
 	}
 }
 
@@ -302,18 +300,16 @@ void CGameTeams::ForceLeaveTeam(int ClientID)
 {
 	m_TeeFinished[ClientID] = false;
 
-	if (m_Core.Team(ClientID) != TEAM_FLOCK
-			&& m_Core.Team(ClientID) != TEAM_SUPER
-			&& m_TeamState[m_Core.Team(ClientID)] != TEAMSTATE_EMPTY)
+	if((m_Core.Team(ClientID) != TEAM_FLOCK || g_Config.m_SvTeam == 3) && m_Core.Team(ClientID) != TEAM_SUPER && m_TeamState[m_Core.Team(ClientID)] != TEAMSTATE_EMPTY)
 	{
 		bool NoOneInOldTeam = true;
-		for (int i = 0; i < MAX_CLIENTS; ++i)
-			if (i != ClientID && m_Core.Team(ClientID) == m_Core.Team(i))
+		for(int i = 0; i < MAX_CLIENTS; ++i)
+			if(i != ClientID && m_Core.Team(ClientID) == m_Core.Team(i))
 			{
 				NoOneInOldTeam = false; //all good exists someone in old team
 				break;
 			}
-		if (NoOneInOldTeam)
+		if(NoOneInOldTeam)
 		{
 			m_TeamState[m_Core.Team(ClientID)] = TEAMSTATE_EMPTY;
 
@@ -328,13 +324,13 @@ void CGameTeams::ForceLeaveTeam(int ClientID)
 
 int CGameTeams::Count(int Team) const
 {
-	if (Team == TEAM_SUPER)
+	if(Team == TEAM_SUPER)
 		return -1;
 
 	int Count = 0;
 
-	for (int i = 0; i < MAX_CLIENTS; ++i)
-		if (m_Core.Team(i) == Team)
+	for(int i = 0; i < MAX_CLIENTS; ++i)
+		if(m_Core.Team(i) == Team)
 			Count++;
 
 	return Count;
@@ -349,11 +345,11 @@ void CGameTeams::ChangeTeamState(int Team, int State)
 
 void CGameTeams::onChangeTeamState(int Team, int State, int OldState)
 {
-	if (OldState != State && State == TEAMSTATE_STARTED)
+	if(OldState != State && State == TEAMSTATE_STARTED)
 	{
 		// OnTeamStateStarting
 	}
-	if (OldState != State && State == TEAMSTATE_FINISHED)
+	if(OldState != State && State == TEAMSTATE_FINISHED)
 	{
 		// OnTeamStateFinishing
 	}
@@ -361,62 +357,72 @@ void CGameTeams::onChangeTeamState(int Team, int State, int OldState)
 
 bool CGameTeams::TeamFinished(int Team)
 {
-	for (int i = 0; i < MAX_CLIENTS; ++i)
-		if (m_Core.Team(i) == Team && !m_TeeFinished[i])
+	for(int i = 0; i < MAX_CLIENTS; ++i)
+		if(m_Core.Team(i) == Team && !m_TeeFinished[i])
 			return false;
 	return true;
 }
 
-int64_t CGameTeams::TeamMask(int Team, int ExceptID, int Asker)
+int64 CGameTeams::TeamMask(int Team, int ExceptID, int Asker)
 {
-	int64_t Mask = 0;
+	int64 Mask = 0;
 
-	for (int i = 0; i < MAX_CLIENTS; ++i)
+	for(int i = 0; i < MAX_CLIENTS; ++i)
 	{
-		if (i == ExceptID)
+		if(i == ExceptID)
 			continue; // Explicitly excluded
-		if (!GetPlayer(i))
+		if(!GetPlayer(i))
 			continue; // Player doesn't exist
 
-		if (!(GetPlayer(i)->GetTeam() == -1 || GetPlayer(i)->IsPaused()))
+		if(!(GetPlayer(i)->GetTeam() == -1 || GetPlayer(i)->IsPaused()))
 		{ // Not spectator
-			if (i != Asker)
+			if(i != Asker)
 			{ // Actions of other players
-				if (!Character(i))
+				if(!Character(i))
 					continue; // Player is currently dead
-				if (!GetPlayer(i)->m_ShowOthers)
+				if(GetPlayer(i)->m_ShowOthers == 2)
 				{
-					if (m_Core.GetSolo(Asker))
-						continue; // When in solo part don't show others
-					if (m_Core.GetSolo(i))
-						continue; // When in solo part don't show others
-					if (m_Core.Team(i) != Team && m_Core.Team(i) != TEAM_SUPER)
+					if(m_Core.Team(i) != Team && m_Core.Team(i) != TEAM_SUPER)
 						continue; // In different teams
-				} // ShowOthers
+				}
+				else if(GetPlayer(i)->m_ShowOthers == 0)
+				{
+					if(m_Core.GetSolo(Asker))
+						continue; // When in solo part don't show others
+					if(m_Core.GetSolo(i))
+						continue; // When in solo part don't show others
+					if(m_Core.Team(i) != Team && m_Core.Team(i) != TEAM_SUPER)
+						continue; // In different teams
+				}
 			} // See everything of yourself
 		}
-		else if (GetPlayer(i)->m_SpectatorID != SPEC_FREEVIEW)
+		else if(GetPlayer(i)->m_SpectatorID != SPEC_FREEVIEW)
 		{ // Spectating specific player
-			if (GetPlayer(i)->m_SpectatorID != Asker)
+			if(GetPlayer(i)->m_SpectatorID != Asker)
 			{ // Actions of other players
-				if (!Character(GetPlayer(i)->m_SpectatorID))
+				if(!Character(GetPlayer(i)->m_SpectatorID))
 					continue; // Player is currently dead
-				if (!GetPlayer(i)->m_ShowOthers)
+				if(GetPlayer(i)->m_ShowOthers == 2)
 				{
-					if (m_Core.GetSolo(Asker))
-						continue; // When in solo part don't show others
-					if (m_Core.GetSolo(GetPlayer(i)->m_SpectatorID))
-						continue; // When in solo part don't show others
-					if (m_Core.Team(GetPlayer(i)->m_SpectatorID) != Team && m_Core.Team(GetPlayer(i)->m_SpectatorID) != TEAM_SUPER)
+					if(m_Core.Team(GetPlayer(i)->m_SpectatorID) != Team && m_Core.Team(GetPlayer(i)->m_SpectatorID) != TEAM_SUPER)
 						continue; // In different teams
-				} // ShowOthers
+				}
+				else if(GetPlayer(i)->m_ShowOthers == 0)
+				{
+					if(m_Core.GetSolo(Asker))
+						continue; // When in solo part don't show others
+					if(m_Core.GetSolo(GetPlayer(i)->m_SpectatorID))
+						continue; // When in solo part don't show others
+					if(m_Core.Team(GetPlayer(i)->m_SpectatorID) != Team && m_Core.Team(GetPlayer(i)->m_SpectatorID) != TEAM_SUPER)
+						continue; // In different teams
+				}
 			} // See everything of player you're spectating
 		}
 		else
 		{ // Freeview
-			if (GetPlayer(i)->m_SpecTeam)
+			if(GetPlayer(i)->m_SpecTeam)
 			{ // Show only players in own team when spectating
-				if (m_Core.Team(i) != Team && m_Core.Team(i) != TEAM_SUPER)
+				if(m_Core.Team(i) != Team && m_Core.Team(i) != TEAM_SUPER)
 					continue; // in different teams
 			}
 		}
@@ -428,10 +434,10 @@ int64_t CGameTeams::TeamMask(int Team, int ExceptID, int Asker)
 
 void CGameTeams::SendTeamsState(int ClientID)
 {
-	if (g_Config.m_SvTeam == 3)
+	if(g_Config.m_SvTeam == 3)
 		return;
 
-	if (!m_pGameContext->m_apPlayers[ClientID] || m_pGameContext->m_apPlayers[ClientID]->GetClientVersion() <= VERSION_DDRACE)
+	if(!m_pGameContext->m_apPlayers[ClientID] || m_pGameContext->m_apPlayers[ClientID]->GetClientVersion() <= VERSION_DDRACE)
 		return;
 
 	CMsgPacker Msg(NETMSGTYPE_SV_TEAMSSTATE);
@@ -442,70 +448,70 @@ void CGameTeams::SendTeamsState(int ClientID)
 	Server()->SendMsg(&Msg, MSGFLAG_VITAL, ClientID);
 }
 
-int CGameTeams::GetDDRaceState(CPlayer* Player)
+int CGameTeams::GetDDRaceState(CPlayer *Player)
 {
-	if (!Player)
+	if(!Player)
 		return DDRACE_NONE;
 
-	CCharacter* pChar = Player->GetCharacter();
-	if (pChar)
+	CCharacter *pChar = Player->GetCharacter();
+	if(pChar)
 		return pChar->m_DDRaceState;
 	return DDRACE_NONE;
 }
 
-void CGameTeams::SetDDRaceState(CPlayer* Player, int DDRaceState)
+void CGameTeams::SetDDRaceState(CPlayer *Player, int DDRaceState)
 {
-	if (!Player)
+	if(!Player)
 		return;
 
-	CCharacter* pChar = Player->GetCharacter();
-	if (pChar)
+	CCharacter *pChar = Player->GetCharacter();
+	if(pChar)
 		pChar->m_DDRaceState = DDRaceState;
 }
 
-int CGameTeams::GetStartTime(CPlayer* Player)
+int CGameTeams::GetStartTime(CPlayer *Player)
 {
-	if (!Player)
+	if(!Player)
 		return 0;
 
-	CCharacter* pChar = Player->GetCharacter();
-	if (pChar)
+	CCharacter *pChar = Player->GetCharacter();
+	if(pChar)
 		return pChar->m_StartTime;
 	return 0;
 }
 
-void CGameTeams::SetStartTime(CPlayer* Player, int StartTime)
+void CGameTeams::SetStartTime(CPlayer *Player, int StartTime)
 {
-	if (!Player)
+	if(!Player)
 		return;
 
-	CCharacter* pChar = Player->GetCharacter();
-	if (pChar)
+	CCharacter *pChar = Player->GetCharacter();
+	if(pChar)
 		pChar->m_StartTime = StartTime;
 }
 
-void CGameTeams::SetCpActive(CPlayer* Player, int CpActive)
+void CGameTeams::SetCpActive(CPlayer *Player, int CpActive)
 {
-	if (!Player)
+	if(!Player)
 		return;
 
-	CCharacter* pChar = Player->GetCharacter();
-	if (pChar)
+	CCharacter *pChar = Player->GetCharacter();
+	if(pChar)
 		pChar->m_CpActive = CpActive;
 }
 
-float *CGameTeams::GetCpCurrent(CPlayer* Player)
+float *CGameTeams::GetCpCurrent(CPlayer *Player)
 {
-	if (!Player)
+	if(!Player)
 		return NULL;
 
-	CCharacter* pChar = Player->GetCharacter();
-	if (pChar)
+	CCharacter *pChar = Player->GetCharacter();
+	if(pChar)
 		return pChar->m_CpCurrent;
 	return NULL;
 }
 
-void CGameTeams::OnTeamFinish(CPlayer** Players, unsigned int Size, float Time, const char *pTimestamp)
+void CGameTeams::OnTeamFinish(CPlayer **Players, unsigned int Size, float Time, const char *pTimestamp)
 {
 	int PlayerCIDs[MAX_CLIENTS];
 
@@ -515,21 +521,21 @@ void CGameTeams::OnTeamFinish(CPlayer** Players, unsigned int Size, float Time,
 
 		if(g_Config.m_SvRejoinTeam0 && g_Config.m_SvTeam != 3 && (m_Core.Team(Players[i]->GetCID()) >= TEAM_SUPER || !m_TeamLocked[m_Core.Team(Players[i]->GetCID())]))
 		{
-			SetForceCharacterTeam(Players[i]->GetCID(), 0);
+			SetForceCharacterTeam(Players[i]->GetCID(), TEAM_FLOCK);
 			char aBuf[512];
 			str_format(aBuf, sizeof(aBuf), "%s joined team 0",
-					GameServer()->Server()->ClientName(Players[i]->GetCID()));
+				GameServer()->Server()->ClientName(Players[i]->GetCID()));
 			GameServer()->SendChat(-1, CGameContext::CHAT_ALL, aBuf);
 		}
 	}
 
-	if (Size >= 2)
+	if(Size >= 2)
 		GameServer()->Score()->SaveTeamScore(PlayerCIDs, Size, Time, pTimestamp);
 }
 
-void CGameTeams::OnFinish(CPlayer* Player, float Time, const char *pTimestamp)
+void CGameTeams::OnFinish(CPlayer *Player, float Time, const char *pTimestamp)
 {
-	if (!Player || !Player->IsPlaying())
+	if(!Player || !Player->IsPlaying())
 		return;
 	//TODO:DDRace:btd: this ugly
 	const int ClientID = Player->GetCID();
@@ -538,50 +544,50 @@ void CGameTeams::OnFinish(CPlayer* Player, float Time, const char *pTimestamp)
 	char aBuf[128];
 	SetCpActive(Player, -2);
 	str_format(aBuf, sizeof(aBuf),
-			"%s finished in: %d minute(s) %5.2f second(s)",
-			Server()->ClientName(ClientID), (int)Time / 60,
-			Time - ((int)Time / 60 * 60));
-	if (g_Config.m_SvHideScore || !g_Config.m_SvSaveWorseScores)
+		"%s finished in: %d minute(s) %5.2f second(s)",
+		Server()->ClientName(ClientID), (int)Time / 60,
+		Time - ((int)Time / 60 * 60));
+	if(g_Config.m_SvHideScore || !g_Config.m_SvSaveWorseScores)
 		GameServer()->SendChatTarget(ClientID, aBuf, CGameContext::CHAT_SIX);
 	else
 		GameServer()->SendChat(-1, CGameContext::CHAT_ALL, aBuf, -1., CGameContext::CHAT_SIX);
 
 	float Diff = fabs(Time - pData->m_BestTime);
 
-	if (Time - pData->m_BestTime < 0)
+	if(Time - pData->m_BestTime < 0)
 	{
 		// new record \o/
 		Server()->SaveDemo(ClientID, Time);
 
-		if (Diff >= 60)
+		if(Diff >= 60)
 			str_format(aBuf, sizeof(aBuf), "New record: %d minute(s) %5.2f second(s) better.",
-					(int)Diff / 60, Diff - ((int)Diff / 60 * 60));
+				(int)Diff / 60, Diff - ((int)Diff / 60 * 60));
 		else
 			str_format(aBuf, sizeof(aBuf), "New record: %5.2f second(s) better.",
-					Diff);
-		if (g_Config.m_SvHideScore || !g_Config.m_SvSaveWorseScores)
+				Diff);
+		if(g_Config.m_SvHideScore || !g_Config.m_SvSaveWorseScores)
 			GameServer()->SendChatTarget(ClientID, aBuf, CGameContext::CHAT_SIX);
 		else
 			GameServer()->SendChat(-1, CGameContext::CHAT_ALL, aBuf, CGameContext::CHAT_SIX);
 	}
-	else if (pData->m_BestTime != 0) // tee has already finished?
+	else if(pData->m_BestTime != 0) // tee has already finished?
 	{
 		Server()->StopRecord(ClientID);
 
-		if (Diff <= 0.005f)
+		if(Diff <= 0.005f)
 		{
 			GameServer()->SendChatTarget(ClientID,
-					"You finished with your best time.");
+				"You finished with your best time.");
 		}
 		else
 		{
-			if (Diff >= 60)
+			if(Diff >= 60)
 				str_format(aBuf, sizeof(aBuf), "%d minute(s) %5.2f second(s) worse, better luck next time.",
-						(int)Diff / 60, Diff - ((int)Diff / 60 * 60));
+					(int)Diff / 60, Diff - ((int)Diff / 60 * 60));
 			else
 				str_format(aBuf, sizeof(aBuf),
-						"%5.2f second(s) worse, better luck next time.",
-						Diff);
+					"%5.2f second(s) worse, better luck next time.",
+					Diff);
 			GameServer()->SendChatTarget(ClientID, aBuf, CGameContext::CHAT_SIX); //this is private, sent only to the tee
 		}
 	}
@@ -592,25 +598,24 @@ void CGameTeams::OnFinish(CPlayer* Player, float Time, const char *pTimestamp)
 
 	bool CallSaveScore = g_Config.m_SvSaveWorseScores;
 
-	if (!pData->m_BestTime || Time < pData->m_BestTime)
+	if(!pData->m_BestTime || Time < pData->m_BestTime)
 	{
 		// update the score
 		pData->Set(Time, GetCpCurrent(Player));
 		CallSaveScore = true;
 	}
 
-	if (CallSaveScore)
-		if (g_Config.m_SvNamelessScore || !str_startswith(Server()->ClientName(ClientID), "nameless tee"))
+	if(CallSaveScore)
+		if(g_Config.m_SvNamelessScore || !str_startswith(Server()->ClientName(ClientID), "nameless tee"))
 			GameServer()->Score()->SaveScore(ClientID, Time, pTimestamp,
-					GetCpCurrent(Player), Player->m_NotEligibleForFinish);
+				GetCpCurrent(Player), Player->m_NotEligibleForFinish);
 
 	bool NeedToSendNewRecord = false;
 	// update server best time
-	if (GameServer()->m_pController->m_CurrentRecord == 0
-			|| Time < GameServer()->m_pController->m_CurrentRecord)
+	if(GameServer()->m_pController->m_CurrentRecord == 0 || Time < GameServer()->m_pController->m_CurrentRecord)
 	{
 		// check for nameless
-		if (g_Config.m_SvNamelessScore || !str_startswith(Server()->ClientName(ClientID), "nameless tee"))
+		if(g_Config.m_SvNamelessScore || !str_startswith(Server()->ClientName(ClientID), "nameless tee"))
 		{
 			GameServer()->m_pController->m_CurrentRecord = Time;
 			//dbg_msg("character", "Finish");
@@ -620,32 +625,31 @@ void CGameTeams::OnFinish(CPlayer* Player, float Time, const char *pTimestamp)
 
 	SetDDRaceState(Player, DDRACE_FINISHED);
 	// set player score
-	if (!pData->m_CurrentTime || pData->m_CurrentTime > Time)
+	if(!pData->m_CurrentTime || pData->m_CurrentTime > Time)
 	{
 		pData->m_CurrentTime = Time;
 		NeedToSendNewRecord = true;
 	}
 
-	if (NeedToSendNewRecord && Player->GetClientVersion() >= VERSION_DDRACE)
+	if(NeedToSendNewRecord && Player->GetClientVersion() >= VERSION_DDRACE)
 	{
-		for (int i = 0; i < MAX_CLIENTS; i++)
+		for(int i = 0; i < MAX_CLIENTS; i++)
 		{
-			if (GameServer()->m_apPlayers[i]
-					&& GameServer()->m_apPlayers[i]->GetClientVersion() >= VERSION_DDRACE)
+			if(GameServer()->m_apPlayers[i] && GameServer()->m_apPlayers[i]->GetClientVersion() >= VERSION_DDRACE)
 			{
 				GameServer()->SendRecord(i);
 			}
 		}
 	}
 
-	if (Player->GetClientVersion() >= VERSION_DDRACE)
+	if(Player->GetClientVersion() >= VERSION_DDRACE)
 	{
 		CNetMsg_Sv_DDRaceTime Msg;
 		Msg.m_Time = (int)(Time * 100.0f);
 		Msg.m_Check = 0;
 		Msg.m_Finish = 1;
 
-		if (pData->m_BestTime)
+		if(pData->m_BestTime)
 		{
 			float Diff = (Time - pData->m_BestTime) * 100;
 			Msg.m_Check = (int)Diff;
@@ -661,11 +665,11 @@ void CGameTeams::OnFinish(CPlayer* Player, float Time, const char *pTimestamp)
 		Msg.m_Diff = Diff * 1000 * (Time < pData->m_BestTime ? -1 : 1);
 		Msg.m_RecordPersonal = Time < pData->m_BestTime;
 		Msg.m_RecordServer = Time < GameServer()->m_pController->m_CurrentRecord;
-		Server()->SendPackMsg(&Msg, MSGFLAG_VITAL|MSGFLAG_NORECORD, -1);
+		Server()->SendPackMsg(&Msg, MSGFLAG_VITAL | MSGFLAG_NORECORD, -1);
 	}
 
 	int TTime = 0 - (int)Time;
-	if (Player->m_Score < TTime || !Player->m_HasFinishScore)
+	if(Player->m_Score < TTime || !Player->m_HasFinishScore)
 	{
 		Player->m_Score = TTime;
 		Player->m_HasFinishScore = true;
@@ -689,9 +693,9 @@ void CGameTeams::ProcessSaveTeam()
 			if(GameServer()->TeeHistorianActive())
 			{
 				GameServer()->TeeHistorian()->RecordTeamSaveSuccess(
-						Team,
-						m_pSaveTeamResult[Team]->m_SaveID,
-						m_pSaveTeamResult[Team]->m_SavedTeam.GetString());
+					Team,
+					m_pSaveTeamResult[Team]->m_SaveID,
+					m_pSaveTeamResult[Team]->m_SavedTeam.GetString());
 			}
 			ResetSavedTeam(m_pSaveTeamResult[Team]->m_RequestingPlayer, Team);
 			char aSaveID[UUID_MAXSTRSIZE];
@@ -703,19 +707,25 @@ void CGameTeams::ProcessSaveTeam()
 			if(GameServer()->TeeHistorianActive())
 				GameServer()->TeeHistorian()->RecordTeamSaveFailure(Team);
 			if(Count(Team) > 0)
-				m_pSaveTeamResult[Team]->m_SavedTeam.load(Team);
+			{
+				// load weak/strong order to prevent switching weak/strong while saving
+				m_pSaveTeamResult[Team]->m_SavedTeam.load(Team, false);
+			}
 			break;
 		case CScoreSaveResult::LOAD_SUCCESS:
 		{
 			if(GameServer()->TeeHistorianActive())
 			{
 				GameServer()->TeeHistorian()->RecordTeamLoadSuccess(
-						Team,
-						m_pSaveTeamResult[Team]->m_SaveID,
-						m_pSaveTeamResult[Team]->m_SavedTeam.GetString());
+					Team,
+					m_pSaveTeamResult[Team]->m_SaveID,
+					m_pSaveTeamResult[Team]->m_SavedTeam.GetString());
 			}
 			if(Count(Team) > 0)
-				m_pSaveTeamResult[Team]->m_SavedTeam.load(Team);
+			{
+				// keep current weak/strong order as on some maps there is no other way of switching
+				m_pSaveTeamResult[Team]->m_SavedTeam.load(Team, true);
+			}
 			char aSaveID[UUID_MAXSTRSIZE];
 			FormatUuid(m_pSaveTeamResult[Team]->m_SaveID, aSaveID, UUID_MAXSTRSIZE);
 			dbg_msg("save", "Load successful: %s", aSaveID);
@@ -740,9 +750,12 @@ void CGameTeams::OnCharacterSpawn(int ClientID)
 	if(GetSaving(Team))
 		return;
 
-	if (m_Core.Team(ClientID) >= TEAM_SUPER || !m_TeamLocked[Team])
+	if(m_Core.Team(ClientID) >= TEAM_SUPER || !m_TeamLocked[Team])
 	{
-		SetForceCharacterTeam(ClientID, 0);
+		if(g_Config.m_SvTeam != 3)
+			SetForceCharacterTeam(ClientID, TEAM_FLOCK);
+		else
+			SetForceCharacterTeam(ClientID, ClientID); // initialize team
 		CheckTeamFinished(Team);
 	}
 }
@@ -756,12 +769,14 @@ void CGameTeams::OnCharacterDeath(int ClientID, int Weapon)
 		return;
 	bool Locked = TeamLocked(Team) && Weapon != WEAPON_GAME;
 
-	if(!Locked)
+	if(g_Config.m_SvTeam == 3)
 	{
-		SetForceCharacterTeam(ClientID, 0);
-		CheckTeamFinished(Team);
+		ChangeTeamState(Team, CGameTeams::TEAMSTATE_OPEN);
+		ResetSwitchers(Team);
+		m_Practice[Team] = false;
+		GameServer()->m_apPlayers[ClientID]->m_VotedForPractice = false;
 	}
-	else
+	else if(Locked)
 	{
 		SetForceCharacterTeam(ClientID, Team);
 
@@ -782,7 +797,7 @@ void CGameTeams::OnCharacterDeath(int ClientID, int Weapon)
 					if(i != ClientID)
 					{
 						GameServer()->m_apPlayers[i]->KillCharacter(WEAPON_SELF);
-						if (Weapon == WEAPON_SELF)
+						if(Weapon == WEAPON_SELF)
 							GameServer()->m_apPlayers[i]->Respawn(true); // spawn the rest of team with weak hook on the killer
 					}
 					if(Count(Team) > 1)
@@ -790,6 +805,11 @@ void CGameTeams::OnCharacterDeath(int ClientID, int Weapon)
 				}
 		}
 	}
+	else
+	{
+		SetForceCharacterTeam(ClientID, TEAM_FLOCK);
+		CheckTeamFinished(Team);
+	}
 }
 
 void CGameTeams::SetTeamLock(int Team, bool Lock)
@@ -828,11 +848,19 @@ void CGameTeams::KillSavedTeam(int ClientID, int Team)
 
 void CGameTeams::ResetSavedTeam(int ClientID, int Team)
 {
-	for (int i = 0; i < MAX_CLIENTS; i++)
+	if(g_Config.m_SvTeam == 3)
 	{
-		if(m_Core.Team(i) == Team && GameServer()->m_apPlayers[i])
+		ChangeTeamState(Team, CGameTeams::TEAMSTATE_OPEN);
+		ResetSwitchers(Team);
+	}
+	else
+	{
+		for(int i = 0; i < MAX_CLIENTS; i++)
 		{
-			SetForceCharacterTeam(i, 0);
+			if(m_Core.Team(i) == Team && GameServer()->m_apPlayers[i])
+			{
+				SetForceCharacterTeam(i, TEAM_FLOCK);
+			}
 		}
 	}
 }
