@@ -2,29 +2,33 @@
 #ifndef GAME_SERVER_TEAMS_H
 #define GAME_SERVER_TEAMS_H
 
-#include <game/teamscore.h>
+#include <engine/shared/config.h>
 #include <game/server/gamecontext.h>
+#include <game/teamscore.h>
 
 class CGameTeams
 {
 	int m_TeamState[MAX_CLIENTS];
 	bool m_TeeFinished[MAX_CLIENTS];
 	bool m_TeamLocked[MAX_CLIENTS];
-	uint64_t m_Invited[MAX_CLIENTS];
+	uint64 m_Invited[MAX_CLIENTS];
 	bool m_Practice[MAX_CLIENTS];
 	std::shared_ptr<CScoreSaveResult> m_pSaveTeamResult[MAX_CLIENTS];
 
-	class CGameContext * m_pGameContext;
+	class CGameContext *m_pGameContext;
 
 	void CheckTeamFinished(int ClientID);
 	bool TeamFinished(int Team);
-	void OnTeamFinish(CPlayer** Players, unsigned int Size, float Time, const char *pTimestamp);
-	void OnFinish(CPlayer* Player, float Time, const char *pTimestamp);
+	void OnTeamFinish(CPlayer **Players, unsigned int Size, float Time, const char *pTimestamp);
+	void OnFinish(CPlayer *Player, float Time, const char *pTimestamp);
 
 public:
 	enum
 	{
-		TEAMSTATE_EMPTY, TEAMSTATE_OPEN, TEAMSTATE_STARTED, TEAMSTATE_FINISHED
+		TEAMSTATE_EMPTY,
+		TEAMSTATE_OPEN,
+		TEAMSTATE_STARTED,
+		TEAMSTATE_FINISHED
 	};
 
 	CTeamsCore m_Core;
@@ -32,11 +36,11 @@ public:
 	CGameTeams(CGameContext *pGameContext);
 
 	//helper methods
-	CCharacter* Character(int ClientID)
+	CCharacter *Character(int ClientID)
 	{
 		return GameServer()->GetPlayerChar(ClientID);
 	}
-	CPlayer* GetPlayer(int ClientID)
+	CPlayer *GetPlayer(int ClientID)
 	{
 		return GameServer()->m_apPlayers[ClientID];
 	}
@@ -60,7 +64,7 @@ public:
 	void ChangeTeamState(int Team, int State);
 	void onChangeTeamState(int Team, int State, int OldState);
 
-	int64_t TeamMask(int Team, int ExceptID = -1, int Asker = -1);
+	int64 TeamMask(int Team, int ExceptID = -1, int Asker = -1);
 
 	int Count(int Team) const;
 
@@ -70,6 +74,7 @@ public:
 	void ForceLeaveTeam(int ClientID);
 
 	void Reset();
+	void ResetSwitchers(int Team);
 
 	void SendTeamsState(int ClientID);
 	void SetTeamLock(int Team, bool Lock);
@@ -78,12 +83,12 @@ public:
 
 	int m_LastChat[MAX_CLIENTS];
 
-	int GetDDRaceState(CPlayer* Player);
-	int GetStartTime(CPlayer* Player);
-	float *GetCpCurrent(CPlayer* Player);
-	void SetDDRaceState(CPlayer* Player, int DDRaceState);
-	void SetStartTime(CPlayer* Player, int StartTime);
-	void SetCpActive(CPlayer* Player, int CpActive);
+	int GetDDRaceState(CPlayer *Player);
+	int GetStartTime(CPlayer *Player);
+	float *GetCpCurrent(CPlayer *Player);
+	void SetDDRaceState(CPlayer *Player, int DDRaceState);
+	void SetStartTime(CPlayer *Player, int StartTime);
+	void SetCpActive(CPlayer *Player, int CpActive);
 	void KillSavedTeam(int ClientID, int Team);
 	void ResetSavedTeam(int ClientID, int Team);
 	void ProcessSaveTeam();
@@ -100,7 +105,7 @@ public:
 
 	bool TeamLocked(int Team)
 	{
-		if (Team <= TEAM_FLOCK || Team >= TEAM_SUPER)
+		if(Team <= TEAM_FLOCK || Team >= TEAM_SUPER)
 			return false;
 
 		return m_TeamLocked[Team];
@@ -123,7 +128,9 @@ public:
 
 	bool GetSaving(int TeamID)
 	{
-		if(TeamID <= TEAM_FLOCK || TeamID >= TEAM_SUPER)
+		if(TeamID < TEAM_FLOCK || TeamID >= TEAM_SUPER)
+			return false;
+		if(g_Config.m_SvTeam != 3 && TeamID == TEAM_FLOCK)
 			return false;
 
 		return m_pSaveTeamResult[TeamID] != nullptr;
@@ -131,7 +138,9 @@ public:
 
 	void EnablePractice(int Team)
 	{
-		if(Team <= TEAM_FLOCK || Team >= TEAM_SUPER)
+		if(Team < TEAM_FLOCK || Team >= TEAM_SUPER)
+			return;
+		if(g_Config.m_SvTeam != 3 && Team == TEAM_FLOCK)
 			return;
 
 		m_Practice[Team] = true;
@@ -139,7 +148,9 @@ public:
 
 	bool IsPractice(int Team)
 	{
-		if(Team <= TEAM_FLOCK || Team >= TEAM_SUPER)
+		if(Team < TEAM_FLOCK || Team >= TEAM_SUPER)
+			return false;
+		if(g_Config.m_SvTeam != 3 && Team == TEAM_FLOCK)
 			return false;
 
 		return m_Practice[Team];
