@@ -2,10 +2,12 @@
 /* If you are missing that file, acquire a complete release at teeworlds.com.                */
 #ifndef GAME_VERSION_H
 #define GAME_VERSION_H
-#define GAME_VERSION "0.6.4, 14.1"
+#ifndef GAME_RELEASE_VERSION
+#define GAME_RELEASE_VERSION "15.1.3"
+#endif
+#define GAME_VERSION "0.6.4, " GAME_RELEASE_VERSION
 #define GAME_NETVERSION "0.6 626fce9a778df4d4"
 #define GAME_NAME "DDNet"
-#define GAME_RELEASE_VERSION "14.1"
-#define CLIENT_VERSIONNR 14010
+#define CLIENT_VERSIONNR 15013
 extern const char *GIT_SHORTREV_HASH;
 #endif
