@@ -31,26 +31,24 @@ protected:
 	TeeHistorian()
 	{
 		mem_zero(&m_Config, sizeof(m_Config));
-		#define MACRO_CONFIG_INT(Name,ScriptName,Def,Min,Max,Save,Desc) \
-			m_Config.m_##Name = (Def);
-		#define MACRO_CONFIG_COL(Name,ScriptName,Def,Save,Desc) MACRO_CONFIG_INT(Name,ScriptName,Def,0,0,Save,Desc)
-		#define MACRO_CONFIG_STR(Name,ScriptName,Len,Def,Save,Desc) \
-			str_copy(m_Config.m_##Name, (Def), sizeof(m_Config.m_##Name));
-		#include <engine/shared/config_variables.h>
-		#undef MACRO_CONFIG_STR
-		#undef MACRO_CONFIG_COL
-		#undef MACRO_CONFIG_INT
+#define MACRO_CONFIG_INT(Name, ScriptName, Def, Min, Max, Save, Desc) \
+	m_Config.m_##Name = (Def);
+#define MACRO_CONFIG_COL(Name, ScriptName, Def, Save, Desc) MACRO_CONFIG_INT(Name, ScriptName, Def, 0, 0, Save, Desc)
+#define MACRO_CONFIG_STR(Name, ScriptName, Len, Def, Save, Desc) \
+	str_copy(m_Config.m_##Name, (Def), sizeof(m_Config.m_##Name));
+#include <engine/shared/config_variables.h>
+#undef MACRO_CONFIG_STR
+#undef MACRO_CONFIG_COL
+#undef MACRO_CONFIG_INT
 
 		RegisterUuids(&m_UuidManager);
 		RegisterTeehistorianUuids(&m_UuidManager);
 		RegisterGameUuids(&m_UuidManager);
 
-		SHA256_DIGEST Sha256 = {{
+		SHA256_DIGEST Sha256 = {{0x01, 0x23, 0x45, 0x67, 0x89, 0x01, 0x23, 0x45, 0x67, 0x89,
 			0x01, 0x23, 0x45, 0x67, 0x89, 0x01, 0x23, 0x45, 0x67, 0x89,
 			0x01, 0x23, 0x45, 0x67, 0x89, 0x01, 0x23, 0x45, 0x67, 0x89,
-			0x01, 0x23, 0x45, 0x67, 0x89, 0x01, 0x23, 0x45, 0x67, 0x89,
-			0x01, 0x23,
-		}};
+			0x01, 0x23}};
 
 		mem_zero(&m_GameInfo, sizeof(m_GameInfo));
 
@@ -127,9 +125,7 @@ protected:
 			::testing::UnitTest::GetInstance()->current_test_info();
 		const char *pTestName = pTestInfo->name();
 
-		if(m_Buffer.Error()
-			|| m_Buffer.Size() != OutputSize
-			|| mem_comp(m_Buffer.Data(), pOutput, OutputSize) != 0)
+		if(m_Buffer.Error() || m_Buffer.Size() != OutputSize || mem_comp(m_Buffer.Data(), pOutput, OutputSize) != 0)
 		{
 			char aFilename[64];
 			IOHANDLE File;
@@ -218,7 +214,8 @@ TEST_F(TeeHistorian, TickImplicitOneTick)
 		0x42, 0x00, 0x01, 0x02, // PLAYERNEW cid=0 x=1 y=2
 		0x40, // FINISH
 	};
-	Tick(1); Player(0, 1, 2);
+	Tick(1);
+	Player(0, 1, 2);
 	Finish();
 	Expect(EXPECTED, sizeof(EXPECTED));
 }
@@ -230,8 +227,10 @@ TEST_F(TeeHistorian, TickImplicitTwoTicks)
 		0x00, 0x01, 0x40, // PLAYER cid=0 dx=1 dy=-1
 		0x40, // FINISH
 	};
-	Tick(1); Player(0, 1, 2);
-	Tick(2); Player(0, 2, 1);
+	Tick(1);
+	Player(0, 1, 2);
+	Tick(2);
+	Player(0, 2, 1);
 	Finish();
 	Expect(EXPECTED, sizeof(EXPECTED));
 }
@@ -243,8 +242,12 @@ TEST_F(TeeHistorian, TickImplicitDescendingClientID)
 		0x42, 0x00, 0x04, 0x05, // PLAYER_NEW cid=0 x=4 y=5
 		0x40, // FINISH
 	};
-	Tick(1); DeadPlayer(0);   Player(1, 2, 3);
-	Tick(2); Player(0, 4, 5); Player(1, 2, 3);
+	Tick(1);
+	DeadPlayer(0);
+	Player(1, 2, 3);
+	Tick(2);
+	Player(0, 4, 5);
+	Player(1, 2, 3);
 	Finish();
 	Expect(EXPECTED, sizeof(EXPECTED));
 }
@@ -257,8 +260,12 @@ TEST_F(TeeHistorian, TickExplicitAscendingClientID)
 		0x42, 0x01, 0x02, 0x03, // PLAYER_NEW cid=1 x=2 y=3
 		0x40, // FINISH
 	};
-	Tick(1); Player(0, 4, 5); DeadPlayer(1);
-	Tick(2); Player(0, 4, 5); Player(1, 2, 3);
+	Tick(1);
+	Player(0, 4, 5);
+	DeadPlayer(1);
+	Tick(2);
+	Player(0, 4, 5);
+	Player(1, 2, 3);
 	Finish();
 	Expect(EXPECTED, sizeof(EXPECTED));
 }
@@ -287,7 +294,8 @@ TEST_F(TeeHistorian, TickExplicitStart)
 		0x42, 0x00, 0x40, 0x40, // PLAYER_NEW cid=0 x=-1 y=-1
 		0x40, // FINISH
 	};
-	Tick(500); Player(0, -1, -1);
+	Tick(500);
+	Player(0, -1, -1);
 	Finish();
 	Expect(EXPECTED, sizeof(EXPECTED));
 }
@@ -299,7 +307,9 @@ TEST_F(TeeHistorian, TickExplicitPlayerMessage)
 		0x46, 0x3f, 0x01, 0x00, // MESSAGE cid=63 msg="\0"
 		0x40, // FINISH
 	};
-	Tick(1); Inputs(); m_TH.RecordPlayerMessage(63, "", 1);
+	Tick(1);
+	Inputs();
+	m_TH.RecordPlayerMessage(63, "", 1);
 	Finish();
 	Expect(EXPECTED, sizeof(EXPECTED));
 }
@@ -315,7 +325,9 @@ TEST_F(TeeHistorian, ExtraMessage)
 		0x00,
 		0x40, // FINISH
 	};
-	Tick(1); Inputs(); m_TH.RecordTestExtra();
+	Tick(1);
+	Inputs();
+	m_TH.RecordTestExtra();
 	Finish();
 	Expect(EXPECTED, sizeof(EXPECTED));
 }
@@ -333,10 +345,10 @@ TEST_F(TeeHistorian, DDNetVersion)
 		0x00,
 		0xfb, 0x13, 0xa5, 0x76, 0xd3, 0x5f, 0x48, 0x93,
 		0xb8, 0x15, 0xee, 0xdc, 0x6d, 0x98, 0x01, 0x5b,
-		0x92, 0xcb, 0x01, 'D',  'D',  'N',  'e',  't',
-		' ',  '1',  '3',  '.',  '1',  ' ',  '(',  '3',
-		'6',  '2',  '3',  'f',  '5',  'e',  '4',  'c',
-		'd',  '1',  '8',  '4',  '5',  '5',  '6',  ')',
+		0x92, 0xcb, 0x01, 'D', 'D', 'N', 'e', 't',
+		' ', '1', '3', '.', '1', ' ', '(', '3',
+		'6', '2', '3', 'f', '5', 'e', '4', 'c',
+		'd', '1', '8', '4', '5', '5', '6', ')',
 		0x00,
 		// EX uuid=1397b63e-ee4e-3919-b86a-b058887fcaf5 data_len=4
 		0x4a,
@@ -349,8 +361,7 @@ TEST_F(TeeHistorian, DDNetVersion)
 	};
 	CUuid ConnectionID = {
 		0xfb, 0x13, 0xa5, 0x76, 0xd3, 0x5f, 0x48, 0x93,
-		0xb8, 0x15, 0xee, 0xdc, 0x6d, 0x98, 0x01, 0x5b,
-	};
+		0xb8, 0x15, 0xee, 0xdc, 0x6d, 0x98, 0x01, 0x5b};
 	m_TH.RecordDDNetVersion(0, ConnectionID, 13010, "DDNet 13.1 (3623f5e4cd184556)");
 	m_TH.RecordDDNetVersionOld(1, 13010);
 	Finish();
@@ -366,15 +377,15 @@ TEST_F(TeeHistorian, Auth)
 		0xb8, 0xba, 0xb2, 0x95, 0x3f, 0xb5, 0x5a, 0x17,
 		0x10,
 		// (AUTH_INIT) cid=0 level=3 auth_name="default_admin"
-		0x00, 0x03, 'd',  'e',  'f',  'a',  'u',  'l',
-		't',  '_',  'a',  'd',  'm',  'i',  'n',  0x00,
+		0x00, 0x03, 'd', 'e', 'f', 'a', 'u', 'l',
+		't', '_', 'a', 'd', 'm', 'i', 'n', 0x00,
 		// EX uuid=37ecd3b8-9218-3bb9-a71b-a935b86f6a81 data_len=9
 		0x4a,
 		0x37, 0xec, 0xd3, 0xb8, 0x92, 0x18, 0x3b, 0xb9,
 		0xa7, 0x1b, 0xa9, 0x35, 0xb8, 0x6f, 0x6a, 0x81,
 		0x09,
 		// (AUTH_LOGIN) cid=1 level=2 auth_name="foobar"
-		0x01, 0x02, 'f',  'o',  'o',  'b',  'a',  'r',
+		0x01, 0x02, 'f', 'o', 'o', 'b', 'a', 'r',
 		0x00,
 		// EX uuid=37ecd3b8-9218-3bb9-a71b-a935b86f6a81 data_len=7
 		0x4a,
@@ -382,7 +393,7 @@ TEST_F(TeeHistorian, Auth)
 		0xa7, 0x1b, 0xa9, 0x35, 0xb8, 0x6f, 0x6a, 0x81,
 		0x07,
 		// (AUTH_LOGIN) cid=1 level=2 auth_name="foobar"
-		0x02, 0x01, 'h',  'e',  'l',  'p',  0x00,
+		0x02, 0x01, 'h', 'e', 'l', 'p', 0x00,
 		// EX uuid=d4f5abe8-edd2-3fb9-abd8-1c8bb84f4a63 data_len=7
 		0x4a,
 		0xd4, 0xf5, 0xab, 0xe8, 0xed, 0xd2, 0x3f, 0xb9,
@@ -402,7 +413,6 @@ TEST_F(TeeHistorian, Auth)
 
 TEST_F(TeeHistorian, JoinLeave)
 {
-
 	const unsigned char EXPECTED[] = {
 		// EX uuid=1899a382-71e3-36da-937d-c9de6bb95b1d data_len=1
 		0x4a,
@@ -423,9 +433,9 @@ TEST_F(TeeHistorian, JoinLeave)
 		// JOIN cid=7
 		0x47, 0x07,
 		// LEAVE cid=6 reason="too many pancakes"
-		0x48, 0x06, 't',  'o',  'o', ' ',  'm',  'a',
-		'n',  'y',  ' ',  'p',  'a', 'n',  'c',  'a',
-		'k',  'e',  's',  0x00,
+		0x48, 0x06, 't', 'o', 'o', ' ', 'm', 'a',
+		'n', 'y', ' ', 'p', 'a', 'n', 'c', 'a',
+		'k', 'e', 's', 0x00,
 		0x40, // FINISH
 	};
 	m_TH.RecordPlayerJoin(6, CTeeHistorian::PROTOCOL_6);
@@ -451,13 +461,11 @@ TEST_F(TeeHistorian, SaveSuccess)
 		// team_save
 		'2', '\t', 'H', '.', '\n', 'l', 'l', '0', 0x00,
 		// FINISH
-		0x40
-	};
+		0x40};
 
 	CUuid SaveID = {
 		0xfb, 0x13, 0xa5, 0x76, 0xd3, 0x5f, 0x48, 0x93,
-		0xb8, 0x15, 0xee, 0xdc, 0x6d, 0x98, 0x01, 0x5b,
-	};
+		0xb8, 0x15, 0xee, 0xdc, 0x6d, 0x98, 0x01, 0x5b};
 	const char *pTeamSave = "2\tH.\nll0";
 	m_TH.RecordTeamSaveSuccess(21, SaveID, pTeamSave);
 	Finish();
@@ -474,8 +482,7 @@ TEST_F(TeeHistorian, SaveFailed)
 		0x01,
 		// team=12
 		0x0c,
-		0x40
-	};
+		0x40};
 
 	m_TH.RecordTeamSaveFailure(12);
 	Finish();
@@ -498,13 +505,11 @@ TEST_F(TeeHistorian, LoadSuccess)
 		// team_save
 		'2', '\t', 'H', '.', '\n', 'l', 'l', '0', 0x00,
 		// FINISH
-		0x40
-	};
+		0x40};
 
 	CUuid SaveID = {
 		0xfb, 0x13, 0xa5, 0x76, 0xd3, 0x5f, 0x48, 0x93,
-		0xb8, 0x15, 0xee, 0xdc, 0x6d, 0x98, 0x01, 0x5b,
-	};
+		0xb8, 0x15, 0xee, 0xdc, 0x6d, 0x98, 0x01, 0x5b};
 	const char *pTeamSave = "2\tH.\nll0";
 	m_TH.RecordTeamLoadSuccess(21, SaveID, pTeamSave);
 	Finish();
@@ -521,11 +526,9 @@ TEST_F(TeeHistorian, LoadFailed)
 		0x01,
 		// team=12
 		0x0c,
-		0x40
-	};
+		0x40};
 
 	m_TH.RecordTeamLoadFailure(12);
 	Finish();
 	Expect(EXPECTED, sizeof(EXPECTED));
 }
-
